/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fdhg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|hg) integrals */

void d1hrr_order_fdhg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[4][5][11] = int_stack + 1850;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2165;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2585;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3125;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3800;
 Libderiv->deriv_classes[5][5][11] = int_stack + 4625;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5066;
 Libderiv->deriv_classes[5][7][11] = int_stack + 5654;
 Libderiv->deriv_classes[5][8][11] = int_stack + 6410;
 Libderiv->deriv_classes[5][9][11] = int_stack + 7355;
 Libderiv->deriv_classes[3][5][10] = int_stack + 8510;
 Libderiv->deriv_classes[3][6][10] = int_stack + 8720;
 Libderiv->deriv_classes[3][7][10] = int_stack + 9000;
 Libderiv->deriv_classes[3][8][10] = int_stack + 9360;
 Libderiv->deriv_classes[3][9][10] = int_stack + 9810;
 Libderiv->deriv_classes[4][5][10] = int_stack + 10360;
 Libderiv->deriv_classes[4][6][10] = int_stack + 10675;
 Libderiv->deriv_classes[4][7][10] = int_stack + 11095;
 Libderiv->deriv_classes[4][8][10] = int_stack + 11635;
 Libderiv->deriv_classes[4][9][10] = int_stack + 12310;
 Libderiv->deriv_classes[5][5][10] = int_stack + 13135;
 Libderiv->deriv_classes[5][6][10] = int_stack + 13576;
 Libderiv->deriv_classes[5][7][10] = int_stack + 14164;
 Libderiv->deriv_classes[5][8][10] = int_stack + 14920;
 Libderiv->deriv_classes[5][9][10] = int_stack + 15865;
 Libderiv->deriv_classes[3][5][9] = int_stack + 17020;
 Libderiv->deriv_classes[3][6][9] = int_stack + 17230;
 Libderiv->deriv_classes[3][7][9] = int_stack + 17510;
 Libderiv->deriv_classes[3][8][9] = int_stack + 17870;
 Libderiv->deriv_classes[3][9][9] = int_stack + 18320;
 Libderiv->deriv_classes[4][5][9] = int_stack + 18870;
 Libderiv->deriv_classes[4][6][9] = int_stack + 19185;
 Libderiv->deriv_classes[4][7][9] = int_stack + 19605;
 Libderiv->deriv_classes[4][8][9] = int_stack + 20145;
 Libderiv->deriv_classes[4][9][9] = int_stack + 20820;
 Libderiv->deriv_classes[5][5][9] = int_stack + 21645;
 Libderiv->deriv_classes[5][6][9] = int_stack + 22086;
 Libderiv->deriv_classes[5][7][9] = int_stack + 22674;
 Libderiv->deriv_classes[5][8][9] = int_stack + 23430;
 Libderiv->deriv_classes[5][9][9] = int_stack + 24375;
 Libderiv->deriv_classes[3][5][8] = int_stack + 25530;
 Libderiv->deriv_classes[3][6][8] = int_stack + 25740;
 Libderiv->deriv_classes[3][7][8] = int_stack + 26020;
 Libderiv->deriv_classes[3][8][8] = int_stack + 26380;
 Libderiv->deriv_classes[3][9][8] = int_stack + 26830;
 Libderiv->deriv_classes[4][5][8] = int_stack + 27380;
 Libderiv->deriv_classes[4][6][8] = int_stack + 27695;
 Libderiv->deriv_classes[4][7][8] = int_stack + 28115;
 Libderiv->deriv_classes[4][8][8] = int_stack + 28655;
 Libderiv->deriv_classes[4][9][8] = int_stack + 29330;
 Libderiv->deriv_classes[5][5][8] = int_stack + 30155;
 Libderiv->deriv_classes[5][6][8] = int_stack + 30596;
 Libderiv->deriv_classes[5][7][8] = int_stack + 31184;
 Libderiv->deriv_classes[5][8][8] = int_stack + 31940;
 Libderiv->deriv_classes[5][9][8] = int_stack + 32885;
 Libderiv->deriv_classes[3][5][7] = int_stack + 34040;
 Libderiv->deriv_classes[3][6][7] = int_stack + 34250;
 Libderiv->deriv_classes[3][7][7] = int_stack + 34530;
 Libderiv->deriv_classes[3][8][7] = int_stack + 34890;
 Libderiv->deriv_classes[3][9][7] = int_stack + 35340;
 Libderiv->deriv_classes[4][5][7] = int_stack + 35890;
 Libderiv->deriv_classes[4][6][7] = int_stack + 36205;
 Libderiv->deriv_classes[4][7][7] = int_stack + 36625;
 Libderiv->deriv_classes[4][8][7] = int_stack + 37165;
 Libderiv->deriv_classes[4][9][7] = int_stack + 37840;
 Libderiv->deriv_classes[5][5][7] = int_stack + 38665;
 Libderiv->deriv_classes[5][6][7] = int_stack + 39106;
 Libderiv->deriv_classes[5][7][7] = int_stack + 39694;
 Libderiv->deriv_classes[5][8][7] = int_stack + 40450;
 Libderiv->deriv_classes[5][9][7] = int_stack + 41395;
 Libderiv->deriv_classes[3][5][6] = int_stack + 42550;
 Libderiv->deriv_classes[3][6][6] = int_stack + 42760;
 Libderiv->deriv_classes[3][7][6] = int_stack + 43040;
 Libderiv->deriv_classes[3][8][6] = int_stack + 43400;
 Libderiv->deriv_classes[3][9][6] = int_stack + 43850;
 Libderiv->deriv_classes[4][5][6] = int_stack + 44400;
 Libderiv->deriv_classes[4][6][6] = int_stack + 44715;
 Libderiv->deriv_classes[4][7][6] = int_stack + 45135;
 Libderiv->deriv_classes[4][8][6] = int_stack + 45675;
 Libderiv->deriv_classes[4][9][6] = int_stack + 46350;
 Libderiv->dvrr_classes[5][5] = int_stack + 47175;
 Libderiv->deriv_classes[5][5][6] = int_stack + 47616;
 Libderiv->dvrr_classes[5][6] = int_stack + 48057;
 Libderiv->deriv_classes[5][6][6] = int_stack + 48645;
 Libderiv->dvrr_classes[5][7] = int_stack + 49233;
 Libderiv->deriv_classes[5][7][6] = int_stack + 49989;
 Libderiv->dvrr_classes[5][8] = int_stack + 50745;
 Libderiv->deriv_classes[5][8][6] = int_stack + 51690;
 Libderiv->deriv_classes[5][9][6] = int_stack + 52635;
 Libderiv->deriv_classes[3][5][2] = int_stack + 53790;
 Libderiv->deriv_classes[3][6][2] = int_stack + 54000;
 Libderiv->deriv_classes[3][7][2] = int_stack + 54280;
 Libderiv->deriv_classes[3][8][2] = int_stack + 54640;
 Libderiv->deriv_classes[3][9][2] = int_stack + 55090;
 Libderiv->deriv_classes[4][5][2] = int_stack + 55640;
 Libderiv->deriv_classes[4][6][2] = int_stack + 55955;
 Libderiv->deriv_classes[4][7][2] = int_stack + 56375;
 Libderiv->deriv_classes[4][8][2] = int_stack + 56915;
 Libderiv->deriv_classes[4][9][2] = int_stack + 57590;
 Libderiv->deriv_classes[5][5][2] = int_stack + 58415;
 Libderiv->deriv_classes[5][6][2] = int_stack + 58856;
 Libderiv->deriv_classes[5][7][2] = int_stack + 59444;
 Libderiv->deriv_classes[5][8][2] = int_stack + 60200;
 Libderiv->deriv_classes[5][9][2] = int_stack + 61145;
 Libderiv->deriv_classes[3][5][1] = int_stack + 62300;
 Libderiv->deriv_classes[3][6][1] = int_stack + 62510;
 Libderiv->deriv_classes[3][7][1] = int_stack + 62790;
 Libderiv->deriv_classes[3][8][1] = int_stack + 63150;
 Libderiv->deriv_classes[3][9][1] = int_stack + 63600;
 Libderiv->deriv_classes[4][5][1] = int_stack + 64150;
 Libderiv->deriv_classes[4][6][1] = int_stack + 64465;
 Libderiv->deriv_classes[4][7][1] = int_stack + 64885;
 Libderiv->deriv_classes[4][8][1] = int_stack + 65425;
 Libderiv->deriv_classes[4][9][1] = int_stack + 66100;
 Libderiv->deriv_classes[5][5][1] = int_stack + 66925;
 Libderiv->deriv_classes[5][6][1] = int_stack + 67366;
 Libderiv->deriv_classes[5][7][1] = int_stack + 67954;
 Libderiv->deriv_classes[5][8][1] = int_stack + 68710;
 Libderiv->deriv_classes[5][9][1] = int_stack + 69655;
 Libderiv->dvrr_classes[3][5] = int_stack + 70810;
 Libderiv->dvrr_classes[3][6] = int_stack + 71020;
 Libderiv->dvrr_classes[3][7] = int_stack + 71300;
 Libderiv->dvrr_classes[3][8] = int_stack + 71660;
 Libderiv->dvrr_classes[3][9] = int_stack + 72110;
 Libderiv->deriv_classes[3][5][0] = int_stack + 72660;
 Libderiv->deriv_classes[3][6][0] = int_stack + 72870;
 Libderiv->deriv_classes[3][7][0] = int_stack + 73150;
 Libderiv->deriv_classes[3][8][0] = int_stack + 73510;
 Libderiv->deriv_classes[3][9][0] = int_stack + 73960;
 Libderiv->dvrr_classes[4][5] = int_stack + 74510;
 Libderiv->dvrr_classes[4][6] = int_stack + 74825;
 Libderiv->dvrr_classes[4][7] = int_stack + 75245;
 Libderiv->dvrr_classes[4][8] = int_stack + 75785;
 Libderiv->dvrr_classes[4][9] = int_stack + 76460;
 Libderiv->deriv_classes[4][5][0] = int_stack + 77285;
 Libderiv->deriv_classes[4][6][0] = int_stack + 77600;
 Libderiv->deriv_classes[4][7][0] = int_stack + 78020;
 Libderiv->deriv_classes[4][8][0] = int_stack + 78560;
 Libderiv->deriv_classes[4][9][0] = int_stack + 79235;
 Libderiv->deriv_classes[5][5][0] = int_stack + 80060;
 Libderiv->deriv_classes[5][6][0] = int_stack + 80501;
 Libderiv->deriv_classes[5][7][0] = int_stack + 81089;
 Libderiv->deriv_classes[5][8][0] = int_stack + 81845;
 Libderiv->deriv_classes[5][9][0] = int_stack + 82790;
 memset(int_stack,0,671560);

 Libderiv->dvrr_stack = int_stack + 295580;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fdhg(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+83945,int_stack+71020,int_stack+70810,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+84575,int_stack+71300,int_stack+71020,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+85415,int_stack+84575,int_stack+83945,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+86675,int_stack+71660,int_stack+71300,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+87755,int_stack+86675,int_stack+84575,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+89435,int_stack+87755,int_stack+85415,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+91535,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70810,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+92165,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71020,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93005,int_stack+92165,int_stack+91535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83945,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94265,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71300,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+95345,int_stack+94265,int_stack+92165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84575,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+97025,int_stack+95345,int_stack+93005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85415,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+91535,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71660,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+99125,int_stack+91535,int_stack+94265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86675,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+91535,int_stack+99125,int_stack+95345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87755,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+99125,int_stack+91535,int_stack+97025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89435,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+91535,int_stack+74825,int_stack+74510,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+92480,int_stack+75245,int_stack+74825,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+93740,int_stack+92480,int_stack+91535,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+95630,int_stack+75785,int_stack+75245,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+102275,int_stack+95630,int_stack+92480,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+104795,int_stack+102275,int_stack+93740,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97250,int_stack+2165,int_stack+1850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74510,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2585,int_stack+2165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74825,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+107945,int_stack+0,int_stack+97250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91535,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+97250,int_stack+3125,int_stack+2585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75245,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+109835,int_stack+97250,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92480,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+112355,int_stack+109835,int_stack+107945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93740,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3800,int_stack+3125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75785,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+115505,int_stack+0,int_stack+97250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95630,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+115505,int_stack+109835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102275,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+115505,int_stack+0,int_stack+112355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104795,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+120230,int_stack+115505,int_stack+99125,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+48057,int_stack+47175,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+49233,int_stack+48057,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+97250,int_stack+1323,int_stack+0,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+99896,int_stack+50745,int_stack+49233,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+107945,int_stack+99896,int_stack+1323,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+129680,int_stack+107945,int_stack+97250,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+5066,int_stack+4625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47175,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+111473,int_stack+5654,int_stack+5066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48057,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+134090,int_stack+111473,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+113237,int_stack+6410,int_stack+5654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49233,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+136736,int_stack+113237,int_stack+111473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+140264,int_stack+136736,int_stack+134090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97250,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+7355,int_stack+6410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50745,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+144674,int_stack+3087,int_stack+113237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99896,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+149210,int_stack+144674,int_stack+136736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107945,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+155090,int_stack+149210,int_stack+140264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129680,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+134090,int_stack+155090,int_stack+115505,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+8720,int_stack+8510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70810, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3717,int_stack+9000,int_stack+8720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71020, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4557,int_stack+3717,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83945, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5817,int_stack+9360,int_stack+9000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71300, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6897,int_stack+5817,int_stack+3717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84575, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148265,int_stack+6897,int_stack+4557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85415, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+9810,int_stack+9360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71660, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+150365,int_stack+3087,int_stack+5817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86675, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3087,int_stack+150365,int_stack+6897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87755, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+150365,int_stack+3087,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89435, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148265,int_stack+10675,int_stack+10360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74510, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3087,int_stack+11095,int_stack+10675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74825, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4347,int_stack+3087,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91535, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148265,int_stack+11635,int_stack+11095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75245, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6237,int_stack+148265,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92480, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+153515,int_stack+6237,int_stack+4347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93740, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+12310,int_stack+11635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75785, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8757,int_stack+3087,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95630, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+156665,int_stack+8757,int_stack+6237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102275, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3087,int_stack+156665,int_stack+153515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104795, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+153515,int_stack+3087,int_stack+150365,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148265,int_stack+13576,int_stack+13135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47175, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+149588,int_stack+14164,int_stack+13576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48057, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7812,int_stack+149588,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10458,int_stack+14920,int_stack+14164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49233, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+111473,int_stack+10458,int_stack+149588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148265,int_stack+111473,int_stack+7812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97250, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+115001,int_stack+15865,int_stack+14920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50745, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+162965,int_stack+115001,int_stack+10458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99896, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7812,int_stack+162965,int_stack+111473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107945, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111473,int_stack+7812,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129680, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+162965,int_stack+111473,int_stack+3087,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+17230,int_stack+17020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70810, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3717,int_stack+17510,int_stack+17230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71020, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4557,int_stack+3717,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83945, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5817,int_stack+17870,int_stack+17510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71300, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6897,int_stack+5817,int_stack+3717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84575, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8577,int_stack+6897,int_stack+4557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85415, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+18320,int_stack+17870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71660, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10677,int_stack+3087,int_stack+5817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86675, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3087,int_stack+10677,int_stack+6897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87755, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10677,int_stack+3087,int_stack+8577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89435, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+19185,int_stack+18870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74510, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+19605,int_stack+19185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74825, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5292,int_stack+4032,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91535, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7182,int_stack+20145,int_stack+19605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75245, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13827,int_stack+7182,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92480, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16347,int_stack+13827,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93740, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+20820,int_stack+20145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75785, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111473,int_stack+3087,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95630, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3087,int_stack+111473,int_stack+13827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111473,int_stack+3087,int_stack+16347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104795, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+177140,int_stack+111473,int_stack+10677,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+22086,int_stack+21645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47175, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4410,int_stack+22674,int_stack+22086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48057, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6174,int_stack+4410,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8820,int_stack+23430,int_stack+22674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49233, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11088,int_stack+8820,int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+14616,int_stack+11088,int_stack+6174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97250, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+24375,int_stack+23430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50745, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19026,int_stack+3087,int_stack+8820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99896, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3087,int_stack+19026,int_stack+11088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107945, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+186590,int_stack+3087,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129680, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3087,int_stack+186590,int_stack+111473,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+111473,int_stack+25740,int_stack+25530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+112103,int_stack+26020,int_stack+25740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+112943,int_stack+112103,int_stack+111473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+114203,int_stack+26380,int_stack+26020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+115283,int_stack+114203,int_stack+112103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+116963,int_stack+115283,int_stack+112943, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+111473,int_stack+26830,int_stack+26380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+186590,int_stack+111473,int_stack+114203, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+111473,int_stack+186590,int_stack+115283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+186590,int_stack+111473,int_stack+116963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+111473,int_stack+27695,int_stack+27380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+112418,int_stack+28115,int_stack+27695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+113678,int_stack+112418,int_stack+111473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+115568,int_stack+28655,int_stack+28115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+117188,int_stack+115568,int_stack+112418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+189740,int_stack+117188,int_stack+113678, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+111473,int_stack+29330,int_stack+28655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+17262,int_stack+111473,int_stack+115568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+111473,int_stack+17262,int_stack+117188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17262,int_stack+111473,int_stack+189740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+189740,int_stack+17262,int_stack+186590,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+186590,int_stack+30596,int_stack+30155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+187913,int_stack+31184,int_stack+30596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111473,int_stack+187913,int_stack+186590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+114119,int_stack+31940,int_stack+31184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+116387,int_stack+114119,int_stack+187913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21987,int_stack+116387,int_stack+111473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+186590,int_stack+32885,int_stack+31940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+26397,int_stack+186590,int_stack+114119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+199190,int_stack+26397,int_stack+116387, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+26397,int_stack+199190,int_stack+21987, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+199190,int_stack+26397,int_stack+17262,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17262,int_stack+34250,int_stack+34040, 0.0, zero_stack, 1.0, int_stack+70810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17892,int_stack+34530,int_stack+34250, 0.0, zero_stack, 1.0, int_stack+71020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18732,int_stack+17892,int_stack+17262, 0.0, zero_stack, 1.0, int_stack+83945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+19992,int_stack+34890,int_stack+34530, 0.0, zero_stack, 1.0, int_stack+71300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21072,int_stack+19992,int_stack+17892, 0.0, zero_stack, 1.0, int_stack+84575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+22752,int_stack+21072,int_stack+18732, 0.0, zero_stack, 1.0, int_stack+85415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+17262,int_stack+35340,int_stack+34890, 0.0, zero_stack, 1.0, int_stack+71660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+24852,int_stack+17262,int_stack+19992, 0.0, zero_stack, 1.0, int_stack+86675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17262,int_stack+24852,int_stack+21072, 0.0, zero_stack, 1.0, int_stack+87755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+186590,int_stack+17262,int_stack+22752, 0.0, zero_stack, 1.0, int_stack+89435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17262,int_stack+36205,int_stack+35890, 0.0, zero_stack, 1.0, int_stack+74510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18207,int_stack+36625,int_stack+36205, 0.0, zero_stack, 1.0, int_stack+74825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19467,int_stack+18207,int_stack+17262, 0.0, zero_stack, 1.0, int_stack+91535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+21357,int_stack+37165,int_stack+36625, 0.0, zero_stack, 1.0, int_stack+75245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22977,int_stack+21357,int_stack+18207, 0.0, zero_stack, 1.0, int_stack+92480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25497,int_stack+22977,int_stack+19467, 0.0, zero_stack, 1.0, int_stack+93740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+17262,int_stack+37840,int_stack+37165, 0.0, zero_stack, 1.0, int_stack+75785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28647,int_stack+17262,int_stack+21357, 0.0, zero_stack, 1.0, int_stack+95630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17262,int_stack+28647,int_stack+22977, 0.0, zero_stack, 1.0, int_stack+102275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+28647,int_stack+17262,int_stack+25497, 0.0, zero_stack, 1.0, int_stack+104795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+17262,int_stack+28647,int_stack+186590,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+186590,int_stack+39106,int_stack+38665, 0.0, zero_stack, 1.0, int_stack+47175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+187913,int_stack+39694,int_stack+39106, 0.0, zero_stack, 1.0, int_stack+48057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33372,int_stack+187913,int_stack+186590, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+36018,int_stack+40450,int_stack+39694, 0.0, zero_stack, 1.0, int_stack+49233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+111473,int_stack+36018,int_stack+187913, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+115001,int_stack+111473,int_stack+33372, 0.0, zero_stack, 1.0, int_stack+97250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+186590,int_stack+41395,int_stack+40450, 0.0, zero_stack, 1.0, int_stack+50745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+148265,int_stack+186590,int_stack+36018, 0.0, zero_stack, 1.0, int_stack+99896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+33372,int_stack+148265,int_stack+111473, 0.0, zero_stack, 1.0, int_stack+107945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+213365,int_stack+33372,int_stack+115001, 0.0, zero_stack, 1.0, int_stack+129680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+219980,int_stack+213365,int_stack+28647,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+213365,int_stack+42760,int_stack+42550, 1.0, int_stack+70810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+213995,int_stack+43040,int_stack+42760, 1.0, int_stack+71020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+214835,int_stack+213995,int_stack+213365, 1.0, int_stack+83945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+216095,int_stack+43400,int_stack+43040, 1.0, int_stack+71300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+217175,int_stack+216095,int_stack+213995, 1.0, int_stack+84575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+111473,int_stack+217175,int_stack+214835, 1.0, int_stack+85415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+83945,int_stack+43850,int_stack+43400, 1.0, int_stack+71660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+213365,int_stack+83945,int_stack+216095, 1.0, int_stack+86675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+113573,int_stack+213365,int_stack+217175, 1.0, int_stack+87755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+186590,int_stack+113573,int_stack+111473, 1.0, int_stack+89435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+111473,int_stack+44715,int_stack+44400, 1.0, int_stack+74510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+112418,int_stack+45135,int_stack+44715, 1.0, int_stack+74825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+113678,int_stack+112418,int_stack+111473, 1.0, int_stack+91535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+115568,int_stack+45675,int_stack+45135, 1.0, int_stack+75245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+117188,int_stack+115568,int_stack+112418, 1.0, int_stack+92480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+213365,int_stack+117188,int_stack+113678, 1.0, int_stack+93740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+91535,int_stack+46350,int_stack+45675, 1.0, int_stack+75785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111473,int_stack+91535,int_stack+115568, 1.0, int_stack+95630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+148265,int_stack+111473,int_stack+117188, 1.0, int_stack+102275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111473,int_stack+148265,int_stack+213365, 1.0, int_stack+104795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+26712,int_stack+111473,int_stack+186590,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+186590,int_stack+48645,int_stack+47616, 1.0, int_stack+47175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+187913,int_stack+49989,int_stack+48645, 1.0, int_stack+48057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+213365,int_stack+187913,int_stack+186590, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+216011,int_stack+51690,int_stack+49989, 1.0, int_stack+49233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+148265,int_stack+216011,int_stack+187913, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36162,int_stack+148265,int_stack+213365, 1.0, int_stack+97250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+52635,int_stack+51690, 1.0, int_stack+50745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+40572,int_stack+0,int_stack+216011, 1.0, int_stack+99896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+213365,int_stack+40572,int_stack+148265, 1.0, int_stack+107945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+40572,int_stack+213365,int_stack+36162, 1.0, int_stack+129680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+234155,int_stack+40572,int_stack+111473,315);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+129680,int_stack+72110,int_stack+71660,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+131030,int_stack+129680,int_stack+86675,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+36162,int_stack+131030,int_stack+87755,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+186590,int_stack+36162,int_stack+89435,10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+36162,int_stack+76460,int_stack+75785,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+38187,int_stack+36162,int_stack+95630,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+41427,int_stack+38187,int_stack+102275,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+36162,int_stack+41427,int_stack+104795,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+40887,int_stack+36162,int_stack+186590,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+50337,int_stack+54000,int_stack+53790,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50967,int_stack+54280,int_stack+54000,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51807,int_stack+50967,int_stack+50337,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+53067,int_stack+54640,int_stack+54280,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+129680,int_stack+53067,int_stack+50967,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+131360,int_stack+129680,int_stack+51807,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+50337,int_stack+55090,int_stack+54640,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+213365,int_stack+50337,int_stack+53067,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50337,int_stack+213365,int_stack+129680,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+213365,int_stack+50337,int_stack+131360,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+50337,int_stack+55955,int_stack+55640,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+51282,int_stack+56375,int_stack+55955,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+52542,int_stack+51282,int_stack+50337,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54432,int_stack+56915,int_stack+56375,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+129680,int_stack+54432,int_stack+51282,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+216515,int_stack+129680,int_stack+52542,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+50337,int_stack+57590,int_stack+56915,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+148265,int_stack+50337,int_stack+54432,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50337,int_stack+148265,int_stack+129680,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+148265,int_stack+50337,int_stack+216515,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+83945,int_stack+148265,int_stack+213365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+213365,int_stack+58856,int_stack+58415,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+214688,int_stack+59444,int_stack+58856,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+216452,int_stack+214688,int_stack+213365,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+50337,int_stack+60200,int_stack+59444,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+52605,int_stack+50337,int_stack+214688,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+129680,int_stack+52605,int_stack+216452,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+213365,int_stack+61145,int_stack+60200,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+56133,int_stack+213365,int_stack+50337,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+213365,int_stack+56133,int_stack+52605,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+50337,int_stack+213365,int_stack+129680,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+93395,int_stack+50337,int_stack+148265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+148265,int_stack+62510,int_stack+62300,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+148895,int_stack+62790,int_stack+62510,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+149735,int_stack+148895,int_stack+148265,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+150995,int_stack+63150,int_stack+62790,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+50337,int_stack+150995,int_stack+148895,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+52017,int_stack+50337,int_stack+149735,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+148265,int_stack+63600,int_stack+63150,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+54117,int_stack+148265,int_stack+150995,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+148265,int_stack+54117,int_stack+50337,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+54117,int_stack+148265,int_stack+52017,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+148265,int_stack+64465,int_stack+64150,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+149210,int_stack+64885,int_stack+64465,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+150470,int_stack+149210,int_stack+148265,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+50337,int_stack+65425,int_stack+64885,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+57267,int_stack+50337,int_stack+149210,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+59787,int_stack+57267,int_stack+150470,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+148265,int_stack+66100,int_stack+65425,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+62937,int_stack+148265,int_stack+50337,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+148265,int_stack+62937,int_stack+57267,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+213365,int_stack+148265,int_stack+59787,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+57267,int_stack+213365,int_stack+54117, 0.0, zero_stack, 1.0, int_stack+186590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+148265,int_stack+67366,int_stack+66925,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+149588,int_stack+67954,int_stack+67366,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+50337,int_stack+149588,int_stack+148265,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+52983,int_stack+68710,int_stack+67954,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+129680,int_stack+52983,int_stack+149588,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+148265,int_stack+129680,int_stack+50337,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+69655,int_stack+68710,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+66717,int_stack+0,int_stack+52983,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50337,int_stack+66717,int_stack+129680,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+107570,int_stack+50337,int_stack+148265,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+248330,int_stack+107570,int_stack+213365, 0.0, zero_stack, 1.0, int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+213365,int_stack+72870,int_stack+72660,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+213995,int_stack+73150,int_stack+72870,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+214835,int_stack+213995,int_stack+213365,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+216095,int_stack+73510,int_stack+73150,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+217175,int_stack+216095,int_stack+213995,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+107570,int_stack+217175,int_stack+214835,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+213365,int_stack+73960,int_stack+73510,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+109670,int_stack+213365,int_stack+216095,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+213365,int_stack+109670,int_stack+217175,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+109670,int_stack+213365,int_stack+107570,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+107570,int_stack+77600,int_stack+77285,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+213365,int_stack+78020,int_stack+77600,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+214625,int_stack+213365,int_stack+107570,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+107570,int_stack+78560,int_stack+78020,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+216515,int_stack+107570,int_stack+213365,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+112820,int_stack+216515,int_stack+214625,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+213365,int_stack+79235,int_stack+78560,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+115970,int_stack+213365,int_stack+107570,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+148265,int_stack+115970,int_stack+216515,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+213365,int_stack+148265,int_stack+112820,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+66717,int_stack+213365,int_stack+109670, 1.0, int_stack+186590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+186590,int_stack+80501,int_stack+80060,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+187913,int_stack+81089,int_stack+80501,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+148265,int_stack+187913,int_stack+186590,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+150911,int_stack+81845,int_stack+81089,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+107570,int_stack+150911,int_stack+187913,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+129680,int_stack+107570,int_stack+148265,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+186590,int_stack+82790,int_stack+81845,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+111098,int_stack+186590,int_stack+150911,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50337,int_stack+111098,int_stack+107570,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+107570,int_stack+50337,int_stack+129680,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+262505,int_stack+107570,int_stack+213365, 1.0, int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+276680,int_stack+134090,int_stack+120230,315);
     Libderiv->ABCD[11] = int_stack + 276680;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+107570,int_stack+162965,int_stack+153515,315);
     Libderiv->ABCD[10] = int_stack + 107570;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+126470,int_stack+3087,int_stack+177140,315);
     Libderiv->ABCD[9] = int_stack + 126470;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+145370,int_stack+199190,int_stack+189740,315);
     Libderiv->ABCD[8] = int_stack + 145370;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+164270,int_stack+219980,int_stack+17262,315);
     Libderiv->ABCD[7] = int_stack + 164270;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+183170,int_stack+234155,int_stack+26712,315);
     Libderiv->ABCD[6] = int_stack + 183170;
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+202070,int_stack+93395,int_stack+83945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 202070;
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+220970,int_stack+248330,int_stack+57267, 0.0, zero_stack, 1.0, int_stack+40887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 220970;
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+239870,int_stack+262505,int_stack+66717, 1.0, int_stack+40887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 239870;

}
