/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fphg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fp|hg) integrals */

void d1hrr_order_fphg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[4][5][11] = int_stack + 1850;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2165;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2585;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3125;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3800;
 Libderiv->deriv_classes[3][5][10] = int_stack + 4625;
 Libderiv->deriv_classes[3][6][10] = int_stack + 4835;
 Libderiv->deriv_classes[3][7][10] = int_stack + 5115;
 Libderiv->deriv_classes[3][8][10] = int_stack + 5475;
 Libderiv->deriv_classes[3][9][10] = int_stack + 5925;
 Libderiv->deriv_classes[4][5][10] = int_stack + 6475;
 Libderiv->deriv_classes[4][6][10] = int_stack + 6790;
 Libderiv->deriv_classes[4][7][10] = int_stack + 7210;
 Libderiv->deriv_classes[4][8][10] = int_stack + 7750;
 Libderiv->deriv_classes[4][9][10] = int_stack + 8425;
 Libderiv->deriv_classes[3][5][9] = int_stack + 9250;
 Libderiv->deriv_classes[3][6][9] = int_stack + 9460;
 Libderiv->deriv_classes[3][7][9] = int_stack + 9740;
 Libderiv->deriv_classes[3][8][9] = int_stack + 10100;
 Libderiv->deriv_classes[3][9][9] = int_stack + 10550;
 Libderiv->deriv_classes[4][5][9] = int_stack + 11100;
 Libderiv->deriv_classes[4][6][9] = int_stack + 11415;
 Libderiv->deriv_classes[4][7][9] = int_stack + 11835;
 Libderiv->deriv_classes[4][8][9] = int_stack + 12375;
 Libderiv->deriv_classes[4][9][9] = int_stack + 13050;
 Libderiv->deriv_classes[3][5][8] = int_stack + 13875;
 Libderiv->deriv_classes[3][6][8] = int_stack + 14085;
 Libderiv->deriv_classes[3][7][8] = int_stack + 14365;
 Libderiv->deriv_classes[3][8][8] = int_stack + 14725;
 Libderiv->deriv_classes[3][9][8] = int_stack + 15175;
 Libderiv->deriv_classes[4][5][8] = int_stack + 15725;
 Libderiv->deriv_classes[4][6][8] = int_stack + 16040;
 Libderiv->deriv_classes[4][7][8] = int_stack + 16460;
 Libderiv->deriv_classes[4][8][8] = int_stack + 17000;
 Libderiv->deriv_classes[4][9][8] = int_stack + 17675;
 Libderiv->deriv_classes[3][5][7] = int_stack + 18500;
 Libderiv->deriv_classes[3][6][7] = int_stack + 18710;
 Libderiv->deriv_classes[3][7][7] = int_stack + 18990;
 Libderiv->deriv_classes[3][8][7] = int_stack + 19350;
 Libderiv->deriv_classes[3][9][7] = int_stack + 19800;
 Libderiv->deriv_classes[4][5][7] = int_stack + 20350;
 Libderiv->deriv_classes[4][6][7] = int_stack + 20665;
 Libderiv->deriv_classes[4][7][7] = int_stack + 21085;
 Libderiv->deriv_classes[4][8][7] = int_stack + 21625;
 Libderiv->deriv_classes[4][9][7] = int_stack + 22300;
 Libderiv->deriv_classes[3][5][6] = int_stack + 23125;
 Libderiv->deriv_classes[3][6][6] = int_stack + 23335;
 Libderiv->deriv_classes[3][7][6] = int_stack + 23615;
 Libderiv->deriv_classes[3][8][6] = int_stack + 23975;
 Libderiv->deriv_classes[3][9][6] = int_stack + 24425;
 Libderiv->dvrr_classes[4][5] = int_stack + 24975;
 Libderiv->deriv_classes[4][5][6] = int_stack + 25290;
 Libderiv->dvrr_classes[4][6] = int_stack + 25605;
 Libderiv->deriv_classes[4][6][6] = int_stack + 26025;
 Libderiv->dvrr_classes[4][7] = int_stack + 26445;
 Libderiv->deriv_classes[4][7][6] = int_stack + 26985;
 Libderiv->dvrr_classes[4][8] = int_stack + 27525;
 Libderiv->deriv_classes[4][8][6] = int_stack + 28200;
 Libderiv->deriv_classes[4][9][6] = int_stack + 28875;
 Libderiv->deriv_classes[3][5][2] = int_stack + 29700;
 Libderiv->deriv_classes[3][6][2] = int_stack + 29910;
 Libderiv->deriv_classes[3][7][2] = int_stack + 30190;
 Libderiv->deriv_classes[3][8][2] = int_stack + 30550;
 Libderiv->deriv_classes[3][9][2] = int_stack + 31000;
 Libderiv->deriv_classes[4][5][2] = int_stack + 31550;
 Libderiv->deriv_classes[4][6][2] = int_stack + 31865;
 Libderiv->deriv_classes[4][7][2] = int_stack + 32285;
 Libderiv->deriv_classes[4][8][2] = int_stack + 32825;
 Libderiv->deriv_classes[4][9][2] = int_stack + 33500;
 Libderiv->deriv_classes[3][5][1] = int_stack + 34325;
 Libderiv->deriv_classes[3][6][1] = int_stack + 34535;
 Libderiv->deriv_classes[3][7][1] = int_stack + 34815;
 Libderiv->deriv_classes[3][8][1] = int_stack + 35175;
 Libderiv->deriv_classes[3][9][1] = int_stack + 35625;
 Libderiv->deriv_classes[4][5][1] = int_stack + 36175;
 Libderiv->deriv_classes[4][6][1] = int_stack + 36490;
 Libderiv->deriv_classes[4][7][1] = int_stack + 36910;
 Libderiv->deriv_classes[4][8][1] = int_stack + 37450;
 Libderiv->deriv_classes[4][9][1] = int_stack + 38125;
 Libderiv->dvrr_classes[3][5] = int_stack + 38950;
 Libderiv->dvrr_classes[3][6] = int_stack + 39160;
 Libderiv->dvrr_classes[3][7] = int_stack + 39440;
 Libderiv->dvrr_classes[3][8] = int_stack + 39800;
 Libderiv->dvrr_classes[3][9] = int_stack + 40250;
 Libderiv->deriv_classes[3][5][0] = int_stack + 40800;
 Libderiv->deriv_classes[3][6][0] = int_stack + 41010;
 Libderiv->deriv_classes[3][7][0] = int_stack + 41290;
 Libderiv->deriv_classes[3][8][0] = int_stack + 41650;
 Libderiv->deriv_classes[3][9][0] = int_stack + 42100;
 Libderiv->deriv_classes[4][5][0] = int_stack + 42650;
 Libderiv->deriv_classes[4][6][0] = int_stack + 42965;
 Libderiv->deriv_classes[4][7][0] = int_stack + 43385;
 Libderiv->deriv_classes[4][8][0] = int_stack + 43925;
 Libderiv->deriv_classes[4][9][0] = int_stack + 44600;
 memset(int_stack,0,363400);

 Libderiv->dvrr_stack = int_stack + 130010;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fphg(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+45425,int_stack+39160,int_stack+38950,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+46055,int_stack+39440,int_stack+39160,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+46895,int_stack+46055,int_stack+45425,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+48155,int_stack+39800,int_stack+39440,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+49235,int_stack+48155,int_stack+46055,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+50915,int_stack+49235,int_stack+46895,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53015,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38950,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+53645,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39160,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54485,int_stack+53645,int_stack+53015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45425,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+55745,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39440,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+56825,int_stack+55745,int_stack+53645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46055,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+58505,int_stack+56825,int_stack+54485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46895,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+53015,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39800,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+60605,int_stack+53015,int_stack+55745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48155,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+53015,int_stack+60605,int_stack+56825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49235,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+60605,int_stack+53015,int_stack+58505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50915,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+53015,int_stack+25605,int_stack+24975,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+53960,int_stack+26445,int_stack+25605,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+55220,int_stack+53960,int_stack+53015,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+57110,int_stack+27525,int_stack+26445,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+63755,int_stack+57110,int_stack+53960,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+66275,int_stack+63755,int_stack+55220,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58730,int_stack+2165,int_stack+1850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24975,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2585,int_stack+2165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25605,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69425,int_stack+0,int_stack+58730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53015,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+58730,int_stack+3125,int_stack+2585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26445,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+71315,int_stack+58730,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53960,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+73835,int_stack+71315,int_stack+69425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55220,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3800,int_stack+3125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27525,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+76985,int_stack+0,int_stack+58730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57110,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+76985,int_stack+71315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63755,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+76985,int_stack+0,int_stack+73835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66275,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+4835,int_stack+4625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38950, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+5115,int_stack+4835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39160, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1470,int_stack+630,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45425, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2730,int_stack+5475,int_stack+5115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39440, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+58730,int_stack+2730,int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46055, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69425,int_stack+58730,int_stack+1470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46895, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+5925,int_stack+5475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39800, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3810,int_stack+0,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48155, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+3810,int_stack+58730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49235, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2800,int_stack+0,int_stack+69425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50915, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69425,int_stack+6790,int_stack+6475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24975, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70370,int_stack+7210,int_stack+6790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25605, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+71630,int_stack+70370,int_stack+69425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53015, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+73520,int_stack+7750,int_stack+7210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26445, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+73520,int_stack+70370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53960, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+81710,int_stack+0,int_stack+71630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55220, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+69425,int_stack+8425,int_stack+7750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27525, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5950,int_stack+69425,int_stack+73520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57110, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+69425,int_stack+5950,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63755, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+84860,int_stack+69425,int_stack+81710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66275, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+81710,int_stack+9460,int_stack+9250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38950, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+82340,int_stack+9740,int_stack+9460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39160, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83180,int_stack+82340,int_stack+81710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+69425,int_stack+10100,int_stack+9740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39440, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+70505,int_stack+69425,int_stack+82340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46055, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+72185,int_stack+70505,int_stack+83180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46895, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+81710,int_stack+10550,int_stack+10100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39800, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+74285,int_stack+81710,int_stack+69425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48155, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+74285,int_stack+70505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49235, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+81710,int_stack+0,int_stack+72185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50915, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+11415,int_stack+11100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24975, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+11835,int_stack+11415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25605, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69425,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53015, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+71315,int_stack+12375,int_stack+11835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+72935,int_stack+71315,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53960, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5950,int_stack+72935,int_stack+69425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55220, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+13050,int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27525, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9100,int_stack+0,int_stack+71315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57110, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+89585,int_stack+9100,int_stack+72935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9100,int_stack+89585,int_stack+5950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5950,int_stack+14085,int_stack+13875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6580,int_stack+14365,int_stack+14085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7420,int_stack+6580,int_stack+5950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+89585,int_stack+14725,int_stack+14365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+90665,int_stack+89585,int_stack+6580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+90665,int_stack+7420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5950,int_stack+15175,int_stack+14725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+69425,int_stack+5950,int_stack+89585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5950,int_stack+69425,int_stack+90665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+69425,int_stack+5950,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+16040,int_stack+15725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+16460,int_stack+16040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5950,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72575,int_stack+17000,int_stack+16460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+74195,int_stack+72575,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+89585,int_stack+74195,int_stack+5950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5950,int_stack+17675,int_stack+17000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13825,int_stack+5950,int_stack+72575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+92735,int_stack+13825,int_stack+74195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+96935,int_stack+92735,int_stack+89585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+89585,int_stack+18710,int_stack+18500, 0.0, zero_stack, 1.0, int_stack+38950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+90215,int_stack+18990,int_stack+18710, 0.0, zero_stack, 1.0, int_stack+39160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+91055,int_stack+90215,int_stack+89585, 0.0, zero_stack, 1.0, int_stack+45425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+92315,int_stack+19350,int_stack+18990, 0.0, zero_stack, 1.0, int_stack+39440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93395,int_stack+92315,int_stack+90215, 0.0, zero_stack, 1.0, int_stack+46055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13825,int_stack+93395,int_stack+91055, 0.0, zero_stack, 1.0, int_stack+46895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+89585,int_stack+19800,int_stack+19350, 0.0, zero_stack, 1.0, int_stack+39800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15925,int_stack+89585,int_stack+92315, 0.0, zero_stack, 1.0, int_stack+48155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+15925,int_stack+93395, 0.0, zero_stack, 1.0, int_stack+49235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5950,int_stack+0,int_stack+13825, 0.0, zero_stack, 1.0, int_stack+50915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13825,int_stack+20665,int_stack+20350, 0.0, zero_stack, 1.0, int_stack+24975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14770,int_stack+21085,int_stack+20665, 0.0, zero_stack, 1.0, int_stack+25605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16030,int_stack+14770,int_stack+13825, 0.0, zero_stack, 1.0, int_stack+53015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17920,int_stack+21625,int_stack+21085, 0.0, zero_stack, 1.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+17920,int_stack+14770, 0.0, zero_stack, 1.0, int_stack+53960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+89585,int_stack+0,int_stack+16030, 0.0, zero_stack, 1.0, int_stack+55220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13825,int_stack+22300,int_stack+21625, 0.0, zero_stack, 1.0, int_stack+27525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19540,int_stack+13825,int_stack+17920, 0.0, zero_stack, 1.0, int_stack+57110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+92735,int_stack+19540,int_stack+0, 0.0, zero_stack, 1.0, int_stack+63755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13825,int_stack+92735,int_stack+89585, 0.0, zero_stack, 1.0, int_stack+66275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+89585,int_stack+23335,int_stack+23125, 1.0, int_stack+38950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+90215,int_stack+23615,int_stack+23335, 1.0, int_stack+39160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+91055,int_stack+90215,int_stack+89585, 1.0, int_stack+45425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+92315,int_stack+23975,int_stack+23615, 1.0, int_stack+39440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93395,int_stack+92315,int_stack+90215, 1.0, int_stack+46055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+93395,int_stack+91055, 1.0, int_stack+46895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+45425,int_stack+24425,int_stack+23975, 1.0, int_stack+39800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+89585,int_stack+45425,int_stack+92315, 1.0, int_stack+48155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18550,int_stack+89585,int_stack+93395, 1.0, int_stack+49235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+89585,int_stack+18550,int_stack+0, 1.0, int_stack+50915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+26025,int_stack+25290, 1.0, int_stack+24975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+26985,int_stack+26025, 1.0, int_stack+25605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18550,int_stack+945,int_stack+0, 1.0, int_stack+53015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20440,int_stack+28200,int_stack+26985, 1.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22060,int_stack+20440,int_stack+945, 1.0, int_stack+53960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+92735,int_stack+22060,int_stack+18550, 1.0, int_stack+55220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+53015,int_stack+28875,int_stack+28200, 1.0, int_stack+27525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+24580,int_stack+53015,int_stack+20440, 1.0, int_stack+57110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+53015,int_stack+24580,int_stack+22060, 1.0, int_stack+63755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+18550,int_stack+53015,int_stack+92735, 1.0, int_stack+66275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+92735,int_stack+40250,int_stack+39800,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+94085,int_stack+92735,int_stack+48155,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+94085,int_stack+49235,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+92735,int_stack+0,int_stack+50915,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+29910,int_stack+29700,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+30190,int_stack+29910,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1470,int_stack+630,int_stack+0,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63755,int_stack+30550,int_stack+30190,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+64835,int_stack+63755,int_stack+630,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+66515,int_stack+64835,int_stack+1470,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+31000,int_stack+30550,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+23275,int_stack+0,int_stack+63755,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+23275,int_stack+64835,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+23275,int_stack+0,int_stack+66515,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+31865,int_stack+31550,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+32285,int_stack+31865,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+26425,int_stack+945,int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28315,int_stack+32825,int_stack+32285,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+29935,int_stack+28315,int_stack+945,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+63755,int_stack+29935,int_stack+26425,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+33500,int_stack+32825,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+45425,int_stack+0,int_stack+28315,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+48665,int_stack+45425,int_stack+29935,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+26425,int_stack+48665,int_stack+63755,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+63755,int_stack+34535,int_stack+34325,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+64385,int_stack+34815,int_stack+34535,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+65225,int_stack+64385,int_stack+63755,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+66485,int_stack+35175,int_stack+34815,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+67565,int_stack+66485,int_stack+64385,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+45425,int_stack+67565,int_stack+65225,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+63755,int_stack+35625,int_stack+35175,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+47525,int_stack+63755,int_stack+66485,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+47525,int_stack+67565,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+47525,int_stack+0,int_stack+45425,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+45425,int_stack+36490,int_stack+36175,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+36910,int_stack+36490,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+50675,int_stack+0,int_stack+45425,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+45425,int_stack+37450,int_stack+36910,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+52565,int_stack+45425,int_stack+0,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+55085,int_stack+52565,int_stack+50675,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+38125,int_stack+37450,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+63755,int_stack+0,int_stack+45425,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+31150,int_stack+63755,int_stack+52565,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+63755,int_stack+31150,int_stack+55085,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+31150,int_stack+41010,int_stack+40800,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+31780,int_stack+41290,int_stack+41010,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+32620,int_stack+31780,int_stack+31150,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+33880,int_stack+41650,int_stack+41290,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+34960,int_stack+33880,int_stack+31780,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+45425,int_stack+34960,int_stack+32620,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+31150,int_stack+42100,int_stack+41650,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+36640,int_stack+31150,int_stack+33880,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+36640,int_stack+34960,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+31150,int_stack+0,int_stack+45425,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+68480,int_stack+42965,int_stack+42650,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+45425,int_stack+43385,int_stack+42965,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+45425,int_stack+68480,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34300,int_stack+43925,int_stack+43385,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+35920,int_stack+34300,int_stack+45425,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+38440,int_stack+35920,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+44600,int_stack+43925,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+41590,int_stack+0,int_stack+34300,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50675,int_stack+41590,int_stack+35920,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+41590,int_stack+50675,int_stack+38440,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+50675,int_stack+76985,int_stack+60605,315);
     Libderiv->ABCD[11] = int_stack + 50675;
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+101660,int_stack+84860,int_stack+2800,315);
     Libderiv->ABCD[10] = int_stack + 101660;
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+111110,int_stack+9100,int_stack+81710,315);
     Libderiv->ABCD[9] = int_stack + 111110;
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+72575,int_stack+96935,int_stack+69425,315);
     Libderiv->ABCD[8] = int_stack + 72575;
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+120560,int_stack+13825,int_stack+5950,315);
     Libderiv->ABCD[7] = int_stack + 120560;
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+0,int_stack+18550,int_stack+89585,315);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+9450,int_stack+26425,int_stack+23275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 9450;
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+18900,int_stack+63755,int_stack+47525, 0.0, zero_stack, 1.0, int_stack+92735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 18900;
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+60125,int_stack+41590,int_stack+31150, 1.0, int_stack+92735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 60125;

}
