/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_g0ii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (g0|ii) integrals */

void d1hrr_order_g0ii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[4][12][11] = int_stack + 4620;
 Libderiv->deriv_classes[4][6][10] = int_stack + 5985;
 Libderiv->deriv_classes[4][7][10] = int_stack + 6405;
 Libderiv->deriv_classes[4][8][10] = int_stack + 6945;
 Libderiv->deriv_classes[4][9][10] = int_stack + 7620;
 Libderiv->deriv_classes[4][10][10] = int_stack + 8445;
 Libderiv->deriv_classes[4][11][10] = int_stack + 9435;
 Libderiv->deriv_classes[4][12][10] = int_stack + 10605;
 Libderiv->deriv_classes[4][6][9] = int_stack + 11970;
 Libderiv->deriv_classes[4][7][9] = int_stack + 12390;
 Libderiv->deriv_classes[4][8][9] = int_stack + 12930;
 Libderiv->deriv_classes[4][9][9] = int_stack + 13605;
 Libderiv->deriv_classes[4][10][9] = int_stack + 14430;
 Libderiv->deriv_classes[4][11][9] = int_stack + 15420;
 Libderiv->deriv_classes[4][12][9] = int_stack + 16590;
 Libderiv->deriv_classes[4][6][8] = int_stack + 17955;
 Libderiv->deriv_classes[4][7][8] = int_stack + 18375;
 Libderiv->deriv_classes[4][8][8] = int_stack + 18915;
 Libderiv->deriv_classes[4][9][8] = int_stack + 19590;
 Libderiv->deriv_classes[4][10][8] = int_stack + 20415;
 Libderiv->deriv_classes[4][11][8] = int_stack + 21405;
 Libderiv->deriv_classes[4][12][8] = int_stack + 22575;
 Libderiv->deriv_classes[4][6][7] = int_stack + 23940;
 Libderiv->deriv_classes[4][7][7] = int_stack + 24360;
 Libderiv->deriv_classes[4][8][7] = int_stack + 24900;
 Libderiv->deriv_classes[4][9][7] = int_stack + 25575;
 Libderiv->deriv_classes[4][10][7] = int_stack + 26400;
 Libderiv->deriv_classes[4][11][7] = int_stack + 27390;
 Libderiv->deriv_classes[4][12][7] = int_stack + 28560;
 Libderiv->dvrr_classes[4][6] = int_stack + 29925;
 Libderiv->deriv_classes[4][6][6] = int_stack + 30345;
 Libderiv->dvrr_classes[4][7] = int_stack + 30765;
 Libderiv->deriv_classes[4][7][6] = int_stack + 31305;
 Libderiv->dvrr_classes[4][8] = int_stack + 31845;
 Libderiv->deriv_classes[4][8][6] = int_stack + 32520;
 Libderiv->dvrr_classes[4][9] = int_stack + 33195;
 Libderiv->deriv_classes[4][9][6] = int_stack + 34020;
 Libderiv->dvrr_classes[4][10] = int_stack + 34845;
 Libderiv->deriv_classes[4][10][6] = int_stack + 35835;
 Libderiv->dvrr_classes[4][11] = int_stack + 36825;
 Libderiv->deriv_classes[4][11][6] = int_stack + 37995;
 Libderiv->deriv_classes[4][12][6] = int_stack + 39165;
 Libderiv->deriv_classes[4][6][2] = int_stack + 40530;
 Libderiv->deriv_classes[4][7][2] = int_stack + 40950;
 Libderiv->deriv_classes[4][8][2] = int_stack + 41490;
 Libderiv->deriv_classes[4][9][2] = int_stack + 42165;
 Libderiv->deriv_classes[4][10][2] = int_stack + 42990;
 Libderiv->deriv_classes[4][11][2] = int_stack + 43980;
 Libderiv->deriv_classes[4][12][2] = int_stack + 45150;
 Libderiv->deriv_classes[4][6][1] = int_stack + 46515;
 Libderiv->deriv_classes[4][7][1] = int_stack + 46935;
 Libderiv->deriv_classes[4][8][1] = int_stack + 47475;
 Libderiv->deriv_classes[4][9][1] = int_stack + 48150;
 Libderiv->deriv_classes[4][10][1] = int_stack + 48975;
 Libderiv->deriv_classes[4][11][1] = int_stack + 49965;
 Libderiv->deriv_classes[4][12][1] = int_stack + 51135;
 Libderiv->deriv_classes[4][6][0] = int_stack + 52500;
 Libderiv->deriv_classes[4][7][0] = int_stack + 52920;
 Libderiv->deriv_classes[4][8][0] = int_stack + 53460;
 Libderiv->deriv_classes[4][9][0] = int_stack + 54135;
 Libderiv->deriv_classes[4][10][0] = int_stack + 54960;
 Libderiv->deriv_classes[4][11][0] = int_stack + 55950;
 Libderiv->deriv_classes[4][12][0] = int_stack + 57120;
 memset(int_stack,0,467880);

 Libderiv->dvrr_stack = int_stack + 244455;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_g0ii(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58485,int_stack+30765,int_stack+29925,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+59745,int_stack+31845,int_stack+30765,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+61365,int_stack+59745,int_stack+58485,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+63885,int_stack+33195,int_stack+31845,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+65910,int_stack+63885,int_stack+59745,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+69150,int_stack+65910,int_stack+61365,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+73350,int_stack+34845,int_stack+33195,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+75825,int_stack+73350,int_stack+63885,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+79875,int_stack+75825,int_stack+65910,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+85275,int_stack+79875,int_stack+69150,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+91575,int_stack+36825,int_stack+34845,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+94545,int_stack+91575,int_stack+73350,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+99495,int_stack+94545,int_stack+75825,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+106245,int_stack+99495,int_stack+79875,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+114345,int_stack+106245,int_stack+85275,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+123165,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29925,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+124425,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30765,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+126045,int_stack+124425,int_stack+123165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58485,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+128565,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31845,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+130590,int_stack+128565,int_stack+124425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59745,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+133830,int_stack+130590,int_stack+126045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61365,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+123165,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33195,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+138030,int_stack+123165,int_stack+128565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63885,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+142080,int_stack+138030,int_stack+130590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65910,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+125640,int_stack+142080,int_stack+133830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69150,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+131940,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34845,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+147480,int_stack+131940,int_stack+123165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73350,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+152430,int_stack+147480,int_stack+138030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75825,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+159180,int_stack+152430,int_stack+142080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79875,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+134910,int_stack+159180,int_stack+125640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85275,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+123165,int_stack+4620,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36825,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+123165,int_stack+131940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91575,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+123165,int_stack+0,int_stack+147480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94545,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+167280,int_stack+123165,int_stack+152430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99495,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+123165,int_stack+167280,int_stack+159180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106245,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+6405,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29925, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+6945,int_stack+6405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30765, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2880,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58485, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+143730,int_stack+7620,int_stack+6945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31845, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+145755,int_stack+143730,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59745, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+148995,int_stack+145755,int_stack+2880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61365, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+8445,int_stack+7620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33195, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2475,int_stack+0,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63885, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+153195,int_stack+2475,int_stack+145755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65910, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+158595,int_stack+153195,int_stack+148995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69150, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+143730,int_stack+9435,int_stack+8445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34845, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+146700,int_stack+143730,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73350, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+164895,int_stack+146700,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75825, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+164895,int_stack+153195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79875, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+171645,int_stack+0,int_stack+158595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85275, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+151650,int_stack+10605,int_stack+9435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36825, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+155160,int_stack+151650,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91575, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+180465,int_stack+155160,int_stack+146700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94545, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+143730,int_stack+180465,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99495, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+153855,int_stack+143730,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106245, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+12390,int_stack+11970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29925, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+12930,int_stack+12390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30765, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2880,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58485, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5400,int_stack+13605,int_stack+12930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31845, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7425,int_stack+5400,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59745, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+143730,int_stack+7425,int_stack+2880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61365, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+14430,int_stack+13605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+147930,int_stack+0,int_stack+5400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180465,int_stack+147930,int_stack+7425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65910, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2475,int_stack+180465,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69150, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+143730,int_stack+15420,int_stack+14430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34845, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+8775,int_stack+143730,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73350, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+185865,int_stack+8775,int_stack+147930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75825, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+192615,int_stack+185865,int_stack+180465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79875, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+200715,int_stack+192615,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+180465,int_stack+16590,int_stack+15420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36825, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+180465,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91575, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+143730,int_stack+0,int_stack+8775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94545, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+0,int_stack+143730,int_stack+185865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99495, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+180465,int_stack+0,int_stack+192615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106245, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+18375,int_stack+17955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+18915,int_stack+18375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2880,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5400,int_stack+19590,int_stack+18915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7425,int_stack+5400,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10665,int_stack+7425,int_stack+2880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+20415,int_stack+19590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+14865,int_stack+0,int_stack+5400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+143730,int_stack+14865,int_stack+7425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2475,int_stack+143730,int_stack+10665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+8775,int_stack+21405,int_stack+20415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+191805,int_stack+8775,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+209535,int_stack+191805,int_stack+14865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+11745,int_stack+209535,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+143730,int_stack+11745,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+0,int_stack+22575,int_stack+21405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+165195,int_stack+0,int_stack+8775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+0,int_stack+165195,int_stack+191805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+216285,int_stack+0,int_stack+209535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+0,int_stack+216285,int_stack+11745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+209535,int_stack+24360,int_stack+23940, 0.0, zero_stack, 1.0, int_stack+29925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+210795,int_stack+24900,int_stack+24360, 0.0, zero_stack, 1.0, int_stack+30765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+212415,int_stack+210795,int_stack+209535, 0.0, zero_stack, 1.0, int_stack+58485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+214935,int_stack+25575,int_stack+24900, 0.0, zero_stack, 1.0, int_stack+31845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+216960,int_stack+214935,int_stack+210795, 0.0, zero_stack, 1.0, int_stack+59745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+220200,int_stack+216960,int_stack+212415, 0.0, zero_stack, 1.0, int_stack+61365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209535,int_stack+26400,int_stack+25575, 0.0, zero_stack, 1.0, int_stack+33195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11340,int_stack+209535,int_stack+214935, 0.0, zero_stack, 1.0, int_stack+63885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15390,int_stack+11340,int_stack+216960, 0.0, zero_stack, 1.0, int_stack+65910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+212010,int_stack+15390,int_stack+220200, 0.0, zero_stack, 1.0, int_stack+69150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+218310,int_stack+27390,int_stack+26400, 0.0, zero_stack, 1.0, int_stack+34845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+221280,int_stack+218310,int_stack+209535, 0.0, zero_stack, 1.0, int_stack+73350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+191805,int_stack+221280,int_stack+11340, 0.0, zero_stack, 1.0, int_stack+75825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+226230,int_stack+191805,int_stack+15390, 0.0, zero_stack, 1.0, int_stack+79875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+11340,int_stack+226230,int_stack+212010, 0.0, zero_stack, 1.0, int_stack+85275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+20160,int_stack+28560,int_stack+27390, 0.0, zero_stack, 1.0, int_stack+36825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+23670,int_stack+20160,int_stack+218310, 0.0, zero_stack, 1.0, int_stack+91575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+209535,int_stack+23670,int_stack+221280, 0.0, zero_stack, 1.0, int_stack+94545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+234330,int_stack+209535,int_stack+191805, 0.0, zero_stack, 1.0, int_stack+99495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+209535,int_stack+234330,int_stack+226230, 0.0, zero_stack, 1.0, int_stack+106245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+191805,int_stack+31305,int_stack+30345, 1.0, int_stack+29925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+193065,int_stack+32520,int_stack+31305, 1.0, int_stack+30765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+194685,int_stack+193065,int_stack+191805, 1.0, int_stack+58485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+197205,int_stack+34020,int_stack+32520, 1.0, int_stack+31845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+220875,int_stack+197205,int_stack+193065, 1.0, int_stack+59745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+224115,int_stack+220875,int_stack+194685, 1.0, int_stack+61365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+58485,int_stack+35835,int_stack+34020, 1.0, int_stack+33195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+191805,int_stack+58485,int_stack+197205, 1.0, int_stack+63885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+228315,int_stack+191805,int_stack+220875, 1.0, int_stack+65910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+60960,int_stack+228315,int_stack+224115, 1.0, int_stack+69150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+220875,int_stack+37995,int_stack+35835, 1.0, int_stack+34845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+67260,int_stack+220875,int_stack+58485, 1.0, int_stack+73350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+233715,int_stack+67260,int_stack+191805, 1.0, int_stack+75825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+191805,int_stack+233715,int_stack+228315, 1.0, int_stack+79875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+223845,int_stack+191805,int_stack+60960, 1.0, int_stack+85275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+58485,int_stack+39165,int_stack+37995, 1.0, int_stack+36825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+72210,int_stack+58485,int_stack+220875, 1.0, int_stack+91575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+58485,int_stack+72210,int_stack+67260, 1.0, int_stack+94545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+66735,int_stack+58485,int_stack+233715, 1.0, int_stack+99495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+76860,int_stack+66735,int_stack+191805, 1.0, int_stack+106245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+191805,int_stack+40950,int_stack+40530,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+193065,int_stack+41490,int_stack+40950,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+194685,int_stack+193065,int_stack+191805,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+197205,int_stack+42165,int_stack+41490,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+58485,int_stack+197205,int_stack+193065,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+61725,int_stack+58485,int_stack+194685,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+191805,int_stack+42990,int_stack+42165,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+65925,int_stack+191805,int_stack+197205,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+194280,int_stack+65925,int_stack+58485,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+69975,int_stack+194280,int_stack+61725,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+220875,int_stack+43980,int_stack+42990,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+58485,int_stack+220875,int_stack+191805,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+88200,int_stack+58485,int_stack+65925,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+94950,int_stack+88200,int_stack+194280,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+191805,int_stack+94950,int_stack+69975,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+63435,int_stack+45150,int_stack+43980,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+66945,int_stack+63435,int_stack+220875,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+103050,int_stack+66945,int_stack+58485,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+58485,int_stack+103050,int_stack+88200,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+232665,int_stack+58485,int_stack+94950,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58485,int_stack+46935,int_stack+46515,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+59745,int_stack+47475,int_stack+46935,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+61365,int_stack+59745,int_stack+58485,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+63885,int_stack+48150,int_stack+47475,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+65910,int_stack+63885,int_stack+59745,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+69150,int_stack+65910,int_stack+61365,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+58485,int_stack+48975,int_stack+48150,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+88200,int_stack+58485,int_stack+63885,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+92250,int_stack+88200,int_stack+65910,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+60960,int_stack+92250,int_stack+69150,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+220875,int_stack+49965,int_stack+48975,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+67260,int_stack+220875,int_stack+58485,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+97650,int_stack+67260,int_stack+88200,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+104400,int_stack+97650,int_stack+92250,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+88200,int_stack+104400,int_stack+60960,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+58485,int_stack+51135,int_stack+49965,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+20160,int_stack+58485,int_stack+220875,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+58485,int_stack+20160,int_stack+67260,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+66735,int_stack+58485,int_stack+97650,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+20160,int_stack+66735,int_stack+104400,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58485,int_stack+52920,int_stack+52500,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+59745,int_stack+53460,int_stack+52920,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+61365,int_stack+59745,int_stack+58485,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+63885,int_stack+54135,int_stack+53460,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+65910,int_stack+63885,int_stack+59745,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+69150,int_stack+65910,int_stack+61365,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+58485,int_stack+54960,int_stack+54135,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+31500,int_stack+58485,int_stack+63885,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+35550,int_stack+31500,int_stack+65910,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+60960,int_stack+35550,int_stack+69150,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+220875,int_stack+55950,int_stack+54960,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+67260,int_stack+220875,int_stack+58485,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+40950,int_stack+67260,int_stack+31500,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+47700,int_stack+40950,int_stack+35550,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+31500,int_stack+47700,int_stack+60960,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+58485,int_stack+57120,int_stack+55950,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+97020,int_stack+58485,int_stack+220875,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+55800,int_stack+97020,int_stack+67260,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+97020,int_stack+55800,int_stack+40950,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+55800,int_stack+97020,int_stack+47700,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+97020,int_stack+123165,int_stack+134910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114345,15);
     Libderiv->ABCD[11] = int_stack + 97020;
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+123165,int_stack+153855,int_stack+171645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114345, 0.0, zero_stack,15);
     Libderiv->ABCD[10] = int_stack + 123165;
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+40320,int_stack+180465,int_stack+200715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114345, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[9] = int_stack + 40320;
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+152550,int_stack+0,int_stack+143730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[8] = int_stack + 152550;
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+134925,int_stack+209535,int_stack+11340, 0.0, zero_stack, 1.0, int_stack+114345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[7] = int_stack + 134925;
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+0,int_stack+76860,int_stack+223845, 1.0, int_stack+114345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+108780,int_stack+232665,int_stack+191805,15);
     Libderiv->ABCD[2] = int_stack + 108780;
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+67140,int_stack+20160,int_stack+88200,15);
     Libderiv->ABCD[1] = int_stack + 67140;
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+11760,int_stack+55800,int_stack+31500,15);
     Libderiv->ABCD[0] = int_stack + 11760;

}
