/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gphd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|hd) integrals */

void d1hrr_order_gphd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1275;
 Libderiv->deriv_classes[5][6][11] = int_stack + 1716;
 Libderiv->deriv_classes[5][7][11] = int_stack + 2304;
 Libderiv->deriv_classes[4][5][10] = int_stack + 3060;
 Libderiv->deriv_classes[4][6][10] = int_stack + 3375;
 Libderiv->deriv_classes[4][7][10] = int_stack + 3795;
 Libderiv->deriv_classes[5][5][10] = int_stack + 4335;
 Libderiv->deriv_classes[5][6][10] = int_stack + 4776;
 Libderiv->deriv_classes[5][7][10] = int_stack + 5364;
 Libderiv->deriv_classes[4][5][9] = int_stack + 6120;
 Libderiv->deriv_classes[4][6][9] = int_stack + 6435;
 Libderiv->deriv_classes[4][7][9] = int_stack + 6855;
 Libderiv->deriv_classes[5][5][9] = int_stack + 7395;
 Libderiv->deriv_classes[5][6][9] = int_stack + 7836;
 Libderiv->deriv_classes[5][7][9] = int_stack + 8424;
 Libderiv->deriv_classes[4][5][8] = int_stack + 9180;
 Libderiv->deriv_classes[4][6][8] = int_stack + 9495;
 Libderiv->deriv_classes[4][7][8] = int_stack + 9915;
 Libderiv->deriv_classes[5][5][8] = int_stack + 10455;
 Libderiv->deriv_classes[5][6][8] = int_stack + 10896;
 Libderiv->deriv_classes[5][7][8] = int_stack + 11484;
 Libderiv->deriv_classes[4][5][7] = int_stack + 12240;
 Libderiv->deriv_classes[4][6][7] = int_stack + 12555;
 Libderiv->deriv_classes[4][7][7] = int_stack + 12975;
 Libderiv->deriv_classes[5][5][7] = int_stack + 13515;
 Libderiv->deriv_classes[5][6][7] = int_stack + 13956;
 Libderiv->deriv_classes[5][7][7] = int_stack + 14544;
 Libderiv->deriv_classes[4][5][6] = int_stack + 15300;
 Libderiv->deriv_classes[4][6][6] = int_stack + 15615;
 Libderiv->deriv_classes[4][7][6] = int_stack + 16035;
 Libderiv->dvrr_classes[5][5] = int_stack + 16575;
 Libderiv->deriv_classes[5][5][6] = int_stack + 17016;
 Libderiv->dvrr_classes[5][6] = int_stack + 17457;
 Libderiv->deriv_classes[5][6][6] = int_stack + 18045;
 Libderiv->deriv_classes[5][7][6] = int_stack + 18633;
 Libderiv->deriv_classes[4][5][2] = int_stack + 19389;
 Libderiv->deriv_classes[4][6][2] = int_stack + 19704;
 Libderiv->deriv_classes[4][7][2] = int_stack + 20124;
 Libderiv->deriv_classes[5][5][2] = int_stack + 20664;
 Libderiv->deriv_classes[5][6][2] = int_stack + 21105;
 Libderiv->deriv_classes[5][7][2] = int_stack + 21693;
 Libderiv->deriv_classes[4][5][1] = int_stack + 22449;
 Libderiv->deriv_classes[4][6][1] = int_stack + 22764;
 Libderiv->deriv_classes[4][7][1] = int_stack + 23184;
 Libderiv->deriv_classes[5][5][1] = int_stack + 23724;
 Libderiv->deriv_classes[5][6][1] = int_stack + 24165;
 Libderiv->deriv_classes[5][7][1] = int_stack + 24753;
 Libderiv->dvrr_classes[4][5] = int_stack + 25509;
 Libderiv->dvrr_classes[4][6] = int_stack + 25824;
 Libderiv->dvrr_classes[4][7] = int_stack + 26244;
 Libderiv->deriv_classes[4][5][0] = int_stack + 26784;
 Libderiv->deriv_classes[4][6][0] = int_stack + 27099;
 Libderiv->deriv_classes[4][7][0] = int_stack + 27519;
 Libderiv->deriv_classes[5][5][0] = int_stack + 28059;
 Libderiv->deriv_classes[5][6][0] = int_stack + 28500;
 Libderiv->deriv_classes[5][7][0] = int_stack + 29088;
 memset(int_stack,0,238752);

 Libderiv->dvrr_stack = int_stack + 60147;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gphd(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+25824,int_stack+25509,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30789,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25509,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31734,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25824,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32994,int_stack+31734,int_stack+30789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29844,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+30789,int_stack+17457,int_stack+16575,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+1716,int_stack+1275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16575,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+36207,int_stack+2304,int_stack+1716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17457,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+36207,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30789,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+3375,int_stack+3060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25509, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35829,int_stack+3795,int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25824, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37089,int_stack+35829,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29844, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+4776,int_stack+4335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16575, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2646,int_stack+5364,int_stack+4776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17457, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38979,int_stack+2646,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30789, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+6435,int_stack+6120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25509, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35829,int_stack+6855,int_stack+6435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25824, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2646,int_stack+35829,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29844, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+7836,int_stack+7395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16575, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+8424,int_stack+7836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17457, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6300,int_stack+4536,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30789, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+9495,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35829,int_stack+9915,int_stack+9495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+41625,int_stack+35829,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+10896,int_stack+10455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+11484,int_stack+10896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8946,int_stack+4536,int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+12555,int_stack+12240, 0.0, zero_stack, 1.0, int_stack+25509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35829,int_stack+12975,int_stack+12555, 0.0, zero_stack, 1.0, int_stack+25824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11592,int_stack+35829,int_stack+34884, 0.0, zero_stack, 1.0, int_stack+29844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+13956,int_stack+13515, 0.0, zero_stack, 1.0, int_stack+16575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+14544,int_stack+13956, 0.0, zero_stack, 1.0, int_stack+17457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+43515,int_stack+4536,int_stack+34884, 0.0, zero_stack, 1.0, int_stack+30789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+15615,int_stack+15300, 1.0, int_stack+25509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35829,int_stack+16035,int_stack+15615, 1.0, int_stack+25824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13482,int_stack+35829,int_stack+34884, 1.0, int_stack+29844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34884,int_stack+18045,int_stack+17016, 1.0, int_stack+16575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+18633,int_stack+18045, 1.0, int_stack+17457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15372,int_stack+4536,int_stack+34884, 1.0, int_stack+30789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+30789,int_stack+26244,int_stack+25824,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+34884,int_stack+30789,int_stack+29844,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+19704,int_stack+19389,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+30789,int_stack+20124,int_stack+19704,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+18018,int_stack+30789,int_stack+29844,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+21105,int_stack+20664,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+21693,int_stack+21105,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+46161,int_stack+4536,int_stack+29844,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+22764,int_stack+22449,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+30789,int_stack+23184,int_stack+22764,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+19908,int_stack+30789,int_stack+29844,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+24165,int_stack+23724,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+24753,int_stack+24165,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+21798,int_stack+4536,int_stack+29844,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+27099,int_stack+26784,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+30789,int_stack+27519,int_stack+27099,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+24444,int_stack+30789,int_stack+29844,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29844,int_stack+28500,int_stack+28059,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4536,int_stack+29088,int_stack+28500,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+26334,int_stack+4536,int_stack+29844,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+48807,int_stack+0,int_stack+32994,126);
     Libderiv->ABCD[11] = int_stack + 48807;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+28980,int_stack+38979,int_stack+37089,126);
     Libderiv->ABCD[10] = int_stack + 28980;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+54477,int_stack+6300,int_stack+2646,126);
     Libderiv->ABCD[9] = int_stack + 54477;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+8946,int_stack+41625,126);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+5670,int_stack+43515,int_stack+11592,126);
     Libderiv->ABCD[7] = int_stack + 5670;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+36774,int_stack+15372,int_stack+13482,126);
     Libderiv->ABCD[6] = int_stack + 36774;
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+11340,int_stack+46161,int_stack+18018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 11340;
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+42444,int_stack+21798,int_stack+19908, 0.0, zero_stack, 1.0, int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 42444;
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+17010,int_stack+26334,int_stack+24444, 1.0, int_stack+34884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 17010;

}
