/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_pphh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (pp|hh) integrals */

void d1hrr_order_pphh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][5][11] = int_stack + 0;
 Libderiv->deriv_classes[1][6][11] = int_stack + 63;
 Libderiv->deriv_classes[1][7][11] = int_stack + 147;
 Libderiv->deriv_classes[1][8][11] = int_stack + 255;
 Libderiv->deriv_classes[1][9][11] = int_stack + 390;
 Libderiv->deriv_classes[1][10][11] = int_stack + 555;
 Libderiv->deriv_classes[2][5][11] = int_stack + 753;
 Libderiv->deriv_classes[2][6][11] = int_stack + 879;
 Libderiv->deriv_classes[2][7][11] = int_stack + 1047;
 Libderiv->deriv_classes[2][8][11] = int_stack + 1263;
 Libderiv->deriv_classes[2][9][11] = int_stack + 1533;
 Libderiv->deriv_classes[2][10][11] = int_stack + 1863;
 Libderiv->deriv_classes[1][5][10] = int_stack + 2259;
 Libderiv->deriv_classes[1][6][10] = int_stack + 2322;
 Libderiv->deriv_classes[1][7][10] = int_stack + 2406;
 Libderiv->deriv_classes[1][8][10] = int_stack + 2514;
 Libderiv->deriv_classes[1][9][10] = int_stack + 2649;
 Libderiv->deriv_classes[1][10][10] = int_stack + 2814;
 Libderiv->deriv_classes[2][5][10] = int_stack + 3012;
 Libderiv->deriv_classes[2][6][10] = int_stack + 3138;
 Libderiv->deriv_classes[2][7][10] = int_stack + 3306;
 Libderiv->deriv_classes[2][8][10] = int_stack + 3522;
 Libderiv->deriv_classes[2][9][10] = int_stack + 3792;
 Libderiv->deriv_classes[2][10][10] = int_stack + 4122;
 Libderiv->deriv_classes[1][5][9] = int_stack + 4518;
 Libderiv->deriv_classes[1][6][9] = int_stack + 4581;
 Libderiv->deriv_classes[1][7][9] = int_stack + 4665;
 Libderiv->deriv_classes[1][8][9] = int_stack + 4773;
 Libderiv->deriv_classes[1][9][9] = int_stack + 4908;
 Libderiv->deriv_classes[1][10][9] = int_stack + 5073;
 Libderiv->deriv_classes[2][5][9] = int_stack + 5271;
 Libderiv->deriv_classes[2][6][9] = int_stack + 5397;
 Libderiv->deriv_classes[2][7][9] = int_stack + 5565;
 Libderiv->deriv_classes[2][8][9] = int_stack + 5781;
 Libderiv->deriv_classes[2][9][9] = int_stack + 6051;
 Libderiv->deriv_classes[2][10][9] = int_stack + 6381;
 Libderiv->deriv_classes[1][5][8] = int_stack + 6777;
 Libderiv->deriv_classes[1][6][8] = int_stack + 6840;
 Libderiv->deriv_classes[1][7][8] = int_stack + 6924;
 Libderiv->deriv_classes[1][8][8] = int_stack + 7032;
 Libderiv->deriv_classes[1][9][8] = int_stack + 7167;
 Libderiv->deriv_classes[1][10][8] = int_stack + 7332;
 Libderiv->deriv_classes[2][5][8] = int_stack + 7530;
 Libderiv->deriv_classes[2][6][8] = int_stack + 7656;
 Libderiv->deriv_classes[2][7][8] = int_stack + 7824;
 Libderiv->deriv_classes[2][8][8] = int_stack + 8040;
 Libderiv->deriv_classes[2][9][8] = int_stack + 8310;
 Libderiv->deriv_classes[2][10][8] = int_stack + 8640;
 Libderiv->deriv_classes[1][5][7] = int_stack + 9036;
 Libderiv->deriv_classes[1][6][7] = int_stack + 9099;
 Libderiv->deriv_classes[1][7][7] = int_stack + 9183;
 Libderiv->deriv_classes[1][8][7] = int_stack + 9291;
 Libderiv->deriv_classes[1][9][7] = int_stack + 9426;
 Libderiv->deriv_classes[1][10][7] = int_stack + 9591;
 Libderiv->deriv_classes[2][5][7] = int_stack + 9789;
 Libderiv->deriv_classes[2][6][7] = int_stack + 9915;
 Libderiv->deriv_classes[2][7][7] = int_stack + 10083;
 Libderiv->deriv_classes[2][8][7] = int_stack + 10299;
 Libderiv->deriv_classes[2][9][7] = int_stack + 10569;
 Libderiv->deriv_classes[2][10][7] = int_stack + 10899;
 Libderiv->deriv_classes[1][5][6] = int_stack + 11295;
 Libderiv->deriv_classes[1][6][6] = int_stack + 11358;
 Libderiv->deriv_classes[1][7][6] = int_stack + 11442;
 Libderiv->deriv_classes[1][8][6] = int_stack + 11550;
 Libderiv->deriv_classes[1][9][6] = int_stack + 11685;
 Libderiv->deriv_classes[1][10][6] = int_stack + 11850;
 Libderiv->dvrr_classes[2][5] = int_stack + 12048;
 Libderiv->deriv_classes[2][5][6] = int_stack + 12174;
 Libderiv->dvrr_classes[2][6] = int_stack + 12300;
 Libderiv->deriv_classes[2][6][6] = int_stack + 12468;
 Libderiv->dvrr_classes[2][7] = int_stack + 12636;
 Libderiv->deriv_classes[2][7][6] = int_stack + 12852;
 Libderiv->dvrr_classes[2][8] = int_stack + 13068;
 Libderiv->deriv_classes[2][8][6] = int_stack + 13338;
 Libderiv->dvrr_classes[2][9] = int_stack + 13608;
 Libderiv->deriv_classes[2][9][6] = int_stack + 13938;
 Libderiv->deriv_classes[2][10][6] = int_stack + 14268;
 Libderiv->deriv_classes[1][5][2] = int_stack + 14664;
 Libderiv->deriv_classes[1][6][2] = int_stack + 14727;
 Libderiv->deriv_classes[1][7][2] = int_stack + 14811;
 Libderiv->deriv_classes[1][8][2] = int_stack + 14919;
 Libderiv->deriv_classes[1][9][2] = int_stack + 15054;
 Libderiv->deriv_classes[1][10][2] = int_stack + 15219;
 Libderiv->deriv_classes[2][5][2] = int_stack + 15417;
 Libderiv->deriv_classes[2][6][2] = int_stack + 15543;
 Libderiv->deriv_classes[2][7][2] = int_stack + 15711;
 Libderiv->deriv_classes[2][8][2] = int_stack + 15927;
 Libderiv->deriv_classes[2][9][2] = int_stack + 16197;
 Libderiv->deriv_classes[2][10][2] = int_stack + 16527;
 Libderiv->deriv_classes[1][5][1] = int_stack + 16923;
 Libderiv->deriv_classes[1][6][1] = int_stack + 16986;
 Libderiv->deriv_classes[1][7][1] = int_stack + 17070;
 Libderiv->deriv_classes[1][8][1] = int_stack + 17178;
 Libderiv->deriv_classes[1][9][1] = int_stack + 17313;
 Libderiv->deriv_classes[1][10][1] = int_stack + 17478;
 Libderiv->deriv_classes[2][5][1] = int_stack + 17676;
 Libderiv->deriv_classes[2][6][1] = int_stack + 17802;
 Libderiv->deriv_classes[2][7][1] = int_stack + 17970;
 Libderiv->deriv_classes[2][8][1] = int_stack + 18186;
 Libderiv->deriv_classes[2][9][1] = int_stack + 18456;
 Libderiv->deriv_classes[2][10][1] = int_stack + 18786;
 Libderiv->dvrr_classes[1][5] = int_stack + 19182;
 Libderiv->dvrr_classes[1][6] = int_stack + 19245;
 Libderiv->dvrr_classes[1][7] = int_stack + 19329;
 Libderiv->dvrr_classes[1][8] = int_stack + 19437;
 Libderiv->dvrr_classes[1][9] = int_stack + 19572;
 Libderiv->dvrr_classes[1][10] = int_stack + 19737;
 Libderiv->deriv_classes[1][5][0] = int_stack + 19935;
 Libderiv->deriv_classes[1][6][0] = int_stack + 19998;
 Libderiv->deriv_classes[1][7][0] = int_stack + 20082;
 Libderiv->deriv_classes[1][8][0] = int_stack + 20190;
 Libderiv->deriv_classes[1][9][0] = int_stack + 20325;
 Libderiv->deriv_classes[1][10][0] = int_stack + 20490;
 Libderiv->deriv_classes[2][5][0] = int_stack + 20688;
 Libderiv->deriv_classes[2][6][0] = int_stack + 20814;
 Libderiv->deriv_classes[2][7][0] = int_stack + 20982;
 Libderiv->deriv_classes[2][8][0] = int_stack + 21198;
 Libderiv->deriv_classes[2][9][0] = int_stack + 21468;
 Libderiv->deriv_classes[2][10][0] = int_stack + 21798;
 memset(int_stack,0,177552);

 Libderiv->dvrr_stack = int_stack + 56655;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_pphh(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+22194,int_stack+19245,int_stack+19182,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+22383,int_stack+19329,int_stack+19245,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+22635,int_stack+22383,int_stack+22194,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+23013,int_stack+19437,int_stack+19329,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+23337,int_stack+23013,int_stack+22383,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+23841,int_stack+23337,int_stack+22635,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+24471,int_stack+19572,int_stack+19437,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+24876,int_stack+24471,int_stack+23013,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+25524,int_stack+24876,int_stack+23337,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+26364,int_stack+25524,int_stack+23841,3);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27309,int_stack+63,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19182,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27498,int_stack+147,int_stack+63, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19245,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27750,int_stack+27498,int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22194,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28128,int_stack+255,int_stack+147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19329,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28452,int_stack+28128,int_stack+27498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22383,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28956,int_stack+28452,int_stack+27750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22635,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+27309,int_stack+390,int_stack+255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19437,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+29586,int_stack+27309,int_stack+28128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23013,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+30234,int_stack+29586,int_stack+28452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23337,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+27714,int_stack+30234,int_stack+28956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23841,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+28659,int_stack+555,int_stack+390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19572,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31074,int_stack+28659,int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24471,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+31884,int_stack+31074,int_stack+29586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24876,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+28659,int_stack+31884,int_stack+30234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25524,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+29919,int_stack+28659,int_stack+27714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26364,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+27309,int_stack+12300,int_stack+12048,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+27687,int_stack+12636,int_stack+12300,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+28191,int_stack+27687,int_stack+27309,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28947,int_stack+13068,int_stack+12636,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+31242,int_stack+28947,int_stack+27687,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+32250,int_stack+31242,int_stack+28191,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+33510,int_stack+13608,int_stack+13068,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+34320,int_stack+33510,int_stack+28947,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+35616,int_stack+34320,int_stack+31242,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+37296,int_stack+35616,int_stack+32250,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39186,int_stack+879,int_stack+753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12048,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+1047,int_stack+879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12300,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39564,int_stack+0,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27309,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+40320,int_stack+1263,int_stack+1047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+40968,int_stack+40320,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27687,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+40968,int_stack+39564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28191,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+39186,int_stack+1533,int_stack+1263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13068,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41976,int_stack+39186,int_stack+40320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28947,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43272,int_stack+41976,int_stack+40968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31242,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+39996,int_stack+43272,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+1863,int_stack+1533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13608,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+44952,int_stack+0,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33510,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+44952,int_stack+41976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44952,int_stack+0,int_stack+43272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35616,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+41886,int_stack+44952,int_stack+39996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37296,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+2322,int_stack+2259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19182, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+189,int_stack+2406,int_stack+2322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19245, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+441,int_stack+189,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22194, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29595,int_stack+2514,int_stack+2406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19329, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+819,int_stack+29595,int_stack+189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22383, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1323,int_stack+819,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22635, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+2649,int_stack+2514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19437, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1953,int_stack+0,int_stack+29595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23013, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+39186,int_stack+1953,int_stack+819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23337, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+40026,int_stack+39186,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23841, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+405,int_stack+2814,int_stack+2649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19572, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+900,int_stack+405,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24471, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+44532,int_stack+900,int_stack+1953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24876, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+44532,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25524, 0.0, zero_stack,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+44532,int_stack+0,int_stack+40026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26364, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+3138,int_stack+3012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12048, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+3306,int_stack+3138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12300, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+882,int_stack+378,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27309, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1638,int_stack+3522,int_stack+3306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2286,int_stack+1638,int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27687, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+39186,int_stack+2286,int_stack+882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28191, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3792,int_stack+3522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13068, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+40446,int_stack+0,int_stack+1638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28947, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45855,int_stack+40446,int_stack+2286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31242, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+810,int_stack+45855,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+39186,int_stack+4122,int_stack+3792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13608, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2700,int_stack+39186,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33510, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+47535,int_stack+2700,int_stack+40446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+39186,int_stack+47535,int_stack+45855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35616, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+45855,int_stack+39186,int_stack+810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37296, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39186,int_stack+4581,int_stack+4518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19182, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39375,int_stack+4665,int_stack+4581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19245, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39627,int_stack+39375,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22194, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29595,int_stack+4773,int_stack+4665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19329, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+40005,int_stack+29595,int_stack+39375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22383, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+40509,int_stack+40005,int_stack+39627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22635, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+39186,int_stack+4908,int_stack+4773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19437, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41139,int_stack+39186,int_stack+29595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23013, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+48501,int_stack+41139,int_stack+40005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23337, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+48501,int_stack+40509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23841, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+39591,int_stack+5073,int_stack+4908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19572, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+40086,int_stack+39591,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24471, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+945,int_stack+40086,int_stack+41139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24876, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+39186,int_stack+945,int_stack+48501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25524, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+48501,int_stack+39186,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26364, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+5397,int_stack+5271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12048, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+5565,int_stack+5397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12300, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+882,int_stack+378,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27309, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1638,int_stack+5781,int_stack+5565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2286,int_stack+1638,int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27687, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3294,int_stack+2286,int_stack+882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28191, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+6051,int_stack+5781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13068, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4554,int_stack+0,int_stack+1638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28947, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+39186,int_stack+4554,int_stack+2286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31242, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+810,int_stack+39186,int_stack+3294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2700,int_stack+6381,int_stack+6051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13608, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+49824,int_stack+2700,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33510, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+51444,int_stack+49824,int_stack+4554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2700,int_stack+51444,int_stack+39186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35616, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+39186,int_stack+2700,int_stack+810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37296, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49824,int_stack+6840,int_stack+6777, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50013,int_stack+6924,int_stack+6840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50265,int_stack+50013,int_stack+49824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29595,int_stack+7032,int_stack+6924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50643,int_stack+29595,int_stack+50013, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51147,int_stack+50643,int_stack+50265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+49824,int_stack+7167,int_stack+7032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51777,int_stack+49824,int_stack+29595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+52425,int_stack+51777,int_stack+50643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+52425,int_stack+51147, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+50229,int_stack+7332,int_stack+7167, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+50724,int_stack+50229,int_stack+49824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+945,int_stack+50724,int_stack+51777, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+49824,int_stack+945,int_stack+52425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+945,int_stack+49824,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+7656,int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+7824,int_stack+7656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49824,int_stack+378,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+50580,int_stack+8040,int_stack+7824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+51228,int_stack+50580,int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52236,int_stack+51228,int_stack+49824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+8310,int_stack+8040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2268,int_stack+0,int_stack+50580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3564,int_stack+2268,int_stack+51228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+49824,int_stack+3564,int_stack+52236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51714,int_stack+8640,int_stack+8310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5244,int_stack+51714,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+51714,int_stack+5244,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5244,int_stack+51714,int_stack+3564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2268,int_stack+5244,int_stack+49824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49824,int_stack+9099,int_stack+9036, 0.0, zero_stack, 1.0, int_stack+19182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50013,int_stack+9183,int_stack+9099, 0.0, zero_stack, 1.0, int_stack+19245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50265,int_stack+50013,int_stack+49824, 0.0, zero_stack, 1.0, int_stack+22194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29595,int_stack+9291,int_stack+9183, 0.0, zero_stack, 1.0, int_stack+19329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50643,int_stack+29595,int_stack+50013, 0.0, zero_stack, 1.0, int_stack+22383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51147,int_stack+50643,int_stack+50265, 0.0, zero_stack, 1.0, int_stack+22635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+49824,int_stack+9426,int_stack+9291, 0.0, zero_stack, 1.0, int_stack+19437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51777,int_stack+49824,int_stack+29595, 0.0, zero_stack, 1.0, int_stack+23013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+52425,int_stack+51777,int_stack+50643, 0.0, zero_stack, 1.0, int_stack+23337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+52425,int_stack+51147, 0.0, zero_stack, 1.0, int_stack+23841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+50229,int_stack+9591,int_stack+9426, 0.0, zero_stack, 1.0, int_stack+19572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+50724,int_stack+50229,int_stack+49824, 0.0, zero_stack, 1.0, int_stack+24471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4914,int_stack+50724,int_stack+51777, 0.0, zero_stack, 1.0, int_stack+24876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+49824,int_stack+4914,int_stack+52425, 0.0, zero_stack, 1.0, int_stack+25524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4914,int_stack+49824,int_stack+0, 0.0, zero_stack, 1.0, int_stack+26364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+9915,int_stack+9789, 0.0, zero_stack, 1.0, int_stack+12048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+10083,int_stack+9915, 0.0, zero_stack, 1.0, int_stack+12300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49824,int_stack+378,int_stack+0, 0.0, zero_stack, 1.0, int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+50580,int_stack+10299,int_stack+10083, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+51228,int_stack+50580,int_stack+378, 0.0, zero_stack, 1.0, int_stack+27687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52236,int_stack+51228,int_stack+49824, 0.0, zero_stack, 1.0, int_stack+28191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+10569,int_stack+10299, 0.0, zero_stack, 1.0, int_stack+13068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6237,int_stack+0,int_stack+50580, 0.0, zero_stack, 1.0, int_stack+28947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7533,int_stack+6237,int_stack+51228, 0.0, zero_stack, 1.0, int_stack+31242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+49824,int_stack+7533,int_stack+52236, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51714,int_stack+10899,int_stack+10569, 0.0, zero_stack, 1.0, int_stack+13608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9213,int_stack+51714,int_stack+0, 0.0, zero_stack, 1.0, int_stack+33510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+51714,int_stack+9213,int_stack+6237, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+53874,int_stack+51714,int_stack+7533, 0.0, zero_stack, 1.0, int_stack+35616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6237,int_stack+53874,int_stack+49824, 0.0, zero_stack, 1.0, int_stack+37296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49824,int_stack+11358,int_stack+11295, 1.0, int_stack+19182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50013,int_stack+11442,int_stack+11358, 1.0, int_stack+19245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50265,int_stack+50013,int_stack+49824, 1.0, int_stack+22194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29595,int_stack+11550,int_stack+11442, 1.0, int_stack+19329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50643,int_stack+29595,int_stack+50013, 1.0, int_stack+22383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51147,int_stack+50643,int_stack+50265, 1.0, int_stack+22635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+22194,int_stack+11685,int_stack+11550, 1.0, int_stack+19437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49824,int_stack+22194,int_stack+29595, 1.0, int_stack+23013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+51777,int_stack+49824,int_stack+50643, 1.0, int_stack+23337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+51777,int_stack+51147, 1.0, int_stack+23841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+22599,int_stack+11850,int_stack+11685, 1.0, int_stack+19572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+23094,int_stack+22599,int_stack+22194, 1.0, int_stack+24471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+50472,int_stack+23094,int_stack+49824, 1.0, int_stack+24876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+22194,int_stack+50472,int_stack+51777, 1.0, int_stack+25524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+49824,int_stack+22194,int_stack+0, 1.0, int_stack+26364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+12468,int_stack+12174, 1.0, int_stack+12048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+12852,int_stack+12468, 1.0, int_stack+12300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22194,int_stack+378,int_stack+0, 1.0, int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22950,int_stack+13338,int_stack+12852, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+51147,int_stack+22950,int_stack+378, 1.0, int_stack+27687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52155,int_stack+51147,int_stack+22194, 1.0, int_stack+28191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+27309,int_stack+13938,int_stack+13338, 1.0, int_stack+13068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53415,int_stack+27309,int_stack+22950, 1.0, int_stack+28947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+22194,int_stack+53415,int_stack+51147, 1.0, int_stack+31242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+54711,int_stack+22194,int_stack+52155, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31242,int_stack+14268,int_stack+13938, 1.0, int_stack+13608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51147,int_stack+31242,int_stack+27309, 1.0, int_stack+33510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+27309,int_stack+51147,int_stack+53415, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+51147,int_stack+27309,int_stack+22194, 1.0, int_stack+35616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+31242,int_stack+51147,int_stack+54711, 1.0, int_stack+37296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+51147,int_stack+19737,int_stack+19572,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+51642,int_stack+51147,int_stack+24471,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+52452,int_stack+51642,int_stack+24876,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+51147,int_stack+52452,int_stack+25524,3);
 /*--- compute (p0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+52407,int_stack+51147,int_stack+26364,3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51147,int_stack+14727,int_stack+14664,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+51336,int_stack+14811,int_stack+14727,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51588,int_stack+51336,int_stack+51147,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+51966,int_stack+14919,int_stack+14811,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+53730,int_stack+51966,int_stack+51336,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+54234,int_stack+53730,int_stack+51588,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+51147,int_stack+15054,int_stack+14919,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+54864,int_stack+51147,int_stack+51966,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+51552,int_stack+54864,int_stack+53730,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+51552,int_stack+54234,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+53730,int_stack+15219,int_stack+15054,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+55512,int_stack+53730,int_stack+51147,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+53730,int_stack+55512,int_stack+54864,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+54810,int_stack+53730,int_stack+51552,3);
 /*--- compute (p0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+22194,int_stack+54810,int_stack+0,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+15543,int_stack+15417,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+15711,int_stack+15543,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53730,int_stack+378,int_stack+0,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54486,int_stack+15927,int_stack+15711,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+55134,int_stack+54486,int_stack+378,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+51147,int_stack+55134,int_stack+53730,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+16197,int_stack+15927,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+23517,int_stack+0,int_stack+54486,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+24813,int_stack+23517,int_stack+55134,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+53730,int_stack+24813,int_stack+51147,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+51147,int_stack+16527,int_stack+16197,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+26493,int_stack+51147,int_stack+0,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+33888,int_stack+26493,int_stack+23517,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+26493,int_stack+33888,int_stack+24813,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+33888,int_stack+26493,int_stack+53730,6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+53730,int_stack+16986,int_stack+16923,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+53919,int_stack+17070,int_stack+16986,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+54171,int_stack+53919,int_stack+53730,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54549,int_stack+17178,int_stack+17070,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+54873,int_stack+54549,int_stack+53919,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+55377,int_stack+54873,int_stack+54171,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+53730,int_stack+17313,int_stack+17178,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+56007,int_stack+53730,int_stack+54549,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+36534,int_stack+56007,int_stack+54873,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+36534,int_stack+55377,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+54135,int_stack+17478,int_stack+17313,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+54630,int_stack+54135,int_stack+53730,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+37374,int_stack+54630,int_stack+56007,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+51147,int_stack+37374,int_stack+36534,3);
 /*--- compute (p0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+36534,int_stack+51147,int_stack+0,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+17802,int_stack+17676,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+17970,int_stack+17802,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51147,int_stack+378,int_stack+0,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+37857,int_stack+18186,int_stack+17970,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+53730,int_stack+37857,int_stack+378,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+54738,int_stack+53730,int_stack+51147,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+51147,int_stack+18456,int_stack+18186,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+23517,int_stack+51147,int_stack+37857,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+24813,int_stack+23517,int_stack+53730,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+26493,int_stack+24813,int_stack+54738,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+53730,int_stack+18786,int_stack+18456,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+54720,int_stack+53730,int_stack+51147,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8883,int_stack+54720,int_stack+23517,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+53730,int_stack+8883,int_stack+24813,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8883,int_stack+53730,int_stack+26493,6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+53730,int_stack+19998,int_stack+19935,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+53919,int_stack+20082,int_stack+19998,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+54171,int_stack+53919,int_stack+53730,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54549,int_stack+20190,int_stack+20082,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+54873,int_stack+54549,int_stack+53919,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+55377,int_stack+54873,int_stack+54171,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+53730,int_stack+20325,int_stack+20190,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+56007,int_stack+53730,int_stack+54549,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+11529,int_stack+56007,int_stack+54873,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+11529,int_stack+55377,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+54135,int_stack+20490,int_stack+20325,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+54630,int_stack+54135,int_stack+53730,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+12369,int_stack+54630,int_stack+56007,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+51147,int_stack+12369,int_stack+11529,3);
 /*--- compute (p0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+11529,int_stack+51147,int_stack+0,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+20814,int_stack+20688,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+20982,int_stack+20814,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51147,int_stack+378,int_stack+0,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+12852,int_stack+21198,int_stack+20982,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13500,int_stack+12852,int_stack+378,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+14508,int_stack+13500,int_stack+51147,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+51147,int_stack+21468,int_stack+21198,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15768,int_stack+51147,int_stack+12852,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+17064,int_stack+15768,int_stack+13500,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+18744,int_stack+17064,int_stack+14508,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+12852,int_stack+21798,int_stack+21468,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13842,int_stack+12852,int_stack+51147,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+53730,int_stack+13842,int_stack+15768,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+12852,int_stack+53730,int_stack+17064,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+53730,int_stack+12852,int_stack+18744,6);
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+12852,int_stack+41886,int_stack+29919,441);
     Libderiv->ABCD[11] = int_stack + 12852;
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+16821,int_stack+45855,int_stack+44532,441);
     Libderiv->ABCD[10] = int_stack + 16821;
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+23517,int_stack+39186,int_stack+48501,441);
     Libderiv->ABCD[9] = int_stack + 23517;
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+37857,int_stack+2268,int_stack+945,441);
     Libderiv->ABCD[8] = int_stack + 37857;
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+0,int_stack+6237,int_stack+4914,441);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (pp|hh) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+3969,int_stack+31242,int_stack+49824,441);
     Libderiv->ABCD[6] = int_stack + 3969;
 /*--- compute (pp|hh) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+27486,int_stack+33888,int_stack+22194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 27486;
 /*--- compute (pp|hh) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+31455,int_stack+8883,int_stack+36534, 0.0, zero_stack, 1.0, int_stack+52407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 31455;
 /*--- compute (pp|hh) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+41826,int_stack+53730,int_stack+11529, 1.0, int_stack+52407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 41826;

}
