/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dphh(Libr12_t *, prim_data *);

  /* Computes (dp|hh) integrals for linear R12-methods */

void hrr_grt_order_dphh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->t2vrr_classes[2][7] = int_stack + 294;
 Libr12->t2vrr_classes[2][8] = int_stack + 510;
 Libr12->t2vrr_classes[2][9] = int_stack + 780;
 Libr12->t2vrr_classes[2][10] = int_stack + 1110;
 Libr12->gvrr_classes[4][5] = int_stack + 1506;
 Libr12->t2vrr_classes[3][5] = int_stack + 1821;
 Libr12->gvrr_classes[4][6] = int_stack + 2031;
 Libr12->t2vrr_classes[3][6] = int_stack + 2451;
 Libr12->gvrr_classes[4][7] = int_stack + 2731;
 Libr12->t2vrr_classes[3][7] = int_stack + 3271;
 Libr12->gvrr_classes[4][8] = int_stack + 3631;
 Libr12->t2vrr_classes[3][8] = int_stack + 4306;
 Libr12->gvrr_classes[4][9] = int_stack + 4756;
 Libr12->t2vrr_classes[3][9] = int_stack + 5581;
 Libr12->t2vrr_classes[3][10] = int_stack + 6131;
 Libr12->gvrr_classes[2][11] = int_stack + 6791;
 Libr12->t1vrr_classes[2][5] = int_stack + 7259;
 Libr12->t1vrr_classes[2][6] = int_stack + 7385;
 Libr12->t1vrr_classes[2][7] = int_stack + 7553;
 Libr12->t1vrr_classes[2][8] = int_stack + 7769;
 Libr12->t1vrr_classes[2][9] = int_stack + 8039;
 Libr12->t1vrr_classes[2][10] = int_stack + 8369;
 Libr12->t1vrr_classes[3][5] = int_stack + 8765;
 Libr12->t1vrr_classes[3][6] = int_stack + 8975;
 Libr12->t1vrr_classes[3][7] = int_stack + 9255;
 Libr12->t1vrr_classes[3][8] = int_stack + 9615;
 Libr12->t1vrr_classes[3][9] = int_stack + 10065;
 Libr12->t1vrr_classes[3][10] = int_stack + 10615;
 Libr12->rvrr_classes[2][5] = int_stack + 11275;
 Libr12->rvrr_classes[2][6] = int_stack + 11401;
 Libr12->rvrr_classes[2][7] = int_stack + 11569;
 Libr12->rvrr_classes[2][8] = int_stack + 11785;
 Libr12->rvrr_classes[2][9] = int_stack + 12055;
 Libr12->rvrr_classes[2][10] = int_stack + 12385;
 Libr12->rvrr_classes[3][5] = int_stack + 12781;
 Libr12->rvrr_classes[3][6] = int_stack + 12991;
 Libr12->rvrr_classes[3][7] = int_stack + 13271;
 Libr12->rvrr_classes[3][8] = int_stack + 13631;
 Libr12->rvrr_classes[3][9] = int_stack + 14081;
 Libr12->rvrr_classes[3][10] = int_stack + 14631;
 Libr12->gvrr_classes[2][5] = int_stack + 15291;
 Libr12->gvrr_classes[2][6] = int_stack + 15417;
 Libr12->gvrr_classes[2][7] = int_stack + 15585;
 Libr12->gvrr_classes[2][8] = int_stack + 15801;
 Libr12->gvrr_classes[2][9] = int_stack + 16071;
 Libr12->gvrr_classes[2][10] = int_stack + 16401;
 Libr12->gvrr_classes[3][5] = int_stack + 16797;
 Libr12->gvrr_classes[3][6] = int_stack + 17007;
 Libr12->gvrr_classes[3][7] = int_stack + 17287;
 Libr12->gvrr_classes[3][8] = int_stack + 17647;
 Libr12->gvrr_classes[3][9] = int_stack + 18097;
 Libr12->gvrr_classes[3][10] = int_stack + 18647;
 memset(int_stack,0,19307*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 19307;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dphh(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19307, int_stack+15417, int_stack+15291, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19685, int_stack+15585, int_stack+15417, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20189, int_stack+19685, int_stack+19307, 6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+20945, int_stack+15801, int_stack+15585, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21593, int_stack+20945, int_stack+19685, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+22601, int_stack+21593, int_stack+20189, 6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+23861, int_stack+16071, int_stack+15801, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+24671, int_stack+23861, int_stack+20945, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+25967, int_stack+24671, int_stack+21593, 6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+27647, int_stack+25967, int_stack+22601, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29537, int_stack+17007, int_stack+16797, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+30167, int_stack+17287, int_stack+17007, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+31007, int_stack+30167, int_stack+29537, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32267, int_stack+17647, int_stack+17287, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+33347, int_stack+32267, int_stack+30167, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+35027, int_stack+33347, int_stack+31007, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+37127, int_stack+18097, int_stack+17647, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+38477, int_stack+37127, int_stack+32267, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+40637, int_stack+38477, int_stack+33347, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+43437, int_stack+40637, int_stack+35027, 10);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+46587, int_stack+16401, int_stack+16071, 6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+47577, int_stack+46587, int_stack+23861, 6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+49197, int_stack+47577, int_stack+24671, 6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+51357, int_stack+49197, int_stack+25967, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53877, int_stack+126, int_stack+0, int_stack+15417, int_stack+16797, int_stack+15291, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54255, int_stack+294, int_stack+126, int_stack+15585, int_stack+17007, int_stack+15417, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54759, int_stack+54255, int_stack+53877, int_stack+19685, int_stack+29537, int_stack+19307, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55515, int_stack+510, int_stack+294, int_stack+15801, int_stack+17287, int_stack+15585, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56163, int_stack+55515, int_stack+54255, int_stack+20945, int_stack+30167, int_stack+19685, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57171, int_stack+56163, int_stack+54759, int_stack+21593, int_stack+31007, int_stack+20189, 2, 0);
 /*--- compute (d0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19307, int_stack+780, int_stack+510, int_stack+16071, int_stack+17647, int_stack+15801, 2, 0);
 /*--- compute (d0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53877, int_stack+19307, int_stack+55515, int_stack+23861, int_stack+32267, int_stack+20945, 2, 0);
 /*--- compute (d0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+58431, int_stack+53877, int_stack+56163, int_stack+24671, int_stack+33347, int_stack+21593, 2, 0);
 /*--- compute (d0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20117, int_stack+58431, int_stack+57171, int_stack+25967, int_stack+35027, int_stack+22601, 2, 0);
 /*--- compute (d0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22007, int_stack+1110, int_stack+780, int_stack+16401, int_stack+18097, int_stack+16071, 2, 0);
 /*--- compute (d0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55173, int_stack+22007, int_stack+19307, int_stack+46587, int_stack+37127, int_stack+23861, 2, 0);
 /*--- compute (d0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22007, int_stack+55173, int_stack+53877, int_stack+47577, int_stack+38477, int_stack+24671, 2, 0);
 /*--- compute (d0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53877, int_stack+22007, int_stack+58431, int_stack+49197, int_stack+40637, int_stack+25967, 2, 0);
 /*--- compute (d0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22007, int_stack+53877, int_stack+20117, int_stack+51357, int_stack+43437, int_stack+27647, 2, 0);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+53877, int_stack+2031, int_stack+1506, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+54822, int_stack+2731, int_stack+2031, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+56082, int_stack+54822, int_stack+53877, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+57972, int_stack+3631, int_stack+2731, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+24653, int_stack+57972, int_stack+54822, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+59592, int_stack+24653, int_stack+56082, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+19307, int_stack+4756, int_stack+3631, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+62742, int_stack+19307, int_stack+57972, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+65982, int_stack+62742, int_stack+24653, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+70182, int_stack+65982, int_stack+59592, 15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+74907, int_stack+18647, int_stack+18097, 10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+76557, int_stack+74907, int_stack+37127, 10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+79257, int_stack+76557, int_stack+38477, 10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+82857, int_stack+79257, int_stack+40637, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87057, int_stack+2451, int_stack+1821, int_stack+17007, int_stack+1506, int_stack+16797, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15291, int_stack+3271, int_stack+2451, int_stack+17287, int_stack+2031, int_stack+17007, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+15291, int_stack+87057, int_stack+30167, int_stack+53877, int_stack+29537, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1260, int_stack+4306, int_stack+3271, int_stack+17647, int_stack+2731, int_stack+17287, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87057, int_stack+1260, int_stack+15291, int_stack+32267, int_stack+54822, int_stack+30167, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53877, int_stack+87057, int_stack+0, int_stack+33347, int_stack+56082, int_stack+31007, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29537, int_stack+5581, int_stack+4306, int_stack+18097, int_stack+3631, int_stack+17647, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2340, int_stack+29537, int_stack+1260, int_stack+37127, int_stack+57972, int_stack+32267, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55977, int_stack+2340, int_stack+87057, int_stack+38477, int_stack+24653, int_stack+33347, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30887, int_stack+55977, int_stack+53877, int_stack+40637, int_stack+59592, int_stack+35027, 3, 0);
 /*--- compute (f0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53877, int_stack+6131, int_stack+5581, int_stack+18647, int_stack+4756, int_stack+18097, 3, 0);
 /*--- compute (f0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24653, int_stack+53877, int_stack+29537, int_stack+74907, int_stack+19307, int_stack+37127, 3, 0);
 /*--- compute (f0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34037, int_stack+24653, int_stack+2340, int_stack+76557, int_stack+62742, int_stack+38477, 3, 0);
 /*--- compute (f0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+74907, int_stack+34037, int_stack+55977, int_stack+79257, int_stack+65982, int_stack+40637, 3, 0);
 /*--- compute (f0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34037, int_stack+74907, int_stack+30887, int_stack+82857, int_stack+70182, int_stack+43437, 3, 0);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+38447, int_stack+51357, int_stack+27647, 6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+6791, int_stack+16401, 6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+24653, int_stack+41093, int_stack+46587, 6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+26633, int_stack+24653, int_stack+47577, 6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+29333, int_stack+26633, int_stack+49197, 6);
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+24653, int_stack+29333, int_stack+51357, 6);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+28181, int_stack+82857, int_stack+43437, 10);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+32591, int_stack+7385, int_stack+7259, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+32969, int_stack+7553, int_stack+7385, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+32969, int_stack+32591, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+41849, int_stack+7769, int_stack+7553, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+42497, int_stack+41849, int_stack+32969, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+32591, int_stack+42497, int_stack+41093, 6);
 /*--- compute (d0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+43505, int_stack+8039, int_stack+7769, 6);
 /*--- compute (d0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+44315, int_stack+43505, int_stack+41849, 6);
 /*--- compute (d0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+45611, int_stack+44315, int_stack+42497, 6);
 /*--- compute (d0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+45611, int_stack+32591, 6);
 /*--- compute (d0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+32591, int_stack+8369, int_stack+8039, 6);
 /*--- compute (d0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+47291, int_stack+32591, int_stack+43505, 6);
 /*--- compute (d0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+48911, int_stack+47291, int_stack+44315, 6);
 /*--- compute (d0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+42983, int_stack+48911, int_stack+45611, 6);
 /*--- compute (d0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+45503, int_stack+42983, int_stack+41093, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+8975, int_stack+8765, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+41723, int_stack+9255, int_stack+8975, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+42563, int_stack+41723, int_stack+41093, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+43823, int_stack+9615, int_stack+9255, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+43823, int_stack+41723, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+49829, int_stack+48149, int_stack+42563, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+10065, int_stack+9615, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+51929, int_stack+41093, int_stack+43823, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+42443, int_stack+51929, int_stack+48149, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+54089, int_stack+42443, int_stack+49829, 10);
 /*--- compute (f0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+10615, int_stack+10065, 10);
 /*--- compute (f0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+57239, int_stack+48149, int_stack+41093, 10);
 /*--- compute (f0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+57239, int_stack+51929, 10);
 /*--- compute (f0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+57239, int_stack+48149, int_stack+42443, 10);
 /*--- compute (f0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+41093, int_stack+57239, int_stack+54089, 10);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+11401, int_stack+11275, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+48527, int_stack+11569, int_stack+11401, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49031, int_stack+48527, int_stack+48149, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+49787, int_stack+11785, int_stack+11569, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+50435, int_stack+49787, int_stack+48527, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+51443, int_stack+50435, int_stack+49031, 6);
 /*--- compute (d0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+12055, int_stack+11785, 6);
 /*--- compute (d0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+52703, int_stack+48149, int_stack+49787, 6);
 /*--- compute (d0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+53999, int_stack+52703, int_stack+50435, 6);
 /*--- compute (d0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+48959, int_stack+53999, int_stack+51443, 6);
 /*--- compute (d0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+50849, int_stack+12385, int_stack+12055, 6);
 /*--- compute (d0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+55679, int_stack+50849, int_stack+48149, 6);
 /*--- compute (d0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+57299, int_stack+55679, int_stack+52703, 6);
 /*--- compute (d0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+50849, int_stack+57299, int_stack+53999, 6);
 /*--- compute (d0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+53369, int_stack+50849, int_stack+48959, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+12991, int_stack+12781, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+48779, int_stack+13271, int_stack+12991, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49619, int_stack+48779, int_stack+48149, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+50879, int_stack+13631, int_stack+13271, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+56015, int_stack+50879, int_stack+48779, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+57695, int_stack+56015, int_stack+49619, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+48149, int_stack+14081, int_stack+13631, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+59795, int_stack+48149, int_stack+50879, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+49499, int_stack+59795, int_stack+56015, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+61955, int_stack+49499, int_stack+57695, 10);
 /*--- compute (f0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+56015, int_stack+14631, int_stack+14081, 10);
 /*--- compute (f0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+65105, int_stack+56015, int_stack+48149, 10);
 /*--- compute (f0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+56015, int_stack+65105, int_stack+59795, 10);
 /*--- compute (f0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+65105, int_stack+56015, int_stack+49499, 10);
 /*--- compute (f0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+56015, int_stack+65105, int_stack+61955, 10);
 /*--- compute (dp|[r12,T2]|hh) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+60425, int_stack+34037, int_stack+22007, 441);
     Libr12->te_ptr[3] = int_stack + 60425;
 /*--- compute (dp|[r12,T1]|hh) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+68363, int_stack+41093, int_stack+45503, int_stack+28181, int_stack+24653, int_stack+38447, 5, 5);
     Libr12->te_ptr[2] = int_stack + 68363;
 /*--- compute (dp||hh) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+41093, int_stack+56015, int_stack+53369, 441);
     Libr12->te_ptr[1] = int_stack + 41093;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+49031, int_stack+28181, int_stack+38447, 441);
     Libr12->te_ptr[0] = int_stack + 49031;

}
