/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdgd(Libr12_t *, prim_data *);

  /* Computes (fd|gd) integrals for linear R12-methods */

void hrr_grt_order_fdgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[4][4] = int_stack + 640;
 Libr12->t2vrr_classes[4][5] = int_stack + 865;
 Libr12->t2vrr_classes[4][6] = int_stack + 1180;
 Libr12->gvrr_classes[6][4] = int_stack + 1600;
 Libr12->t2vrr_classes[5][4] = int_stack + 2020;
 Libr12->gvrr_classes[6][5] = int_stack + 2335;
 Libr12->t2vrr_classes[5][5] = int_stack + 2923;
 Libr12->t2vrr_classes[5][6] = int_stack + 3364;
 Libr12->gvrr_classes[3][7] = int_stack + 3952;
 Libr12->t1vrr_classes[3][4] = int_stack + 4312;
 Libr12->t1vrr_classes[3][5] = int_stack + 4462;
 Libr12->t1vrr_classes[3][6] = int_stack + 4672;
 Libr12->gvrr_classes[4][7] = int_stack + 4952;
 Libr12->t1vrr_classes[4][4] = int_stack + 5492;
 Libr12->t1vrr_classes[4][5] = int_stack + 5717;
 Libr12->t1vrr_classes[4][6] = int_stack + 6032;
 Libr12->t1vrr_classes[5][4] = int_stack + 6452;
 Libr12->t1vrr_classes[5][5] = int_stack + 6767;
 Libr12->t1vrr_classes[5][6] = int_stack + 7208;
 Libr12->rvrr_classes[3][4] = int_stack + 7796;
 Libr12->rvrr_classes[3][5] = int_stack + 7946;
 Libr12->rvrr_classes[3][6] = int_stack + 8156;
 Libr12->rvrr_classes[4][4] = int_stack + 8436;
 Libr12->rvrr_classes[4][5] = int_stack + 8661;
 Libr12->rvrr_classes[4][6] = int_stack + 8976;
 Libr12->rvrr_classes[5][4] = int_stack + 9396;
 Libr12->rvrr_classes[5][5] = int_stack + 9711;
 Libr12->rvrr_classes[5][6] = int_stack + 10152;
 Libr12->gvrr_classes[3][4] = int_stack + 10740;
 Libr12->gvrr_classes[3][5] = int_stack + 10890;
 Libr12->gvrr_classes[3][6] = int_stack + 11100;
 Libr12->gvrr_classes[4][4] = int_stack + 11380;
 Libr12->gvrr_classes[4][5] = int_stack + 11605;
 Libr12->gvrr_classes[4][6] = int_stack + 11920;
 Libr12->gvrr_classes[5][4] = int_stack + 12340;
 Libr12->gvrr_classes[5][5] = int_stack + 12655;
 Libr12->gvrr_classes[5][6] = int_stack + 13096;
 memset(int_stack,0,13684*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 13684;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdgd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13684, int_stack+10890, int_stack+10740, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+14134, int_stack+11605, int_stack+11380, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14809, int_stack+11100, int_stack+10890, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15439, int_stack+150, int_stack+0, int_stack+10890, int_stack+11380, int_stack+10740, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15889, int_stack+360, int_stack+150, int_stack+11100, int_stack+11605, int_stack+10890, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16519, int_stack+15889, int_stack+15439, int_stack+14809, int_stack+14134, int_stack+13684, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+15439, int_stack+12655, int_stack+12340, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17419, int_stack+11920, int_stack+11605, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18364, int_stack+865, int_stack+640, int_stack+11605, int_stack+12340, int_stack+11380, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19039, int_stack+1180, int_stack+865, int_stack+11920, int_stack+12655, int_stack+11605, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+19039, int_stack+18364, int_stack+17419, int_stack+15439, int_stack+14134, 4, 0);
 /*--- compute (fp|[r12,T2]|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+18364, int_stack+0, int_stack+16519, 90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+21064, int_stack+2335, int_stack+1600, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+22324, int_stack+13096, int_stack+12655, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16384, int_stack+2923, int_stack+2020, int_stack+12655, int_stack+1600, int_stack+12340, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23647, int_stack+3364, int_stack+2923, int_stack+13096, int_stack+2335, int_stack+12655, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1350, int_stack+23647, int_stack+16384, int_stack+22324, int_stack+21064, int_stack+15439, 5, 0);
 /*--- compute (gp|[r12,T2]|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+23647, int_stack+1350, int_stack+0, 90);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+14809, int_stack+13684, 10);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+900, int_stack+17419, int_stack+14134, 15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+27697, int_stack+900, int_stack+0, 90);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2250, int_stack+3952, int_stack+11100, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21064, int_stack+2250, int_stack+14809, 10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2250, int_stack+4952, int_stack+11920, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10740, int_stack+2250, int_stack+17419, 15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+30397, int_stack+10740, int_stack+21064, 126);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2250, int_stack+22324, int_stack+15439, 21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+12630, int_stack+2250, int_stack+900, 90);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22324, int_stack+4462, int_stack+4312, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+22774, int_stack+4672, int_stack+4462, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4140, int_stack+22774, int_stack+22324, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22324, int_stack+5717, int_stack+5492, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16680, int_stack+6032, int_stack+5717, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5040, int_stack+16680, int_stack+22324, 15);
 /*--- compute (fp|[r12,T1]|gd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+34177, int_stack+5040, int_stack+4140, int_stack+900, int_stack+21064, int_stack+0, 4, 2);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+21064, int_stack+6767, int_stack+6452, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+22009, int_stack+7208, int_stack+6767, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+36877, int_stack+22009, int_stack+21064, 21);
 /*--- compute (gp|[r12,T1]|gd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+38767, int_stack+36877, int_stack+5040, int_stack+2250, int_stack+10740, int_stack+900, 4, 2);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10740, int_stack+7946, int_stack+7796, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11190, int_stack+8156, int_stack+7946, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+36877, int_stack+11190, int_stack+10740, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10740, int_stack+8661, int_stack+8436, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11415, int_stack+8976, int_stack+8661, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+21064, int_stack+11415, int_stack+10740, 15);
 /*--- compute (fp||gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+21064, int_stack+36877, 90);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+36877, int_stack+9711, int_stack+9396, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10740, int_stack+10152, int_stack+9711, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2700, int_stack+10740, int_stack+36877, 21);
 /*--- compute (gp||gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+4590, int_stack+2700, int_stack+21064, 90);
 /*--- compute (fd|[r12,T2]|gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+42817, int_stack+23647, int_stack+18364, 90);
     Libr12->te_ptr[3] = int_stack + 42817;
 /*--- compute (fd|[r12,T1]|gd) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+16680, int_stack+38767, int_stack+34177, int_stack+12630, int_stack+30397, int_stack+27697, 4, 2);
     Libr12->te_ptr[2] = int_stack + 16680;
 /*--- compute (fd||gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+30397, int_stack+4590, int_stack+0, 90);
     Libr12->te_ptr[1] = int_stack + 30397;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+12630, int_stack+27697, 90);
     Libr12->te_ptr[0] = int_stack + 0;

}
