/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdgg(Libr12_t *, prim_data *);

  /* Computes (fd|gg) integrals for linear R12-methods */

void hrr_grt_order_fdgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[3][7] = int_stack + 640;
 Libr12->t2vrr_classes[3][8] = int_stack + 1000;
 Libr12->t2vrr_classes[4][4] = int_stack + 1450;
 Libr12->t2vrr_classes[4][5] = int_stack + 1675;
 Libr12->t2vrr_classes[4][6] = int_stack + 1990;
 Libr12->t2vrr_classes[4][7] = int_stack + 2410;
 Libr12->t2vrr_classes[4][8] = int_stack + 2950;
 Libr12->gvrr_classes[6][4] = int_stack + 3625;
 Libr12->t2vrr_classes[5][4] = int_stack + 4045;
 Libr12->gvrr_classes[6][5] = int_stack + 4360;
 Libr12->t2vrr_classes[5][5] = int_stack + 4948;
 Libr12->gvrr_classes[6][6] = int_stack + 5389;
 Libr12->t2vrr_classes[5][6] = int_stack + 6173;
 Libr12->gvrr_classes[6][7] = int_stack + 6761;
 Libr12->t2vrr_classes[5][7] = int_stack + 7769;
 Libr12->t2vrr_classes[5][8] = int_stack + 8525;
 Libr12->gvrr_classes[3][9] = int_stack + 9470;
 Libr12->t1vrr_classes[3][4] = int_stack + 10020;
 Libr12->t1vrr_classes[3][5] = int_stack + 10170;
 Libr12->t1vrr_classes[3][6] = int_stack + 10380;
 Libr12->t1vrr_classes[3][7] = int_stack + 10660;
 Libr12->t1vrr_classes[3][8] = int_stack + 11020;
 Libr12->gvrr_classes[4][9] = int_stack + 11470;
 Libr12->t1vrr_classes[4][4] = int_stack + 12295;
 Libr12->t1vrr_classes[4][5] = int_stack + 12520;
 Libr12->t1vrr_classes[4][6] = int_stack + 12835;
 Libr12->t1vrr_classes[4][7] = int_stack + 13255;
 Libr12->t1vrr_classes[4][8] = int_stack + 13795;
 Libr12->t1vrr_classes[5][4] = int_stack + 14470;
 Libr12->t1vrr_classes[5][5] = int_stack + 14785;
 Libr12->t1vrr_classes[5][6] = int_stack + 15226;
 Libr12->t1vrr_classes[5][7] = int_stack + 15814;
 Libr12->t1vrr_classes[5][8] = int_stack + 16570;
 Libr12->rvrr_classes[3][4] = int_stack + 17515;
 Libr12->rvrr_classes[3][5] = int_stack + 17665;
 Libr12->rvrr_classes[3][6] = int_stack + 17875;
 Libr12->rvrr_classes[3][7] = int_stack + 18155;
 Libr12->rvrr_classes[3][8] = int_stack + 18515;
 Libr12->rvrr_classes[4][4] = int_stack + 18965;
 Libr12->rvrr_classes[4][5] = int_stack + 19190;
 Libr12->rvrr_classes[4][6] = int_stack + 19505;
 Libr12->rvrr_classes[4][7] = int_stack + 19925;
 Libr12->rvrr_classes[4][8] = int_stack + 20465;
 Libr12->rvrr_classes[5][4] = int_stack + 21140;
 Libr12->rvrr_classes[5][5] = int_stack + 21455;
 Libr12->rvrr_classes[5][6] = int_stack + 21896;
 Libr12->rvrr_classes[5][7] = int_stack + 22484;
 Libr12->rvrr_classes[5][8] = int_stack + 23240;
 Libr12->gvrr_classes[3][4] = int_stack + 24185;
 Libr12->gvrr_classes[3][5] = int_stack + 24335;
 Libr12->gvrr_classes[3][6] = int_stack + 24545;
 Libr12->gvrr_classes[3][7] = int_stack + 24825;
 Libr12->gvrr_classes[3][8] = int_stack + 25185;
 Libr12->gvrr_classes[4][4] = int_stack + 25635;
 Libr12->gvrr_classes[4][5] = int_stack + 25860;
 Libr12->gvrr_classes[4][6] = int_stack + 26175;
 Libr12->gvrr_classes[4][7] = int_stack + 26595;
 Libr12->gvrr_classes[4][8] = int_stack + 27135;
 Libr12->gvrr_classes[5][4] = int_stack + 27810;
 Libr12->gvrr_classes[5][5] = int_stack + 28125;
 Libr12->gvrr_classes[5][6] = int_stack + 28566;
 Libr12->gvrr_classes[5][7] = int_stack + 29154;
 Libr12->gvrr_classes[5][8] = int_stack + 29910;
 memset(int_stack,0,30855*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 30855;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdgg(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+30855, int_stack+24335, int_stack+24185, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+31305, int_stack+24545, int_stack+24335, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+31935, int_stack+31305, int_stack+30855, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+32835, int_stack+24825, int_stack+24545, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+33675, int_stack+32835, int_stack+31305, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+34935, int_stack+33675, int_stack+31935, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+36435, int_stack+25860, int_stack+25635, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+37110, int_stack+26175, int_stack+25860, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+38055, int_stack+37110, int_stack+36435, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+39405, int_stack+26595, int_stack+26175, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+40665, int_stack+39405, int_stack+37110, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+42555, int_stack+40665, int_stack+38055, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+44805, int_stack+25185, int_stack+24825, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+45885, int_stack+44805, int_stack+32835, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+47565, int_stack+45885, int_stack+33675, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49665, int_stack+150, int_stack+0, int_stack+24335, int_stack+25635, int_stack+24185, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+50115, int_stack+360, int_stack+150, int_stack+24545, int_stack+25860, int_stack+24335, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+50745, int_stack+50115, int_stack+49665, int_stack+31305, int_stack+36435, int_stack+30855, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51645, int_stack+640, int_stack+360, int_stack+24825, int_stack+26175, int_stack+24545, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+52485, int_stack+51645, int_stack+50115, int_stack+32835, int_stack+37110, int_stack+31305, 3, 0);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53745, int_stack+52485, int_stack+50745, int_stack+33675, int_stack+38055, int_stack+31935, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30855, int_stack+1000, int_stack+640, int_stack+25185, int_stack+26595, int_stack+24825, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49665, int_stack+30855, int_stack+51645, int_stack+44805, int_stack+39405, int_stack+32835, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30855, int_stack+49665, int_stack+52485, int_stack+45885, int_stack+40665, int_stack+33675, 3, 0);
 /*--- compute (f0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49665, int_stack+30855, int_stack+53745, int_stack+47565, int_stack+42555, int_stack+34935, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+30855, int_stack+28125, int_stack+27810, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+31800, int_stack+28566, int_stack+28125, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+51915, int_stack+31800, int_stack+30855, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+33123, int_stack+29154, int_stack+28566, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+53805, int_stack+33123, int_stack+31800, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+56451, int_stack+53805, int_stack+51915, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+59601, int_stack+27135, int_stack+26595, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+61221, int_stack+59601, int_stack+39405, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+63741, int_stack+61221, int_stack+40665, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24185, int_stack+1675, int_stack+1450, int_stack+25860, int_stack+27810, int_stack+25635, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1990, int_stack+1675, int_stack+26175, int_stack+28125, int_stack+25860, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66891, int_stack+0, int_stack+24185, int_stack+37110, int_stack+30855, int_stack+36435, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68241, int_stack+2410, int_stack+1990, int_stack+26595, int_stack+28566, int_stack+26175, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69501, int_stack+68241, int_stack+0, int_stack+39405, int_stack+31800, int_stack+37110, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+69501, int_stack+66891, int_stack+40665, int_stack+51915, int_stack+38055, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36435, int_stack+2950, int_stack+2410, int_stack+27135, int_stack+29154, int_stack+26595, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+71391, int_stack+36435, int_stack+68241, int_stack+59601, int_stack+33123, int_stack+39405, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36435, int_stack+71391, int_stack+69501, int_stack+61221, int_stack+53805, int_stack+40665, 4, 0);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66891, int_stack+36435, int_stack+0, int_stack+63741, int_stack+56451, int_stack+42555, 4, 0);
 /*--- compute (fp|[r12,T2]|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+70266, int_stack+66891, int_stack+49665, 225);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+49665, int_stack+4360, int_stack+3625, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+5389, int_stack+4360, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+36435, int_stack+0, int_stack+49665, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+38955, int_stack+6761, int_stack+5389, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+77016, int_stack+38955, int_stack+0, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+80544, int_stack+77016, int_stack+36435, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+84744, int_stack+29910, int_stack+29154, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+87012, int_stack+84744, int_stack+33123, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+90540, int_stack+87012, int_stack+53805, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+50925, int_stack+4948, int_stack+4045, int_stack+28125, int_stack+3625, int_stack+27810, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+6173, int_stack+4948, int_stack+28566, int_stack+4360, int_stack+28125, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3087, int_stack+1764, int_stack+50925, int_stack+31800, int_stack+49665, int_stack+30855, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49665, int_stack+7769, int_stack+6173, int_stack+29154, int_stack+5389, int_stack+28566, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94950, int_stack+49665, int_stack+1764, int_stack+33123, int_stack+0, int_stack+31800, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97596, int_stack+94950, int_stack+3087, int_stack+53805, int_stack+36435, int_stack+51915, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30855, int_stack+8525, int_stack+7769, int_stack+29910, int_stack+6761, int_stack+29154, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+30855, int_stack+49665, int_stack+84744, int_stack+38955, int_stack+33123, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36435, int_stack+0, int_stack+94950, int_stack+87012, int_stack+77016, int_stack+53805, 5, 0);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+36435, int_stack+97596, int_stack+90540, int_stack+80544, int_stack+56451, 5, 0);
 /*--- compute (gp|[r12,T2]|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+77016, int_stack+0, int_stack+66891, 225);
 /*--- compute (f0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+66891, int_stack+47565, int_stack+34935, 10);
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+63741, int_stack+42555, 15);
 /*--- compute (fp|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+49665, int_stack+0, int_stack+66891, 225);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+3375, int_stack+9470, int_stack+25185, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+4725, int_stack+3375, int_stack+44805, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+6885, int_stack+4725, int_stack+45885, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+3375, int_stack+6885, int_stack+47565, 10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+6525, int_stack+11470, int_stack+27135, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+87141, int_stack+6525, int_stack+59601, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+94950, int_stack+87141, int_stack+61221, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+24185, int_stack+94950, int_stack+63741, 15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+28910, int_stack+24185, int_stack+3375, 315);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+94950, int_stack+90540, int_stack+56451, 21);
 /*--- compute (gp|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+56415, int_stack+94950, int_stack+0, 225);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+99675, int_stack+10170, int_stack+10020, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+100125, int_stack+10380, int_stack+10170, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+87141, int_stack+100125, int_stack+99675, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+88041, int_stack+10660, int_stack+10380, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+88881, int_stack+88041, int_stack+100125, 10);
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+90141, int_stack+88881, int_stack+87141, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+99675, int_stack+11020, int_stack+10660, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+91641, int_stack+99675, int_stack+88041, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+6525, int_stack+91641, int_stack+88881, 10);
 /*--- compute (f0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+91641, int_stack+6525, int_stack+90141, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6525, int_stack+12520, int_stack+12295, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7200, int_stack+12835, int_stack+12520, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8145, int_stack+7200, int_stack+6525, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9495, int_stack+13255, int_stack+12835, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10755, int_stack+9495, int_stack+7200, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+87141, int_stack+10755, int_stack+8145, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+6525, int_stack+13795, int_stack+13255, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38360, int_stack+6525, int_stack+9495, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+6525, int_stack+38360, int_stack+10755, 15);
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+38360, int_stack+6525, int_stack+87141, 15);
 /*--- compute (fp|[r12,T1]|gg) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+6525, int_stack+38360, int_stack+91641, int_stack+0, int_stack+3375, int_stack+66891, 4, 4);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3375, int_stack+14785, int_stack+14470, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4320, int_stack+15226, int_stack+14785, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+87141, int_stack+4320, int_stack+3375, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+89031, int_stack+15814, int_stack+15226, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+90795, int_stack+89031, int_stack+4320, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3375, int_stack+90795, int_stack+87141, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13275, int_stack+16570, int_stack+15814, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+41735, int_stack+13275, int_stack+89031, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+99675, int_stack+41735, int_stack+90795, 21);
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+41735, int_stack+99675, int_stack+3375, 21);
 /*--- compute (gp|[r12,T1]|gg) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+99675, int_stack+41735, int_stack+38360, int_stack+94950, int_stack+24185, int_stack+0, 4, 4);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+17665, int_stack+17515, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+17875, int_stack+17665, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1080, int_stack+450, int_stack+0, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1980, int_stack+18155, int_stack+17875, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2820, int_stack+1980, int_stack+450, 10);
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+4080, int_stack+2820, int_stack+1080, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+18515, int_stack+18155, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+24185, int_stack+0, int_stack+1980, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+24185, int_stack+2820, 10);
 /*--- compute (f0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+24185, int_stack+0, int_stack+4080, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+19190, int_stack+18965, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+675, int_stack+19505, int_stack+19190, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1620, int_stack+675, int_stack+0, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2970, int_stack+19925, int_stack+19505, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4230, int_stack+2970, int_stack+675, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+26435, int_stack+4230, int_stack+1620, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+20465, int_stack+19925, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38360, int_stack+0, int_stack+2970, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+38360, int_stack+4230, 15);
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+0, int_stack+26435, 15);
 /*--- compute (fp||gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+38360, int_stack+3150, int_stack+24185, 225);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24185, int_stack+21455, int_stack+21140, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25130, int_stack+21896, int_stack+21455, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+26453, int_stack+25130, int_stack+24185, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+22484, int_stack+21896, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+45110, int_stack+0, int_stack+25130, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+13275, int_stack+45110, int_stack+26453, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+24185, int_stack+23240, int_stack+22484, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+16425, int_stack+24185, int_stack+0, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19953, int_stack+16425, int_stack+45110, 21);
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+87141, int_stack+19953, int_stack+13275, 21);
 /*--- compute (gp||gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+13275, int_stack+87141, int_stack+3150, 225);
 /*--- compute (fd|[r12,T2]|gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+109800, int_stack+77016, int_stack+70266, 225);
     Libr12->te_ptr[3] = int_stack + 109800;
 /*--- compute (fd|[r12,T1]|gg) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+66540, int_stack+99675, int_stack+6525, int_stack+56415, int_stack+28910, int_stack+49665, 4, 4);
     Libr12->te_ptr[2] = int_stack + 66540;
 /*--- compute (fd||gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+23400, int_stack+13275, int_stack+38360, 225);
     Libr12->te_ptr[1] = int_stack + 23400;
 /*--- compute (fd|gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+56415, int_stack+49665, 225);
     Libr12->te_ptr[0] = int_stack + 0;

}
