/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ffhf(Libr12_t *, prim_data *);

  /* Computes (ff|hf) integrals for linear R12-methods */

void hrr_grt_order_ffhf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[3][8] = int_stack + 850;
 Libr12->t2vrr_classes[4][5] = int_stack + 1300;
 Libr12->t2vrr_classes[4][6] = int_stack + 1615;
 Libr12->t2vrr_classes[4][7] = int_stack + 2035;
 Libr12->t2vrr_classes[4][8] = int_stack + 2575;
 Libr12->t2vrr_classes[5][5] = int_stack + 3250;
 Libr12->t2vrr_classes[5][6] = int_stack + 3691;
 Libr12->t2vrr_classes[5][7] = int_stack + 4279;
 Libr12->t2vrr_classes[5][8] = int_stack + 5035;
 Libr12->gvrr_classes[7][5] = int_stack + 5980;
 Libr12->t2vrr_classes[6][5] = int_stack + 6736;
 Libr12->gvrr_classes[7][6] = int_stack + 7324;
 Libr12->t2vrr_classes[6][6] = int_stack + 8332;
 Libr12->gvrr_classes[7][7] = int_stack + 9116;
 Libr12->t2vrr_classes[6][7] = int_stack + 10412;
 Libr12->t2vrr_classes[6][8] = int_stack + 11420;
 Libr12->gvrr_classes[3][9] = int_stack + 12680;
 Libr12->t1vrr_classes[3][5] = int_stack + 13230;
 Libr12->t1vrr_classes[3][6] = int_stack + 13440;
 Libr12->t1vrr_classes[3][7] = int_stack + 13720;
 Libr12->t1vrr_classes[3][8] = int_stack + 14080;
 Libr12->gvrr_classes[4][9] = int_stack + 14530;
 Libr12->t1vrr_classes[4][5] = int_stack + 15355;
 Libr12->t1vrr_classes[4][6] = int_stack + 15670;
 Libr12->t1vrr_classes[4][7] = int_stack + 16090;
 Libr12->t1vrr_classes[4][8] = int_stack + 16630;
 Libr12->gvrr_classes[5][9] = int_stack + 17305;
 Libr12->t1vrr_classes[5][5] = int_stack + 18460;
 Libr12->t1vrr_classes[5][6] = int_stack + 18901;
 Libr12->t1vrr_classes[5][7] = int_stack + 19489;
 Libr12->t1vrr_classes[5][8] = int_stack + 20245;
 Libr12->t1vrr_classes[6][5] = int_stack + 21190;
 Libr12->t1vrr_classes[6][6] = int_stack + 21778;
 Libr12->t1vrr_classes[6][7] = int_stack + 22562;
 Libr12->t1vrr_classes[6][8] = int_stack + 23570;
 Libr12->rvrr_classes[3][5] = int_stack + 24830;
 Libr12->rvrr_classes[3][6] = int_stack + 25040;
 Libr12->rvrr_classes[3][7] = int_stack + 25320;
 Libr12->rvrr_classes[3][8] = int_stack + 25680;
 Libr12->rvrr_classes[4][5] = int_stack + 26130;
 Libr12->rvrr_classes[4][6] = int_stack + 26445;
 Libr12->rvrr_classes[4][7] = int_stack + 26865;
 Libr12->rvrr_classes[4][8] = int_stack + 27405;
 Libr12->rvrr_classes[5][5] = int_stack + 28080;
 Libr12->rvrr_classes[5][6] = int_stack + 28521;
 Libr12->rvrr_classes[5][7] = int_stack + 29109;
 Libr12->rvrr_classes[5][8] = int_stack + 29865;
 Libr12->rvrr_classes[6][5] = int_stack + 30810;
 Libr12->rvrr_classes[6][6] = int_stack + 31398;
 Libr12->rvrr_classes[6][7] = int_stack + 32182;
 Libr12->rvrr_classes[6][8] = int_stack + 33190;
 Libr12->gvrr_classes[3][5] = int_stack + 34450;
 Libr12->gvrr_classes[3][6] = int_stack + 34660;
 Libr12->gvrr_classes[3][7] = int_stack + 34940;
 Libr12->gvrr_classes[3][8] = int_stack + 35300;
 Libr12->gvrr_classes[4][5] = int_stack + 35750;
 Libr12->gvrr_classes[4][6] = int_stack + 36065;
 Libr12->gvrr_classes[4][7] = int_stack + 36485;
 Libr12->gvrr_classes[4][8] = int_stack + 37025;
 Libr12->gvrr_classes[5][5] = int_stack + 37700;
 Libr12->gvrr_classes[5][6] = int_stack + 38141;
 Libr12->gvrr_classes[5][7] = int_stack + 38729;
 Libr12->gvrr_classes[5][8] = int_stack + 39485;
 Libr12->gvrr_classes[6][5] = int_stack + 40430;
 Libr12->gvrr_classes[6][6] = int_stack + 41018;
 Libr12->gvrr_classes[6][7] = int_stack + 41802;
 Libr12->gvrr_classes[6][8] = int_stack + 42810;
 memset(int_stack,0,44070*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 44070;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ffhf(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44070, int_stack+34660, int_stack+34450, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+44700, int_stack+34940, int_stack+34660, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+45540, int_stack+44700, int_stack+44070, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46800, int_stack+36065, int_stack+35750, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+47745, int_stack+36485, int_stack+36065, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49005, int_stack+47745, int_stack+46800, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+50895, int_stack+35300, int_stack+34940, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+51975, int_stack+50895, int_stack+44700, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53655, int_stack+210, int_stack+0, int_stack+34660, int_stack+35750, int_stack+34450, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54285, int_stack+490, int_stack+210, int_stack+34940, int_stack+36065, int_stack+34660, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55125, int_stack+54285, int_stack+53655, int_stack+44700, int_stack+46800, int_stack+44070, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56385, int_stack+850, int_stack+490, int_stack+35300, int_stack+36485, int_stack+34940, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57465, int_stack+56385, int_stack+54285, int_stack+50895, int_stack+47745, int_stack+44700, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+59145, int_stack+57465, int_stack+55125, int_stack+51975, int_stack+49005, int_stack+45540, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44070, int_stack+38141, int_stack+37700, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+53655, int_stack+38729, int_stack+38141, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+55419, int_stack+53655, int_stack+44070, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+61245, int_stack+37025, int_stack+36485, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+62865, int_stack+61245, int_stack+47745, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+58065, int_stack+1615, int_stack+1300, int_stack+36065, int_stack+37700, int_stack+35750, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2035, int_stack+1615, int_stack+36485, int_stack+38141, int_stack+36065, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+65385, int_stack+0, int_stack+58065, int_stack+47745, int_stack+44070, int_stack+46800, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67275, int_stack+2575, int_stack+2035, int_stack+37025, int_stack+38729, int_stack+36485, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68895, int_stack+67275, int_stack+0, int_stack+61245, int_stack+53655, int_stack+47745, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+68895, int_stack+65385, int_stack+62865, int_stack+55419, int_stack+49005, 4, 0);
 /*--- compute (fp|[r12,T2]|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+65385, int_stack+0, int_stack+59145, 210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46800, int_stack+41018, int_stack+40430, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+58065, int_stack+41802, int_stack+41018, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+71685, int_stack+58065, int_stack+46800, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+75213, int_stack+39485, int_stack+38729, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+77481, int_stack+75213, int_stack+53655, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+81009, int_stack+3691, int_stack+3250, int_stack+38141, int_stack+40430, int_stack+37700, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+82332, int_stack+4279, int_stack+3691, int_stack+38729, int_stack+41018, int_stack+38141, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84096, int_stack+82332, int_stack+81009, int_stack+53655, int_stack+46800, int_stack+44070, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+86742, int_stack+5035, int_stack+4279, int_stack+39485, int_stack+41802, int_stack+38729, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+89010, int_stack+86742, int_stack+82332, int_stack+75213, int_stack+58065, int_stack+53655, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+92538, int_stack+89010, int_stack+84096, int_stack+77481, int_stack+71685, int_stack+55419, 5, 0);
 /*--- compute (gp|[r12,T2]|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+81009, int_stack+92538, int_stack+0, 210);
 /*--- compute (fd|[r12,T2]|hf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+96948, int_stack+81009, int_stack+65385, 210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+65385, int_stack+7324, int_stack+5980, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+67653, int_stack+9116, int_stack+7324, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+67653, int_stack+65385, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+109548, int_stack+42810, int_stack+41802, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+112572, int_stack+109548, int_stack+58065, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53655, int_stack+8332, int_stack+6736, int_stack+41018, int_stack+5980, int_stack+40430, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4536, int_stack+10412, int_stack+8332, int_stack+41802, int_stack+7324, int_stack+41018, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+117276, int_stack+4536, int_stack+53655, int_stack+58065, int_stack+65385, int_stack+46800, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+120804, int_stack+11420, int_stack+10412, int_stack+42810, int_stack+9116, int_stack+41802, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+40430, int_stack+120804, int_stack+4536, int_stack+109548, int_stack+67653, int_stack+58065, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4536, int_stack+40430, int_stack+117276, int_stack+112572, int_stack+0, int_stack+71685, 6, 0);
 /*--- compute (hp|[r12,T2]|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+117276, int_stack+4536, int_stack+92538, 210);
 /*--- compute (gd|[r12,T2]|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+130506, int_stack+117276, int_stack+81009, 210);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+81009, int_stack+51975, int_stack+45540, 10);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+83109, int_stack+62865, int_stack+49005, 15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+65385, int_stack+83109, int_stack+81009, 210);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+86259, int_stack+77481, int_stack+55419, 21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+117276, int_stack+86259, int_stack+83109, 210);
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+117276, int_stack+65385, 210);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+90669, int_stack+12680, int_stack+35300, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+92019, int_stack+90669, int_stack+50895, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+126726, int_stack+92019, int_stack+51975, 10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+90669, int_stack+14530, int_stack+37025, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+92694, int_stack+90669, int_stack+61245, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+40430, int_stack+92694, int_stack+62865, 15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+44630, int_stack+40430, int_stack+126726, 280);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+90669, int_stack+17305, int_stack+39485, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+53030, int_stack+90669, int_stack+75213, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+90669, int_stack+53030, int_stack+77481, 21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+149406, int_stack+90669, int_stack+40430, 280);
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+162006, int_stack+149406, int_stack+44630, 280);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+53030, int_stack+112572, int_stack+71685, 28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+178806, int_stack+53030, int_stack+86259, 210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+192036, int_stack+178806, int_stack+117276, 210);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+13440, int_stack+13230, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+71685, int_stack+13720, int_stack+13440, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+72525, int_stack+71685, int_stack+12600, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+14080, int_stack+13720, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+73785, int_stack+12600, int_stack+71685, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+73785, int_stack+72525, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+71685, int_stack+15670, int_stack+15355, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+72630, int_stack+16090, int_stack+15670, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+73890, int_stack+72630, int_stack+71685, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+75780, int_stack+16630, int_stack+16090, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+77400, int_stack+75780, int_stack+72630, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+14700, int_stack+77400, int_stack+73890, 15);
 /*--- compute (fp|[r12,T1]|hf) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+71685, int_stack+14700, int_stack+12600, int_stack+83109, int_stack+126726, int_stack+81009, 5, 3);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+126726, int_stack+18901, int_stack+18460, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+128049, int_stack+19489, int_stack+18901, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+77985, int_stack+128049, int_stack+126726, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+80631, int_stack+20245, int_stack+19489, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+58910, int_stack+80631, int_stack+128049, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+109548, int_stack+58910, int_stack+77985, 21);
 /*--- compute (gp|[r12,T1]|hf) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+210936, int_stack+109548, int_stack+14700, int_stack+86259, int_stack+40430, int_stack+83109, 5, 3);
 /*--- compute (fd|[r12,T1]|hf) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+220386, int_stack+210936, int_stack+71685, int_stack+117276, int_stack+44630, int_stack+65385, 5, 3);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+58910, int_stack+21778, int_stack+21190, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+60674, int_stack+22562, int_stack+21778, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+63026, int_stack+60674, int_stack+58910, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+66554, int_stack+23570, int_stack+22562, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+69578, int_stack+66554, int_stack+60674, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+74282, int_stack+69578, int_stack+63026, 28);
 /*--- compute (hp|[r12,T1]|hf) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+58910, int_stack+74282, int_stack+109548, int_stack+53030, int_stack+90669, int_stack+86259, 5, 3);
 /*--- compute (gd|[r12,T1]|hf) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+72140, int_stack+58910, int_stack+210936, int_stack+178806, int_stack+149406, int_stack+117276, 5, 3);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+149406, int_stack+25040, int_stack+24830, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+150036, int_stack+25320, int_stack+25040, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+150876, int_stack+150036, int_stack+149406, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+152136, int_stack+25680, int_stack+25320, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+153216, int_stack+152136, int_stack+150036, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+154896, int_stack+153216, int_stack+150876, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+149406, int_stack+26445, int_stack+26130, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+150351, int_stack+26865, int_stack+26445, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+151611, int_stack+150351, int_stack+149406, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+156996, int_stack+27405, int_stack+26865, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+158616, int_stack+156996, int_stack+150351, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+178806, int_stack+158616, int_stack+151611, 15);
 /*--- compute (fp||hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+181956, int_stack+178806, int_stack+154896, 210);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+149406, int_stack+28521, int_stack+28080, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+150729, int_stack+29109, int_stack+28521, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+152493, int_stack+150729, int_stack+149406, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+155139, int_stack+29865, int_stack+29109, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+157407, int_stack+155139, int_stack+150729, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+210936, int_stack+157407, int_stack+152493, 21);
 /*--- compute (gp||hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+149406, int_stack+210936, int_stack+178806, 210);
 /*--- compute (fd||hf) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+109548, int_stack+149406, int_stack+181956, 210);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+178806, int_stack+31398, int_stack+30810, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+180570, int_stack+32182, int_stack+31398, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+182922, int_stack+180570, int_stack+178806, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+186450, int_stack+33190, int_stack+32182, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+215346, int_stack+186450, int_stack+180570, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+122148, int_stack+215346, int_stack+182922, 28);
 /*--- compute (hp||hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+178806, int_stack+122148, int_stack+210936, 210);
 /*--- compute (gd||hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+12600, int_stack+178806, int_stack+149406, 210);
 /*--- compute (ff|[r12,T2]|hf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+31500, int_stack+130506, int_stack+96948, 210);
     Libr12->te_ptr[3] = int_stack + 31500;
 /*--- compute (ff|[r12,T1]|hf) ---*/
   t1hrr1_build_ff(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+122148, int_stack+72140, int_stack+220386, int_stack+192036, int_stack+162006, int_stack+0, 5, 3);
     Libr12->te_ptr[2] = int_stack + 122148;
 /*--- compute (ff||hf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+210936, int_stack+12600, int_stack+109548, 210);
     Libr12->te_ptr[1] = int_stack + 210936;
 /*--- compute (ff|hf) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+143148, int_stack+192036, int_stack+0, 210);
     Libr12->te_ptr[0] = int_stack + 143148;

}
