/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_dph0(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+12, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+31, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+50, r12vrr_stack+40, r12vrr_stack+21, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+80, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+34, r12vrr_stack+6, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+95, r12vrr_stack+3, r12vrr_stack+31, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+101, r12vrr_stack+95, r12vrr_stack+34, r12vrr_stack+3, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+111, r12vrr_stack+101, r12vrr_stack+40, r12vrr_stack+95, r12vrr_stack+34, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+12, r12vrr_stack+31, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+126, r12vrr_stack+15, r12vrr_stack+34, r12vrr_stack+0, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+136, r12vrr_stack+21, r12vrr_stack+126, r12vrr_stack+6, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+151, r12vrr_stack+80, r12vrr_stack+136, NULL, NULL, r12vrr_stack+21);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+196, r12vrr_stack+111, r12vrr_stack+80, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+241, r12vrr_stack+196, r12vrr_stack+151, r12vrr_stack+111, r12vrr_stack+80, r12vrr_stack+50);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+331, r12vrr_stack+6, r12vrr_stack+15, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+349, r12vrr_stack+21, r12vrr_stack+126, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+379, r12vrr_stack+50, r12vrr_stack+349, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+331);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+439, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+442, r12vrr_stack+31, r12vrr_stack+439, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+448, r12vrr_stack+34, r12vrr_stack+442, r12vrr_stack+12, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+458, r12vrr_stack+126, r12vrr_stack+448, r12vrr_stack+15, r12vrr_stack+34, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+473, r12vrr_stack+136, r12vrr_stack+458, NULL, NULL, r12vrr_stack+126);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+151, r12vrr_stack+473, r12vrr_stack+80, r12vrr_stack+136, r12vrr_stack+349);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+241, r12vrr_stack+518, r12vrr_stack+196, r12vrr_stack+151, r12vrr_stack+379);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+758, r12vrr_stack+136, r12vrr_stack+458, r12vrr_stack+21, r12vrr_stack+126, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+779, r12vrr_stack+80, r12vrr_stack+136, r12vrr_stack+40, r12vrr_stack+21, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+800, r12vrr_stack+779, r12vrr_stack+758, NULL, NULL, r12vrr_stack+136);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+863, r12vrr_stack+111, r12vrr_stack+80, r12vrr_stack+101, r12vrr_stack+40, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+884, r12vrr_stack+863, r12vrr_stack+779, NULL, NULL, r12vrr_stack+80);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+40, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+43, r12vrr_stack+439, r12vrr_stack+40, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+947, r12vrr_stack+442, r12vrr_stack+43, r12vrr_stack+31, r12vrr_stack+439, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+957, r12vrr_stack+448, r12vrr_stack+947, r12vrr_stack+34, r12vrr_stack+442, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+972, r12vrr_stack+458, r12vrr_stack+957, r12vrr_stack+126, r12vrr_stack+448, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+993, r12vrr_stack+758, r12vrr_stack+972, NULL, NULL, r12vrr_stack+458);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1056, r12vrr_stack+800, r12vrr_stack+993, r12vrr_stack+779, r12vrr_stack+758, r12vrr_stack+473);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1182, r12vrr_stack+884, r12vrr_stack+800, r12vrr_stack+863, r12vrr_stack+779, r12vrr_stack+151);
 tmp = r12vrr_stack + 1182;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1308, r12vrr_stack+1182, r12vrr_stack+1056, r12vrr_stack+884, r12vrr_stack+800, r12vrr_stack+518);
 tmp = r12vrr_stack + 1308;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1518, r12vrr_stack+779, r12vrr_stack+758, r12vrr_stack+80, r12vrr_stack+136, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1546, r12vrr_stack+863, r12vrr_stack+779, r12vrr_stack+111, r12vrr_stack+80, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1574, r12vrr_stack+758, r12vrr_stack+972, r12vrr_stack+136, r12vrr_stack+458, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1602, r12vrr_stack+1518, r12vrr_stack+1574, NULL, NULL, r12vrr_stack+758);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1686, r12vrr_stack+1546, r12vrr_stack+1518, NULL, NULL, r12vrr_stack+779);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1770, r12vrr_stack+1686, r12vrr_stack+1602, r12vrr_stack+1546, r12vrr_stack+1518, r12vrr_stack+800);
 tmp = r12vrr_stack + 1770;
 target_ptr = Libr12->gvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+1546, r12vrr_stack+0, r12vrr_stack+12, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1555, r12vrr_stack+15, r12vrr_stack+34, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1938, r12vrr_stack+331, r12vrr_stack+1555, r12vrr_stack+6, r12vrr_stack+15, r12vrr_stack+1546);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1974, r12vrr_stack+126, r12vrr_stack+448, NULL, NULL, r12vrr_stack+34);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+2004, r12vrr_stack+349, r12vrr_stack+1974, r12vrr_stack+21, r12vrr_stack+126, r12vrr_stack+1555);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+2064, r12vrr_stack+379, r12vrr_stack+2004, r12vrr_stack+50, r12vrr_stack+349, r12vrr_stack+1938);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+331, r12vrr_stack+458, r12vrr_stack+957, NULL, NULL, r12vrr_stack+448);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2164, r12vrr_stack+473, r12vrr_stack+331, r12vrr_stack+136, r12vrr_stack+458, r12vrr_stack+1974);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2254, r12vrr_stack+518, r12vrr_stack+2164, r12vrr_stack+151, r12vrr_stack+473, r12vrr_stack+2004);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2404, r12vrr_stack+608, r12vrr_stack+2254, r12vrr_stack+241, r12vrr_stack+518, r12vrr_stack+2064);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+473, r12vrr_stack+40, r12vrr_stack+0, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+479, r12vrr_stack+43, r12vrr_stack+473, r12vrr_stack+439, r12vrr_stack+40, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+489, r12vrr_stack+947, r12vrr_stack+479, r12vrr_stack+442, r12vrr_stack+43, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+779, r12vrr_stack+957, r12vrr_stack+489, r12vrr_stack+448, r12vrr_stack+947, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+473, r12vrr_stack+972, r12vrr_stack+779, NULL, NULL, r12vrr_stack+957);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1938, r12vrr_stack+993, r12vrr_stack+473, r12vrr_stack+758, r12vrr_stack+972, r12vrr_stack+331);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2629, r12vrr_stack+1056, r12vrr_stack+1938, r12vrr_stack+800, r12vrr_stack+993, r12vrr_stack+2164);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+1938, r12vrr_stack+1308, r12vrr_stack+2629, r12vrr_stack+1182, r12vrr_stack+1056, r12vrr_stack+2254);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1546, r12vrr_stack+972, r12vrr_stack+779, r12vrr_stack+458, r12vrr_stack+957, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2629, r12vrr_stack+1574, r12vrr_stack+1546, NULL, NULL, r12vrr_stack+972);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2713, r12vrr_stack+1602, r12vrr_stack+2629, r12vrr_stack+1518, r12vrr_stack+1574, r12vrr_stack+993);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2881, r12vrr_stack+1770, r12vrr_stack+2713, r12vrr_stack+1686, r12vrr_stack+1602, r12vrr_stack+1056);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+0, &(Data->ss_r12_ss), NULL, r12vrr_stack+3, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+1518, r12vrr_stack+0, &(Data->ss_r12_ss), r12vrr_stack+95, r12vrr_stack+3, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+1524, r12vrr_stack+1518, r12vrr_stack+0, r12vrr_stack+101, r12vrr_stack+95, r12vrr_stack+3, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+1524, r12vrr_stack+1518, r12vrr_stack+111, r12vrr_stack+101, r12vrr_stack+95, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+1524, r12vrr_stack+863, r12vrr_stack+111, r12vrr_stack+101, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+1518, r12vrr_stack+15, NULL, r12vrr_stack+884, r12vrr_stack+863, NULL, r12vrr_stack+111);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+36, r12vrr_stack+1518, r12vrr_stack+15, r12vrr_stack+1182, r12vrr_stack+884, r12vrr_stack+863, r12vrr_stack+196);
 tmp = r12vrr_stack + 36;
 target_ptr = Libr12->rvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+758, r12vrr_stack+1182, r12vrr_stack+1770, r12vrr_stack+1308, r12vrr_stack+608, r12vrr_stack+241);
 tmp = r12vrr_stack + 758;
 target_ptr = Libr12->t2vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2629, r12vrr_stack+1308, r12vrr_stack+2881, r12vrr_stack+1938, r12vrr_stack+2404, r12vrr_stack+608);
 tmp = r12vrr_stack + 2629;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3161, r12vrr_stack+1182, r12vrr_stack+1308, r12vrr_stack+1770, r12vrr_stack+1686, r12vrr_stack+884);
 tmp = r12vrr_stack + 3161;
 target_ptr = Libr12->t1vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3287, r12vrr_stack+1308, r12vrr_stack+1938, r12vrr_stack+2881, r12vrr_stack+1770, r12vrr_stack+1182);
 tmp = r12vrr_stack + 3287;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+1581, r12vrr_stack+36, r12vrr_stack+1518, r12vrr_stack+1308, r12vrr_stack+1182, r12vrr_stack+884, r12vrr_stack+241);
 tmp = r12vrr_stack + 1581;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];


}

