/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_fdh0(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+219, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+234, r12vrr_stack+219, r12vrr_stack+204, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+279, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+282, r12vrr_stack+279, r12vrr_stack+49, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+52, r12vrr_stack+279, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+58, r12vrr_stack+282, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+313, r12vrr_stack+298, r12vrr_stack+219, NULL, NULL, r12vrr_stack+58);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+12, r12vrr_stack+49, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+368, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+383, r12vrr_stack+204, r12vrr_stack+368, NULL, NULL, r12vrr_stack+74);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+428, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+84);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+114);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+144);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+758, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+767, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+785, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+758);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+821, r12vrr_stack+74, r12vrr_stack+358, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+851, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+767);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+911, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+785);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+127, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+68, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1011, r12vrr_stack+368, r12vrr_stack+127, NULL, NULL, r12vrr_stack+358);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1056, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+821);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1146, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+851);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1296, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+911);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1542, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1563, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+74, r12vrr_stack+358, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1584, r12vrr_stack+1521, r12vrr_stack+1563, NULL, NULL, r12vrr_stack+368);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1647, r12vrr_stack+1542, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1710, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+383);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+288, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+1542, NULL, NULL, r12vrr_stack+219);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+234);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+234, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+237, r12vrr_stack+114, r12vrr_stack+234, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+15, r12vrr_stack+237, r12vrr_stack+49, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+243, r12vrr_stack+117, r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+258, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+358, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2046, r12vrr_stack+1563, r12vrr_stack+258, NULL, NULL, r12vrr_stack+127);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2109, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+1011);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2235, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1056);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+428);
 tmp = r12vrr_stack + 2445;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1146);
 tmp = r12vrr_stack + 2655;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+204, r12vrr_stack+368, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2998, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+219, r12vrr_stack+204, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3026, r12vrr_stack+2998, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+298, r12vrr_stack+219, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+2998, NULL, NULL, r12vrr_stack+1542);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+368, r12vrr_stack+127, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3222, r12vrr_stack+2970, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+1563);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3306, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1584);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1647);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+1710);
 tmp = r12vrr_stack + 3642;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+1647, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+1650, r12vrr_stack+3, r12vrr_stack+12, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1659, r12vrr_stack+758, r12vrr_stack+1650, r12vrr_stack+0, r12vrr_stack+3, r12vrr_stack+1647);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1677, r12vrr_stack+68, r12vrr_stack+52, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+3110, r12vrr_stack+767, r12vrr_stack+1677, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+1650);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+3146, r12vrr_stack+785, r12vrr_stack+3110, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+1659);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+204, r12vrr_stack+358, r12vrr_stack+117, NULL, NULL, r12vrr_stack+52);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3922, r12vrr_stack+821, r12vrr_stack+204, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+1677);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3982, r12vrr_stack+851, r12vrr_stack+3922, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+3110);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+4082, r12vrr_stack+911, r12vrr_stack+3982, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+3146);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+142, r12vrr_stack+127, r12vrr_stack+243, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+4232, r12vrr_stack+1011, r12vrr_stack+142, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+204);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+4322, r12vrr_stack+1056, r12vrr_stack+4232, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+3922);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+4472, r12vrr_stack+1146, r12vrr_stack+4322, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+3982);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4697, r12vrr_stack+1296, r12vrr_stack+4472, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+4082);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+234, r12vrr_stack+0, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+368, r12vrr_stack+237, r12vrr_stack+6, r12vrr_stack+114, r12vrr_stack+234, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1695, r12vrr_stack+58, r12vrr_stack+368, r12vrr_stack+15, r12vrr_stack+237, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+378, r12vrr_stack+243, r12vrr_stack+1695, r12vrr_stack+117, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+399, r12vrr_stack+258, r12vrr_stack+378, NULL, NULL, r12vrr_stack+243);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5012, r12vrr_stack+2046, r12vrr_stack+399, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+142);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5138, r12vrr_stack+2109, r12vrr_stack+5012, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+4232);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5348, r12vrr_stack+2235, r12vrr_stack+5138, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+4322);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+5663, r12vrr_stack+2655, r12vrr_stack+5348, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+4472);
 tmp = r12vrr_stack + 5663;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+21, r12vrr_stack+258, r12vrr_stack+378, r12vrr_stack+127, r12vrr_stack+243, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1710, r12vrr_stack+1521, r12vrr_stack+21, NULL, NULL, r12vrr_stack+258);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6104, r12vrr_stack+3222, r12vrr_stack+1710, r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+2046);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6272, r12vrr_stack+3306, r12vrr_stack+6104, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2109);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6552, r12vrr_stack+3642, r12vrr_stack+6272, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+2235);
 tmp = r12vrr_stack + 6552;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+2970, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+2973, r12vrr_stack+1647, r12vrr_stack+2970, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+2979, r12vrr_stack+12, r12vrr_stack+49, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2988, r12vrr_stack+1650, r12vrr_stack+2979, r12vrr_stack+3, r12vrr_stack+12, r12vrr_stack+2970);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+3006, r12vrr_stack+1659, r12vrr_stack+2988, r12vrr_stack+758, r12vrr_stack+1650, r12vrr_stack+2973);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+3036, r12vrr_stack+52, r12vrr_stack+15, NULL, NULL, r12vrr_stack+49);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+3054, r12vrr_stack+1677, r12vrr_stack+3036, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+2979);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1549, r12vrr_stack+3110, r12vrr_stack+3054, r12vrr_stack+767, r12vrr_stack+1677, r12vrr_stack+2988);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+6972, r12vrr_stack+3146, r12vrr_stack+1549, r12vrr_stack+785, r12vrr_stack+3110, r12vrr_stack+3006);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+68, r12vrr_stack+117, r12vrr_stack+58, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+758, r12vrr_stack+204, r12vrr_stack+68, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+3036);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3090, r12vrr_stack+3922, r12vrr_stack+758, r12vrr_stack+821, r12vrr_stack+204, r12vrr_stack+3054);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+7062, r12vrr_stack+3982, r12vrr_stack+3090, r12vrr_stack+851, r12vrr_stack+3922, r12vrr_stack+1549);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+7212, r12vrr_stack+4082, r12vrr_stack+7062, r12vrr_stack+911, r12vrr_stack+3982, r12vrr_stack+6972);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+6972, r12vrr_stack+243, r12vrr_stack+1695, NULL, NULL, r12vrr_stack+58);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1549, r12vrr_stack+142, r12vrr_stack+6972, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+68);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3922, r12vrr_stack+4232, r12vrr_stack+1549, r12vrr_stack+1011, r12vrr_stack+142, r12vrr_stack+758);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+758, r12vrr_stack+4322, r12vrr_stack+3922, r12vrr_stack+1056, r12vrr_stack+4232, r12vrr_stack+3090);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+7422, r12vrr_stack+4472, r12vrr_stack+758, r12vrr_stack+1146, r12vrr_stack+4322, r12vrr_stack+7062);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+7737, r12vrr_stack+4697, r12vrr_stack+7422, r12vrr_stack+1296, r12vrr_stack+4472, r12vrr_stack+7212);

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+983, r12vrr_stack+0, r12vrr_stack+3, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+983, r12vrr_stack+234, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+983, r12vrr_stack+368, r12vrr_stack+358, r12vrr_stack+237, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+0, r12vrr_stack+1695, r12vrr_stack+983, r12vrr_stack+58, r12vrr_stack+368, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+983, r12vrr_stack+378, r12vrr_stack+0, NULL, NULL, r12vrr_stack+1695);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1046, r12vrr_stack+399, r12vrr_stack+983, r12vrr_stack+258, r12vrr_stack+378, r12vrr_stack+6972);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6972, r12vrr_stack+5012, r12vrr_stack+1046, r12vrr_stack+2046, r12vrr_stack+399, r12vrr_stack+1549);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4072, r12vrr_stack+5138, r12vrr_stack+6972, r12vrr_stack+2109, r12vrr_stack+5012, r12vrr_stack+3922);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+6972, r12vrr_stack+5348, r12vrr_stack+4072, r12vrr_stack+2235, r12vrr_stack+5138, r12vrr_stack+758);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+3922, r12vrr_stack+5663, r12vrr_stack+6972, r12vrr_stack+2655, r12vrr_stack+5348, r12vrr_stack+7422);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6972, r12vrr_stack+378, r12vrr_stack+0, r12vrr_stack+243, r12vrr_stack+1695, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7000, r12vrr_stack+21, r12vrr_stack+6972, NULL, NULL, r12vrr_stack+378);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7084, r12vrr_stack+1710, r12vrr_stack+7000, r12vrr_stack+1521, r12vrr_stack+21, r12vrr_stack+399);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7252, r12vrr_stack+6104, r12vrr_stack+7084, r12vrr_stack+3222, r12vrr_stack+1710, r12vrr_stack+5012);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+758, r12vrr_stack+6272, r12vrr_stack+7252, r12vrr_stack+3306, r12vrr_stack+6104, r12vrr_stack+5138);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+6972, r12vrr_stack+6552, r12vrr_stack+758, r12vrr_stack+3642, r12vrr_stack+6272, r12vrr_stack+5348);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+758, &(Data->ss_r12_ss), NULL, r12vrr_stack+279, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+761, r12vrr_stack+758, &(Data->ss_r12_ss), r12vrr_stack+282, r12vrr_stack+279, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+767, r12vrr_stack+761, r12vrr_stack+758, r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+279, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+777, r12vrr_stack+767, r12vrr_stack+761, r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+282, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+792, r12vrr_stack+777, r12vrr_stack+767, r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+288, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+813, r12vrr_stack+792, NULL, r12vrr_stack+1857, r12vrr_stack+1836, NULL, r12vrr_stack+298);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+876, r12vrr_stack+813, r12vrr_stack+792, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+313);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+1002, r12vrr_stack+876, r12vrr_stack+813, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+518);
 tmp = r12vrr_stack + 1002;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+6104, r12vrr_stack+1002, r12vrr_stack+876, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+608);
 tmp = r12vrr_stack + 6104;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+758, r12vrr_stack+2445, r12vrr_stack+3642, r12vrr_stack+2655, r12vrr_stack+1296, r12vrr_stack+608);
 tmp = r12vrr_stack + 758;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5012, r12vrr_stack+2655, r12vrr_stack+6552, r12vrr_stack+5663, r12vrr_stack+4697, r12vrr_stack+1296);
 tmp = r12vrr_stack + 5012;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+5663, r12vrr_stack+6972, r12vrr_stack+3922, r12vrr_stack+7737, r12vrr_stack+4697);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5327, r12vrr_stack+2445, r12vrr_stack+2655, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+1920);
 tmp = r12vrr_stack + 5327;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1521, r12vrr_stack+2655, r12vrr_stack+5663, r12vrr_stack+6552, r12vrr_stack+3642, r12vrr_stack+2445);
 tmp = r12vrr_stack + 1521;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1836, r12vrr_stack+5663, r12vrr_stack+3922, r12vrr_stack+6972, r12vrr_stack+6552, r12vrr_stack+2655);
 tmp = r12vrr_stack + 1836;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+6419, r12vrr_stack+6104, r12vrr_stack+1002, r12vrr_stack+5663, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1296);
 tmp = r12vrr_stack + 6419;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];


}

