/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_fpgd(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+3);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+476, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+479, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+488, r12vrr_stack+6, r12vrr_stack+479, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+476);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+506, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+524, r12vrr_stack+39, r12vrr_stack+506, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+479);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+560, r12vrr_stack+75, r12vrr_stack+524, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+488);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+57, r12vrr_stack+21, r12vrr_stack+3, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+63, r12vrr_stack+210, r12vrr_stack+57, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+620, r12vrr_stack+216, r12vrr_stack+63, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+650, r12vrr_stack+226, r12vrr_stack+620, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+506);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+256, r12vrr_stack+650, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+524);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+376, r12vrr_stack+710, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+560);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+960, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+975, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+990, r12vrr_stack+216, r12vrr_stack+63, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1005, r12vrr_stack+960, r12vrr_stack+990, NULL, NULL, r12vrr_stack+216);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1050, r12vrr_stack+975, r12vrr_stack+960, NULL, NULL, r12vrr_stack+111);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1095, r12vrr_stack+1050, r12vrr_stack+1005, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+226);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1185, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1200, r12vrr_stack+1185, r12vrr_stack+975, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1245, r12vrr_stack+1200, r12vrr_stack+1050, r12vrr_stack+1185, r12vrr_stack+975, r12vrr_stack+131);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+131, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+3, r12vrr_stack+131, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+134, r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+144, r12vrr_stack+63, r12vrr_stack+134, r12vrr_stack+210, r12vrr_stack+57, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1335, r12vrr_stack+990, r12vrr_stack+144, NULL, NULL, r12vrr_stack+63);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1380, r12vrr_stack+1005, r12vrr_stack+1335, r12vrr_stack+960, r12vrr_stack+990, r12vrr_stack+620);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1470, r12vrr_stack+1095, r12vrr_stack+1380, r12vrr_stack+1050, r12vrr_stack+1005, r12vrr_stack+650);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+1245, r12vrr_stack+1095, r12vrr_stack+1200, r12vrr_stack+1050, r12vrr_stack+256);
 tmp = r12vrr_stack + 1620;
 target_ptr = Libr12->gvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1770, r12vrr_stack+1620, r12vrr_stack+1470, r12vrr_stack+1245, r12vrr_stack+1095, r12vrr_stack+710);
 tmp = r12vrr_stack + 1770;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1995, r12vrr_stack+960, r12vrr_stack+990, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2016, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2037, r12vrr_stack+2016, r12vrr_stack+1995, NULL, NULL, r12vrr_stack+960);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2100, r12vrr_stack+1185, r12vrr_stack+975, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2121, r12vrr_stack+2100, r12vrr_stack+2016, NULL, NULL, r12vrr_stack+975);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2184, r12vrr_stack+990, r12vrr_stack+144, r12vrr_stack+216, r12vrr_stack+63, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2205, r12vrr_stack+1995, r12vrr_stack+2184, NULL, NULL, r12vrr_stack+990);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2268, r12vrr_stack+2037, r12vrr_stack+2205, r12vrr_stack+2016, r12vrr_stack+1995, r12vrr_stack+1005);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2394, r12vrr_stack+2121, r12vrr_stack+2037, r12vrr_stack+2100, r12vrr_stack+2016, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2520, r12vrr_stack+2394, r12vrr_stack+2268, r12vrr_stack+2121, r12vrr_stack+2037, r12vrr_stack+1095);
 tmp = r12vrr_stack + 2520;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1050, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+131, r12vrr_stack+1050, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1053, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+131, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1063, r12vrr_stack+134, r12vrr_stack+1053, r12vrr_stack+57, r12vrr_stack+24, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2730, r12vrr_stack+144, r12vrr_stack+1063, r12vrr_stack+63, r12vrr_stack+134, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2751, r12vrr_stack+2184, r12vrr_stack+2730, NULL, NULL, r12vrr_stack+144);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2814, r12vrr_stack+2205, r12vrr_stack+2751, r12vrr_stack+1995, r12vrr_stack+2184, r12vrr_stack+1335);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2940, r12vrr_stack+2268, r12vrr_stack+2814, r12vrr_stack+2037, r12vrr_stack+2205, r12vrr_stack+1380);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3150, r12vrr_stack+2520, r12vrr_stack+2940, r12vrr_stack+2394, r12vrr_stack+2268, r12vrr_stack+1470);
 tmp = r12vrr_stack + 3150;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3465, r12vrr_stack+1995, r12vrr_stack+2184, r12vrr_stack+960, r12vrr_stack+990, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3493, r12vrr_stack+2016, r12vrr_stack+1995, r12vrr_stack+975, r12vrr_stack+960, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3521, r12vrr_stack+3493, r12vrr_stack+3465, NULL, NULL, r12vrr_stack+1995);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3605, r12vrr_stack+2100, r12vrr_stack+2016, r12vrr_stack+1185, r12vrr_stack+975, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3633, r12vrr_stack+3605, r12vrr_stack+3493, NULL, NULL, r12vrr_stack+2016);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+960, r12vrr_stack+2184, r12vrr_stack+2730, r12vrr_stack+990, r12vrr_stack+144, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3717, r12vrr_stack+3465, r12vrr_stack+960, NULL, NULL, r12vrr_stack+2184);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3801, r12vrr_stack+3521, r12vrr_stack+3717, r12vrr_stack+3493, r12vrr_stack+3465, r12vrr_stack+2205);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3969, r12vrr_stack+3633, r12vrr_stack+3521, r12vrr_stack+3605, r12vrr_stack+3493, r12vrr_stack+2037);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4137, r12vrr_stack+3969, r12vrr_stack+3801, r12vrr_stack+3633, r12vrr_stack+3521, r12vrr_stack+2268);
 tmp = r12vrr_stack + 4137;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2037, r12vrr_stack+1050, r12vrr_stack+3, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2043, r12vrr_stack+15, r12vrr_stack+2037, r12vrr_stack+131, r12vrr_stack+1050, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2053, r12vrr_stack+1053, r12vrr_stack+2043, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2068, r12vrr_stack+1063, r12vrr_stack+2053, r12vrr_stack+134, r12vrr_stack+1053, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4417, r12vrr_stack+2730, r12vrr_stack+2068, r12vrr_stack+144, r12vrr_stack+1063, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4445, r12vrr_stack+960, r12vrr_stack+4417, NULL, NULL, r12vrr_stack+2730);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4529, r12vrr_stack+3717, r12vrr_stack+4445, r12vrr_stack+3465, r12vrr_stack+960, r12vrr_stack+2751);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4697, r12vrr_stack+3801, r12vrr_stack+4529, r12vrr_stack+3521, r12vrr_stack+3717, r12vrr_stack+2814);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4977, r12vrr_stack+4137, r12vrr_stack+4697, r12vrr_stack+3969, r12vrr_stack+3801, r12vrr_stack+2940);
 tmp = r12vrr_stack + 4977;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5397, r12vrr_stack+3465, r12vrr_stack+960, r12vrr_stack+1995, r12vrr_stack+2184, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5433, r12vrr_stack+3493, r12vrr_stack+3465, r12vrr_stack+2016, r12vrr_stack+1995, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5469, r12vrr_stack+5433, r12vrr_stack+5397, NULL, NULL, r12vrr_stack+3465);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5577, r12vrr_stack+3605, r12vrr_stack+3493, r12vrr_stack+2100, r12vrr_stack+2016, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5613, r12vrr_stack+5577, r12vrr_stack+5433, NULL, NULL, r12vrr_stack+3493);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3465, r12vrr_stack+960, r12vrr_stack+4417, r12vrr_stack+2184, r12vrr_stack+2730, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5721, r12vrr_stack+5397, r12vrr_stack+3465, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5829, r12vrr_stack+5469, r12vrr_stack+5721, r12vrr_stack+5433, r12vrr_stack+5397, r12vrr_stack+3717);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6045, r12vrr_stack+5613, r12vrr_stack+5469, r12vrr_stack+5577, r12vrr_stack+5433, r12vrr_stack+3521);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6261, r12vrr_stack+6045, r12vrr_stack+5829, r12vrr_stack+5613, r12vrr_stack+5469, r12vrr_stack+3801);
 tmp = r12vrr_stack + 6261;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+5433, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+24, r12vrr_stack+476, r12vrr_stack+5433, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+5436, r12vrr_stack+30, r12vrr_stack+21, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+5445, r12vrr_stack+479, r12vrr_stack+5436, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+5433);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+5577, r12vrr_stack+488, r12vrr_stack+5445, r12vrr_stack+6, r12vrr_stack+479, r12vrr_stack+24);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+476, r12vrr_stack+210, r12vrr_stack+57, NULL, NULL, r12vrr_stack+21);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+5607, r12vrr_stack+506, r12vrr_stack+476, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+5436);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+5643, r12vrr_stack+524, r12vrr_stack+5607, r12vrr_stack+39, r12vrr_stack+506, r12vrr_stack+5445);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+3501, r12vrr_stack+560, r12vrr_stack+5643, r12vrr_stack+75, r12vrr_stack+524, r12vrr_stack+5577);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+5577, r12vrr_stack+63, r12vrr_stack+134, NULL, NULL, r12vrr_stack+57);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+494, r12vrr_stack+620, r12vrr_stack+5577, r12vrr_stack+216, r12vrr_stack+63, r12vrr_stack+476);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+21, r12vrr_stack+650, r12vrr_stack+494, r12vrr_stack+226, r12vrr_stack+620, r12vrr_stack+5607);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+6621, r12vrr_stack+710, r12vrr_stack+21, r12vrr_stack+256, r12vrr_stack+650, r12vrr_stack+5643);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+6771, r12vrr_stack+810, r12vrr_stack+6621, r12vrr_stack+376, r12vrr_stack+710, r12vrr_stack+3501);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+3501, r12vrr_stack+144, r12vrr_stack+1063, NULL, NULL, r12vrr_stack+134);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+5607, r12vrr_stack+1335, r12vrr_stack+3501, r12vrr_stack+990, r12vrr_stack+144, r12vrr_stack+5577);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+554, r12vrr_stack+1380, r12vrr_stack+5607, r12vrr_stack+1005, r12vrr_stack+1335, r12vrr_stack+494);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+6981, r12vrr_stack+1470, r12vrr_stack+554, r12vrr_stack+1095, r12vrr_stack+1380, r12vrr_stack+21);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+7206, r12vrr_stack+1770, r12vrr_stack+6981, r12vrr_stack+1620, r12vrr_stack+1470, r12vrr_stack+6621);
 tmp = r12vrr_stack + 7206;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+6621, r12vrr_stack+2730, r12vrr_stack+2068, NULL, NULL, r12vrr_stack+1063);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+21, r12vrr_stack+2751, r12vrr_stack+6621, r12vrr_stack+2184, r12vrr_stack+2730, r12vrr_stack+3501);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1335, r12vrr_stack+2814, r12vrr_stack+21, r12vrr_stack+2205, r12vrr_stack+2751, r12vrr_stack+5607);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+7521, r12vrr_stack+2940, r12vrr_stack+1335, r12vrr_stack+2268, r12vrr_stack+2814, r12vrr_stack+554);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7836, r12vrr_stack+3150, r12vrr_stack+7521, r12vrr_stack+2520, r12vrr_stack+2940, r12vrr_stack+6981);
 tmp = r12vrr_stack + 7836;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6981, r12vrr_stack+3, r12vrr_stack+0, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+6987, r12vrr_stack+2037, r12vrr_stack+6981, r12vrr_stack+1050, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+2043, r12vrr_stack+6987, r12vrr_stack+15, r12vrr_stack+2037, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+6981, r12vrr_stack+2053, r12vrr_stack+0, r12vrr_stack+1053, r12vrr_stack+2043, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+7002, r12vrr_stack+2068, r12vrr_stack+6981, r12vrr_stack+1063, r12vrr_stack+2053, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7030, r12vrr_stack+4417, r12vrr_stack+7002, NULL, NULL, r12vrr_stack+2068);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2751, r12vrr_stack+4445, r12vrr_stack+7030, r12vrr_stack+960, r12vrr_stack+4417, r12vrr_stack+6621);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+476, r12vrr_stack+4529, r12vrr_stack+2751, r12vrr_stack+3717, r12vrr_stack+4445, r12vrr_stack+21);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+8277, r12vrr_stack+4697, r12vrr_stack+476, r12vrr_stack+3801, r12vrr_stack+4529, r12vrr_stack+1335);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8697, r12vrr_stack+4977, r12vrr_stack+8277, r12vrr_stack+4137, r12vrr_stack+4697, r12vrr_stack+7521);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5433, r12vrr_stack+4417, r12vrr_stack+7002, r12vrr_stack+2730, r12vrr_stack+2068, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2730, r12vrr_stack+3465, r12vrr_stack+5433, NULL, NULL, r12vrr_stack+4417);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2838, r12vrr_stack+5721, r12vrr_stack+2730, r12vrr_stack+5397, r12vrr_stack+3465, r12vrr_stack+4445);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8277, r12vrr_stack+5829, r12vrr_stack+2838, r12vrr_stack+5469, r12vrr_stack+5721, r12vrr_stack+4529);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9285, r12vrr_stack+6261, r12vrr_stack+8277, r12vrr_stack+6045, r12vrr_stack+5829, r12vrr_stack+4697);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+8277, &(Data->ss_r12_ss), NULL, r12vrr_stack+161, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+8280, r12vrr_stack+8277, &(Data->ss_r12_ss), r12vrr_stack+164, r12vrr_stack+161, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+8286, r12vrr_stack+8280, r12vrr_stack+8277, r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+161, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+8296, r12vrr_stack+8286, r12vrr_stack+8280, r12vrr_stack+1185, r12vrr_stack+170, r12vrr_stack+164, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+8311, r12vrr_stack+8296, NULL, r12vrr_stack+1200, r12vrr_stack+1185, NULL, r12vrr_stack+170);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+8356, r12vrr_stack+8311, r12vrr_stack+8296, r12vrr_stack+1245, r12vrr_stack+1200, r12vrr_stack+1185, r12vrr_stack+180);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+6621, r12vrr_stack+8356, r12vrr_stack+8311, r12vrr_stack+1620, r12vrr_stack+1245, r12vrr_stack+1200, r12vrr_stack+316);
 tmp = r12vrr_stack + 6621;
 target_ptr = Libr12->rvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+8311, r12vrr_stack+8296, r12vrr_stack+8286, r12vrr_stack+2100, r12vrr_stack+1185, r12vrr_stack+170, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+8446, r12vrr_stack+8311, NULL, r12vrr_stack+2121, r12vrr_stack+2100, NULL, r12vrr_stack+1185);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+8509, r12vrr_stack+8446, r12vrr_stack+8311, r12vrr_stack+2394, r12vrr_stack+2121, r12vrr_stack+2100, r12vrr_stack+1200);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+2184, r12vrr_stack+8509, r12vrr_stack+8446, r12vrr_stack+2520, r12vrr_stack+2394, r12vrr_stack+2121, r12vrr_stack+1245);
 tmp = r12vrr_stack + 2184;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+8446, r12vrr_stack+8311, r12vrr_stack+8296, r12vrr_stack+3605, r12vrr_stack+2100, r12vrr_stack+1185, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+3465, r12vrr_stack+8446, NULL, r12vrr_stack+3633, r12vrr_stack+3605, NULL, r12vrr_stack+2100);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+5397, r12vrr_stack+3465, r12vrr_stack+8446, r12vrr_stack+3969, r12vrr_stack+3633, r12vrr_stack+3605, r12vrr_stack+2121);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+5565, r12vrr_stack+5397, r12vrr_stack+3465, r12vrr_stack+4137, r12vrr_stack+3969, r12vrr_stack+3633, r12vrr_stack+2394);
 tmp = r12vrr_stack + 5565;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3465, r12vrr_stack+1620, r12vrr_stack+2520, r12vrr_stack+1770, r12vrr_stack+810, r12vrr_stack+376);
 tmp = r12vrr_stack + 3465;
 target_ptr = Libr12->t2vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3615, r12vrr_stack+2520, r12vrr_stack+4137, r12vrr_stack+3150, r12vrr_stack+1770, r12vrr_stack+1620);
 tmp = r12vrr_stack + 3615;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2730, r12vrr_stack+4137, r12vrr_stack+6261, r12vrr_stack+4977, r12vrr_stack+3150, r12vrr_stack+2520);
 tmp = r12vrr_stack + 2730;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6981, r12vrr_stack+1770, r12vrr_stack+3150, r12vrr_stack+7206, r12vrr_stack+6771, r12vrr_stack+810);
 tmp = r12vrr_stack + 6981;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7521, r12vrr_stack+3150, r12vrr_stack+4977, r12vrr_stack+7836, r12vrr_stack+7206, r12vrr_stack+1770);
 tmp = r12vrr_stack + 7521;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4417, r12vrr_stack+4977, r12vrr_stack+9285, r12vrr_stack+8697, r12vrr_stack+7836, r12vrr_stack+3150);
 tmp = r12vrr_stack + 4417;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6771, r12vrr_stack+1620, r12vrr_stack+1770, r12vrr_stack+2520, r12vrr_stack+2394, r12vrr_stack+1245);
 tmp = r12vrr_stack + 6771;
 target_ptr = Libr12->t1vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1335, r12vrr_stack+2520, r12vrr_stack+3150, r12vrr_stack+4137, r12vrr_stack+3969, r12vrr_stack+2394);
 tmp = r12vrr_stack + 1335;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+476, r12vrr_stack+4137, r12vrr_stack+4977, r12vrr_stack+6261, r12vrr_stack+6045, r12vrr_stack+3969);
 tmp = r12vrr_stack + 476;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5845, r12vrr_stack+1770, r12vrr_stack+7206, r12vrr_stack+3150, r12vrr_stack+2520, r12vrr_stack+1620);
 tmp = r12vrr_stack + 5845;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7206, r12vrr_stack+3150, r12vrr_stack+7836, r12vrr_stack+4977, r12vrr_stack+4137, r12vrr_stack+2520);
 tmp = r12vrr_stack + 7206;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7836, r12vrr_stack+4977, r12vrr_stack+8697, r12vrr_stack+9285, r12vrr_stack+6261, r12vrr_stack+4137);
 tmp = r12vrr_stack + 7836;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+8635, r12vrr_stack+6621, r12vrr_stack+8356, r12vrr_stack+1770, r12vrr_stack+1620, r12vrr_stack+1245, r12vrr_stack+376);
 tmp = r12vrr_stack + 8635;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+1770, r12vrr_stack+2184, r12vrr_stack+8509, r12vrr_stack+3150, r12vrr_stack+2520, r12vrr_stack+2394, r12vrr_stack+1620);
 tmp = r12vrr_stack + 1770;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+2085, r12vrr_stack+5565, r12vrr_stack+5397, r12vrr_stack+4977, r12vrr_stack+4137, r12vrr_stack+3969, r12vrr_stack+2520);
 tmp = r12vrr_stack + 2085;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];


}

