/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (d0|hg) integrals */

void d12vrr_order_d0hg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+21, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30, dvrr_stack+6, dvrr_stack+24, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+30, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+65, dvrr_stack+12, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+68, dvrr_stack+15, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+74, dvrr_stack+40, dvrr_stack+68, dvrr_stack+15, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+99, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+102, dvrr_stack+21, dvrr_stack+99, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+108, dvrr_stack+24, dvrr_stack+102, dvrr_stack+0, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+118, dvrr_stack+30, dvrr_stack+108, dvrr_stack+6, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+133, dvrr_stack+50, dvrr_stack+118, dvrr_stack+40, dvrr_stack+30, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+154, dvrr_stack+84, dvrr_stack+50, dvrr_stack+74, dvrr_stack+40, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+175, dvrr_stack+154, dvrr_stack+133, dvrr_stack+84, dvrr_stack+50, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+203, dvrr_stack+0, dvrr_stack+65, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+209, dvrr_stack+203, dvrr_stack+68, dvrr_stack+0, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+219, dvrr_stack+209, dvrr_stack+74, dvrr_stack+203, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+234, dvrr_stack+219, dvrr_stack+84, dvrr_stack+209, dvrr_stack+74, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+255, dvrr_stack+234, dvrr_stack+154, dvrr_stack+219, dvrr_stack+84, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+283, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+286, dvrr_stack+99, dvrr_stack+283, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+292, dvrr_stack+102, dvrr_stack+286, dvrr_stack+21, dvrr_stack+99, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+302, dvrr_stack+108, dvrr_stack+292, dvrr_stack+24, dvrr_stack+102, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+317, dvrr_stack+118, dvrr_stack+302, dvrr_stack+30, dvrr_stack+108, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+338, dvrr_stack+133, dvrr_stack+317, dvrr_stack+50, dvrr_stack+118, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+366, dvrr_stack+175, dvrr_stack+338, dvrr_stack+154, dvrr_stack+133, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+402, dvrr_stack+255, dvrr_stack+175, dvrr_stack+234, dvrr_stack+154, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+438, dvrr_stack+402, dvrr_stack+366, dvrr_stack+255, dvrr_stack+175, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+283, dvrr_stack+21, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+483, dvrr_stack+286, dvrr_stack+24, dvrr_stack+99, dvrr_stack+283, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+493, dvrr_stack+292, dvrr_stack+483, dvrr_stack+102, dvrr_stack+286, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+508, dvrr_stack+302, dvrr_stack+493, dvrr_stack+108, dvrr_stack+292, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+529, dvrr_stack+317, dvrr_stack+508, dvrr_stack+118, dvrr_stack+302, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+557, dvrr_stack+338, dvrr_stack+529, dvrr_stack+133, dvrr_stack+317, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+593, dvrr_stack+366, dvrr_stack+557, dvrr_stack+175, dvrr_stack+338, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+638, dvrr_stack+438, dvrr_stack+593, dvrr_stack+402, dvrr_stack+366, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+99, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+102, dvrr_stack+99, dvrr_stack+0, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+108, dvrr_stack+102, dvrr_stack+203, dvrr_stack+99, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+693, dvrr_stack+108, dvrr_stack+209, dvrr_stack+102, dvrr_stack+203, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+708, dvrr_stack+693, dvrr_stack+219, dvrr_stack+108, dvrr_stack+209, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+729, dvrr_stack+708, dvrr_stack+234, dvrr_stack+693, dvrr_stack+219, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+757, dvrr_stack+729, dvrr_stack+255, dvrr_stack+708, dvrr_stack+234, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+793, dvrr_stack+757, dvrr_stack+402, dvrr_stack+729, dvrr_stack+255, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+838, dvrr_stack+793, dvrr_stack+438, dvrr_stack+757, dvrr_stack+402, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+893, dvrr_stack+838, dvrr_stack+638, NULL, NULL, dvrr_stack+438);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1058, dvrr_stack+366, dvrr_stack+557, NULL, NULL, dvrr_stack+338);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+99, dvrr_stack+21, dvrr_stack+0, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1166, dvrr_stack+24, dvrr_stack+99, dvrr_stack+283, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1176, dvrr_stack+483, dvrr_stack+1166, dvrr_stack+286, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1191, dvrr_stack+493, dvrr_stack+1176, dvrr_stack+292, dvrr_stack+483, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1212, dvrr_stack+508, dvrr_stack+1191, dvrr_stack+302, dvrr_stack+493, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1240, dvrr_stack+529, dvrr_stack+1212, dvrr_stack+317, dvrr_stack+508, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1276, dvrr_stack+557, dvrr_stack+1240, dvrr_stack+338, dvrr_stack+529, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1321, dvrr_stack+593, dvrr_stack+1276, NULL, NULL, dvrr_stack+557);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1456, dvrr_stack+438, dvrr_stack+593, NULL, NULL, dvrr_stack+366);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1591, dvrr_stack+1456, dvrr_stack+1321, dvrr_stack+438, dvrr_stack+593, dvrr_stack+1058);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1861, dvrr_stack+593, dvrr_stack+1276, dvrr_stack+366, dvrr_stack+557, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1916, dvrr_stack+638, dvrr_stack+1861, NULL, NULL, dvrr_stack+593);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+105, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+283, dvrr_stack+0, dvrr_stack+105, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+289, dvrr_stack+99, dvrr_stack+283, dvrr_stack+21, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+299, dvrr_stack+1166, dvrr_stack+289, dvrr_stack+24, dvrr_stack+99, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2081, dvrr_stack+1176, dvrr_stack+299, dvrr_stack+483, dvrr_stack+1166, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2102, dvrr_stack+1191, dvrr_stack+2081, dvrr_stack+493, dvrr_stack+1176, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2130, dvrr_stack+1212, dvrr_stack+2102, dvrr_stack+508, dvrr_stack+1191, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+483, dvrr_stack+1240, dvrr_stack+2130, dvrr_stack+529, dvrr_stack+1212, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2166, dvrr_stack+1276, dvrr_stack+483, dvrr_stack+557, dvrr_stack+1240, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2221, dvrr_stack+1861, dvrr_stack+2166, NULL, NULL, dvrr_stack+1276);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2386, dvrr_stack+1916, dvrr_stack+2221, dvrr_stack+638, dvrr_stack+1861, dvrr_stack+1321);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2716, dvrr_stack+893, dvrr_stack+1916, dvrr_stack+838, dvrr_stack+638, dvrr_stack+1456);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3046, dvrr_stack+2716, dvrr_stack+2386, dvrr_stack+893, dvrr_stack+1916, dvrr_stack+1591);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+3596, dvrr_stack+219, dvrr_stack+84, NULL, NULL, dvrr_stack+74);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+3641, dvrr_stack+234, dvrr_stack+154, NULL, NULL, dvrr_stack+84);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+3704, dvrr_stack+708, dvrr_stack+234, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+3767, dvrr_stack+3704, dvrr_stack+3641, dvrr_stack+708, dvrr_stack+234, dvrr_stack+3596);
 tmp = dvrr_stack + 3767;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3893, dvrr_stack+255, dvrr_stack+175, NULL, NULL, dvrr_stack+154);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3977, dvrr_stack+729, dvrr_stack+255, NULL, NULL, dvrr_stack+234);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4061, dvrr_stack+3977, dvrr_stack+3893, dvrr_stack+729, dvrr_stack+255, dvrr_stack+3641);
 tmp = dvrr_stack + 4061;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+4229,dvrr_stack+4061,dvrr_stack+3767,6);


 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4607, dvrr_stack+402, dvrr_stack+366, NULL, NULL, dvrr_stack+175);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4715, dvrr_stack+757, dvrr_stack+402, NULL, NULL, dvrr_stack+255);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4823, dvrr_stack+4715, dvrr_stack+4607, dvrr_stack+757, dvrr_stack+402, dvrr_stack+3893);
 tmp = dvrr_stack + 4823;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+5039,dvrr_stack+4823,dvrr_stack+4061,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+5543,dvrr_stack+5039,dvrr_stack+4229,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+6299, dvrr_stack+5543, dvrr_stack+3767);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6677, dvrr_stack+793, dvrr_stack+438, NULL, NULL, dvrr_stack+402);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6812, dvrr_stack+6677, dvrr_stack+1456, dvrr_stack+793, dvrr_stack+438, dvrr_stack+4607);
 tmp = dvrr_stack + 6812;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+7082,dvrr_stack+6812,dvrr_stack+4823,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+7730,dvrr_stack+7082,dvrr_stack+5039,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+8738, dvrr_stack+7730, dvrr_stack+4061);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+9242,dvrr_stack+2716,dvrr_stack+6812,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+10052,dvrr_stack+9242,dvrr_stack+7082,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+11348, dvrr_stack+10052, dvrr_stack+4823);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11996, dvrr_stack+638, dvrr_stack+1861, dvrr_stack+438, dvrr_stack+593, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12062, dvrr_stack+838, dvrr_stack+638, dvrr_stack+793, dvrr_stack+438, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12128, dvrr_stack+1861, dvrr_stack+2166, dvrr_stack+593, dvrr_stack+1276, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12194, dvrr_stack+11996, dvrr_stack+12128, NULL, NULL, dvrr_stack+1861);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12392, dvrr_stack+12062, dvrr_stack+11996, NULL, NULL, dvrr_stack+638);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12590, dvrr_stack+12392, dvrr_stack+12194, dvrr_stack+12062, dvrr_stack+11996, dvrr_stack+1916);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+12986,dvrr_stack+12590,dvrr_stack+2716,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+13976,dvrr_stack+12986,dvrr_stack+9242,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+15596, dvrr_stack+13976, dvrr_stack+6812);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+16406, dvrr_stack+11996, dvrr_stack+12128, dvrr_stack+638, dvrr_stack+1861, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+16484, dvrr_stack+12062, dvrr_stack+11996, dvrr_stack+838, dvrr_stack+638, NULL);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+314, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+638, dvrr_stack+105, dvrr_stack+314, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+644, dvrr_stack+283, dvrr_stack+638, dvrr_stack+0, dvrr_stack+105, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+654, dvrr_stack+289, dvrr_stack+644, dvrr_stack+99, dvrr_stack+283, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+669, dvrr_stack+299, dvrr_stack+654, dvrr_stack+1166, dvrr_stack+289, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+638, dvrr_stack+2081, dvrr_stack+669, dvrr_stack+1176, dvrr_stack+299, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12062, dvrr_stack+2102, dvrr_stack+638, dvrr_stack+1191, dvrr_stack+2081, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+438, dvrr_stack+2130, dvrr_stack+12062, dvrr_stack+1212, dvrr_stack+2102, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+638, dvrr_stack+483, dvrr_stack+438, dvrr_stack+1240, dvrr_stack+2130, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12062, dvrr_stack+2166, dvrr_stack+638, dvrr_stack+1276, dvrr_stack+483, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+2081, dvrr_stack+12128, dvrr_stack+12062, dvrr_stack+1861, dvrr_stack+2166, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+16562, dvrr_stack+16406, dvrr_stack+2081, NULL, NULL, dvrr_stack+12128);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+16796, dvrr_stack+16484, dvrr_stack+16406, NULL, NULL, dvrr_stack+11996);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+17030, dvrr_stack+16796, dvrr_stack+16562, dvrr_stack+16484, dvrr_stack+16406, dvrr_stack+12194);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+17498,dvrr_stack+17030,dvrr_stack+12590,6);


 /* compute (2 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+18686,dvrr_stack+17498,dvrr_stack+12986,6);


 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,330,dvrr_stack+20666, dvrr_stack+18686, dvrr_stack+2716);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+16406, dvrr_stack+5543, dvrr_stack+3767);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+21656, dvrr_stack+7730, dvrr_stack+4061);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+22160, dvrr_stack+10052, dvrr_stack+4823);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+22808, dvrr_stack+13976, dvrr_stack+6812);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,330,dvrr_stack+23618, dvrr_stack+18686, dvrr_stack+2716);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+24608, dvrr_stack+5543, dvrr_stack+3767);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+5543, dvrr_stack+7730, dvrr_stack+4061);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+7730, dvrr_stack+10052, dvrr_stack+4823);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+10052, dvrr_stack+13976, dvrr_stack+6812);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,330,dvrr_stack+13976, dvrr_stack+18686, dvrr_stack+2716);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+18686, dvrr_stack+209, dvrr_stack+74, NULL, NULL, dvrr_stack+68);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+438, dvrr_stack+693, dvrr_stack+219, NULL, NULL, dvrr_stack+209);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+18716, dvrr_stack+438, dvrr_stack+3596, dvrr_stack+693, dvrr_stack+219, dvrr_stack+18686);

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+18806,dvrr_stack+3767,dvrr_stack+18716,6);


 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+19076, dvrr_stack+18806, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+19166, dvrr_stack+5039, NULL);
 tmp = dvrr_stack + 19166;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+19334, dvrr_stack+4229, NULL);
 tmp = dvrr_stack + 19334;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+19460, dvrr_stack+7082, NULL);
 tmp = dvrr_stack + 19460;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+19676, dvrr_stack+9242, NULL);
 tmp = dvrr_stack + 19676;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+19946, dvrr_stack+12986, NULL);
 tmp = dvrr_stack + 19946;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+14966, dvrr_stack+17498, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+20276, dvrr_stack+18806, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+20366, dvrr_stack+5039, NULL);
 tmp = dvrr_stack + 20366;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+20534, dvrr_stack+4229, NULL);
 tmp = dvrr_stack + 20534;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+15362, dvrr_stack+7082, NULL);
 tmp = dvrr_stack + 15362;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+10862, dvrr_stack+9242, NULL);
 tmp = dvrr_stack + 10862;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+8378, dvrr_stack+12986, NULL);
 tmp = dvrr_stack + 8378;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+24986, dvrr_stack+17498, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+11132, dvrr_stack+18806, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+18806, dvrr_stack+5039, NULL);
 tmp = dvrr_stack + 18806;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+11222, dvrr_stack+4229, NULL);
 tmp = dvrr_stack + 11222;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+4229, dvrr_stack+7082, NULL);
 tmp = dvrr_stack + 4229;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+7082, dvrr_stack+9242, NULL);
 tmp = dvrr_stack + 7082;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+9242, dvrr_stack+12986, NULL);
 tmp = dvrr_stack + 9242;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+12986, dvrr_stack+17498, NULL);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15578, dvrr_stack+203, dvrr_stack+68, NULL, NULL, dvrr_stack+65);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+8708, dvrr_stack+108, dvrr_stack+209, NULL, NULL, dvrr_stack+203);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+17498, dvrr_stack+8708, dvrr_stack+18686, dvrr_stack+108, dvrr_stack+209, dvrr_stack+15578);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+17558, dvrr_stack+3767, dvrr_stack+17498);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+17648, dvrr_stack+4823, dvrr_stack+3767);
 tmp = dvrr_stack + 17648;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+17816, dvrr_stack+4061, dvrr_stack+18716);
 tmp = dvrr_stack + 17816;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+17942, dvrr_stack+6812, dvrr_stack+4061);
 tmp = dvrr_stack + 17942;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+18158, dvrr_stack+2716, dvrr_stack+4823);
 tmp = dvrr_stack + 18158;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+13382, dvrr_stack+12590, dvrr_stack+6812);
 tmp = dvrr_stack + 13382;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+9572, dvrr_stack+17030, dvrr_stack+2716);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+18428, dvrr_stack+3767, dvrr_stack+17498);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+18518, dvrr_stack+4823, dvrr_stack+3767);
 tmp = dvrr_stack + 18518;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+13712, dvrr_stack+4061, dvrr_stack+18716);
 tmp = dvrr_stack + 13712;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+7352, dvrr_stack+6812, dvrr_stack+4061);
 tmp = dvrr_stack + 7352;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+5039, dvrr_stack+2716, dvrr_stack+4823);
 tmp = dvrr_stack + 5039;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+25382, dvrr_stack+12590, dvrr_stack+6812);
 tmp = dvrr_stack + 25382;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+25712, dvrr_stack+17030, dvrr_stack+2716);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+13838, dvrr_stack+3767, dvrr_stack+17498);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+5309, dvrr_stack+4823, dvrr_stack+3767);
 tmp = dvrr_stack + 5309;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+7568, dvrr_stack+4061, dvrr_stack+18716);
 tmp = dvrr_stack + 7568;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+6047, dvrr_stack+6812, dvrr_stack+4061);
 tmp = dvrr_stack + 6047;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+26108, dvrr_stack+2716, dvrr_stack+4823);
 tmp = dvrr_stack + 26108;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+26378, dvrr_stack+12590, dvrr_stack+6812);
 tmp = dvrr_stack + 26378;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+26708, dvrr_stack+17030, dvrr_stack+2716);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+16784,dvrr_stack+3977,dvrr_stack+3704,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+9968, dvrr_stack+16784, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+8708, dvrr_stack+74, dvrr_stack+40, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+13928, dvrr_stack+84, dvrr_stack+50, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+4445, dvrr_stack+3596, dvrr_stack+13928, dvrr_stack+219, dvrr_stack+84, dvrr_stack+8708);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+4535, dvrr_stack+154, dvrr_stack+133, NULL, NULL, dvrr_stack+50);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+16973, dvrr_stack+3641, dvrr_stack+4535, dvrr_stack+234, dvrr_stack+154, dvrr_stack+13928);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+17099, dvrr_stack+3767, dvrr_stack+16973, dvrr_stack+3704, dvrr_stack+3641, dvrr_stack+4445);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+18974, dvrr_stack+175, dvrr_stack+338, NULL, NULL, dvrr_stack+133);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+17309, dvrr_stack+3893, dvrr_stack+18974, dvrr_stack+255, dvrr_stack+175, dvrr_stack+4535);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+27104, dvrr_stack+4061, dvrr_stack+17309, dvrr_stack+3977, dvrr_stack+3893, dvrr_stack+16973);

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+27384,dvrr_stack+27104,dvrr_stack+17099,10);


 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+28014, dvrr_stack+27384, NULL);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+28224,dvrr_stack+4715,dvrr_stack+3977,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+219, dvrr_stack+28224, NULL);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28476, dvrr_stack+4607, dvrr_stack+1058, dvrr_stack+402, dvrr_stack+366, dvrr_stack+18974);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28692, dvrr_stack+4823, dvrr_stack+28476, dvrr_stack+4715, dvrr_stack+4607, dvrr_stack+17309);

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+29052,dvrr_stack+28692,dvrr_stack+27104,10);


 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+29892, dvrr_stack+29052, NULL);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+30172,dvrr_stack+6677,dvrr_stack+4715,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+30496, dvrr_stack+30172, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30604, dvrr_stack+6812, dvrr_stack+1591, dvrr_stack+6677, dvrr_stack+1456, dvrr_stack+28476);

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+31054,dvrr_stack+30604,dvrr_stack+28692,10);


 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+32134, dvrr_stack+31054, NULL);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+32494,dvrr_stack+893,dvrr_stack+6677,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+32899, dvrr_stack+32494, NULL);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+33034,dvrr_stack+3046,dvrr_stack+30604,10);


 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+34384, dvrr_stack+33034, NULL);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+34834,dvrr_stack+12392,dvrr_stack+893,3);


 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+35329, dvrr_stack+34834, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35494, dvrr_stack+12128, dvrr_stack+12062, NULL, NULL, dvrr_stack+2166);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35692, dvrr_stack+12194, dvrr_stack+35494, dvrr_stack+11996, dvrr_stack+12128, dvrr_stack+2221);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+36088, dvrr_stack+12590, dvrr_stack+35692, dvrr_stack+12392, dvrr_stack+12194, dvrr_stack+2386);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+36748,dvrr_stack+36088,dvrr_stack+3046,10);


 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+35494, dvrr_stack+36748, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+12590, dvrr_stack+16784, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+12653, dvrr_stack+27384, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+12863, dvrr_stack+28224, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+11996, dvrr_stack+29052, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+12276, dvrr_stack+30172, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+38398, dvrr_stack+31054, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+38758, dvrr_stack+32494, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+38893, dvrr_stack+33034, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+39343, dvrr_stack+34834, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+39508, dvrr_stack+36748, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+5477, dvrr_stack+16784, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+40058, dvrr_stack+27384, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+27384, dvrr_stack+28224, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+27468, dvrr_stack+29052, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+29052, dvrr_stack+30172, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+29160, dvrr_stack+31054, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+31054, dvrr_stack+32494, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+31189, dvrr_stack+33034, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+33034, dvrr_stack+34834, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+33199, dvrr_stack+36748, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+36748, dvrr_stack+3977, dvrr_stack+438);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15578, dvrr_stack+68, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+36811, dvrr_stack+18686, dvrr_stack+8708, dvrr_stack+209, dvrr_stack+74, dvrr_stack+15578);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+36871, dvrr_stack+18716, dvrr_stack+4445, dvrr_stack+438, dvrr_stack+3596, dvrr_stack+36811);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+37021, dvrr_stack+27104, dvrr_stack+36871);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+18686, dvrr_stack+4715, dvrr_stack+3704);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+37231, dvrr_stack+28692, dvrr_stack+17099);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+37511, dvrr_stack+6677, dvrr_stack+3977);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+37619, dvrr_stack+30604, dvrr_stack+27104);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+37979, dvrr_stack+893, dvrr_stack+4715);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+34834, dvrr_stack+3046, dvrr_stack+28692);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+38114, dvrr_stack+12392, dvrr_stack+6677);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+33749, dvrr_stack+36088, dvrr_stack+30604);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+38279, dvrr_stack+3977, dvrr_stack+438);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+32494, dvrr_stack+27104, dvrr_stack+36871);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+34299, dvrr_stack+4715, dvrr_stack+3704);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+31639, dvrr_stack+28692, dvrr_stack+17099);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+32704, dvrr_stack+6677, dvrr_stack+3977);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+29520, dvrr_stack+30604, dvrr_stack+27104);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+31919, dvrr_stack+893, dvrr_stack+4715);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+40268, dvrr_stack+3046, dvrr_stack+28692);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+30172, dvrr_stack+12392, dvrr_stack+6677);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+40718, dvrr_stack+36088, dvrr_stack+30604);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+32812, dvrr_stack+3977, dvrr_stack+438);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+28224, dvrr_stack+27104, dvrr_stack+36871);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+36811, dvrr_stack+4715, dvrr_stack+3704);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+41268, dvrr_stack+28692, dvrr_stack+17099);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+36895, dvrr_stack+6677, dvrr_stack+3977);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+41548, dvrr_stack+30604, dvrr_stack+27104);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+30337, dvrr_stack+893, dvrr_stack+4715);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+41908, dvrr_stack+3046, dvrr_stack+28692);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+27748, dvrr_stack+12392, dvrr_stack+6677);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+42358, dvrr_stack+36088, dvrr_stack+30604);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+32054, dvrr_stack+3767, dvrr_stack+708);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+37003, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+18770, dvrr_stack+40, dvrr_stack+30, NULL, NULL, dvrr_stack+6);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+27913, dvrr_stack+8708, dvrr_stack+18770, dvrr_stack+74, dvrr_stack+40, dvrr_stack+37003);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+35284, dvrr_stack+50, dvrr_stack+118, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+16784, dvrr_stack+13928, dvrr_stack+35284, dvrr_stack+84, dvrr_stack+50, dvrr_stack+18770);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+12384, dvrr_stack+4445, dvrr_stack+16784, dvrr_stack+3596, dvrr_stack+13928, dvrr_stack+27913);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+27913, dvrr_stack+133, dvrr_stack+317, NULL, NULL, dvrr_stack+118);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+36044, dvrr_stack+4535, dvrr_stack+27913, dvrr_stack+154, dvrr_stack+133, dvrr_stack+35284);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+36170, dvrr_stack+16973, dvrr_stack+36044, dvrr_stack+3641, dvrr_stack+4535, dvrr_stack+16784);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+36380, dvrr_stack+17099, dvrr_stack+36170, dvrr_stack+3767, dvrr_stack+16973, dvrr_stack+12384);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+16784, dvrr_stack+36380, dvrr_stack+3767);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+12384, dvrr_stack+4061, dvrr_stack+729);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+12468, dvrr_stack+338, dvrr_stack+529, NULL, NULL, dvrr_stack+317);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+0, dvrr_stack+18974, dvrr_stack+12468, dvrr_stack+175, dvrr_stack+338, dvrr_stack+27913);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+42908, dvrr_stack+17309, dvrr_stack+0, dvrr_stack+3893, dvrr_stack+18974, dvrr_stack+36044);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+43188, dvrr_stack+27104, dvrr_stack+42908, dvrr_stack+4061, dvrr_stack+17309, dvrr_stack+36170);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+36044, dvrr_stack+43188, dvrr_stack+4061);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+3596, dvrr_stack+4823, dvrr_stack+757);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+17309, dvrr_stack+557, dvrr_stack+1240, NULL, NULL, dvrr_stack+529);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43608, dvrr_stack+1058, dvrr_stack+17309, dvrr_stack+366, dvrr_stack+557, dvrr_stack+12468);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43824, dvrr_stack+28476, dvrr_stack+43608, dvrr_stack+4607, dvrr_stack+1058, dvrr_stack+0);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+44184, dvrr_stack+28692, dvrr_stack+43824, dvrr_stack+4823, dvrr_stack+28476, dvrr_stack+42908);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+44724, dvrr_stack+44184, dvrr_stack+4823);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+42908, dvrr_stack+6812, dvrr_stack+793);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+43043, dvrr_stack+1276, dvrr_stack+483, NULL, NULL, dvrr_stack+1240);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4445, dvrr_stack+1321, dvrr_stack+43043, dvrr_stack+593, dvrr_stack+1276, dvrr_stack+17309);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+45084, dvrr_stack+1591, dvrr_stack+4445, dvrr_stack+1456, dvrr_stack+1321, dvrr_stack+43608);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+45534, dvrr_stack+30604, dvrr_stack+45084, dvrr_stack+6812, dvrr_stack+1591, dvrr_stack+43824);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+43608, dvrr_stack+45534, dvrr_stack+6812);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+17309, dvrr_stack+2716, dvrr_stack+838);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+2166, dvrr_stack+638, NULL, NULL, dvrr_stack+483);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1058, dvrr_stack+2221, dvrr_stack+0, dvrr_stack+1861, dvrr_stack+2166, dvrr_stack+43043);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+46209, dvrr_stack+2386, dvrr_stack+1058, dvrr_stack+1916, dvrr_stack+2221, dvrr_stack+4445);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1058, dvrr_stack+3046, dvrr_stack+46209, dvrr_stack+2716, dvrr_stack+2386, dvrr_stack+45084);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+46209, dvrr_stack+1058, dvrr_stack+2716);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+45084, dvrr_stack+3767, dvrr_stack+708);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+45147, dvrr_stack+36380, dvrr_stack+3767);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+17474, dvrr_stack+4061, dvrr_stack+729);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+1883, dvrr_stack+43188, dvrr_stack+4061);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+45357, dvrr_stack+4823, dvrr_stack+757);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+2163, dvrr_stack+44184, dvrr_stack+4823);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+46759, dvrr_stack+6812, dvrr_stack+793);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+46894, dvrr_stack+45534, dvrr_stack+6812);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+47344, dvrr_stack+2716, dvrr_stack+838);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+47509, dvrr_stack+1058, dvrr_stack+2716);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+45465, dvrr_stack+3767, dvrr_stack+708);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+48059, dvrr_stack+36380, dvrr_stack+3767);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+3767, dvrr_stack+4061, dvrr_stack+729);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+48269, dvrr_stack+43188, dvrr_stack+4061);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+4061, dvrr_stack+4823, dvrr_stack+757);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+48549, dvrr_stack+44184, dvrr_stack+4823);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+4823, dvrr_stack+6812, dvrr_stack+793);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+43043, dvrr_stack+45534, dvrr_stack+6812);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+6812, dvrr_stack+2716, dvrr_stack+838);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+45528, dvrr_stack+1058, dvrr_stack+2716);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+1058, dvrr_stack+3046, dvrr_stack+893);
 tmp = dvrr_stack + 1058;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+1388, dvrr_stack+3046, dvrr_stack+893);
 tmp = dvrr_stack + 1388;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+2523, dvrr_stack+3046, dvrr_stack+893);
 tmp = dvrr_stack + 2523;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+3851, dvrr_stack+6299, NULL);
 tmp = dvrr_stack + 3851;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+4445, dvrr_stack+8738, NULL);
 tmp = dvrr_stack + 4445;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+2853, dvrr_stack+11348, NULL);
 tmp = dvrr_stack + 2853;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+3069, dvrr_stack+15596, NULL);
 tmp = dvrr_stack + 3069;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,330,dvrr_stack+44058, dvrr_stack+20666, NULL);
 tmp = dvrr_stack + 44058;
 target_ptr = Libderiv->deriv2_classes[2][9][143];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+1718, dvrr_stack+6299, NULL);
 tmp = dvrr_stack + 1718;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+3339, dvrr_stack+8738, NULL);
 tmp = dvrr_stack + 3339;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+0, dvrr_stack+11348, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+44388, dvrr_stack+15596, NULL);
 tmp = dvrr_stack + 44388;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,330,dvrr_stack+36324, dvrr_stack+20666, NULL);
 tmp = dvrr_stack + 36324;
 target_ptr = Libderiv->deriv2_classes[2][9][131];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+46078, dvrr_stack+16406, NULL);
 tmp = dvrr_stack + 46078;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+28434, dvrr_stack+21656, NULL);
 tmp = dvrr_stack + 28434;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+303, dvrr_stack+22160, NULL);
 tmp = dvrr_stack + 303;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+519, dvrr_stack+22808, NULL);
 tmp = dvrr_stack + 519;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+48909, dvrr_stack+23618, NULL);
 tmp = dvrr_stack + 48909;
 target_ptr = Libderiv->deriv2_classes[2][9][130];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+49239, dvrr_stack+6299, NULL);
 tmp = dvrr_stack + 49239;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+49365, dvrr_stack+8738, NULL);
 tmp = dvrr_stack + 49365;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+49533, dvrr_stack+11348, NULL);
 tmp = dvrr_stack + 49533;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+11348, dvrr_stack+15596, NULL);
 tmp = dvrr_stack + 11348;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,330,dvrr_stack+11618, dvrr_stack+20666, NULL);
 tmp = dvrr_stack + 11618;
 target_ptr = Libderiv->deriv2_classes[2][9][119];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+49749, dvrr_stack+16406, NULL);
 tmp = dvrr_stack + 49749;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+8708, dvrr_stack+21656, NULL);
 tmp = dvrr_stack + 8708;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+8876, dvrr_stack+22160, NULL);
 tmp = dvrr_stack + 8876;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+15578, dvrr_stack+22808, NULL);
 tmp = dvrr_stack + 15578;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+15848, dvrr_stack+23618, NULL);
 tmp = dvrr_stack + 15848;
 target_ptr = Libderiv->deriv2_classes[2][9][118];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+49875, dvrr_stack+24608, NULL);
 tmp = dvrr_stack + 49875;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+50001, dvrr_stack+5543, NULL);
 tmp = dvrr_stack + 50001;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+50169, dvrr_stack+7730, NULL);
 tmp = dvrr_stack + 50169;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+16178, dvrr_stack+10052, NULL);
 tmp = dvrr_stack + 16178;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+16448, dvrr_stack+13976, NULL);
 tmp = dvrr_stack + 16448;
 target_ptr = Libderiv->deriv2_classes[2][9][117];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+13928, dvrr_stack+19166, dvrr_stack+19076);
 tmp = dvrr_stack + 13928;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+14054, dvrr_stack+19460, dvrr_stack+19334);
 tmp = dvrr_stack + 14054;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+14222, dvrr_stack+19676, dvrr_stack+19166);
 tmp = dvrr_stack + 14222;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+14438, dvrr_stack+19946, dvrr_stack+19460);
 tmp = dvrr_stack + 14438;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+10031, dvrr_stack+14966, dvrr_stack+19676);
 tmp = dvrr_stack + 10031;
 target_ptr = Libderiv->deriv2_classes[2][9][107];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+14708, dvrr_stack+20366, dvrr_stack+20276);
 tmp = dvrr_stack + 14708;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+789, dvrr_stack+15362, dvrr_stack+20534);
 tmp = dvrr_stack + 789;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+10361, dvrr_stack+10862, dvrr_stack+20366);
 tmp = dvrr_stack + 10361;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+10577, dvrr_stack+8378, dvrr_stack+15362);
 tmp = dvrr_stack + 10577;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+7694, dvrr_stack+24986, dvrr_stack+10862);
 tmp = dvrr_stack + 7694;
 target_ptr = Libderiv->deriv2_classes[2][9][106];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+14834, dvrr_stack+18806, dvrr_stack+11132);
 tmp = dvrr_stack + 14834;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+8024, dvrr_stack+4229, dvrr_stack+11222);
 tmp = dvrr_stack + 8024;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+5540, dvrr_stack+7082, dvrr_stack+18806);
 tmp = dvrr_stack + 5540;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+5756, dvrr_stack+9242, dvrr_stack+4229);
 tmp = dvrr_stack + 5756;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+20660, dvrr_stack+12986, dvrr_stack+7082);
 tmp = dvrr_stack + 20660;
 target_ptr = Libderiv->deriv2_classes[2][9][105];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+9092, dvrr_stack+17648, dvrr_stack+17558);
 tmp = dvrr_stack + 9092;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+8192, dvrr_stack+17942, dvrr_stack+17816);
 tmp = dvrr_stack + 8192;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+20990, dvrr_stack+18158, dvrr_stack+17648);
 tmp = dvrr_stack + 20990;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+21206, dvrr_stack+13382, dvrr_stack+17942);
 tmp = dvrr_stack + 21206;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+21476, dvrr_stack+9572, dvrr_stack+18158);
 tmp = dvrr_stack + 21476;
 target_ptr = Libderiv->deriv2_classes[2][9][104];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+21806, dvrr_stack+19166, dvrr_stack+19076);
 tmp = dvrr_stack + 21806;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+21932, dvrr_stack+19460, dvrr_stack+19334);
 tmp = dvrr_stack + 21932;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+22100, dvrr_stack+19676, dvrr_stack+19166);
 tmp = dvrr_stack + 22100;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+22316, dvrr_stack+19946, dvrr_stack+19460);
 tmp = dvrr_stack + 22316;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+22586, dvrr_stack+14966, dvrr_stack+19676);
 tmp = dvrr_stack + 22586;
 target_ptr = Libderiv->deriv2_classes[2][9][95];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+22916, dvrr_stack+20366, dvrr_stack+20276);
 tmp = dvrr_stack + 22916;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+23042, dvrr_stack+15362, dvrr_stack+20534);
 tmp = dvrr_stack + 23042;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+23210, dvrr_stack+10862, dvrr_stack+20366);
 tmp = dvrr_stack + 23210;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+23426, dvrr_stack+8378, dvrr_stack+15362);
 tmp = dvrr_stack + 23426;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+23696, dvrr_stack+24986, dvrr_stack+10862);
 tmp = dvrr_stack + 23696;
 target_ptr = Libderiv->deriv2_classes[2][9][94];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+24026, dvrr_stack+18806, dvrr_stack+11132);
 tmp = dvrr_stack + 24026;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+24152, dvrr_stack+4229, dvrr_stack+11222);
 tmp = dvrr_stack + 24152;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+24320, dvrr_stack+7082, dvrr_stack+18806);
 tmp = dvrr_stack + 24320;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+24536, dvrr_stack+9242, dvrr_stack+4229);
 tmp = dvrr_stack + 24536;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+6263, dvrr_stack+12986, dvrr_stack+7082);
 tmp = dvrr_stack + 6263;
 target_ptr = Libderiv->deriv2_classes[2][9][93];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+24806, dvrr_stack+17648, dvrr_stack+17558);
 tmp = dvrr_stack + 24806;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+50385, dvrr_stack+17942, dvrr_stack+17816);
 tmp = dvrr_stack + 50385;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+50553, dvrr_stack+18158, dvrr_stack+17648);
 tmp = dvrr_stack + 50553;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+50769, dvrr_stack+13382, dvrr_stack+17942);
 tmp = dvrr_stack + 50769;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+51039, dvrr_stack+9572, dvrr_stack+18158);
 tmp = dvrr_stack + 51039;
 target_ptr = Libderiv->deriv2_classes[2][9][92];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+51369, dvrr_stack+18518, dvrr_stack+18428);
 tmp = dvrr_stack + 51369;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+51495, dvrr_stack+7352, dvrr_stack+13712);
 tmp = dvrr_stack + 51495;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+51663, dvrr_stack+5039, dvrr_stack+18518);
 tmp = dvrr_stack + 51663;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+51879, dvrr_stack+25382, dvrr_stack+7352);
 tmp = dvrr_stack + 51879;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+52149, dvrr_stack+25712, dvrr_stack+5039);
 tmp = dvrr_stack + 52149;
 target_ptr = Libderiv->deriv2_classes[2][9][91];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+52479, dvrr_stack+19166, dvrr_stack+19076);
 tmp = dvrr_stack + 52479;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+52605, dvrr_stack+19460, dvrr_stack+19334);
 tmp = dvrr_stack + 52605;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+52773, dvrr_stack+19676, dvrr_stack+19166);
 tmp = dvrr_stack + 52773;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+52989, dvrr_stack+19946, dvrr_stack+19460);
 tmp = dvrr_stack + 52989;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+19946, dvrr_stack+14966, dvrr_stack+19676);
 tmp = dvrr_stack + 19946;
 target_ptr = Libderiv->deriv2_classes[2][9][83];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+53259, dvrr_stack+20366, dvrr_stack+20276);
 tmp = dvrr_stack + 53259;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+18974, dvrr_stack+15362, dvrr_stack+20534);
 tmp = dvrr_stack + 18974;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+19142, dvrr_stack+10862, dvrr_stack+20366);
 tmp = dvrr_stack + 19142;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+20276, dvrr_stack+8378, dvrr_stack+15362);
 tmp = dvrr_stack + 20276;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+19358, dvrr_stack+24986, dvrr_stack+10862);
 tmp = dvrr_stack + 19358;
 target_ptr = Libderiv->deriv2_classes[2][9][82];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+19688, dvrr_stack+18806, dvrr_stack+11132);
 tmp = dvrr_stack + 19688;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+14960, dvrr_stack+4229, dvrr_stack+11222);
 tmp = dvrr_stack + 14960;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+15128, dvrr_stack+7082, dvrr_stack+18806);
 tmp = dvrr_stack + 15128;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+10847, dvrr_stack+9242, dvrr_stack+4229);
 tmp = dvrr_stack + 10847;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+9218, dvrr_stack+12986, dvrr_stack+7082);
 tmp = dvrr_stack + 9218;
 target_ptr = Libderiv->deriv2_classes[2][9][81];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+6977, dvrr_stack+17648, dvrr_stack+17558);
 tmp = dvrr_stack + 6977;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+7103, dvrr_stack+17942, dvrr_stack+17816);
 tmp = dvrr_stack + 7103;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+4169, dvrr_stack+18158, dvrr_stack+17648);
 tmp = dvrr_stack + 4169;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+17558, dvrr_stack+13382, dvrr_stack+17942);
 tmp = dvrr_stack + 17558;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+17828, dvrr_stack+9572, dvrr_stack+18158);
 tmp = dvrr_stack + 17828;
 target_ptr = Libderiv->deriv2_classes[2][9][80];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+18158, dvrr_stack+18518, dvrr_stack+18428);
 tmp = dvrr_stack + 18158;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+18284, dvrr_stack+7352, dvrr_stack+13712);
 tmp = dvrr_stack + 18284;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+15344, dvrr_stack+5039, dvrr_stack+18518);
 tmp = dvrr_stack + 15344;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+9548, dvrr_stack+25382, dvrr_stack+7352);
 tmp = dvrr_stack + 9548;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+12947, dvrr_stack+25712, dvrr_stack+5039);
 tmp = dvrr_stack + 12947;
 target_ptr = Libderiv->deriv2_classes[2][9][79];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+18452, dvrr_stack+5309, dvrr_stack+13838);
 tmp = dvrr_stack + 18452;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+7271, dvrr_stack+6047, dvrr_stack+7568);
 tmp = dvrr_stack + 7271;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+7439, dvrr_stack+26108, dvrr_stack+5309);
 tmp = dvrr_stack + 7439;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+4958, dvrr_stack+26378, dvrr_stack+6047);
 tmp = dvrr_stack + 4958;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+26378, dvrr_stack+26708, dvrr_stack+26108);
 tmp = dvrr_stack + 26378;
 target_ptr = Libderiv->deriv2_classes[2][9][78];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+26708, dvrr_stack+28014, dvrr_stack+9968);
 tmp = dvrr_stack + 26708;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+26834, dvrr_stack+29892, dvrr_stack+219);
 tmp = dvrr_stack + 26834;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+5228, dvrr_stack+32134, dvrr_stack+30496);
 tmp = dvrr_stack + 5228;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+13277, dvrr_stack+34384, dvrr_stack+32899);
 tmp = dvrr_stack + 13277;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,55,dvrr_stack+13547, dvrr_stack+35494, dvrr_stack+35329);
 tmp = dvrr_stack + 13547;
 target_ptr = Libderiv->deriv2_classes[2][9][35];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+19814, dvrr_stack+12653, dvrr_stack+12590);
 tmp = dvrr_stack + 19814;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+18770, dvrr_stack+11996, dvrr_stack+12863);
 tmp = dvrr_stack + 18770;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+11117, dvrr_stack+38398, dvrr_stack+12276);
 tmp = dvrr_stack + 11117;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+8360, dvrr_stack+38893, dvrr_stack+38758);
 tmp = dvrr_stack + 8360;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+24932, dvrr_stack+39508, dvrr_stack+39343);
 tmp = dvrr_stack + 24932;
 target_ptr = Libderiv->deriv2_classes[2][9][34];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+9818, dvrr_stack+40058, dvrr_stack+5477);
 tmp = dvrr_stack + 9818;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+6026, dvrr_stack+27468, dvrr_stack+27384);
 tmp = dvrr_stack + 6026;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+25262, dvrr_stack+29160, dvrr_stack+29052);
 tmp = dvrr_stack + 25262;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+25478, dvrr_stack+31189, dvrr_stack+31054);
 tmp = dvrr_stack + 25478;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+25748, dvrr_stack+33199, dvrr_stack+33034);
 tmp = dvrr_stack + 25748;
 target_ptr = Libderiv->deriv2_classes[2][9][33];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+26078, dvrr_stack+37021, dvrr_stack+36748);
 tmp = dvrr_stack + 26078;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+26204, dvrr_stack+37231, dvrr_stack+18686);
 tmp = dvrr_stack + 26204;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+53385, dvrr_stack+37619, dvrr_stack+37511);
 tmp = dvrr_stack + 53385;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+53601, dvrr_stack+34834, dvrr_stack+37979);
 tmp = dvrr_stack + 53601;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+53871, dvrr_stack+33749, dvrr_stack+38114);
 tmp = dvrr_stack + 53871;
 target_ptr = Libderiv->deriv2_classes[2][9][32];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+54201, dvrr_stack+32494, dvrr_stack+38279);
 tmp = dvrr_stack + 54201;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+54327, dvrr_stack+31639, dvrr_stack+34299);
 tmp = dvrr_stack + 54327;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+54495, dvrr_stack+29520, dvrr_stack+32704);
 tmp = dvrr_stack + 54495;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+54711, dvrr_stack+40268, dvrr_stack+31919);
 tmp = dvrr_stack + 54711;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+54981, dvrr_stack+40718, dvrr_stack+30172);
 tmp = dvrr_stack + 54981;
 target_ptr = Libderiv->deriv2_classes[2][9][31];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+55311, dvrr_stack+17099, dvrr_stack+3704);
 tmp = dvrr_stack + 55311;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+55437, dvrr_stack+28224, dvrr_stack+32812);
 tmp = dvrr_stack + 55437;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+55563, dvrr_stack+27104, dvrr_stack+3977);
 tmp = dvrr_stack + 55563;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+55731, dvrr_stack+41268, dvrr_stack+36811);
 tmp = dvrr_stack + 55731;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+55899, dvrr_stack+28692, dvrr_stack+4715);
 tmp = dvrr_stack + 55899;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+56115, dvrr_stack+41548, dvrr_stack+36895);
 tmp = dvrr_stack + 56115;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+56331, dvrr_stack+30604, dvrr_stack+6677);
 tmp = dvrr_stack + 56331;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+56601, dvrr_stack+41908, dvrr_stack+30337);
 tmp = dvrr_stack + 56601;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+56871, dvrr_stack+42358, dvrr_stack+27748);
 tmp = dvrr_stack + 56871;
 target_ptr = Libderiv->deriv2_classes[2][9][30];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+57201, dvrr_stack+16784, dvrr_stack+32054);
 tmp = dvrr_stack + 57201;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+57327, dvrr_stack+36044, dvrr_stack+12384);
 tmp = dvrr_stack + 57327;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+57495, dvrr_stack+44724, dvrr_stack+3596);
 tmp = dvrr_stack + 57495;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+57711, dvrr_stack+43608, dvrr_stack+42908);
 tmp = dvrr_stack + 57711;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+57981, dvrr_stack+46209, dvrr_stack+17309);
 tmp = dvrr_stack + 57981;
 target_ptr = Libderiv->deriv2_classes[2][9][26];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+58311, dvrr_stack+28014, dvrr_stack+9968);
 tmp = dvrr_stack + 58311;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+58437, dvrr_stack+29892, dvrr_stack+219);
 tmp = dvrr_stack + 58437;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+58605, dvrr_stack+32134, dvrr_stack+30496);
 tmp = dvrr_stack + 58605;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+58821, dvrr_stack+34384, dvrr_stack+32899);
 tmp = dvrr_stack + 58821;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,55,dvrr_stack+59091, dvrr_stack+35494, dvrr_stack+35329);
 tmp = dvrr_stack + 59091;
 target_ptr = Libderiv->deriv2_classes[2][9][23];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+59421, dvrr_stack+12653, dvrr_stack+12590);
 tmp = dvrr_stack + 59421;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+59547, dvrr_stack+11996, dvrr_stack+12863);
 tmp = dvrr_stack + 59547;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+59715, dvrr_stack+38398, dvrr_stack+12276);
 tmp = dvrr_stack + 59715;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+59931, dvrr_stack+38893, dvrr_stack+38758);
 tmp = dvrr_stack + 59931;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+60201, dvrr_stack+39508, dvrr_stack+39343);
 tmp = dvrr_stack + 60201;
 target_ptr = Libderiv->deriv2_classes[2][9][22];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+60531, dvrr_stack+40058, dvrr_stack+5477);
 tmp = dvrr_stack + 60531;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+60657, dvrr_stack+27468, dvrr_stack+27384);
 tmp = dvrr_stack + 60657;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+60825, dvrr_stack+29160, dvrr_stack+29052);
 tmp = dvrr_stack + 60825;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+61041, dvrr_stack+31189, dvrr_stack+31054);
 tmp = dvrr_stack + 61041;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+61311, dvrr_stack+33199, dvrr_stack+33034);
 tmp = dvrr_stack + 61311;
 target_ptr = Libderiv->deriv2_classes[2][9][21];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+61641, dvrr_stack+37021, dvrr_stack+36748);
 tmp = dvrr_stack + 61641;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+61767, dvrr_stack+37231, dvrr_stack+18686);
 tmp = dvrr_stack + 61767;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+61935, dvrr_stack+37619, dvrr_stack+37511);
 tmp = dvrr_stack + 61935;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+62151, dvrr_stack+34834, dvrr_stack+37979);
 tmp = dvrr_stack + 62151;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+62421, dvrr_stack+33749, dvrr_stack+38114);
 tmp = dvrr_stack + 62421;
 target_ptr = Libderiv->deriv2_classes[2][9][20];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+62751, dvrr_stack+32494, dvrr_stack+38279);
 tmp = dvrr_stack + 62751;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+62877, dvrr_stack+31639, dvrr_stack+34299);
 tmp = dvrr_stack + 62877;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+63045, dvrr_stack+29520, dvrr_stack+32704);
 tmp = dvrr_stack + 63045;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+63261, dvrr_stack+40268, dvrr_stack+31919);
 tmp = dvrr_stack + 63261;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+63531, dvrr_stack+40718, dvrr_stack+30172);
 tmp = dvrr_stack + 63531;
 target_ptr = Libderiv->deriv2_classes[2][9][19];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+63861, dvrr_stack+17099, dvrr_stack+3704);
 tmp = dvrr_stack + 63861;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+63987, dvrr_stack+28224, dvrr_stack+32812);
 tmp = dvrr_stack + 63987;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+64113, dvrr_stack+27104, dvrr_stack+3977);
 tmp = dvrr_stack + 64113;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+64281, dvrr_stack+41268, dvrr_stack+36811);
 tmp = dvrr_stack + 64281;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+64449, dvrr_stack+28692, dvrr_stack+4715);
 tmp = dvrr_stack + 64449;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+64665, dvrr_stack+41548, dvrr_stack+36895);
 tmp = dvrr_stack + 64665;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+64881, dvrr_stack+30604, dvrr_stack+6677);
 tmp = dvrr_stack + 64881;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+65151, dvrr_stack+41908, dvrr_stack+30337);
 tmp = dvrr_stack + 65151;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+65421, dvrr_stack+42358, dvrr_stack+27748);
 tmp = dvrr_stack + 65421;
 target_ptr = Libderiv->deriv2_classes[2][9][18];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+65751, dvrr_stack+16784, dvrr_stack+32054);
 tmp = dvrr_stack + 65751;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+65877, dvrr_stack+36044, dvrr_stack+12384);
 tmp = dvrr_stack + 65877;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+66045, dvrr_stack+44724, dvrr_stack+3596);
 tmp = dvrr_stack + 66045;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+66261, dvrr_stack+43608, dvrr_stack+42908);
 tmp = dvrr_stack + 66261;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+66531, dvrr_stack+46209, dvrr_stack+17309);
 tmp = dvrr_stack + 66531;
 target_ptr = Libderiv->deriv2_classes[2][9][14];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+66861, dvrr_stack+45147, dvrr_stack+45084);
 tmp = dvrr_stack + 66861;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+66987, dvrr_stack+1883, dvrr_stack+17474);
 tmp = dvrr_stack + 66987;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+67155, dvrr_stack+2163, dvrr_stack+45357);
 tmp = dvrr_stack + 67155;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+67371, dvrr_stack+46894, dvrr_stack+46759);
 tmp = dvrr_stack + 67371;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+67641, dvrr_stack+47509, dvrr_stack+47344);
 tmp = dvrr_stack + 67641;
 target_ptr = Libderiv->deriv2_classes[2][9][13];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+67971, dvrr_stack+28014, dvrr_stack+9968);
 tmp = dvrr_stack + 67971;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+68097, dvrr_stack+29892, dvrr_stack+219);
 tmp = dvrr_stack + 68097;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+68265, dvrr_stack+32134, dvrr_stack+30496);
 tmp = dvrr_stack + 68265;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+27913, dvrr_stack+34384, dvrr_stack+32899);
 tmp = dvrr_stack + 27913;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,55,dvrr_stack+34383, dvrr_stack+35494, dvrr_stack+35329);
 tmp = dvrr_stack + 34383;
 target_ptr = Libderiv->deriv2_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+35284, dvrr_stack+12653, dvrr_stack+12590);
 tmp = dvrr_stack + 35284;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+12468, dvrr_stack+11996, dvrr_stack+12863);
 tmp = dvrr_stack + 12468;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+11948, dvrr_stack+38398, dvrr_stack+12276);
 tmp = dvrr_stack + 11948;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+12636, dvrr_stack+38893, dvrr_stack+38758);
 tmp = dvrr_stack + 12636;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+35410, dvrr_stack+39508, dvrr_stack+39343);
 tmp = dvrr_stack + 35410;
 target_ptr = Libderiv->deriv2_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+12164, dvrr_stack+40058, dvrr_stack+5477);
 tmp = dvrr_stack + 12164;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+35740, dvrr_stack+27468, dvrr_stack+27384);
 tmp = dvrr_stack + 35740;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+27384, dvrr_stack+29160, dvrr_stack+29052);
 tmp = dvrr_stack + 27384;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+29052, dvrr_stack+31189, dvrr_stack+31054);
 tmp = dvrr_stack + 29052;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+31054, dvrr_stack+33199, dvrr_stack+33034);
 tmp = dvrr_stack + 31054;
 target_ptr = Libderiv->deriv2_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+31384, dvrr_stack+37021, dvrr_stack+36748);
 tmp = dvrr_stack + 31384;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+29322, dvrr_stack+37231, dvrr_stack+18686);
 tmp = dvrr_stack + 29322;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+37003, dvrr_stack+37619, dvrr_stack+37511);
 tmp = dvrr_stack + 37003;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+37219, dvrr_stack+34834, dvrr_stack+37979);
 tmp = dvrr_stack + 37219;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+37489, dvrr_stack+33749, dvrr_stack+38114);
 tmp = dvrr_stack + 37489;
 target_ptr = Libderiv->deriv2_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+31510, dvrr_stack+32494, dvrr_stack+38279);
 tmp = dvrr_stack + 31510;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+18578, dvrr_stack+31639, dvrr_stack+34299);
 tmp = dvrr_stack + 18578;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+31636, dvrr_stack+29520, dvrr_stack+32704);
 tmp = dvrr_stack + 31636;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+29490, dvrr_stack+40268, dvrr_stack+31919);
 tmp = dvrr_stack + 29490;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+29760, dvrr_stack+40718, dvrr_stack+30172);
 tmp = dvrr_stack + 29760;
 target_ptr = Libderiv->deriv2_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+31852, dvrr_stack+17099, dvrr_stack+3704);
 tmp = dvrr_stack + 31852;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+30090, dvrr_stack+28224, dvrr_stack+32812);
 tmp = dvrr_stack + 30090;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+28183, dvrr_stack+27104, dvrr_stack+3977);
 tmp = dvrr_stack + 28183;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+27002, dvrr_stack+41268, dvrr_stack+36811);
 tmp = dvrr_stack + 27002;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+36654, dvrr_stack+28692, dvrr_stack+4715);
 tmp = dvrr_stack + 36654;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+16994, dvrr_stack+41548, dvrr_stack+36895);
 tmp = dvrr_stack + 16994;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+37819, dvrr_stack+30604, dvrr_stack+6677);
 tmp = dvrr_stack + 37819;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+38089, dvrr_stack+41908, dvrr_stack+30337);
 tmp = dvrr_stack + 38089;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+30216, dvrr_stack+42358, dvrr_stack+27748);
 tmp = dvrr_stack + 30216;
 target_ptr = Libderiv->deriv2_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+30546, dvrr_stack+16784, dvrr_stack+32054);
 tmp = dvrr_stack + 30546;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+31978, dvrr_stack+36044, dvrr_stack+12384);
 tmp = dvrr_stack + 31978;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+16778, dvrr_stack+44724, dvrr_stack+3596);
 tmp = dvrr_stack + 16778;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+32146, dvrr_stack+43608, dvrr_stack+42908);
 tmp = dvrr_stack + 32146;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+32416, dvrr_stack+46209, dvrr_stack+17309);
 tmp = dvrr_stack + 32416;
 target_ptr = Libderiv->deriv2_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+32746, dvrr_stack+45147, dvrr_stack+45084);
 tmp = dvrr_stack + 32746;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+32872, dvrr_stack+1883, dvrr_stack+17474);
 tmp = dvrr_stack + 32872;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+33040, dvrr_stack+2163, dvrr_stack+45357);
 tmp = dvrr_stack + 33040;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+33256, dvrr_stack+46894, dvrr_stack+46759);
 tmp = dvrr_stack + 33256;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+33526, dvrr_stack+47509, dvrr_stack+47344);
 tmp = dvrr_stack + 33526;
 target_ptr = Libderiv->deriv2_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+33856, dvrr_stack+48059, dvrr_stack+45465);
 tmp = dvrr_stack + 33856;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+33982, dvrr_stack+48269, dvrr_stack+3767);
 tmp = dvrr_stack + 33982;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+34150, dvrr_stack+48549, dvrr_stack+4061);
 tmp = dvrr_stack + 34150;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+30672, dvrr_stack+43043, dvrr_stack+4823);
 tmp = dvrr_stack + 30672;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+1844, dvrr_stack+45528, dvrr_stack+6812);
 tmp = dvrr_stack + 1844;
 target_ptr = Libderiv->deriv2_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];


}

