/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (ff|hf) integrals */

void d12vrr_order_ffhf(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+12, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+6, dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+6);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+98, dvrr_stack+95, dvrr_stack+31, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+104, dvrr_stack+98, dvrr_stack+34, dvrr_stack+95, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+114, dvrr_stack+104, dvrr_stack+40, dvrr_stack+98, dvrr_stack+34, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+129, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+132, dvrr_stack+12, dvrr_stack+129, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+138, dvrr_stack+15, dvrr_stack+132, dvrr_stack+0, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+148, dvrr_stack+21, dvrr_stack+138, dvrr_stack+6, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+163, dvrr_stack+80, dvrr_stack+148, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+208, dvrr_stack+114, dvrr_stack+80, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+253, dvrr_stack+208, dvrr_stack+163, dvrr_stack+114, dvrr_stack+80, dvrr_stack+50);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+343, dvrr_stack+80, dvrr_stack+148, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+364, dvrr_stack+114, dvrr_stack+80, dvrr_stack+104, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+385, dvrr_stack+364, dvrr_stack+343, NULL, NULL, dvrr_stack+80);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+448, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+451, dvrr_stack+448, dvrr_stack+95, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+457, dvrr_stack+451, dvrr_stack+98, dvrr_stack+448, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+467, dvrr_stack+457, dvrr_stack+104, dvrr_stack+451, dvrr_stack+98, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+482, dvrr_stack+467, dvrr_stack+114, dvrr_stack+457, dvrr_stack+104, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+503, dvrr_stack+482, dvrr_stack+364, NULL, NULL, dvrr_stack+114);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+448, dvrr_stack+129, dvrr_stack+95, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+566, dvrr_stack+132, dvrr_stack+448, dvrr_stack+12, dvrr_stack+129, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+576, dvrr_stack+138, dvrr_stack+566, dvrr_stack+15, dvrr_stack+132, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+591, dvrr_stack+148, dvrr_stack+576, dvrr_stack+21, dvrr_stack+138, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+612, dvrr_stack+343, dvrr_stack+591, NULL, NULL, dvrr_stack+148);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+675, dvrr_stack+385, dvrr_stack+612, dvrr_stack+364, dvrr_stack+343, dvrr_stack+163);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+801, dvrr_stack+503, dvrr_stack+385, dvrr_stack+482, dvrr_stack+364, dvrr_stack+208);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+927, dvrr_stack+801, dvrr_stack+675, dvrr_stack+503, dvrr_stack+385, dvrr_stack+253);
 tmp = dvrr_stack + 927;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1137, dvrr_stack+343, dvrr_stack+591, dvrr_stack+80, dvrr_stack+148, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1165, dvrr_stack+364, dvrr_stack+343, dvrr_stack+114, dvrr_stack+80, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1193, dvrr_stack+1165, dvrr_stack+1137, NULL, NULL, dvrr_stack+343);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+364, dvrr_stack+467, dvrr_stack+114, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1305, dvrr_stack+1277, dvrr_stack+1165, NULL, NULL, dvrr_stack+364);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+454, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1389, dvrr_stack+95, dvrr_stack+454, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1395, dvrr_stack+448, dvrr_stack+1389, dvrr_stack+129, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1405, dvrr_stack+566, dvrr_stack+1395, dvrr_stack+132, dvrr_stack+448, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1420, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+138, dvrr_stack+566, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1441, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+148, dvrr_stack+576, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1469, dvrr_stack+1137, dvrr_stack+1441, NULL, NULL, dvrr_stack+591);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1553, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+612);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1721, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+385);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1889, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+675);
 tmp = dvrr_stack + 1889;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+2169,dvrr_stack+1889,dvrr_stack+927,10);


 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+343, dvrr_stack+591, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2835, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+364, dvrr_stack+343, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2871, dvrr_stack+2835, dvrr_stack+2799, NULL, NULL, dvrr_stack+1137);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2979, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+482, dvrr_stack+364, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3015, dvrr_stack+2979, dvrr_stack+2835, NULL, NULL, dvrr_stack+1165);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+364, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+367, dvrr_stack+454, dvrr_stack+364, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+373, dvrr_stack+1389, dvrr_stack+367, dvrr_stack+95, dvrr_stack+454, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+482, dvrr_stack+1395, dvrr_stack+373, dvrr_stack+448, dvrr_stack+1389, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3123, dvrr_stack+1405, dvrr_stack+482, dvrr_stack+566, dvrr_stack+1395, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3144, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+576, dvrr_stack+1405, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+591, dvrr_stack+1420, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3208, dvrr_stack+2799, dvrr_stack+3172, NULL, NULL, dvrr_stack+1441);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3316, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1469);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3532, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1193);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3748, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+1553);
 tmp = dvrr_stack + 3748;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+4108,dvrr_stack+3748,dvrr_stack+1889,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+4948,dvrr_stack+4108,dvrr_stack+2169,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+6208, dvrr_stack+4948, dvrr_stack+927);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6838, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+1137, dvrr_stack+1441, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6883, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1165, dvrr_stack+1137, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6928, dvrr_stack+6883, dvrr_stack+6838, NULL, NULL, dvrr_stack+2799);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7063, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1277, dvrr_stack+1165, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7108, dvrr_stack+7063, dvrr_stack+6883, NULL, NULL, dvrr_stack+2835);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1165, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+364, dvrr_stack+1165, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1168, dvrr_stack+367, dvrr_stack+497, dvrr_stack+454, dvrr_stack+364, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1178, dvrr_stack+373, dvrr_stack+1168, dvrr_stack+1389, dvrr_stack+367, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+1178, dvrr_stack+1395, dvrr_stack+373, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7243, dvrr_stack+3123, dvrr_stack+1277, dvrr_stack+1405, dvrr_stack+482, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7271, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+1420, dvrr_stack+3123, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+1441, dvrr_stack+3144, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7352, dvrr_stack+6838, dvrr_stack+7307, NULL, NULL, dvrr_stack+3172);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7487, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+3208);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7757, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2871);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8027, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+3316);
 tmp = dvrr_stack + 8027;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+8477,dvrr_stack+8027,dvrr_stack+3748,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+9557,dvrr_stack+8477,dvrr_stack+4108,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+11237, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+2799, dvrr_stack+3172, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12132, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+2835, dvrr_stack+2799, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12187, dvrr_stack+12132, dvrr_stack+12077, NULL, NULL, dvrr_stack+6838);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2979, dvrr_stack+2835, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12407, dvrr_stack+12352, dvrr_stack+12132, NULL, NULL, dvrr_stack+6883);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2835, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2838, dvrr_stack+1165, dvrr_stack+2835, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2844, dvrr_stack+497, dvrr_stack+2838, dvrr_stack+364, dvrr_stack+1165, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2854, dvrr_stack+1168, dvrr_stack+2844, dvrr_stack+367, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2979, dvrr_stack+1178, dvrr_stack+2854, dvrr_stack+373, dvrr_stack+1168, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12572, dvrr_stack+1277, dvrr_stack+2979, dvrr_stack+482, dvrr_stack+1178, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12600, dvrr_stack+7243, dvrr_stack+12572, dvrr_stack+3123, dvrr_stack+1277, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12636, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+3144, dvrr_stack+7243, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12681, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+3172, dvrr_stack+7271, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12736, dvrr_stack+12077, dvrr_stack+12681, NULL, NULL, dvrr_stack+7307);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12901, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+7352);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13231, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+6928);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13561, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+7487);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+14111,dvrr_stack+13561,dvrr_stack+8027,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+15461,dvrr_stack+14111,dvrr_stack+8477,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+17621, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12407, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+6838, dvrr_stack+7307, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12473, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+6883, dvrr_stack+6838, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18701, dvrr_stack+12473, dvrr_stack+12407, NULL, NULL, dvrr_stack+12077);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18899, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+7063, dvrr_stack+6883, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18965, dvrr_stack+18899, dvrr_stack+12473, NULL, NULL, dvrr_stack+12132);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+364, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+12132, dvrr_stack+2835, dvrr_stack+364, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+12138, dvrr_stack+2838, dvrr_stack+12132, dvrr_stack+1165, dvrr_stack+2835, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3000, dvrr_stack+2844, dvrr_stack+12138, dvrr_stack+497, dvrr_stack+2838, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+12148, dvrr_stack+2854, dvrr_stack+3000, dvrr_stack+1168, dvrr_stack+2844, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6883, dvrr_stack+2979, dvrr_stack+12148, dvrr_stack+1178, dvrr_stack+2854, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7063, dvrr_stack+12572, dvrr_stack+6883, dvrr_stack+1277, dvrr_stack+2979, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+12600, dvrr_stack+7063, dvrr_stack+7243, dvrr_stack+12572, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19163, dvrr_stack+12636, dvrr_stack+12352, dvrr_stack+7271, dvrr_stack+12600, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19218, dvrr_stack+12681, dvrr_stack+19163, dvrr_stack+7307, dvrr_stack+12636, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19284, dvrr_stack+12407, dvrr_stack+19218, NULL, NULL, dvrr_stack+12681);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19482, dvrr_stack+18701, dvrr_stack+19284, dvrr_stack+12473, dvrr_stack+12407, dvrr_stack+12736);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19878, dvrr_stack+18965, dvrr_stack+18701, dvrr_stack+18899, dvrr_stack+12473, dvrr_stack+12187);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20274, dvrr_stack+19878, dvrr_stack+19482, dvrr_stack+18965, dvrr_stack+18701, dvrr_stack+12901);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+20934,dvrr_stack+20274,dvrr_stack+13561,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+22584,dvrr_stack+20934,dvrr_stack+14111,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+25284, dvrr_stack+22584, dvrr_stack+8027);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+12169, dvrr_stack+6, dvrr_stack+15, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+12473, dvrr_stack+21, dvrr_stack+138, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+12503, dvrr_stack+50, dvrr_stack+12473, dvrr_stack+40, dvrr_stack+21, dvrr_stack+12169);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+18899, dvrr_stack+148, dvrr_stack+576, NULL, NULL, dvrr_stack+138);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+18944, dvrr_stack+163, dvrr_stack+18899, dvrr_stack+80, dvrr_stack+148, dvrr_stack+12473);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+26634, dvrr_stack+253, dvrr_stack+18944, dvrr_stack+208, dvrr_stack+163, dvrr_stack+12503);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+19034, dvrr_stack+591, dvrr_stack+1420, NULL, NULL, dvrr_stack+576);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+26784, dvrr_stack+612, dvrr_stack+19034, dvrr_stack+343, dvrr_stack+591, dvrr_stack+18899);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+26910, dvrr_stack+675, dvrr_stack+26784, dvrr_stack+385, dvrr_stack+612, dvrr_stack+18944);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+27120, dvrr_stack+927, dvrr_stack+26910, dvrr_stack+801, dvrr_stack+675, dvrr_stack+26634);
 tmp = dvrr_stack + 27120;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+27435, dvrr_stack+1441, dvrr_stack+3144, NULL, NULL, dvrr_stack+1420);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+27519, dvrr_stack+1469, dvrr_stack+27435, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+19034);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+27687, dvrr_stack+1553, dvrr_stack+27519, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+26784);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+27967, dvrr_stack+1889, dvrr_stack+27687, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+26910);
 tmp = dvrr_stack + 27967;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+28387,dvrr_stack+27967,dvrr_stack+27120,15);


 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29332, dvrr_stack+3172, dvrr_stack+7271, NULL, NULL, dvrr_stack+3144);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29440, dvrr_stack+3208, dvrr_stack+29332, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+27435);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29656, dvrr_stack+3316, dvrr_stack+29440, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+27519);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30016, dvrr_stack+3748, dvrr_stack+29656, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+27687);
 tmp = dvrr_stack + 30016;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+30556,dvrr_stack+30016,dvrr_stack+27967,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+31816,dvrr_stack+30556,dvrr_stack+28387,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+33706, dvrr_stack+31816, dvrr_stack+27120);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+34651, dvrr_stack+7307, dvrr_stack+12636, NULL, NULL, dvrr_stack+7271);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+34786, dvrr_stack+7352, dvrr_stack+34651, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+29332);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+35056, dvrr_stack+7487, dvrr_stack+34786, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+29440);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+35506, dvrr_stack+8027, dvrr_stack+35056, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+29656);
 tmp = dvrr_stack + 35506;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+36181,dvrr_stack+35506,dvrr_stack+30016,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+37801,dvrr_stack+36181,dvrr_stack+30556,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+40321, dvrr_stack+37801, dvrr_stack+27967);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+41581, dvrr_stack+12681, dvrr_stack+19163, NULL, NULL, dvrr_stack+12636);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+41746, dvrr_stack+12736, dvrr_stack+41581, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+34651);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+42076, dvrr_stack+12901, dvrr_stack+41746, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+34786);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+42626, dvrr_stack+13561, dvrr_stack+42076, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+35056);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+43451,dvrr_stack+42626,dvrr_stack+35506,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+45476,dvrr_stack+43451,dvrr_stack+36181,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+48716, dvrr_stack+45476, dvrr_stack+30016);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12187, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+364, dvrr_stack+12187, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+12397, dvrr_stack+12132, dvrr_stack+497, dvrr_stack+2835, dvrr_stack+364, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+12138, dvrr_stack+12397, dvrr_stack+2838, dvrr_stack+12132, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+343, dvrr_stack+3000, dvrr_stack+80, dvrr_stack+2844, dvrr_stack+12138, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12190, dvrr_stack+12148, dvrr_stack+343, dvrr_stack+2854, dvrr_stack+3000, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12218, dvrr_stack+6883, dvrr_stack+12190, dvrr_stack+2979, dvrr_stack+12148, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6838, dvrr_stack+7063, dvrr_stack+12218, dvrr_stack+12572, dvrr_stack+6883, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+12352, dvrr_stack+6838, dvrr_stack+12600, dvrr_stack+7063, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+19163, dvrr_stack+12077, dvrr_stack+12636, dvrr_stack+12352, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50336, dvrr_stack+19218, dvrr_stack+19097, NULL, NULL, dvrr_stack+19163);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50534, dvrr_stack+19284, dvrr_stack+50336, dvrr_stack+12407, dvrr_stack+19218, dvrr_stack+41581);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50930, dvrr_stack+19482, dvrr_stack+50534, dvrr_stack+18701, dvrr_stack+19284, dvrr_stack+41746);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51590, dvrr_stack+20274, dvrr_stack+50930, dvrr_stack+19878, dvrr_stack+19482, dvrr_stack+42076);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+52580,dvrr_stack+51590,dvrr_stack+42626,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+55055,dvrr_stack+52580,dvrr_stack+43451,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+59105, dvrr_stack+55055, dvrr_stack+35506);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+12563, dvrr_stack+0, dvrr_stack+12, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+19878, dvrr_stack+15, dvrr_stack+132, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+19896, dvrr_stack+12169, dvrr_stack+19878, dvrr_stack+6, dvrr_stack+15, dvrr_stack+12563);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19932, dvrr_stack+138, dvrr_stack+566, NULL, NULL, dvrr_stack+132);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+19962, dvrr_stack+12473, dvrr_stack+19932, dvrr_stack+21, dvrr_stack+138, dvrr_stack+19878);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+20022, dvrr_stack+12503, dvrr_stack+19962, dvrr_stack+50, dvrr_stack+12473, dvrr_stack+19896);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+20122, dvrr_stack+576, dvrr_stack+1405, NULL, NULL, dvrr_stack+566);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+20167, dvrr_stack+18899, dvrr_stack+20122, dvrr_stack+148, dvrr_stack+576, dvrr_stack+19932);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+18701, dvrr_stack+18944, dvrr_stack+20167, dvrr_stack+163, dvrr_stack+18899, dvrr_stack+19962);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+61130, dvrr_stack+26634, dvrr_stack+18701, dvrr_stack+253, dvrr_stack+18944, dvrr_stack+20022);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+12407, dvrr_stack+1420, dvrr_stack+3123, NULL, NULL, dvrr_stack+1405);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+6911, dvrr_stack+19034, dvrr_stack+12407, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+20122);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+61355, dvrr_stack+26784, dvrr_stack+6911, dvrr_stack+612, dvrr_stack+19034, dvrr_stack+20167);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+61565, dvrr_stack+26910, dvrr_stack+61355, dvrr_stack+675, dvrr_stack+26784, dvrr_stack+18701);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+61880, dvrr_stack+27120, dvrr_stack+61565, dvrr_stack+927, dvrr_stack+26910, dvrr_stack+61130);
 tmp = dvrr_stack + 61880;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1193, dvrr_stack+3144, dvrr_stack+7243, NULL, NULL, dvrr_stack+3123);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+591, dvrr_stack+27435, dvrr_stack+1193, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+12407);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+62321, dvrr_stack+27519, dvrr_stack+591, dvrr_stack+1469, dvrr_stack+27435, dvrr_stack+6911);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+62601, dvrr_stack+27687, dvrr_stack+62321, dvrr_stack+1553, dvrr_stack+27519, dvrr_stack+61355);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+63021, dvrr_stack+27967, dvrr_stack+62601, dvrr_stack+1889, dvrr_stack+27687, dvrr_stack+61565);
 tmp = dvrr_stack + 63021;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+63609,dvrr_stack+63021,dvrr_stack+61880,21);


 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1441, dvrr_stack+7271, dvrr_stack+12600, NULL, NULL, dvrr_stack+7243);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+64932, dvrr_stack+29332, dvrr_stack+1441, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+1193);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65148, dvrr_stack+29440, dvrr_stack+64932, dvrr_stack+3208, dvrr_stack+29332, dvrr_stack+591);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65508, dvrr_stack+29656, dvrr_stack+65148, dvrr_stack+3316, dvrr_stack+29440, dvrr_stack+62321);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66048, dvrr_stack+30016, dvrr_stack+65508, dvrr_stack+3748, dvrr_stack+29656, dvrr_stack+62601);
 tmp = dvrr_stack + 66048;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+66804,dvrr_stack+66048,dvrr_stack+63021,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+68568,dvrr_stack+66804,dvrr_stack+63609,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+71214, dvrr_stack+68568, dvrr_stack+61880);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+12636, dvrr_stack+12352, NULL, NULL, dvrr_stack+12600);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+72537, dvrr_stack+34651, dvrr_stack+3172, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+1441);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+72807, dvrr_stack+34786, dvrr_stack+72537, dvrr_stack+7352, dvrr_stack+34651, dvrr_stack+64932);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+73257, dvrr_stack+35056, dvrr_stack+72807, dvrr_stack+7487, dvrr_stack+34786, dvrr_stack+65148);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+73932, dvrr_stack+35506, dvrr_stack+73257, dvrr_stack+8027, dvrr_stack+35056, dvrr_stack+65508);
 tmp = dvrr_stack + 73932;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+74877,dvrr_stack+73932,dvrr_stack+66048,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+77145,dvrr_stack+74877,dvrr_stack+66804,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+80673, dvrr_stack+77145, dvrr_stack+63021);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+19163, dvrr_stack+12077, NULL, NULL, dvrr_stack+12352);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82437, dvrr_stack+41581, dvrr_stack+7307, dvrr_stack+12681, dvrr_stack+19163, dvrr_stack+3172);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82767, dvrr_stack+41746, dvrr_stack+82437, dvrr_stack+12736, dvrr_stack+41581, dvrr_stack+72537);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+83317, dvrr_stack+42076, dvrr_stack+82767, dvrr_stack+12901, dvrr_stack+41746, dvrr_stack+72807);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+84142, dvrr_stack+42626, dvrr_stack+83317, dvrr_stack+13561, dvrr_stack+42076, dvrr_stack+73257);

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+85297,dvrr_stack+84142,dvrr_stack+73932,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+88132,dvrr_stack+85297,dvrr_stack+74877,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+92668, dvrr_stack+88132, dvrr_stack+66048);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12470, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+12681, dvrr_stack+12187, dvrr_stack+12470, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+497, dvrr_stack+12681, dvrr_stack+364, dvrr_stack+12187, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+12687, dvrr_stack+12397, dvrr_stack+21, dvrr_stack+12132, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+12702, dvrr_stack+80, dvrr_stack+12687, dvrr_stack+12138, dvrr_stack+12397, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12723, dvrr_stack+343, dvrr_stack+12702, dvrr_stack+3000, dvrr_stack+80, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12751, dvrr_stack+12190, dvrr_stack+12723, dvrr_stack+12148, dvrr_stack+343, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12787, dvrr_stack+12218, dvrr_stack+12751, dvrr_stack+6883, dvrr_stack+12190, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+6838, dvrr_stack+12787, dvrr_stack+7063, dvrr_stack+12218, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12832, dvrr_stack+12077, dvrr_stack+2799, dvrr_stack+12352, dvrr_stack+6838, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12898, dvrr_stack+19097, dvrr_stack+12832, NULL, NULL, dvrr_stack+12077);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+94936, dvrr_stack+50336, dvrr_stack+12898, dvrr_stack+19218, dvrr_stack+19097, dvrr_stack+7307);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+95332, dvrr_stack+50534, dvrr_stack+94936, dvrr_stack+19284, dvrr_stack+50336, dvrr_stack+82437);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+95992, dvrr_stack+50930, dvrr_stack+95332, dvrr_stack+19482, dvrr_stack+50534, dvrr_stack+82767);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+96982, dvrr_stack+51590, dvrr_stack+95992, dvrr_stack+20274, dvrr_stack+50930, dvrr_stack+83317);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+98368,dvrr_stack+96982,dvrr_stack+84142,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+101833,dvrr_stack+98368,dvrr_stack+85297,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+107503, dvrr_stack+101833, dvrr_stack+73932);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+364, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+7099, dvrr_stack+12, dvrr_stack+129, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+19218, dvrr_stack+12563, dvrr_stack+7099, dvrr_stack+0, dvrr_stack+12, dvrr_stack+364);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+19236, dvrr_stack+132, dvrr_stack+448, NULL, NULL, dvrr_stack+129);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+19254, dvrr_stack+19878, dvrr_stack+19236, dvrr_stack+15, dvrr_stack+132, dvrr_stack+7099);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+148, dvrr_stack+19896, dvrr_stack+19254, dvrr_stack+12169, dvrr_stack+19878, dvrr_stack+19218);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19290, dvrr_stack+566, dvrr_stack+1395, NULL, NULL, dvrr_stack+448);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+19320, dvrr_stack+19932, dvrr_stack+19290, dvrr_stack+138, dvrr_stack+566, dvrr_stack+19236);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+19380, dvrr_stack+19962, dvrr_stack+19320, dvrr_stack+12473, dvrr_stack+19932, dvrr_stack+19254);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+19480, dvrr_stack+20022, dvrr_stack+19380, dvrr_stack+12503, dvrr_stack+19962, dvrr_stack+148);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+19630, dvrr_stack+1405, dvrr_stack+482, NULL, NULL, dvrr_stack+1395);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+19675, dvrr_stack+20122, dvrr_stack+19630, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+19290);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+7472, dvrr_stack+20167, dvrr_stack+19675, dvrr_stack+18899, dvrr_stack+20122, dvrr_stack+19320);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+3307, dvrr_stack+18701, dvrr_stack+7472, dvrr_stack+18944, dvrr_stack+20167, dvrr_stack+19380);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+110338, dvrr_stack+61130, dvrr_stack+3307, dvrr_stack+26634, dvrr_stack+18701, dvrr_stack+19480);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+19765, dvrr_stack+3123, dvrr_stack+1277, NULL, NULL, dvrr_stack+482);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+13096, dvrr_stack+12407, dvrr_stack+19765, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+19630);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+110653, dvrr_stack+6911, dvrr_stack+13096, dvrr_stack+19034, dvrr_stack+12407, dvrr_stack+19675);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+110863, dvrr_stack+61355, dvrr_stack+110653, dvrr_stack+26784, dvrr_stack+6911, dvrr_stack+7472);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+111178, dvrr_stack+61565, dvrr_stack+110863, dvrr_stack+26910, dvrr_stack+61355, dvrr_stack+3307);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+111619, dvrr_stack+61880, dvrr_stack+111178, dvrr_stack+27120, dvrr_stack+61565, dvrr_stack+110338);
 tmp = dvrr_stack + 111619;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+26784, dvrr_stack+7243, dvrr_stack+12572, NULL, NULL, dvrr_stack+1277);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+26868, dvrr_stack+1193, dvrr_stack+26784, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+19765);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+112207, dvrr_stack+591, dvrr_stack+26868, dvrr_stack+27435, dvrr_stack+1193, dvrr_stack+13096);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+112487, dvrr_stack+62321, dvrr_stack+112207, dvrr_stack+27519, dvrr_stack+591, dvrr_stack+110653);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+112907, dvrr_stack+62601, dvrr_stack+112487, dvrr_stack+27687, dvrr_stack+62321, dvrr_stack+110863);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+113495, dvrr_stack+63021, dvrr_stack+112907, dvrr_stack+27967, dvrr_stack+62601, dvrr_stack+111178);
 tmp = dvrr_stack + 113495;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+114279,dvrr_stack+113495,dvrr_stack+111619,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27435, dvrr_stack+12600, dvrr_stack+7063, NULL, NULL, dvrr_stack+12572);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27543, dvrr_stack+1441, dvrr_stack+27435, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+26784);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+116043, dvrr_stack+64932, dvrr_stack+27543, dvrr_stack+29332, dvrr_stack+1441, dvrr_stack+26868);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+116403, dvrr_stack+65148, dvrr_stack+116043, dvrr_stack+29440, dvrr_stack+64932, dvrr_stack+112207);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+116943, dvrr_stack+65508, dvrr_stack+116403, dvrr_stack+29656, dvrr_stack+65148, dvrr_stack+112487);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117699, dvrr_stack+66048, dvrr_stack+116943, dvrr_stack+30016, dvrr_stack+65508, dvrr_stack+112907);
 tmp = dvrr_stack + 117699;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+118707,dvrr_stack+117699,dvrr_stack+113495,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+121059,dvrr_stack+118707,dvrr_stack+114279,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+124587, dvrr_stack+121059, dvrr_stack+111619);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7622, dvrr_stack+12352, dvrr_stack+6838, NULL, NULL, dvrr_stack+7063);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+29332, dvrr_stack+3172, dvrr_stack+7622, dvrr_stack+12636, dvrr_stack+12352, dvrr_stack+27435);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+126351, dvrr_stack+72537, dvrr_stack+29332, dvrr_stack+34651, dvrr_stack+3172, dvrr_stack+27543);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+126801, dvrr_stack+72807, dvrr_stack+126351, dvrr_stack+34786, dvrr_stack+72537, dvrr_stack+116043);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127476, dvrr_stack+73257, dvrr_stack+126801, dvrr_stack+35056, dvrr_stack+72807, dvrr_stack+116403);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+128421, dvrr_stack+73932, dvrr_stack+127476, dvrr_stack+35506, dvrr_stack+73257, dvrr_stack+116943);

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+129681,dvrr_stack+128421,dvrr_stack+117699,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+132705,dvrr_stack+129681,dvrr_stack+118707,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+137409, dvrr_stack+132705, dvrr_stack+113495);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34651, dvrr_stack+12077, dvrr_stack+2799, NULL, NULL, dvrr_stack+6838);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34816, dvrr_stack+7307, dvrr_stack+34651, dvrr_stack+19163, dvrr_stack+12077, dvrr_stack+7622);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+139761, dvrr_stack+82437, dvrr_stack+34816, dvrr_stack+41581, dvrr_stack+7307, dvrr_stack+29332);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+140311, dvrr_stack+82767, dvrr_stack+139761, dvrr_stack+41746, dvrr_stack+82437, dvrr_stack+126351);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+141136, dvrr_stack+83317, dvrr_stack+140311, dvrr_stack+42076, dvrr_stack+82767, dvrr_stack+126801);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+142291, dvrr_stack+84142, dvrr_stack+141136, dvrr_stack+42626, dvrr_stack+83317, dvrr_stack+127476);

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+143831,dvrr_stack+142291,dvrr_stack+128421,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+147611,dvrr_stack+143831,dvrr_stack+129681,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+153659, dvrr_stack+147611, dvrr_stack+117699);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+41581, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12470, dvrr_stack+41581, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+138, dvrr_stack+12681, dvrr_stack+15, dvrr_stack+12187, dvrr_stack+12470, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+576, dvrr_stack+21, dvrr_stack+138, dvrr_stack+497, dvrr_stack+12681, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1420, dvrr_stack+12687, dvrr_stack+576, dvrr_stack+12397, dvrr_stack+21, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3144, dvrr_stack+12702, dvrr_stack+1420, dvrr_stack+80, dvrr_stack+12687, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7271, dvrr_stack+12723, dvrr_stack+3144, dvrr_stack+343, dvrr_stack+12702, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+41581, dvrr_stack+12751, dvrr_stack+7271, dvrr_stack+12190, dvrr_stack+12723, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19163, dvrr_stack+12787, dvrr_stack+41581, dvrr_stack+12218, dvrr_stack+12751, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41626, dvrr_stack+2799, dvrr_stack+19163, dvrr_stack+6838, dvrr_stack+12787, NULL);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41692, dvrr_stack+12832, dvrr_stack+41626, NULL, NULL, dvrr_stack+2799);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41890, dvrr_stack+12898, dvrr_stack+41692, dvrr_stack+19097, dvrr_stack+12832, dvrr_stack+34651);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+156683, dvrr_stack+94936, dvrr_stack+41890, dvrr_stack+50336, dvrr_stack+12898, dvrr_stack+34816);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41626, dvrr_stack+95332, dvrr_stack+156683, dvrr_stack+50534, dvrr_stack+94936, dvrr_stack+139761);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+156683, dvrr_stack+95992, dvrr_stack+41626, dvrr_stack+50930, dvrr_stack+95332, dvrr_stack+140311);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+158069, dvrr_stack+96982, dvrr_stack+156683, dvrr_stack+51590, dvrr_stack+95992, dvrr_stack+141136);

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+159917,dvrr_stack+158069,dvrr_stack+142291,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+164537,dvrr_stack+159917,dvrr_stack+143831,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+172097, dvrr_stack+164537, dvrr_stack+128421);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+156683, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+41626, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+94936, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+175877, dvrr_stack+22584, dvrr_stack+8027);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+96016, dvrr_stack+31816, dvrr_stack+27120);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+177227, dvrr_stack+37801, dvrr_stack+27967);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+178487, dvrr_stack+45476, dvrr_stack+30016);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+180107, dvrr_stack+55055, dvrr_stack+35506);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+182132, dvrr_stack+68568, dvrr_stack+61880);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+183455, dvrr_stack+77145, dvrr_stack+63021);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+185219, dvrr_stack+88132, dvrr_stack+66048);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+187487, dvrr_stack+101833, dvrr_stack+73932);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+190322, dvrr_stack+121059, dvrr_stack+111619);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+192086, dvrr_stack+132705, dvrr_stack+113495);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+194438, dvrr_stack+147611, dvrr_stack+117699);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+197462, dvrr_stack+164537, dvrr_stack+128421);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+157313, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+4948, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+9557, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+15461, dvrr_stack+22584, dvrr_stack+8027);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+22584, dvrr_stack+31816, dvrr_stack+27120);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+31816, dvrr_stack+37801, dvrr_stack+27967);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+37801, dvrr_stack+45476, dvrr_stack+30016);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+45476, dvrr_stack+55055, dvrr_stack+35506);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+55055, dvrr_stack+68568, dvrr_stack+61880);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+68568, dvrr_stack+77145, dvrr_stack+63021);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+77145, dvrr_stack+88132, dvrr_stack+66048);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+88132, dvrr_stack+101833, dvrr_stack+73932);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+101833, dvrr_stack+121059, dvrr_stack+111619);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+121059, dvrr_stack+132705, dvrr_stack+113495);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+132705, dvrr_stack+147611, dvrr_stack+117699);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+147611, dvrr_stack+164537, dvrr_stack+128421);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+164537, dvrr_stack+34, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+164555, dvrr_stack+104, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+164585, dvrr_stack+164555, dvrr_stack+50, dvrr_stack+104, dvrr_stack+40, dvrr_stack+164537);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+164645, dvrr_stack+467, dvrr_stack+114, NULL, NULL, dvrr_stack+104);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+164690, dvrr_stack+164645, dvrr_stack+208, dvrr_stack+467, dvrr_stack+114, dvrr_stack+164555);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+164780, dvrr_stack+164690, dvrr_stack+253, dvrr_stack+164645, dvrr_stack+208, dvrr_stack+164585);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+164930,dvrr_stack+927,dvrr_stack+164780,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+165380, dvrr_stack+164930, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+165530, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 165530;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+165810, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 165810;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+35146, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 35146;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+166020, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 166020;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+166470, dvrr_stack+20934, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+13222, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+7271, dvrr_stack+164537, dvrr_stack+12169, dvrr_stack+34, dvrr_stack+6, dvrr_stack+13222);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+167020, dvrr_stack+164585, dvrr_stack+12503, dvrr_stack+164555, dvrr_stack+50, dvrr_stack+7271);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+167120, dvrr_stack+164780, dvrr_stack+26634, dvrr_stack+164690, dvrr_stack+253, dvrr_stack+167020);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+167345,dvrr_stack+27120,dvrr_stack+167120,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+168020, dvrr_stack+167345, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+5788, dvrr_stack+30556, NULL);
 tmp = dvrr_stack + 5788;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+168245, dvrr_stack+28387, NULL);
 tmp = dvrr_stack + 168245;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+168560, dvrr_stack+36181, NULL);
 tmp = dvrr_stack + 168560;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+169100, dvrr_stack+43451, NULL);
 tmp = dvrr_stack + 169100;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+169775, dvrr_stack+52580, NULL);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+12187, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+208, dvrr_stack+13222, dvrr_stack+12563, dvrr_stack+3, dvrr_stack+0, dvrr_stack+12187);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+226, dvrr_stack+7271, dvrr_stack+19896, dvrr_stack+164537, dvrr_stack+12169, dvrr_stack+208);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+170600, dvrr_stack+167020, dvrr_stack+20022, dvrr_stack+164585, dvrr_stack+12503, dvrr_stack+226);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+170750, dvrr_stack+167120, dvrr_stack+61130, dvrr_stack+164780, dvrr_stack+26634, dvrr_stack+170600);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+171065,dvrr_stack+61880,dvrr_stack+170750,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+151391, dvrr_stack+171065, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+151706, dvrr_stack+66804, NULL);
 tmp = dvrr_stack + 151706;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+152294, dvrr_stack+63609, NULL);
 tmp = dvrr_stack + 152294;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+152735, dvrr_stack+74877, NULL);
 tmp = dvrr_stack + 152735;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+135729, dvrr_stack+85297, NULL);
 tmp = dvrr_stack + 135729;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+123411, dvrr_stack+98368, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+12187, dvrr_stack+364, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+26634, dvrr_stack+208, dvrr_stack+19218, dvrr_stack+13222, dvrr_stack+12563, dvrr_stack+6);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+26664, dvrr_stack+226, dvrr_stack+148, dvrr_stack+7271, dvrr_stack+19896, dvrr_stack+26634);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+136674, dvrr_stack+170600, dvrr_stack+19480, dvrr_stack+167020, dvrr_stack+20022, dvrr_stack+26664);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+136884, dvrr_stack+170750, dvrr_stack+110338, dvrr_stack+167120, dvrr_stack+61130, dvrr_stack+136674);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+79413,dvrr_stack+111619,dvrr_stack+136884,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+103597, dvrr_stack+79413, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+104017, dvrr_stack+118707, NULL);
 tmp = dvrr_stack + 104017;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+104801, dvrr_stack+114279, NULL);
 tmp = dvrr_stack + 104801;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+105389, dvrr_stack+129681, NULL);
 tmp = dvrr_stack + 105389;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+90967, dvrr_stack+143831, NULL);
 tmp = dvrr_stack + 90967;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+56378, dvrr_stack+159917, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+153491, dvrr_stack+164930, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+106397, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 106397;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+106677, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 106677;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+106887, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 106887;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+70332, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 70332;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+57918, dvrr_stack+20934, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+107247, dvrr_stack+167345, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+92227, dvrr_stack+30556, NULL);
 tmp = dvrr_stack + 92227;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+70782, dvrr_stack+28387, NULL);
 tmp = dvrr_stack + 70782;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+58468, dvrr_stack+36181, NULL);
 tmp = dvrr_stack + 58468;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+47501, dvrr_stack+43451, NULL);
 tmp = dvrr_stack + 47501;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+39421, dvrr_stack+52580, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+48176, dvrr_stack+171065, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+33076, dvrr_stack+66804, NULL);
 tmp = dvrr_stack + 33076;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+23529, dvrr_stack+63609, NULL);
 tmp = dvrr_stack + 23529;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+23970, dvrr_stack+74877, NULL);
 tmp = dvrr_stack + 23970;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+50336, dvrr_stack+85297, NULL);
 tmp = dvrr_stack + 50336;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+201242, dvrr_stack+98368, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+24726, dvrr_stack+79413, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+16811, dvrr_stack+118707, NULL);
 tmp = dvrr_stack + 16811;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+10637, dvrr_stack+114279, NULL);
 tmp = dvrr_stack + 10637;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+202397, dvrr_stack+129681, NULL);
 tmp = dvrr_stack + 202397;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+203405, dvrr_stack+143831, NULL);
 tmp = dvrr_stack + 203405;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+204665, dvrr_stack+159917, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+48491, dvrr_stack+164930, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+164930, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 164930;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+4108, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 4108;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+2169, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 2169;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+8477, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 8477;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+14111, dvrr_stack+20934, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+20934, dvrr_stack+167345, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+167345, dvrr_stack+30556, NULL);
 tmp = dvrr_stack + 167345;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+30556, dvrr_stack+28387, NULL);
 tmp = dvrr_stack + 30556;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+28387, dvrr_stack+36181, NULL);
 tmp = dvrr_stack + 28387;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+36181, dvrr_stack+43451, NULL);
 tmp = dvrr_stack + 36181;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+43451, dvrr_stack+52580, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+52580, dvrr_stack+171065, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+171065, dvrr_stack+66804, NULL);
 tmp = dvrr_stack + 171065;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+66804, dvrr_stack+63609, NULL);
 tmp = dvrr_stack + 66804;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+63609, dvrr_stack+74877, NULL);
 tmp = dvrr_stack + 63609;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+36856, dvrr_stack+85297, NULL);
 tmp = dvrr_stack + 36856;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+85297, dvrr_stack+98368, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+98368, dvrr_stack+79413, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+79413, dvrr_stack+118707, NULL);
 tmp = dvrr_stack + 79413;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+118707, dvrr_stack+114279, NULL);
 tmp = dvrr_stack + 118707;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+114279, dvrr_stack+129681, NULL);
 tmp = dvrr_stack + 114279;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+129681, dvrr_stack+143831, NULL);
 tmp = dvrr_stack + 129681;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+143831, dvrr_stack+159917, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+159917, dvrr_stack+31, dvrr_stack+3, NULL, NULL, Data->F+3);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+12169, dvrr_stack+98, dvrr_stack+34, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+159926, dvrr_stack+12169, dvrr_stack+164537, dvrr_stack+98, dvrr_stack+34, dvrr_stack+159917);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+26754, dvrr_stack+457, dvrr_stack+104, NULL, NULL, dvrr_stack+98);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+34, dvrr_stack+26754, dvrr_stack+164555, dvrr_stack+457, dvrr_stack+104, dvrr_stack+12169);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+159962, dvrr_stack+34, dvrr_stack+164585, dvrr_stack+26754, dvrr_stack+164555, dvrr_stack+159926);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+160062, dvrr_stack+927, dvrr_stack+159962);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+160212, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 160212;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+160492, dvrr_stack+1889, dvrr_stack+164780);
 tmp = dvrr_stack + 160492;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+160702, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 160702;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+161062, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 161062;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+161512, dvrr_stack+20274, dvrr_stack+8027);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+153641, dvrr_stack+159917, dvrr_stack+13222, dvrr_stack+31, dvrr_stack+3, dvrr_stack+0);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+162062, dvrr_stack+159926, dvrr_stack+7271, dvrr_stack+12169, dvrr_stack+164537, dvrr_stack+153641);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+162122, dvrr_stack+159962, dvrr_stack+167020, dvrr_stack+34, dvrr_stack+164585, dvrr_stack+162062);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+162272, dvrr_stack+27120, dvrr_stack+162122);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+162497, dvrr_stack+30016, dvrr_stack+27120);
 tmp = dvrr_stack + 162497;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+162917, dvrr_stack+27967, dvrr_stack+167120);
 tmp = dvrr_stack + 162917;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+163232, dvrr_stack+35506, dvrr_stack+27967);
 tmp = dvrr_stack + 163232;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+163772, dvrr_stack+42626, dvrr_stack+30016);
 tmp = dvrr_stack + 163772;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+145371, dvrr_stack+51590, dvrr_stack+35506);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+497, dvrr_stack+0, dvrr_stack+12187, Data->F+3, Data->F+4, NULL);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+26754, dvrr_stack+153641, dvrr_stack+208, dvrr_stack+159917, dvrr_stack+13222, dvrr_stack+497);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+164447, dvrr_stack+162062, dvrr_stack+226, dvrr_stack+159926, dvrr_stack+7271, dvrr_stack+26754);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+146196, dvrr_stack+162122, dvrr_stack+170600, dvrr_stack+159962, dvrr_stack+167020, dvrr_stack+164447);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+146406, dvrr_stack+61880, dvrr_stack+146196);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+146721, dvrr_stack+66048, dvrr_stack+61880);
 tmp = dvrr_stack + 146721;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+130941, dvrr_stack+63021, dvrr_stack+170750);
 tmp = dvrr_stack + 130941;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+115287, dvrr_stack+73932, dvrr_stack+63021);
 tmp = dvrr_stack + 115287;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+30871, dvrr_stack+84142, dvrr_stack+66048);
 tmp = dvrr_stack + 30871;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+131382, dvrr_stack+96982, dvrr_stack+73932);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+12397, dvrr_stack+497, dvrr_stack+6, dvrr_stack+0, dvrr_stack+12187, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+159917, dvrr_stack+26754, dvrr_stack+26634, dvrr_stack+153641, dvrr_stack+208, dvrr_stack+12397);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+157943, dvrr_stack+164447, dvrr_stack+26664, dvrr_stack+162062, dvrr_stack+226, dvrr_stack+159917);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+147309, dvrr_stack+146196, dvrr_stack+136674, dvrr_stack+162122, dvrr_stack+170600, dvrr_stack+157943);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+119295, dvrr_stack+111619, dvrr_stack+147309);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+119715, dvrr_stack+117699, dvrr_stack+111619);
 tmp = dvrr_stack + 119715;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+98788, dvrr_stack+113495, dvrr_stack+136884);
 tmp = dvrr_stack + 98788;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+99376, dvrr_stack+128421, dvrr_stack+113495);
 tmp = dvrr_stack + 99376;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+100384, dvrr_stack+142291, dvrr_stack+117699);
 tmp = dvrr_stack + 100384;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+86452, dvrr_stack+158069, dvrr_stack+128421);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+164447, dvrr_stack+927, dvrr_stack+159962);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+120499, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 120499;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+120779, dvrr_stack+1889, dvrr_stack+164780);
 tmp = dvrr_stack + 120779;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+80197, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 80197;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+74877, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 74877;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+75327, dvrr_stack+20274, dvrr_stack+8027);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+75877, dvrr_stack+27120, dvrr_stack+162122);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+76102, dvrr_stack+30016, dvrr_stack+27120);
 tmp = dvrr_stack + 76102;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+76522, dvrr_stack+27967, dvrr_stack+167120);
 tmp = dvrr_stack + 76522;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+64365, dvrr_stack+35506, dvrr_stack+27967);
 tmp = dvrr_stack + 64365;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+67245, dvrr_stack+42626, dvrr_stack+30016);
 tmp = dvrr_stack + 67245;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+52895, dvrr_stack+51590, dvrr_stack+35506);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+67920, dvrr_stack+61880, dvrr_stack+146196);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+53720, dvrr_stack+66048, dvrr_stack+61880);
 tmp = dvrr_stack + 53720;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+171653, dvrr_stack+63021, dvrr_stack+170750);
 tmp = dvrr_stack + 171653;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+44276, dvrr_stack+73932, dvrr_stack+63021);
 tmp = dvrr_stack + 44276;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+21159, dvrr_stack+84142, dvrr_stack+66048);
 tmp = dvrr_stack + 21159;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+206205, dvrr_stack+96982, dvrr_stack+73932);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+54308, dvrr_stack+111619, dvrr_stack+147309);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+14661, dvrr_stack+117699, dvrr_stack+111619);
 tmp = dvrr_stack + 14661;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+8927, dvrr_stack+113495, dvrr_stack+136884);
 tmp = dvrr_stack + 8927;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+207360, dvrr_stack+128421, dvrr_stack+113495);
 tmp = dvrr_stack + 207360;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+208368, dvrr_stack+142291, dvrr_stack+117699);
 tmp = dvrr_stack + 208368;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+209628, dvrr_stack+158069, dvrr_stack+128421);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+132537, dvrr_stack+927, dvrr_stack+159962);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+76837, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 76837;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+68235, dvrr_stack+1889, dvrr_stack+164780);
 tmp = dvrr_stack + 68235;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+45032, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 45032;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+22104, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 22104;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+13561, dvrr_stack+20274, dvrr_stack+8027);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+54728, dvrr_stack+27120, dvrr_stack+162122);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+4318, dvrr_stack+30016, dvrr_stack+27120);
 tmp = dvrr_stack + 4318;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+28927, dvrr_stack+27967, dvrr_stack+167120);
 tmp = dvrr_stack + 28927;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+211168, dvrr_stack+35506, dvrr_stack+27967);
 tmp = dvrr_stack + 211168;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+20257, dvrr_stack+42626, dvrr_stack+30016);
 tmp = dvrr_stack + 20257;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+42466, dvrr_stack+51590, dvrr_stack+35506);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+167020, dvrr_stack+61880, dvrr_stack+146196);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+51281, dvrr_stack+66048, dvrr_stack+61880);
 tmp = dvrr_stack + 51281;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+51869, dvrr_stack+63021, dvrr_stack+170750);
 tmp = dvrr_stack + 51869;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+211708, dvrr_stack+73932, dvrr_stack+63021);
 tmp = dvrr_stack + 211708;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+212464, dvrr_stack+84142, dvrr_stack+66048);
 tmp = dvrr_stack + 212464;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+213409, dvrr_stack+96982, dvrr_stack+73932);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+96961, dvrr_stack+111619, dvrr_stack+147309);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+97381, dvrr_stack+117699, dvrr_stack+111619);
 tmp = dvrr_stack + 97381;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+214564, dvrr_stack+113495, dvrr_stack+136884);
 tmp = dvrr_stack + 214564;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+215152, dvrr_stack+128421, dvrr_stack+113495);
 tmp = dvrr_stack + 215152;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+216160, dvrr_stack+142291, dvrr_stack+117699);
 tmp = dvrr_stack + 216160;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+217420, dvrr_stack+158069, dvrr_stack+128421);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+157943,dvrr_stack+1721,dvrr_stack+801,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+147309, dvrr_stack+157943, NULL);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+158321,dvrr_stack+3532,dvrr_stack+1721,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+147435, dvrr_stack+158321, NULL);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+158825,dvrr_stack+7757,dvrr_stack+3532,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+159473, dvrr_stack+158825, NULL);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+218960,dvrr_stack+13231,dvrr_stack+7757,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+2529, dvrr_stack+218960, NULL);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+172094, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+0, dvrr_stack+364, dvrr_stack+172094, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+13222, dvrr_stack+129, dvrr_stack+95, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+153641, dvrr_stack+7099, dvrr_stack+13222, dvrr_stack+12, dvrr_stack+129, dvrr_stack+172094);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+26754, dvrr_stack+19218, dvrr_stack+153641, dvrr_stack+12563, dvrr_stack+7099, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+12169, dvrr_stack+448, dvrr_stack+1389, NULL, NULL, dvrr_stack+95);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+7271, dvrr_stack+19236, dvrr_stack+12169, dvrr_stack+132, dvrr_stack+448, dvrr_stack+13222);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+12, dvrr_stack+19254, dvrr_stack+7271, dvrr_stack+19878, dvrr_stack+19236, dvrr_stack+153641);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+29242, dvrr_stack+148, dvrr_stack+12, dvrr_stack+19896, dvrr_stack+19254, dvrr_stack+26754);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+22554, dvrr_stack+1395, dvrr_stack+373, NULL, NULL, dvrr_stack+1389);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+146196, dvrr_stack+19290, dvrr_stack+22554, dvrr_stack+566, dvrr_stack+1395, dvrr_stack+12169);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+146256, dvrr_stack+19320, dvrr_stack+146196, dvrr_stack+19932, dvrr_stack+19290, dvrr_stack+7271);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+164780, dvrr_stack+19380, dvrr_stack+146256, dvrr_stack+19962, dvrr_stack+19320, dvrr_stack+12);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+162062, dvrr_stack+19480, dvrr_stack+164780, dvrr_stack+20022, dvrr_stack+19380, dvrr_stack+29242);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+146356, dvrr_stack+482, dvrr_stack+1178, NULL, NULL, dvrr_stack+373);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+159689, dvrr_stack+19630, dvrr_stack+146356, dvrr_stack+1405, dvrr_stack+482, dvrr_stack+22554);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+159779, dvrr_stack+19675, dvrr_stack+159689, dvrr_stack+20122, dvrr_stack+19630, dvrr_stack+146196);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+167765, dvrr_stack+7472, dvrr_stack+159779, dvrr_stack+20167, dvrr_stack+19675, dvrr_stack+146256);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+29602, dvrr_stack+3307, dvrr_stack+167765, dvrr_stack+18701, dvrr_stack+7472, dvrr_stack+164780);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+18701, dvrr_stack+110338, dvrr_stack+29602, dvrr_stack+61130, dvrr_stack+3307, dvrr_stack+162062);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+61130, dvrr_stack+1277, dvrr_stack+2979, NULL, NULL, dvrr_stack+1178);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+61193, dvrr_stack+19765, dvrr_stack+61130, dvrr_stack+3123, dvrr_stack+1277, dvrr_stack+146356);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+4738, dvrr_stack+13096, dvrr_stack+61193, dvrr_stack+12407, dvrr_stack+19765, dvrr_stack+159689);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+19828, dvrr_stack+110653, dvrr_stack+4738, dvrr_stack+6911, dvrr_stack+13096, dvrr_stack+159779);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+219770, dvrr_stack+110863, dvrr_stack+19828, dvrr_stack+61355, dvrr_stack+110653, dvrr_stack+167765);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+220211, dvrr_stack+111178, dvrr_stack+219770, dvrr_stack+61565, dvrr_stack+110863, dvrr_stack+29602);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+220799, dvrr_stack+111619, dvrr_stack+220211, dvrr_stack+61880, dvrr_stack+111178, dvrr_stack+18701);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+45392, dvrr_stack+12572, dvrr_stack+6883, NULL, NULL, dvrr_stack+2979);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+61319, dvrr_stack+26784, dvrr_stack+45392, dvrr_stack+7243, dvrr_stack+12572, dvrr_stack+61130);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+61487, dvrr_stack+26868, dvrr_stack+61319, dvrr_stack+1193, dvrr_stack+26784, dvrr_stack+61193);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+221555, dvrr_stack+112207, dvrr_stack+61487, dvrr_stack+591, dvrr_stack+26868, dvrr_stack+4738);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+221975, dvrr_stack+112487, dvrr_stack+221555, dvrr_stack+62321, dvrr_stack+112207, dvrr_stack+19828);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+222563, dvrr_stack+112907, dvrr_stack+221975, dvrr_stack+62601, dvrr_stack+112487, dvrr_stack+219770);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+223347, dvrr_stack+113495, dvrr_stack+222563, dvrr_stack+63021, dvrr_stack+112907, dvrr_stack+220211);

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+224355,dvrr_stack+223347,dvrr_stack+220799,36);


 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+226623, dvrr_stack+224355, NULL);

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62321, dvrr_stack+7063, dvrr_stack+12218, NULL, NULL, dvrr_stack+6883);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62429, dvrr_stack+27435, dvrr_stack+62321, dvrr_stack+12600, dvrr_stack+7063, dvrr_stack+45392);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62645, dvrr_stack+27543, dvrr_stack+62429, dvrr_stack+1441, dvrr_stack+27435, dvrr_stack+61319);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+227379, dvrr_stack+116043, dvrr_stack+62645, dvrr_stack+64932, dvrr_stack+27543, dvrr_stack+61487);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+227919, dvrr_stack+116403, dvrr_stack+227379, dvrr_stack+65148, dvrr_stack+116043, dvrr_stack+221555);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+228675, dvrr_stack+116943, dvrr_stack+227919, dvrr_stack+65508, dvrr_stack+116403, dvrr_stack+221975);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+229683, dvrr_stack+117699, dvrr_stack+228675, dvrr_stack+66048, dvrr_stack+116943, dvrr_stack+222563);

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+230979,dvrr_stack+229683,dvrr_stack+223347,36);


 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+64905, dvrr_stack+230979, NULL);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+65913, dvrr_stack+6838, dvrr_stack+12787, NULL, NULL, dvrr_stack+12218);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+52310, dvrr_stack+7622, dvrr_stack+65913, dvrr_stack+12352, dvrr_stack+6838, dvrr_stack+62321);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+234003, dvrr_stack+29332, dvrr_stack+52310, dvrr_stack+3172, dvrr_stack+7622, dvrr_stack+62429);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+234453, dvrr_stack+126351, dvrr_stack+234003, dvrr_stack+72537, dvrr_stack+29332, dvrr_stack+62645);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+235128, dvrr_stack+126801, dvrr_stack+234453, dvrr_stack+72807, dvrr_stack+126351, dvrr_stack+227379);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+236073, dvrr_stack+127476, dvrr_stack+235128, dvrr_stack+73257, dvrr_stack+126801, dvrr_stack+227919);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237333, dvrr_stack+128421, dvrr_stack+236073, dvrr_stack+73932, dvrr_stack+127476, dvrr_stack+228675);

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+238953,dvrr_stack+237333,dvrr_stack+229683,36);


 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+72537, dvrr_stack+238953, NULL);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3123, dvrr_stack+2799, dvrr_stack+19163, NULL, NULL, dvrr_stack+12787);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+242841, dvrr_stack+34651, dvrr_stack+3123, dvrr_stack+12077, dvrr_stack+2799, dvrr_stack+65913);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+243171, dvrr_stack+34816, dvrr_stack+242841, dvrr_stack+7307, dvrr_stack+34651, dvrr_stack+52310);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+243721, dvrr_stack+139761, dvrr_stack+243171, dvrr_stack+82437, dvrr_stack+34816, dvrr_stack+234003);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+244546, dvrr_stack+140311, dvrr_stack+243721, dvrr_stack+82767, dvrr_stack+139761, dvrr_stack+234453);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+242841, dvrr_stack+141136, dvrr_stack+244546, dvrr_stack+83317, dvrr_stack+140311, dvrr_stack+235128);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+244381, dvrr_stack+142291, dvrr_stack+242841, dvrr_stack+84142, dvrr_stack+141136, dvrr_stack+236073);

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+246361,dvrr_stack+244381,dvrr_stack+237333,36);


 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+139761, dvrr_stack+246361, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+242841, dvrr_stack+157943, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+242967, dvrr_stack+158321, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+243135, dvrr_stack+158825, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+243351, dvrr_stack+218960, NULL);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+243621, dvrr_stack+224355, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+141381, dvrr_stack+230979, NULL);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+142389, dvrr_stack+238953, NULL);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+82437, dvrr_stack+246361, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+143685, dvrr_stack+157943, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+157943, dvrr_stack+158321, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+158111, dvrr_stack+158825, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+158327, dvrr_stack+218960, NULL);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+218960, dvrr_stack+224355, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+224355, dvrr_stack+230979, NULL);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+230979, dvrr_stack+238953, NULL);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+238953, dvrr_stack+246361, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+246361, dvrr_stack+1721, dvrr_stack+164690);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+246487, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+246655, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+246871, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+167335, dvrr_stack+6, dvrr_stack+0, dvrr_stack+12187, dvrr_stack+364, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+247141, dvrr_stack+26634, dvrr_stack+26754, dvrr_stack+208, dvrr_stack+19218, dvrr_stack+167335);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+247186, dvrr_stack+26664, dvrr_stack+29242, dvrr_stack+226, dvrr_stack+148, dvrr_stack+247141);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+247312, dvrr_stack+136674, dvrr_stack+162062, dvrr_stack+170600, dvrr_stack+19480, dvrr_stack+247186);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+247592, dvrr_stack+136884, dvrr_stack+18701, dvrr_stack+170750, dvrr_stack+110338, dvrr_stack+247312);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+248132, dvrr_stack+223347, dvrr_stack+247592);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+248888, dvrr_stack+229683, dvrr_stack+220799);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+249896, dvrr_stack+237333, dvrr_stack+223347);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+240573, dvrr_stack+244381, dvrr_stack+229683);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+170600, dvrr_stack+1721, dvrr_stack+164690);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+170726, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+136674, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+136890, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+251192, dvrr_stack+223347, dvrr_stack+247592);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+232275, dvrr_stack+229683, dvrr_stack+220799);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+251948, dvrr_stack+237333, dvrr_stack+223347);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+253244, dvrr_stack+244381, dvrr_stack+229683);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+170894, dvrr_stack+1721, dvrr_stack+164690);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+137160, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+247141, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+242193, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+225363, dvrr_stack+223347, dvrr_stack+247592);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+84057, dvrr_stack+229683, dvrr_stack+220799);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+254864, dvrr_stack+237333, dvrr_stack+223347);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+256160, dvrr_stack+244381, dvrr_stack+229683);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+13231, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+247357, dvrr_stack+61880, dvrr_stack+927);
 tmp = dvrr_stack + 247357;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+13357, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+247672, dvrr_stack+63021, dvrr_stack+1889);
 tmp = dvrr_stack + 247672;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+257780, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+233283, dvrr_stack+66048, dvrr_stack+3748);
 tmp = dvrr_stack + 233283;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+242463, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+158597, dvrr_stack+73932, dvrr_stack+8027);
 tmp = dvrr_stack + 158597;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+226119, dvrr_stack+27120, dvrr_stack+801);
 tmp = dvrr_stack + 226119;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+244377, dvrr_stack+111619, dvrr_stack+27120);
 tmp = dvrr_stack + 244377;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+226329, dvrr_stack+27967, dvrr_stack+1721);
 tmp = dvrr_stack + 226329;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+244818, dvrr_stack+113495, dvrr_stack+27967);
 tmp = dvrr_stack + 244818;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+245406, dvrr_stack+30016, dvrr_stack+3532);
 tmp = dvrr_stack + 245406;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+257996, dvrr_stack+117699, dvrr_stack+30016);
 tmp = dvrr_stack + 257996;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+245766, dvrr_stack+35506, dvrr_stack+7757);
 tmp = dvrr_stack + 245766;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+258752, dvrr_stack+128421, dvrr_stack+35506);
 tmp = dvrr_stack + 258752;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+259697, dvrr_stack+220799, dvrr_stack+61880);
 tmp = dvrr_stack + 259697;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+260285, dvrr_stack+223347, dvrr_stack+63021);
 tmp = dvrr_stack + 260285;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+261069, dvrr_stack+229683, dvrr_stack+66048);
 tmp = dvrr_stack + 261069;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+262077, dvrr_stack+237333, dvrr_stack+73932);
 tmp = dvrr_stack + 262077;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+12187, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+172094, dvrr_stack+12187, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+167335, dvrr_stack+0, dvrr_stack+6, dvrr_stack+364, dvrr_stack+172094, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+13525, dvrr_stack+95, dvrr_stack+454, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+132687, dvrr_stack+13222, dvrr_stack+13525, dvrr_stack+129, dvrr_stack+95, dvrr_stack+12187);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+167990, dvrr_stack+153641, dvrr_stack+132687, dvrr_stack+7099, dvrr_stack+13222, dvrr_stack+6);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+171020, dvrr_stack+26754, dvrr_stack+167990, dvrr_stack+19218, dvrr_stack+153641, dvrr_stack+167335);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+153641, dvrr_stack+1389, dvrr_stack+367, NULL, NULL, dvrr_stack+454);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+137328, dvrr_stack+12169, dvrr_stack+153641, dvrr_stack+448, dvrr_stack+1389, dvrr_stack+13525);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+208, dvrr_stack+7271, dvrr_stack+137328, dvrr_stack+19236, dvrr_stack+12169, dvrr_stack+132687);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+268, dvrr_stack+12, dvrr_stack+208, dvrr_stack+19254, dvrr_stack+7271, dvrr_stack+167990);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+26634, dvrr_stack+29242, dvrr_stack+268, dvrr_stack+148, dvrr_stack+12, dvrr_stack+171020);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+167990, dvrr_stack+373, dvrr_stack+1168, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+29242, dvrr_stack+22554, dvrr_stack+167990, dvrr_stack+1395, dvrr_stack+373, dvrr_stack+153641);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+1389, dvrr_stack+146196, dvrr_stack+29242, dvrr_stack+19290, dvrr_stack+22554, dvrr_stack+137328);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1489, dvrr_stack+146256, dvrr_stack+1389, dvrr_stack+19320, dvrr_stack+146196, dvrr_stack+208);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+0, dvrr_stack+164780, dvrr_stack+1489, dvrr_stack+19380, dvrr_stack+146256, dvrr_stack+268);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+263337, dvrr_stack+162062, dvrr_stack+0, dvrr_stack+19480, dvrr_stack+164780, dvrr_stack+26634);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+171020, dvrr_stack+1178, dvrr_stack+2854, NULL, NULL, dvrr_stack+1168);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+26634, dvrr_stack+146356, dvrr_stack+171020, dvrr_stack+482, dvrr_stack+1178, dvrr_stack+167990);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+162062, dvrr_stack+159689, dvrr_stack+26634, dvrr_stack+19630, dvrr_stack+146356, dvrr_stack+29242);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+210, dvrr_stack+159779, dvrr_stack+162062, dvrr_stack+19675, dvrr_stack+159689, dvrr_stack+1389);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+263617, dvrr_stack+167765, dvrr_stack+210, dvrr_stack+7472, dvrr_stack+159779, dvrr_stack+1489);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+34651, dvrr_stack+29602, dvrr_stack+263617, dvrr_stack+3307, dvrr_stack+167765, dvrr_stack+0);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+19121, dvrr_stack+18701, dvrr_stack+34651, dvrr_stack+110338, dvrr_stack+29602, dvrr_stack+263337);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+263337, dvrr_stack+2979, dvrr_stack+12148, NULL, NULL, dvrr_stack+2854);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+263400, dvrr_stack+61130, dvrr_stack+263337, dvrr_stack+1277, dvrr_stack+2979, dvrr_stack+171020);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+0, dvrr_stack+61193, dvrr_stack+263400, dvrr_stack+19765, dvrr_stack+61130, dvrr_stack+26634);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+110338, dvrr_stack+4738, dvrr_stack+0, dvrr_stack+13096, dvrr_stack+61193, dvrr_stack+162062);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+263932, dvrr_stack+19828, dvrr_stack+110338, dvrr_stack+110653, dvrr_stack+4738, dvrr_stack+210);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+264373, dvrr_stack+219770, dvrr_stack+263932, dvrr_stack+110863, dvrr_stack+19828, dvrr_stack+263617);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+264961, dvrr_stack+220211, dvrr_stack+264373, dvrr_stack+111178, dvrr_stack+219770, dvrr_stack+34651);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+110653, dvrr_stack+220799, dvrr_stack+264961, dvrr_stack+111619, dvrr_stack+220211, dvrr_stack+19121);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+18701, dvrr_stack+110653, dvrr_stack+111619);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+27036, dvrr_stack+6883, dvrr_stack+12190, NULL, NULL, dvrr_stack+12148);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1137, dvrr_stack+45392, dvrr_stack+27036, dvrr_stack+12572, dvrr_stack+6883, dvrr_stack+263337);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+34651, dvrr_stack+61319, dvrr_stack+1137, dvrr_stack+26784, dvrr_stack+45392, dvrr_stack+263400);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+263337, dvrr_stack+61487, dvrr_stack+34651, dvrr_stack+26868, dvrr_stack+61319, dvrr_stack+0);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+19457, dvrr_stack+221555, dvrr_stack+263337, dvrr_stack+112207, dvrr_stack+61487, dvrr_stack+110338);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+219716, dvrr_stack+221975, dvrr_stack+19457, dvrr_stack+112487, dvrr_stack+221555, dvrr_stack+263932);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+265717, dvrr_stack+222563, dvrr_stack+219716, dvrr_stack+112907, dvrr_stack+221975, dvrr_stack+264373);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+112207, dvrr_stack+223347, dvrr_stack+265717, dvrr_stack+113495, dvrr_stack+222563, dvrr_stack+264961);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+221555, dvrr_stack+112207, dvrr_stack+113495);

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242733, dvrr_stack+12218, dvrr_stack+12751, NULL, NULL, dvrr_stack+12190);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+62321, dvrr_stack+242733, dvrr_stack+7063, dvrr_stack+12218, dvrr_stack+27036);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+222563, dvrr_stack+62429, dvrr_stack+2799, dvrr_stack+27435, dvrr_stack+62321, dvrr_stack+1137);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+263757, dvrr_stack+62645, dvrr_stack+222563, dvrr_stack+27543, dvrr_stack+62429, dvrr_stack+34651);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+264297, dvrr_stack+227379, dvrr_stack+263757, dvrr_stack+116043, dvrr_stack+62645, dvrr_stack+263337);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+266725, dvrr_stack+227919, dvrr_stack+264297, dvrr_stack+116403, dvrr_stack+227379, dvrr_stack+19457);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+267733, dvrr_stack+228675, dvrr_stack+266725, dvrr_stack+116943, dvrr_stack+227919, dvrr_stack+219716);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+116043, dvrr_stack+229683, dvrr_stack+267733, dvrr_stack+117699, dvrr_stack+228675, dvrr_stack+265717);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+227379, dvrr_stack+116043, dvrr_stack+117699);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219716, dvrr_stack+12787, dvrr_stack+41581, NULL, NULL, dvrr_stack+12751);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219851, dvrr_stack+65913, dvrr_stack+219716, dvrr_stack+6838, dvrr_stack+12787, dvrr_stack+242733);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+220121, dvrr_stack+52310, dvrr_stack+219851, dvrr_stack+7622, dvrr_stack+65913, dvrr_stack+2799);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19457, dvrr_stack+234003, dvrr_stack+220121, dvrr_stack+29332, dvrr_stack+52310, dvrr_stack+222563);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219716, dvrr_stack+234453, dvrr_stack+19457, dvrr_stack+126351, dvrr_stack+234003, dvrr_stack+263757);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+265053, dvrr_stack+235128, dvrr_stack+219716, dvrr_stack+126801, dvrr_stack+234453, dvrr_stack+264297);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+263337, dvrr_stack+236073, dvrr_stack+265053, dvrr_stack+127476, dvrr_stack+235128, dvrr_stack+266725);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+126351, dvrr_stack+237333, dvrr_stack+263337, dvrr_stack+128421, dvrr_stack+236073, dvrr_stack+267733);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+263337, dvrr_stack+126351, dvrr_stack+128421);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+264957, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+110338, dvrr_stack+61880, dvrr_stack+927);
 tmp = dvrr_stack + 110338;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+1137, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+265083, dvrr_stack+63021, dvrr_stack+1889);
 tmp = dvrr_stack + 265083;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+2799, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+265503, dvrr_stack+66048, dvrr_stack+3748);
 tmp = dvrr_stack + 265503;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+52310, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+266043, dvrr_stack+73932, dvrr_stack+8027);
 tmp = dvrr_stack + 266043;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+4738, dvrr_stack+27120, dvrr_stack+801);
 tmp = dvrr_stack + 4738;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+266718, dvrr_stack+111619, dvrr_stack+27120);
 tmp = dvrr_stack + 266718;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+267159, dvrr_stack+27967, dvrr_stack+1721);
 tmp = dvrr_stack + 267159;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+267439, dvrr_stack+113495, dvrr_stack+27967);
 tmp = dvrr_stack + 267439;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+268027, dvrr_stack+30016, dvrr_stack+3532);
 tmp = dvrr_stack + 268027;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+268387, dvrr_stack+117699, dvrr_stack+30016);
 tmp = dvrr_stack + 268387;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+269143, dvrr_stack+35506, dvrr_stack+7757);
 tmp = dvrr_stack + 269143;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+219716, dvrr_stack+128421, dvrr_stack+35506);
 tmp = dvrr_stack + 219716;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+19457, dvrr_stack+220799, dvrr_stack+61880);
 tmp = dvrr_stack + 19457;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+222563, dvrr_stack+223347, dvrr_stack+63021);
 tmp = dvrr_stack + 222563;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+228675, dvrr_stack+229683, dvrr_stack+66048);
 tmp = dvrr_stack + 228675;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+233823, dvrr_stack+237333, dvrr_stack+73932);
 tmp = dvrr_stack + 233823;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+29242, dvrr_stack+110653, dvrr_stack+111619);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+235083, dvrr_stack+112207, dvrr_stack+113495);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+269593, dvrr_stack+116043, dvrr_stack+117699);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+270889, dvrr_stack+126351, dvrr_stack+128421);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+272509, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+272635, dvrr_stack+61880, dvrr_stack+927);
 tmp = dvrr_stack + 272635;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+927, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+34651, dvrr_stack+63021, dvrr_stack+1889);
 tmp = dvrr_stack + 34651;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+1889, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+62321, dvrr_stack+66048, dvrr_stack+3748);
 tmp = dvrr_stack + 62321;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+6838, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+0, dvrr_stack+73932, dvrr_stack+8027);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+162062, dvrr_stack+27120, dvrr_stack+801);
 tmp = dvrr_stack + 162062;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+8027, dvrr_stack+111619, dvrr_stack+27120);
 tmp = dvrr_stack + 8027;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+7108, dvrr_stack+27967, dvrr_stack+1721);
 tmp = dvrr_stack + 7108;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+26634, dvrr_stack+113495, dvrr_stack+27967);
 tmp = dvrr_stack + 26634;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+3748, dvrr_stack+30016, dvrr_stack+3532);
 tmp = dvrr_stack + 3748;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+27222, dvrr_stack+117699, dvrr_stack+30016);
 tmp = dvrr_stack + 27222;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+3015, dvrr_stack+35506, dvrr_stack+7757);
 tmp = dvrr_stack + 3015;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+236091, dvrr_stack+128421, dvrr_stack+35506);
 tmp = dvrr_stack + 236091;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+35506, dvrr_stack+220799, dvrr_stack+61880);
 tmp = dvrr_stack + 35506;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+220661, dvrr_stack+223347, dvrr_stack+63021);
 tmp = dvrr_stack + 220661;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+223347, dvrr_stack+229683, dvrr_stack+66048);
 tmp = dvrr_stack + 223347;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+229683, dvrr_stack+237333, dvrr_stack+73932);
 tmp = dvrr_stack + 229683;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+65913, dvrr_stack+110653, dvrr_stack+111619);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+110653, dvrr_stack+112207, dvrr_stack+113495);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+111661, dvrr_stack+116043, dvrr_stack+117699);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+116043, dvrr_stack+126351, dvrr_stack+128421);

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+146196, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 146196;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+126351, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 126351;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+126631, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 126631;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+126991, dvrr_stack+25284, NULL);
 tmp = dvrr_stack + 126991;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+127441, dvrr_stack+33706, NULL);
 tmp = dvrr_stack + 127441;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+127756, dvrr_stack+40321, NULL);
 tmp = dvrr_stack + 127756;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+128176, dvrr_stack+48716, NULL);
 tmp = dvrr_stack + 128176;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+128716, dvrr_stack+59105, NULL);
 tmp = dvrr_stack + 128716;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+117663, dvrr_stack+71214, NULL);
 tmp = dvrr_stack + 117663;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+118104, dvrr_stack+80673, NULL);
 tmp = dvrr_stack + 118104;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+112957, dvrr_stack+92668, NULL);
 tmp = dvrr_stack + 112957;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+61130, dvrr_stack+107503, NULL);
 tmp = dvrr_stack + 61130;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+7388, dvrr_stack+124587, NULL);
 tmp = dvrr_stack + 7388;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+237036, dvrr_stack+137409, NULL);
 tmp = dvrr_stack + 237036;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+237820, dvrr_stack+153659, NULL);
 tmp = dvrr_stack + 237820;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+272950, dvrr_stack+172097, NULL);
 tmp = dvrr_stack + 272950;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+129391, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 129391;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+113713, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 113713;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+1305, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 1305;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+274210, dvrr_stack+25284, NULL);
 tmp = dvrr_stack + 274210;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+274660, dvrr_stack+33706, NULL);
 tmp = dvrr_stack + 274660;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+62861, dvrr_stack+40321, NULL);
 tmp = dvrr_stack + 62861;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+29998, dvrr_stack+48716, NULL);
 tmp = dvrr_stack + 29998;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+12077, dvrr_stack+59105, NULL);
 tmp = dvrr_stack + 12077;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+12752, dvrr_stack+71214, NULL);
 tmp = dvrr_stack + 12752;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+73833, dvrr_stack+80673, NULL);
 tmp = dvrr_stack + 73833;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+274975, dvrr_stack+92668, NULL);
 tmp = dvrr_stack + 274975;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+275731, dvrr_stack+107503, NULL);
 tmp = dvrr_stack + 275731;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+276676, dvrr_stack+124587, NULL);
 tmp = dvrr_stack + 276676;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+277264, dvrr_stack+137409, NULL);
 tmp = dvrr_stack + 277264;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+278048, dvrr_stack+153659, NULL);
 tmp = dvrr_stack + 278048;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+279056, dvrr_stack+172097, NULL);
 tmp = dvrr_stack + 279056;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+113993, dvrr_stack+156683, NULL);
 tmp = dvrr_stack + 113993;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+3465, dvrr_stack+41626, NULL);
 tmp = dvrr_stack + 3465;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+280316, dvrr_stack+94936, NULL);
 tmp = dvrr_stack + 280316;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+74421, dvrr_stack+175877, NULL);
 tmp = dvrr_stack + 74421;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+280676, dvrr_stack+96016, NULL);
 tmp = dvrr_stack + 280676;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+280991, dvrr_stack+177227, NULL);
 tmp = dvrr_stack + 280991;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+281411, dvrr_stack+178487, NULL);
 tmp = dvrr_stack + 281411;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+281951, dvrr_stack+180107, NULL);
 tmp = dvrr_stack + 281951;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+282626, dvrr_stack+182132, NULL);
 tmp = dvrr_stack + 282626;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+283067, dvrr_stack+183455, NULL);
 tmp = dvrr_stack + 283067;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+283655, dvrr_stack+185219, NULL);
 tmp = dvrr_stack + 283655;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+284411, dvrr_stack+187487, NULL);
 tmp = dvrr_stack + 284411;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+285356, dvrr_stack+190322, NULL);
 tmp = dvrr_stack + 285356;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+285944, dvrr_stack+192086, NULL);
 tmp = dvrr_stack + 285944;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+286728, dvrr_stack+194438, NULL);
 tmp = dvrr_stack + 286728;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+287736, dvrr_stack+197462, NULL);
 tmp = dvrr_stack + 287736;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+1665, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 1665;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+6208, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 6208;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+27978, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 27978;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+17595, dvrr_stack+25284, NULL);
 tmp = dvrr_stack + 17595;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+6488, dvrr_stack+33706, NULL);
 tmp = dvrr_stack + 6488;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+33664, dvrr_stack+40321, NULL);
 tmp = dvrr_stack + 33664;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+40246, dvrr_stack+48716, NULL);
 tmp = dvrr_stack + 40246;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+48641, dvrr_stack+59105, NULL);
 tmp = dvrr_stack + 48641;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+59008, dvrr_stack+71214, NULL);
 tmp = dvrr_stack + 59008;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+71097, dvrr_stack+80673, NULL);
 tmp = dvrr_stack + 71097;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+80557, dvrr_stack+92668, NULL);
 tmp = dvrr_stack + 80557;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+81313, dvrr_stack+107503, NULL);
 tmp = dvrr_stack + 81313;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+107472, dvrr_stack+124587, NULL);
 tmp = dvrr_stack + 107472;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+124566, dvrr_stack+137409, NULL);
 tmp = dvrr_stack + 124566;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+137328, dvrr_stack+153659, NULL);
 tmp = dvrr_stack + 137328;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+138336, dvrr_stack+172097, NULL);
 tmp = dvrr_stack + 138336;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+20045, dvrr_stack+156683, NULL);
 tmp = dvrr_stack + 20045;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+63281, dvrr_stack+41626, NULL);
 tmp = dvrr_stack + 63281;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+159689, dvrr_stack+94936, NULL);
 tmp = dvrr_stack + 159689;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+153641, dvrr_stack+175877, NULL);
 tmp = dvrr_stack + 153641;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+154091, dvrr_stack+96016, NULL);
 tmp = dvrr_stack + 154091;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+154406, dvrr_stack+177227, NULL);
 tmp = dvrr_stack + 154406;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+154826, dvrr_stack+178487, NULL);
 tmp = dvrr_stack + 154826;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+155366, dvrr_stack+180107, NULL);
 tmp = dvrr_stack + 155366;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+156041, dvrr_stack+182132, NULL);
 tmp = dvrr_stack + 156041;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+156482, dvrr_stack+183455, NULL);
 tmp = dvrr_stack + 156482;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+172094, dvrr_stack+185219, NULL);
 tmp = dvrr_stack + 172094;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+172850, dvrr_stack+187487, NULL);
 tmp = dvrr_stack + 172850;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+173795, dvrr_stack+190322, NULL);
 tmp = dvrr_stack + 173795;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+174383, dvrr_stack+192086, NULL);
 tmp = dvrr_stack + 174383;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+175167, dvrr_stack+194438, NULL);
 tmp = dvrr_stack + 175167;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+176175, dvrr_stack+197462, NULL);
 tmp = dvrr_stack + 176175;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+675, dvrr_stack+157313, NULL);
 tmp = dvrr_stack + 675;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+157070, dvrr_stack+4948, NULL);
 tmp = dvrr_stack + 157070;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+4948, dvrr_stack+9557, NULL);
 tmp = dvrr_stack + 4948;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+5308, dvrr_stack+15461, NULL);
 tmp = dvrr_stack + 5308;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+157350, dvrr_stack+22584, NULL);
 tmp = dvrr_stack + 157350;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+22554, dvrr_stack+31816, NULL);
 tmp = dvrr_stack + 22554;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+31816, dvrr_stack+37801, NULL);
 tmp = dvrr_stack + 31816;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+37801, dvrr_stack+45476, NULL);
 tmp = dvrr_stack + 37801;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+38476, dvrr_stack+55055, NULL);
 tmp = dvrr_stack + 38476;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+32356, dvrr_stack+68568, NULL);
 tmp = dvrr_stack + 32356;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+45392, dvrr_stack+77145, NULL);
 tmp = dvrr_stack + 45392;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+46148, dvrr_stack+88132, NULL);
 tmp = dvrr_stack + 46148;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+177435, dvrr_stack+101833, NULL);
 tmp = dvrr_stack + 177435;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+178023, dvrr_stack+121059, NULL);
 tmp = dvrr_stack + 178023;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+178807, dvrr_stack+132705, NULL);
 tmp = dvrr_stack + 178807;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+132687, dvrr_stack+147611, NULL);
 tmp = dvrr_stack + 132687;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+38917, dvrr_stack+165530, dvrr_stack+165380);
 tmp = dvrr_stack + 38917;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+39127, dvrr_stack+35146, dvrr_stack+165810);
 tmp = dvrr_stack + 39127;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+47093, dvrr_stack+166020, dvrr_stack+165530);
 tmp = dvrr_stack + 47093;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+22974, dvrr_stack+166470, dvrr_stack+35146);
 tmp = dvrr_stack + 22974;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+133947, dvrr_stack+5788, dvrr_stack+168020);
 tmp = dvrr_stack + 133947;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+134262, dvrr_stack+168560, dvrr_stack+168245);
 tmp = dvrr_stack + 134262;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+134682, dvrr_stack+169100, dvrr_stack+5788);
 tmp = dvrr_stack + 134682;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+179815, dvrr_stack+169775, dvrr_stack+168560);
 tmp = dvrr_stack + 179815;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+135222, dvrr_stack+151706, dvrr_stack+151391);
 tmp = dvrr_stack + 135222;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+180490, dvrr_stack+152735, dvrr_stack+152294);
 tmp = dvrr_stack + 180490;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+181078, dvrr_stack+135729, dvrr_stack+151706);
 tmp = dvrr_stack + 181078;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+181834, dvrr_stack+123411, dvrr_stack+152735);
 tmp = dvrr_stack + 181834;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+182779, dvrr_stack+104017, dvrr_stack+103597);
 tmp = dvrr_stack + 182779;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+183367, dvrr_stack+105389, dvrr_stack+104801);
 tmp = dvrr_stack + 183367;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+184151, dvrr_stack+90967, dvrr_stack+104017);
 tmp = dvrr_stack + 184151;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+185159, dvrr_stack+56378, dvrr_stack+105389);
 tmp = dvrr_stack + 185159;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+62075, dvrr_stack+106397, dvrr_stack+153491);
 tmp = dvrr_stack + 62075;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+186419, dvrr_stack+106887, dvrr_stack+106677);
 tmp = dvrr_stack + 186419;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+186699, dvrr_stack+70332, dvrr_stack+106397);
 tmp = dvrr_stack + 186699;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+187059, dvrr_stack+57918, dvrr_stack+106887);
 tmp = dvrr_stack + 187059;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+187509, dvrr_stack+92227, dvrr_stack+107247);
 tmp = dvrr_stack + 187509;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+187824, dvrr_stack+58468, dvrr_stack+70782);
 tmp = dvrr_stack + 187824;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+188244, dvrr_stack+47501, dvrr_stack+92227);
 tmp = dvrr_stack + 188244;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+188784, dvrr_stack+39421, dvrr_stack+58468);
 tmp = dvrr_stack + 188784;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+189459, dvrr_stack+33076, dvrr_stack+48176);
 tmp = dvrr_stack + 189459;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+189900, dvrr_stack+23970, dvrr_stack+23529);
 tmp = dvrr_stack + 189900;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+190488, dvrr_stack+50336, dvrr_stack+33076);
 tmp = dvrr_stack + 190488;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+191244, dvrr_stack+201242, dvrr_stack+23970);
 tmp = dvrr_stack + 191244;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+192189, dvrr_stack+16811, dvrr_stack+24726);
 tmp = dvrr_stack + 192189;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+192777, dvrr_stack+202397, dvrr_stack+10637);
 tmp = dvrr_stack + 192777;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+193561, dvrr_stack+203405, dvrr_stack+16811);
 tmp = dvrr_stack + 193561;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+194569, dvrr_stack+204665, dvrr_stack+202397);
 tmp = dvrr_stack + 194569;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+167765, dvrr_stack+164930, dvrr_stack+48491);
 tmp = dvrr_stack + 167765;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+195829, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 195829;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+196109, dvrr_stack+8477, dvrr_stack+164930);
 tmp = dvrr_stack + 196109;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+196469, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 196469;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+196919, dvrr_stack+167345, dvrr_stack+20934);
 tmp = dvrr_stack + 196919;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+197234, dvrr_stack+28387, dvrr_stack+30556);
 tmp = dvrr_stack + 197234;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+197654, dvrr_stack+36181, dvrr_stack+167345);
 tmp = dvrr_stack + 197654;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+198194, dvrr_stack+43451, dvrr_stack+28387);
 tmp = dvrr_stack + 198194;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+198869, dvrr_stack+171065, dvrr_stack+52580);
 tmp = dvrr_stack + 198869;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+199310, dvrr_stack+63609, dvrr_stack+66804);
 tmp = dvrr_stack + 199310;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+199898, dvrr_stack+36856, dvrr_stack+171065);
 tmp = dvrr_stack + 199898;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+147603, dvrr_stack+85297, dvrr_stack+63609);
 tmp = dvrr_stack + 147603;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+200654, dvrr_stack+79413, dvrr_stack+98368);
 tmp = dvrr_stack + 200654;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+148548, dvrr_stack+114279, dvrr_stack+118707);
 tmp = dvrr_stack + 148548;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+149332, dvrr_stack+129681, dvrr_stack+79413);
 tmp = dvrr_stack + 149332;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+120989, dvrr_stack+143831, dvrr_stack+114279);
 tmp = dvrr_stack + 120989;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+157665, dvrr_stack+160212, dvrr_stack+160062);
 tmp = dvrr_stack + 157665;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+150340, dvrr_stack+160702, dvrr_stack+160492);
 tmp = dvrr_stack + 150340;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+150620, dvrr_stack+161062, dvrr_stack+160212);
 tmp = dvrr_stack + 150620;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+122249, dvrr_stack+161512, dvrr_stack+160702);
 tmp = dvrr_stack + 122249;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+150980, dvrr_stack+162497, dvrr_stack+162272);
 tmp = dvrr_stack + 150980;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+122699, dvrr_stack+163232, dvrr_stack+162917);
 tmp = dvrr_stack + 122699;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+101644, dvrr_stack+163772, dvrr_stack+162497);
 tmp = dvrr_stack + 101644;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+102184, dvrr_stack+145371, dvrr_stack+163232);
 tmp = dvrr_stack + 102184;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+102859, dvrr_stack+146721, dvrr_stack+146406);
 tmp = dvrr_stack + 102859;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+87992, dvrr_stack+115287, dvrr_stack+130941);
 tmp = dvrr_stack + 87992;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+88580, dvrr_stack+30871, dvrr_stack+146721);
 tmp = dvrr_stack + 88580;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+89336, dvrr_stack+131382, dvrr_stack+115287);
 tmp = dvrr_stack + 89336;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+90281, dvrr_stack+119715, dvrr_stack+119295);
 tmp = dvrr_stack + 90281;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+77117, dvrr_stack+99376, dvrr_stack+98788);
 tmp = dvrr_stack + 77117;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+77901, dvrr_stack+100384, dvrr_stack+119715);
 tmp = dvrr_stack + 77901;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+68445, dvrr_stack+86452, dvrr_stack+99376);
 tmp = dvrr_stack + 68445;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+85065, dvrr_stack+165530, dvrr_stack+165380);
 tmp = dvrr_stack + 85065;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+164597, dvrr_stack+35146, dvrr_stack+165810);
 tmp = dvrr_stack + 164597;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+78909, dvrr_stack+166020, dvrr_stack+165530);
 tmp = dvrr_stack + 78909;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+69705, dvrr_stack+166470, dvrr_stack+35146);
 tmp = dvrr_stack + 69705;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+54953, dvrr_stack+5788, dvrr_stack+168020);
 tmp = dvrr_stack + 54953;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+55268, dvrr_stack+168560, dvrr_stack+168245);
 tmp = dvrr_stack + 55268;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+55688, dvrr_stack+169100, dvrr_stack+5788);
 tmp = dvrr_stack + 55688;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+15445, dvrr_stack+169775, dvrr_stack+168560);
 tmp = dvrr_stack + 15445;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+16120, dvrr_stack+151706, dvrr_stack+151391);
 tmp = dvrr_stack + 16120;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+9515, dvrr_stack+152735, dvrr_stack+152294);
 tmp = dvrr_stack + 9515;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+125350, dvrr_stack+135729, dvrr_stack+151706);
 tmp = dvrr_stack + 125350;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+108060, dvrr_stack+123411, dvrr_stack+152735);
 tmp = dvrr_stack + 108060;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+109005, dvrr_stack+104017, dvrr_stack+103597);
 tmp = dvrr_stack + 109005;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+92647, dvrr_stack+105389, dvrr_stack+104801);
 tmp = dvrr_stack + 92647;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+93431, dvrr_stack+90967, dvrr_stack+104017);
 tmp = dvrr_stack + 93431;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+94439, dvrr_stack+56378, dvrr_stack+105389);
 tmp = dvrr_stack + 94439;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+123119, dvrr_stack+106397, dvrr_stack+153491);
 tmp = dvrr_stack + 123119;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+103300, dvrr_stack+106887, dvrr_stack+106677);
 tmp = dvrr_stack + 103300;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+10103, dvrr_stack+70332, dvrr_stack+106397);
 tmp = dvrr_stack + 10103;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+109593, dvrr_stack+57918, dvrr_stack+106887);
 tmp = dvrr_stack + 109593;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+95699, dvrr_stack+92227, dvrr_stack+107247);
 tmp = dvrr_stack + 95699;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+96014, dvrr_stack+58468, dvrr_stack+70782);
 tmp = dvrr_stack + 96014;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+71685, dvrr_stack+47501, dvrr_stack+92227);
 tmp = dvrr_stack + 71685;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+59449, dvrr_stack+39421, dvrr_stack+58468);
 tmp = dvrr_stack + 59449;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+96434, dvrr_stack+33076, dvrr_stack+48176);
 tmp = dvrr_stack + 96434;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+60124, dvrr_stack+23970, dvrr_stack+23529);
 tmp = dvrr_stack + 60124;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+49316, dvrr_stack+50336, dvrr_stack+33076);
 tmp = dvrr_stack + 49316;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+40786, dvrr_stack+201242, dvrr_stack+23970);
 tmp = dvrr_stack + 40786;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+41731, dvrr_stack+16811, dvrr_stack+24726);
 tmp = dvrr_stack + 41731;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+25146, dvrr_stack+202397, dvrr_stack+10637);
 tmp = dvrr_stack + 25146;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+288996, dvrr_stack+203405, dvrr_stack+16811);
 tmp = dvrr_stack + 288996;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+290004, dvrr_stack+204665, dvrr_stack+202397);
 tmp = dvrr_stack + 290004;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+291264, dvrr_stack+164930, dvrr_stack+48491);
 tmp = dvrr_stack + 291264;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+291474, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 291474;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+60712, dvrr_stack+8477, dvrr_stack+164930);
 tmp = dvrr_stack + 60712;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+34084, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 34084;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+25930, dvrr_stack+167345, dvrr_stack+20934);
 tmp = dvrr_stack + 25930;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+18045, dvrr_stack+28387, dvrr_stack+30556);
 tmp = dvrr_stack + 18045;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+11225, dvrr_stack+36181, dvrr_stack+167345);
 tmp = dvrr_stack + 11225;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+291754, dvrr_stack+43451, dvrr_stack+28387);
 tmp = dvrr_stack + 291754;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+292429, dvrr_stack+171065, dvrr_stack+52580);
 tmp = dvrr_stack + 292429;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+292870, dvrr_stack+63609, dvrr_stack+66804);
 tmp = dvrr_stack + 292870;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+293458, dvrr_stack+36856, dvrr_stack+171065);
 tmp = dvrr_stack + 293458;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+294214, dvrr_stack+85297, dvrr_stack+63609);
 tmp = dvrr_stack + 294214;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+295159, dvrr_stack+79413, dvrr_stack+98368);
 tmp = dvrr_stack + 295159;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+295747, dvrr_stack+114279, dvrr_stack+118707);
 tmp = dvrr_stack + 295747;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+296531, dvrr_stack+129681, dvrr_stack+79413);
 tmp = dvrr_stack + 296531;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+297539, dvrr_stack+143831, dvrr_stack+114279);
 tmp = dvrr_stack + 297539;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+16561, dvrr_stack+160212, dvrr_stack+160062);
 tmp = dvrr_stack + 16561;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+110043, dvrr_stack+160702, dvrr_stack+160492);
 tmp = dvrr_stack + 110043;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+26245, dvrr_stack+161062, dvrr_stack+160212);
 tmp = dvrr_stack + 26245;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+298799, dvrr_stack+161512, dvrr_stack+160702);
 tmp = dvrr_stack + 298799;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+299249, dvrr_stack+162497, dvrr_stack+162272);
 tmp = dvrr_stack + 299249;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+299564, dvrr_stack+163232, dvrr_stack+162917);
 tmp = dvrr_stack + 299564;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+299984, dvrr_stack+163772, dvrr_stack+162497);
 tmp = dvrr_stack + 299984;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+300524, dvrr_stack+145371, dvrr_stack+163232);
 tmp = dvrr_stack + 300524;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+301199, dvrr_stack+146721, dvrr_stack+146406);
 tmp = dvrr_stack + 301199;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+301640, dvrr_stack+115287, dvrr_stack+130941);
 tmp = dvrr_stack + 301640;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+302228, dvrr_stack+30871, dvrr_stack+146721);
 tmp = dvrr_stack + 302228;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+302984, dvrr_stack+131382, dvrr_stack+115287);
 tmp = dvrr_stack + 302984;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+303929, dvrr_stack+119715, dvrr_stack+119295);
 tmp = dvrr_stack + 303929;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+304517, dvrr_stack+99376, dvrr_stack+98788);
 tmp = dvrr_stack + 304517;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+305301, dvrr_stack+100384, dvrr_stack+119715);
 tmp = dvrr_stack + 305301;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+306309, dvrr_stack+86452, dvrr_stack+99376);
 tmp = dvrr_stack + 306309;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+307569, dvrr_stack+120499, dvrr_stack+164447);
 tmp = dvrr_stack + 307569;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+72225, dvrr_stack+80197, dvrr_stack+120779);
 tmp = dvrr_stack + 72225;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+307779, dvrr_stack+74877, dvrr_stack+120499);
 tmp = dvrr_stack + 307779;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+308139, dvrr_stack+75327, dvrr_stack+80197);
 tmp = dvrr_stack + 308139;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+308589, dvrr_stack+76102, dvrr_stack+75877);
 tmp = dvrr_stack + 308589;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+308904, dvrr_stack+64365, dvrr_stack+76522);
 tmp = dvrr_stack + 308904;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+309324, dvrr_stack+67245, dvrr_stack+76102);
 tmp = dvrr_stack + 309324;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+309864, dvrr_stack+52895, dvrr_stack+64365);
 tmp = dvrr_stack + 309864;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+310539, dvrr_stack+53720, dvrr_stack+67920);
 tmp = dvrr_stack + 310539;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+310980, dvrr_stack+44276, dvrr_stack+171653);
 tmp = dvrr_stack + 310980;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+311568, dvrr_stack+21159, dvrr_stack+53720);
 tmp = dvrr_stack + 311568;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+312324, dvrr_stack+206205, dvrr_stack+44276);
 tmp = dvrr_stack + 312324;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+313269, dvrr_stack+14661, dvrr_stack+54308);
 tmp = dvrr_stack + 313269;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+313857, dvrr_stack+207360, dvrr_stack+8927);
 tmp = dvrr_stack + 313857;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+314641, dvrr_stack+208368, dvrr_stack+14661);
 tmp = dvrr_stack + 314641;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+315649, dvrr_stack+209628, dvrr_stack+207360);
 tmp = dvrr_stack + 315649;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+126106, dvrr_stack+165530, dvrr_stack+165380);
 tmp = dvrr_stack + 126106;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+165210, dvrr_stack+35146, dvrr_stack+165810);
 tmp = dvrr_stack + 165210;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+316909, dvrr_stack+166020, dvrr_stack+165530);
 tmp = dvrr_stack + 316909;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+317269, dvrr_stack+166470, dvrr_stack+35146);
 tmp = dvrr_stack + 317269;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+166470, dvrr_stack+5788, dvrr_stack+168020);
 tmp = dvrr_stack + 166470;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+317719, dvrr_stack+168560, dvrr_stack+168245);
 tmp = dvrr_stack + 317719;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+318139, dvrr_stack+169100, dvrr_stack+5788);
 tmp = dvrr_stack + 318139;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+318679, dvrr_stack+169775, dvrr_stack+168560);
 tmp = dvrr_stack + 318679;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+169775, dvrr_stack+151706, dvrr_stack+151391);
 tmp = dvrr_stack + 169775;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+319354, dvrr_stack+152735, dvrr_stack+152294);
 tmp = dvrr_stack + 319354;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+319942, dvrr_stack+135729, dvrr_stack+151706);
 tmp = dvrr_stack + 319942;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+320698, dvrr_stack+123411, dvrr_stack+152735);
 tmp = dvrr_stack + 320698;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+123329, dvrr_stack+104017, dvrr_stack+103597);
 tmp = dvrr_stack + 123329;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+321643, dvrr_stack+105389, dvrr_stack+104801);
 tmp = dvrr_stack + 321643;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+322427, dvrr_stack+90967, dvrr_stack+104017);
 tmp = dvrr_stack + 322427;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+323435, dvrr_stack+56378, dvrr_stack+105389);
 tmp = dvrr_stack + 323435;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+170216, dvrr_stack+106397, dvrr_stack+153491);
 tmp = dvrr_stack + 170216;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+324695, dvrr_stack+106887, dvrr_stack+106677);
 tmp = dvrr_stack + 324695;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+151295, dvrr_stack+70332, dvrr_stack+106397);
 tmp = dvrr_stack + 151295;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+123917, dvrr_stack+57918, dvrr_stack+106887);
 tmp = dvrr_stack + 123917;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+103580, dvrr_stack+92227, dvrr_stack+107247);
 tmp = dvrr_stack + 103580;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+56228, dvrr_stack+58468, dvrr_stack+70782);
 tmp = dvrr_stack + 56228;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+56648, dvrr_stack+47501, dvrr_stack+92227);
 tmp = dvrr_stack + 56648;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+57188, dvrr_stack+39421, dvrr_stack+58468);
 tmp = dvrr_stack + 57188;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+39407, dvrr_stack+33076, dvrr_stack+48176);
 tmp = dvrr_stack + 39407;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+57863, dvrr_stack+23970, dvrr_stack+23529);
 tmp = dvrr_stack + 57863;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+324975, dvrr_stack+50336, dvrr_stack+33076);
 tmp = dvrr_stack + 324975;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+325731, dvrr_stack+201242, dvrr_stack+23970);
 tmp = dvrr_stack + 325731;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+201242, dvrr_stack+16811, dvrr_stack+24726);
 tmp = dvrr_stack + 201242;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+326676, dvrr_stack+202397, dvrr_stack+10637);
 tmp = dvrr_stack + 326676;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+327460, dvrr_stack+203405, dvrr_stack+16811);
 tmp = dvrr_stack + 327460;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+328468, dvrr_stack+204665, dvrr_stack+202397);
 tmp = dvrr_stack + 328468;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+204665, dvrr_stack+164930, dvrr_stack+48491);
 tmp = dvrr_stack + 204665;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+204875, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 204875;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+205155, dvrr_stack+8477, dvrr_stack+164930);
 tmp = dvrr_stack + 205155;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+205515, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 205515;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+14111, dvrr_stack+167345, dvrr_stack+20934);
 tmp = dvrr_stack + 14111;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+24726, dvrr_stack+28387, dvrr_stack+30556);
 tmp = dvrr_stack + 24726;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+201830, dvrr_stack+36181, dvrr_stack+167345);
 tmp = dvrr_stack + 201830;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+329728, dvrr_stack+43451, dvrr_stack+28387);
 tmp = dvrr_stack + 329728;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+48176, dvrr_stack+171065, dvrr_stack+52580);
 tmp = dvrr_stack + 48176;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+330403, dvrr_stack+63609, dvrr_stack+66804);
 tmp = dvrr_stack + 330403;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+43291, dvrr_stack+36856, dvrr_stack+171065);
 tmp = dvrr_stack + 43291;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+330991, dvrr_stack+85297, dvrr_stack+63609);
 tmp = dvrr_stack + 330991;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+85275, dvrr_stack+79413, dvrr_stack+98368);
 tmp = dvrr_stack + 85275;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+331936, dvrr_stack+114279, dvrr_stack+118707);
 tmp = dvrr_stack + 331936;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+332720, dvrr_stack+129681, dvrr_stack+79413);
 tmp = dvrr_stack + 332720;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+333728, dvrr_stack+143831, dvrr_stack+114279);
 tmp = dvrr_stack + 333728;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+52580, dvrr_stack+160212, dvrr_stack+160062);
 tmp = dvrr_stack + 52580;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+39848, dvrr_stack+160702, dvrr_stack+160492);
 tmp = dvrr_stack + 39848;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+143811, dvrr_stack+161062, dvrr_stack+160212);
 tmp = dvrr_stack + 143811;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+144171, dvrr_stack+161512, dvrr_stack+160702);
 tmp = dvrr_stack + 144171;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+161512, dvrr_stack+162497, dvrr_stack+162272);
 tmp = dvrr_stack + 161512;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+144621, dvrr_stack+163232, dvrr_stack+162917);
 tmp = dvrr_stack + 144621;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+85863, dvrr_stack+163772, dvrr_stack+162497);
 tmp = dvrr_stack + 85863;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+334988, dvrr_stack+145371, dvrr_stack+163232);
 tmp = dvrr_stack + 334988;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+145041, dvrr_stack+146721, dvrr_stack+146406);
 tmp = dvrr_stack + 145041;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+145482, dvrr_stack+115287, dvrr_stack+130941);
 tmp = dvrr_stack + 145482;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+335663, dvrr_stack+30871, dvrr_stack+146721);
 tmp = dvrr_stack + 335663;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+336419, dvrr_stack+131382, dvrr_stack+115287);
 tmp = dvrr_stack + 336419;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+131382, dvrr_stack+119715, dvrr_stack+119295);
 tmp = dvrr_stack + 131382;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+337364, dvrr_stack+99376, dvrr_stack+98788);
 tmp = dvrr_stack + 337364;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+338148, dvrr_stack+100384, dvrr_stack+119715);
 tmp = dvrr_stack + 338148;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+339156, dvrr_stack+86452, dvrr_stack+99376);
 tmp = dvrr_stack + 339156;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+119295, dvrr_stack+120499, dvrr_stack+164447);
 tmp = dvrr_stack + 119295;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+131970, dvrr_stack+80197, dvrr_stack+120779);
 tmp = dvrr_stack + 131970;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+340416, dvrr_stack+74877, dvrr_stack+120499);
 tmp = dvrr_stack + 340416;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+86403, dvrr_stack+75327, dvrr_stack+80197);
 tmp = dvrr_stack + 86403;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+146406, dvrr_stack+76102, dvrr_stack+75877);
 tmp = dvrr_stack + 146406;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+75327, dvrr_stack+64365, dvrr_stack+76522);
 tmp = dvrr_stack + 75327;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+86853, dvrr_stack+67245, dvrr_stack+76102);
 tmp = dvrr_stack + 86853;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+340776, dvrr_stack+52895, dvrr_stack+64365);
 tmp = dvrr_stack + 340776;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+52790, dvrr_stack+53720, dvrr_stack+67920);
 tmp = dvrr_stack + 52790;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+87393, dvrr_stack+44276, dvrr_stack+171653);
 tmp = dvrr_stack + 87393;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+341451, dvrr_stack+21159, dvrr_stack+53720);
 tmp = dvrr_stack + 341451;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+342207, dvrr_stack+206205, dvrr_stack+44276);
 tmp = dvrr_stack + 342207;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+205965, dvrr_stack+14661, dvrr_stack+54308);
 tmp = dvrr_stack + 205965;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+206553, dvrr_stack+207360, dvrr_stack+8927);
 tmp = dvrr_stack + 206553;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+343152, dvrr_stack+208368, dvrr_stack+14661);
 tmp = dvrr_stack + 343152;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+344160, dvrr_stack+209628, dvrr_stack+207360);
 tmp = dvrr_stack + 344160;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+119505, dvrr_stack+76837, dvrr_stack+132537);
 tmp = dvrr_stack + 119505;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+209628, dvrr_stack+45032, dvrr_stack+68235);
 tmp = dvrr_stack + 209628;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+209908, dvrr_stack+22104, dvrr_stack+76837);
 tmp = dvrr_stack + 209908;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+210268, dvrr_stack+13561, dvrr_stack+45032);
 tmp = dvrr_stack + 210268;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+67920, dvrr_stack+4318, dvrr_stack+54728);
 tmp = dvrr_stack + 67920;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+210718, dvrr_stack+211168, dvrr_stack+28927);
 tmp = dvrr_stack + 210718;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+54308, dvrr_stack+20257, dvrr_stack+4318);
 tmp = dvrr_stack + 54308;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+345420, dvrr_stack+42466, dvrr_stack+211168);
 tmp = dvrr_stack + 345420;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+53231, dvrr_stack+51281, dvrr_stack+167020);
 tmp = dvrr_stack + 53231;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+346095, dvrr_stack+211708, dvrr_stack+51869);
 tmp = dvrr_stack + 346095;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+42319, dvrr_stack+212464, dvrr_stack+51281);
 tmp = dvrr_stack + 42319;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+346683, dvrr_stack+213409, dvrr_stack+211708);
 tmp = dvrr_stack + 346683;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+213409, dvrr_stack+97381, dvrr_stack+96961);
 tmp = dvrr_stack + 213409;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+347628, dvrr_stack+215152, dvrr_stack+214564);
 tmp = dvrr_stack + 347628;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+348412, dvrr_stack+216160, dvrr_stack+97381);
 tmp = dvrr_stack + 348412;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+349420, dvrr_stack+217420, dvrr_stack+215152);
 tmp = dvrr_stack + 349420;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+217420, dvrr_stack+168245, dvrr_stack+147309);
 tmp = dvrr_stack + 217420;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+217630, dvrr_stack+5788, dvrr_stack+147435);
 tmp = dvrr_stack + 217630;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+217910, dvrr_stack+168560, dvrr_stack+159473);
 tmp = dvrr_stack + 217910;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+218270, dvrr_stack+169100, dvrr_stack+2529);
 tmp = dvrr_stack + 218270;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+213997, dvrr_stack+152294, dvrr_stack+165810);
 tmp = dvrr_stack + 213997;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+132250, dvrr_stack+151706, dvrr_stack+165530);
 tmp = dvrr_stack + 132250;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+166785, dvrr_stack+152735, dvrr_stack+35146);
 tmp = dvrr_stack + 166785;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+350680, dvrr_stack+135729, dvrr_stack+166020);
 tmp = dvrr_stack + 350680;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+351355, dvrr_stack+104801, dvrr_stack+168245);
 tmp = dvrr_stack + 351355;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+98165, dvrr_stack+104017, dvrr_stack+5788);
 tmp = dvrr_stack + 98165;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+351796, dvrr_stack+105389, dvrr_stack+168560);
 tmp = dvrr_stack + 351796;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+352552, dvrr_stack+90967, dvrr_stack+169100);
 tmp = dvrr_stack + 352552;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+353497, dvrr_stack+226623, dvrr_stack+152294);
 tmp = dvrr_stack + 353497;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+354085, dvrr_stack+64905, dvrr_stack+151706);
 tmp = dvrr_stack + 354085;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+354869, dvrr_stack+72537, dvrr_stack+152735);
 tmp = dvrr_stack + 354869;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+355877, dvrr_stack+139761, dvrr_stack+135729);
 tmp = dvrr_stack + 355877;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+218720, dvrr_stack+70782, dvrr_stack+242841);
 tmp = dvrr_stack + 218720;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+75747, dvrr_stack+92227, dvrr_stack+242967);
 tmp = dvrr_stack + 75747;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+357137, dvrr_stack+58468, dvrr_stack+243135);
 tmp = dvrr_stack + 357137;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+357497, dvrr_stack+47501, dvrr_stack+243351);
 tmp = dvrr_stack + 357497;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+13525, dvrr_stack+23529, dvrr_stack+106677);
 tmp = dvrr_stack + 13525;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+96875, dvrr_stack+33076, dvrr_stack+106397);
 tmp = dvrr_stack + 96875;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+357947, dvrr_stack+23970, dvrr_stack+106887);
 tmp = dvrr_stack + 357947;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+358487, dvrr_stack+50336, dvrr_stack+70332);
 tmp = dvrr_stack + 358487;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+359162, dvrr_stack+10637, dvrr_stack+70782);
 tmp = dvrr_stack + 359162;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+359603, dvrr_stack+16811, dvrr_stack+92227);
 tmp = dvrr_stack + 359603;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+360191, dvrr_stack+202397, dvrr_stack+58468);
 tmp = dvrr_stack + 360191;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+360947, dvrr_stack+203405, dvrr_stack+47501);
 tmp = dvrr_stack + 360947;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+361892, dvrr_stack+243621, dvrr_stack+23529);
 tmp = dvrr_stack + 361892;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+362480, dvrr_stack+141381, dvrr_stack+33076);
 tmp = dvrr_stack + 362480;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+363264, dvrr_stack+142389, dvrr_stack+23970);
 tmp = dvrr_stack + 363264;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+364272, dvrr_stack+82437, dvrr_stack+50336);
 tmp = dvrr_stack + 364272;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+214312, dvrr_stack+30556, dvrr_stack+143685);
 tmp = dvrr_stack + 214312;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+365532, dvrr_stack+167345, dvrr_stack+157943);
 tmp = dvrr_stack + 365532;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+365812, dvrr_stack+28387, dvrr_stack+158111);
 tmp = dvrr_stack + 365812;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+366172, dvrr_stack+36181, dvrr_stack+158327);
 tmp = dvrr_stack + 366172;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+366622, dvrr_stack+66804, dvrr_stack+4108);
 tmp = dvrr_stack + 366622;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+366937, dvrr_stack+171065, dvrr_stack+164930);
 tmp = dvrr_stack + 366937;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+367357, dvrr_stack+63609, dvrr_stack+2169);
 tmp = dvrr_stack + 367357;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+367897, dvrr_stack+36856, dvrr_stack+8477);
 tmp = dvrr_stack + 367897;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+368572, dvrr_stack+118707, dvrr_stack+30556);
 tmp = dvrr_stack + 368572;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+369013, dvrr_stack+79413, dvrr_stack+167345);
 tmp = dvrr_stack + 369013;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+369601, dvrr_stack+114279, dvrr_stack+28387);
 tmp = dvrr_stack + 369601;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+370357, dvrr_stack+129681, dvrr_stack+36181);
 tmp = dvrr_stack + 370357;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+371302, dvrr_stack+218960, dvrr_stack+66804);
 tmp = dvrr_stack + 371302;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+371890, dvrr_stack+224355, dvrr_stack+171065);
 tmp = dvrr_stack + 371890;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+372674, dvrr_stack+230979, dvrr_stack+63609);
 tmp = dvrr_stack + 372674;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+373682, dvrr_stack+238953, dvrr_stack+36856);
 tmp = dvrr_stack + 373682;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+162272, dvrr_stack+162917, dvrr_stack+246361);
 tmp = dvrr_stack + 162272;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+11765, dvrr_stack+162497, dvrr_stack+246487);
 tmp = dvrr_stack + 11765;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+374942, dvrr_stack+163232, dvrr_stack+246655);
 tmp = dvrr_stack + 374942;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+375302, dvrr_stack+163772, dvrr_stack+246871);
 tmp = dvrr_stack + 375302;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+375752, dvrr_stack+130941, dvrr_stack+160492);
 tmp = dvrr_stack + 375752;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+376067, dvrr_stack+146721, dvrr_stack+160212);
 tmp = dvrr_stack + 376067;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+376487, dvrr_stack+115287, dvrr_stack+160702);
 tmp = dvrr_stack + 376487;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+377027, dvrr_stack+30871, dvrr_stack+161062);
 tmp = dvrr_stack + 377027;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+377702, dvrr_stack+98788, dvrr_stack+162917);
 tmp = dvrr_stack + 377702;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+378143, dvrr_stack+119715, dvrr_stack+162497);
 tmp = dvrr_stack + 378143;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+378731, dvrr_stack+99376, dvrr_stack+163232);
 tmp = dvrr_stack + 378731;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+379487, dvrr_stack+100384, dvrr_stack+163772);
 tmp = dvrr_stack + 379487;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+380432, dvrr_stack+248132, dvrr_stack+130941);
 tmp = dvrr_stack + 380432;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+381020, dvrr_stack+248888, dvrr_stack+146721);
 tmp = dvrr_stack + 381020;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+381804, dvrr_stack+249896, dvrr_stack+115287);
 tmp = dvrr_stack + 381804;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+382812, dvrr_stack+240573, dvrr_stack+30871);
 tmp = dvrr_stack + 382812;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+161827, dvrr_stack+76522, dvrr_stack+170600);
 tmp = dvrr_stack + 161827;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+384072, dvrr_stack+76102, dvrr_stack+170726);
 tmp = dvrr_stack + 384072;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+384352, dvrr_stack+64365, dvrr_stack+136674);
 tmp = dvrr_stack + 384352;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+384712, dvrr_stack+67245, dvrr_stack+136890);
 tmp = dvrr_stack + 384712;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+385162, dvrr_stack+171653, dvrr_stack+120779);
 tmp = dvrr_stack + 385162;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+385477, dvrr_stack+53720, dvrr_stack+120499);
 tmp = dvrr_stack + 385477;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+385897, dvrr_stack+44276, dvrr_stack+80197);
 tmp = dvrr_stack + 385897;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+386437, dvrr_stack+21159, dvrr_stack+74877);
 tmp = dvrr_stack + 386437;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+387112, dvrr_stack+8927, dvrr_stack+76522);
 tmp = dvrr_stack + 387112;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+387553, dvrr_stack+14661, dvrr_stack+76102);
 tmp = dvrr_stack + 387553;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+388141, dvrr_stack+207360, dvrr_stack+64365);
 tmp = dvrr_stack + 388141;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+388897, dvrr_stack+208368, dvrr_stack+67245);
 tmp = dvrr_stack + 388897;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+389842, dvrr_stack+251192, dvrr_stack+171653);
 tmp = dvrr_stack + 389842;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+390430, dvrr_stack+232275, dvrr_stack+53720);
 tmp = dvrr_stack + 390430;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+391214, dvrr_stack+251948, dvrr_stack+44276);
 tmp = dvrr_stack + 391214;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+392222, dvrr_stack+253244, dvrr_stack+21159);
 tmp = dvrr_stack + 392222;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+14426, dvrr_stack+28927, dvrr_stack+170894);
 tmp = dvrr_stack + 14426;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+393482, dvrr_stack+4318, dvrr_stack+137160);
 tmp = dvrr_stack + 393482;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+393762, dvrr_stack+211168, dvrr_stack+247141);
 tmp = dvrr_stack + 393762;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+394122, dvrr_stack+20257, dvrr_stack+242193);
 tmp = dvrr_stack + 394122;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+394572, dvrr_stack+51869, dvrr_stack+68235);
 tmp = dvrr_stack + 394572;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+394887, dvrr_stack+51281, dvrr_stack+76837);
 tmp = dvrr_stack + 394887;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+395307, dvrr_stack+211708, dvrr_stack+45032);
 tmp = dvrr_stack + 395307;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+395847, dvrr_stack+212464, dvrr_stack+22104);
 tmp = dvrr_stack + 395847;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+396522, dvrr_stack+214564, dvrr_stack+28927);
 tmp = dvrr_stack + 396522;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+396963, dvrr_stack+97381, dvrr_stack+4318);
 tmp = dvrr_stack + 396963;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+397551, dvrr_stack+215152, dvrr_stack+211168);
 tmp = dvrr_stack + 397551;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+398307, dvrr_stack+216160, dvrr_stack+20257);
 tmp = dvrr_stack + 398307;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+399252, dvrr_stack+225363, dvrr_stack+51869);
 tmp = dvrr_stack + 399252;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+399840, dvrr_stack+84057, dvrr_stack+51281);
 tmp = dvrr_stack + 399840;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+400624, dvrr_stack+254864, dvrr_stack+211708);
 tmp = dvrr_stack + 400624;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+401632, dvrr_stack+256160, dvrr_stack+212464);
 tmp = dvrr_stack + 401632;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+107247, dvrr_stack+247357, dvrr_stack+13231);
 tmp = dvrr_stack + 107247;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+402892, dvrr_stack+247672, dvrr_stack+13357);
 tmp = dvrr_stack + 402892;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+403172, dvrr_stack+233283, dvrr_stack+257780);
 tmp = dvrr_stack + 403172;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+403532, dvrr_stack+158597, dvrr_stack+242463);
 tmp = dvrr_stack + 403532;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+403982, dvrr_stack+244377, dvrr_stack+226119);
 tmp = dvrr_stack + 403982;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+404297, dvrr_stack+244818, dvrr_stack+226329);
 tmp = dvrr_stack + 404297;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+404717, dvrr_stack+257996, dvrr_stack+245406);
 tmp = dvrr_stack + 404717;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+405257, dvrr_stack+258752, dvrr_stack+245766);
 tmp = dvrr_stack + 405257;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+405932, dvrr_stack+259697, dvrr_stack+247357);
 tmp = dvrr_stack + 405932;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+406373, dvrr_stack+260285, dvrr_stack+247672);
 tmp = dvrr_stack + 406373;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+406961, dvrr_stack+261069, dvrr_stack+233283);
 tmp = dvrr_stack + 406961;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+407717, dvrr_stack+262077, dvrr_stack+158597);
 tmp = dvrr_stack + 407717;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+408662, dvrr_stack+18701, dvrr_stack+244377);
 tmp = dvrr_stack + 408662;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+409250, dvrr_stack+221555, dvrr_stack+244818);
 tmp = dvrr_stack + 409250;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+410034, dvrr_stack+227379, dvrr_stack+257996);
 tmp = dvrr_stack + 410034;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+411042, dvrr_stack+263337, dvrr_stack+258752);
 tmp = dvrr_stack + 411042;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+412302, dvrr_stack+168245, dvrr_stack+147309);
 tmp = dvrr_stack + 412302;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+412512, dvrr_stack+5788, dvrr_stack+147435);
 tmp = dvrr_stack + 412512;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+412792, dvrr_stack+168560, dvrr_stack+159473);
 tmp = dvrr_stack + 412792;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+413152, dvrr_stack+169100, dvrr_stack+2529);
 tmp = dvrr_stack + 413152;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+413602, dvrr_stack+152294, dvrr_stack+165810);
 tmp = dvrr_stack + 413602;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+413917, dvrr_stack+151706, dvrr_stack+165530);
 tmp = dvrr_stack + 413917;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+414337, dvrr_stack+152735, dvrr_stack+35146);
 tmp = dvrr_stack + 414337;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+414877, dvrr_stack+135729, dvrr_stack+166020);
 tmp = dvrr_stack + 414877;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+415552, dvrr_stack+104801, dvrr_stack+168245);
 tmp = dvrr_stack + 415552;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+415993, dvrr_stack+104017, dvrr_stack+5788);
 tmp = dvrr_stack + 415993;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+416581, dvrr_stack+105389, dvrr_stack+168560);
 tmp = dvrr_stack + 416581;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+417337, dvrr_stack+90967, dvrr_stack+169100);
 tmp = dvrr_stack + 417337;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+418282, dvrr_stack+226623, dvrr_stack+152294);
 tmp = dvrr_stack + 418282;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+418870, dvrr_stack+64905, dvrr_stack+151706);
 tmp = dvrr_stack + 418870;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+419654, dvrr_stack+72537, dvrr_stack+152735);
 tmp = dvrr_stack + 419654;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+420662, dvrr_stack+139761, dvrr_stack+135729);
 tmp = dvrr_stack + 420662;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+167975, dvrr_stack+70782, dvrr_stack+242841);
 tmp = dvrr_stack + 167975;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+421922, dvrr_stack+92227, dvrr_stack+242967);
 tmp = dvrr_stack + 421922;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+422202, dvrr_stack+58468, dvrr_stack+243135);
 tmp = dvrr_stack + 422202;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+422562, dvrr_stack+47501, dvrr_stack+243351);
 tmp = dvrr_stack + 422562;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+423012, dvrr_stack+23529, dvrr_stack+106677);
 tmp = dvrr_stack + 423012;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+423327, dvrr_stack+33076, dvrr_stack+106397);
 tmp = dvrr_stack + 423327;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+423747, dvrr_stack+23970, dvrr_stack+106887);
 tmp = dvrr_stack + 423747;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+424287, dvrr_stack+50336, dvrr_stack+70332);
 tmp = dvrr_stack + 424287;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+424962, dvrr_stack+10637, dvrr_stack+70782);
 tmp = dvrr_stack + 424962;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+425403, dvrr_stack+16811, dvrr_stack+92227);
 tmp = dvrr_stack + 425403;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+425991, dvrr_stack+202397, dvrr_stack+58468);
 tmp = dvrr_stack + 425991;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+426747, dvrr_stack+203405, dvrr_stack+47501);
 tmp = dvrr_stack + 426747;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+427692, dvrr_stack+243621, dvrr_stack+23529);
 tmp = dvrr_stack + 427692;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+428280, dvrr_stack+141381, dvrr_stack+33076);
 tmp = dvrr_stack + 428280;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+429064, dvrr_stack+142389, dvrr_stack+23970);
 tmp = dvrr_stack + 429064;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+430072, dvrr_stack+82437, dvrr_stack+50336);
 tmp = dvrr_stack + 430072;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+431332, dvrr_stack+30556, dvrr_stack+143685);
 tmp = dvrr_stack + 431332;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+431542, dvrr_stack+167345, dvrr_stack+157943);
 tmp = dvrr_stack + 431542;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+431822, dvrr_stack+28387, dvrr_stack+158111);
 tmp = dvrr_stack + 431822;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+432182, dvrr_stack+36181, dvrr_stack+158327);
 tmp = dvrr_stack + 432182;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+432632, dvrr_stack+66804, dvrr_stack+4108);
 tmp = dvrr_stack + 432632;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+432947, dvrr_stack+171065, dvrr_stack+164930);
 tmp = dvrr_stack + 432947;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+433367, dvrr_stack+63609, dvrr_stack+2169);
 tmp = dvrr_stack + 433367;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+433907, dvrr_stack+36856, dvrr_stack+8477);
 tmp = dvrr_stack + 433907;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+434582, dvrr_stack+118707, dvrr_stack+30556);
 tmp = dvrr_stack + 434582;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+435023, dvrr_stack+79413, dvrr_stack+167345);
 tmp = dvrr_stack + 435023;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+435611, dvrr_stack+114279, dvrr_stack+28387);
 tmp = dvrr_stack + 435611;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+436367, dvrr_stack+129681, dvrr_stack+36181);
 tmp = dvrr_stack + 436367;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+437312, dvrr_stack+218960, dvrr_stack+66804);
 tmp = dvrr_stack + 437312;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+437900, dvrr_stack+224355, dvrr_stack+171065);
 tmp = dvrr_stack + 437900;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+438684, dvrr_stack+230979, dvrr_stack+63609);
 tmp = dvrr_stack + 438684;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+439692, dvrr_stack+238953, dvrr_stack+36856);
 tmp = dvrr_stack + 439692;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+13840, dvrr_stack+162917, dvrr_stack+246361);
 tmp = dvrr_stack + 13840;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+440952, dvrr_stack+162497, dvrr_stack+246487);
 tmp = dvrr_stack + 440952;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+441232, dvrr_stack+163232, dvrr_stack+246655);
 tmp = dvrr_stack + 441232;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+441592, dvrr_stack+163772, dvrr_stack+246871);
 tmp = dvrr_stack + 441592;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+442042, dvrr_stack+130941, dvrr_stack+160492);
 tmp = dvrr_stack + 442042;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+442357, dvrr_stack+146721, dvrr_stack+160212);
 tmp = dvrr_stack + 442357;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+442777, dvrr_stack+115287, dvrr_stack+160702);
 tmp = dvrr_stack + 442777;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+443317, dvrr_stack+30871, dvrr_stack+161062);
 tmp = dvrr_stack + 443317;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+443992, dvrr_stack+98788, dvrr_stack+162917);
 tmp = dvrr_stack + 443992;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+444433, dvrr_stack+119715, dvrr_stack+162497);
 tmp = dvrr_stack + 444433;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+445021, dvrr_stack+99376, dvrr_stack+163232);
 tmp = dvrr_stack + 445021;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+445777, dvrr_stack+100384, dvrr_stack+163772);
 tmp = dvrr_stack + 445777;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+446722, dvrr_stack+248132, dvrr_stack+130941);
 tmp = dvrr_stack + 446722;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+447310, dvrr_stack+248888, dvrr_stack+146721);
 tmp = dvrr_stack + 447310;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+448094, dvrr_stack+249896, dvrr_stack+115287);
 tmp = dvrr_stack + 448094;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+449102, dvrr_stack+240573, dvrr_stack+30871);
 tmp = dvrr_stack + 449102;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+450362, dvrr_stack+76522, dvrr_stack+170600);
 tmp = dvrr_stack + 450362;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+450572, dvrr_stack+76102, dvrr_stack+170726);
 tmp = dvrr_stack + 450572;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+450852, dvrr_stack+64365, dvrr_stack+136674);
 tmp = dvrr_stack + 450852;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+451212, dvrr_stack+67245, dvrr_stack+136890);
 tmp = dvrr_stack + 451212;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+451662, dvrr_stack+171653, dvrr_stack+120779);
 tmp = dvrr_stack + 451662;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+451977, dvrr_stack+53720, dvrr_stack+120499);
 tmp = dvrr_stack + 451977;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+452397, dvrr_stack+44276, dvrr_stack+80197);
 tmp = dvrr_stack + 452397;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+452937, dvrr_stack+21159, dvrr_stack+74877);
 tmp = dvrr_stack + 452937;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+453612, dvrr_stack+8927, dvrr_stack+76522);
 tmp = dvrr_stack + 453612;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+454053, dvrr_stack+14661, dvrr_stack+76102);
 tmp = dvrr_stack + 454053;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+454641, dvrr_stack+207360, dvrr_stack+64365);
 tmp = dvrr_stack + 454641;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+455397, dvrr_stack+208368, dvrr_stack+67245);
 tmp = dvrr_stack + 455397;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+456342, dvrr_stack+251192, dvrr_stack+171653);
 tmp = dvrr_stack + 456342;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+456930, dvrr_stack+232275, dvrr_stack+53720);
 tmp = dvrr_stack + 456930;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+457714, dvrr_stack+251948, dvrr_stack+44276);
 tmp = dvrr_stack + 457714;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+458722, dvrr_stack+253244, dvrr_stack+21159);
 tmp = dvrr_stack + 458722;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+50072, dvrr_stack+28927, dvrr_stack+170894);
 tmp = dvrr_stack + 50072;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+459982, dvrr_stack+4318, dvrr_stack+137160);
 tmp = dvrr_stack + 459982;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+460262, dvrr_stack+211168, dvrr_stack+247141);
 tmp = dvrr_stack + 460262;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+460622, dvrr_stack+20257, dvrr_stack+242193);
 tmp = dvrr_stack + 460622;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+461072, dvrr_stack+51869, dvrr_stack+68235);
 tmp = dvrr_stack + 461072;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+461387, dvrr_stack+51281, dvrr_stack+76837);
 tmp = dvrr_stack + 461387;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+461807, dvrr_stack+211708, dvrr_stack+45032);
 tmp = dvrr_stack + 461807;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+462347, dvrr_stack+212464, dvrr_stack+22104);
 tmp = dvrr_stack + 462347;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+463022, dvrr_stack+214564, dvrr_stack+28927);
 tmp = dvrr_stack + 463022;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+463463, dvrr_stack+97381, dvrr_stack+4318);
 tmp = dvrr_stack + 463463;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+464051, dvrr_stack+215152, dvrr_stack+211168);
 tmp = dvrr_stack + 464051;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+464807, dvrr_stack+216160, dvrr_stack+20257);
 tmp = dvrr_stack + 464807;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+465752, dvrr_stack+225363, dvrr_stack+51869);
 tmp = dvrr_stack + 465752;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+466340, dvrr_stack+84057, dvrr_stack+51281);
 tmp = dvrr_stack + 466340;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+467124, dvrr_stack+254864, dvrr_stack+211708);
 tmp = dvrr_stack + 467124;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+468132, dvrr_stack+256160, dvrr_stack+212464);
 tmp = dvrr_stack + 468132;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+469392, dvrr_stack+247357, dvrr_stack+13231);
 tmp = dvrr_stack + 469392;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+469602, dvrr_stack+247672, dvrr_stack+13357);
 tmp = dvrr_stack + 469602;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+469882, dvrr_stack+233283, dvrr_stack+257780);
 tmp = dvrr_stack + 469882;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+470242, dvrr_stack+158597, dvrr_stack+242463);
 tmp = dvrr_stack + 470242;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+470692, dvrr_stack+244377, dvrr_stack+226119);
 tmp = dvrr_stack + 470692;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+471007, dvrr_stack+244818, dvrr_stack+226329);
 tmp = dvrr_stack + 471007;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+471427, dvrr_stack+257996, dvrr_stack+245406);
 tmp = dvrr_stack + 471427;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+471967, dvrr_stack+258752, dvrr_stack+245766);
 tmp = dvrr_stack + 471967;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+472642, dvrr_stack+259697, dvrr_stack+247357);
 tmp = dvrr_stack + 472642;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+473083, dvrr_stack+260285, dvrr_stack+247672);
 tmp = dvrr_stack + 473083;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+473671, dvrr_stack+261069, dvrr_stack+233283);
 tmp = dvrr_stack + 473671;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+474427, dvrr_stack+262077, dvrr_stack+158597);
 tmp = dvrr_stack + 474427;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+475372, dvrr_stack+18701, dvrr_stack+244377);
 tmp = dvrr_stack + 475372;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+475960, dvrr_stack+221555, dvrr_stack+244818);
 tmp = dvrr_stack + 475960;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+476744, dvrr_stack+227379, dvrr_stack+257996);
 tmp = dvrr_stack + 476744;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+477752, dvrr_stack+263337, dvrr_stack+258752);
 tmp = dvrr_stack + 477752;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+479012, dvrr_stack+110338, dvrr_stack+264957);
 tmp = dvrr_stack + 479012;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+479222, dvrr_stack+265083, dvrr_stack+1137);
 tmp = dvrr_stack + 479222;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+479502, dvrr_stack+265503, dvrr_stack+2799);
 tmp = dvrr_stack + 479502;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+479862, dvrr_stack+266043, dvrr_stack+52310);
 tmp = dvrr_stack + 479862;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+480312, dvrr_stack+266718, dvrr_stack+4738);
 tmp = dvrr_stack + 480312;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+480627, dvrr_stack+267439, dvrr_stack+267159);
 tmp = dvrr_stack + 480627;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+481047, dvrr_stack+268387, dvrr_stack+268027);
 tmp = dvrr_stack + 481047;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+481587, dvrr_stack+219716, dvrr_stack+269143);
 tmp = dvrr_stack + 481587;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+482262, dvrr_stack+19457, dvrr_stack+110338);
 tmp = dvrr_stack + 482262;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+482703, dvrr_stack+222563, dvrr_stack+265083);
 tmp = dvrr_stack + 482703;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+483291, dvrr_stack+228675, dvrr_stack+265503);
 tmp = dvrr_stack + 483291;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+484047, dvrr_stack+233823, dvrr_stack+266043);
 tmp = dvrr_stack + 484047;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+484992, dvrr_stack+29242, dvrr_stack+266718);
 tmp = dvrr_stack + 484992;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+485580, dvrr_stack+235083, dvrr_stack+267439);
 tmp = dvrr_stack + 485580;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+486364, dvrr_stack+269593, dvrr_stack+268387);
 tmp = dvrr_stack + 486364;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+487372, dvrr_stack+270889, dvrr_stack+219716);
 tmp = dvrr_stack + 487372;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+488632, dvrr_stack+168245, dvrr_stack+147309);
 tmp = dvrr_stack + 488632;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+488842, dvrr_stack+5788, dvrr_stack+147435);
 tmp = dvrr_stack + 488842;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+489122, dvrr_stack+168560, dvrr_stack+159473);
 tmp = dvrr_stack + 489122;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+489482, dvrr_stack+169100, dvrr_stack+2529);
 tmp = dvrr_stack + 489482;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+159272, dvrr_stack+152294, dvrr_stack+165810);
 tmp = dvrr_stack + 159272;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+489932, dvrr_stack+151706, dvrr_stack+165530);
 tmp = dvrr_stack + 489932;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+490352, dvrr_stack+152735, dvrr_stack+35146);
 tmp = dvrr_stack + 490352;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+490892, dvrr_stack+135729, dvrr_stack+166020);
 tmp = dvrr_stack + 490892;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+165490, dvrr_stack+104801, dvrr_stack+168245);
 tmp = dvrr_stack + 165490;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+104801, dvrr_stack+104017, dvrr_stack+5788);
 tmp = dvrr_stack + 104801;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+103895, dvrr_stack+105389, dvrr_stack+168560);
 tmp = dvrr_stack + 103895;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+105389, dvrr_stack+90967, dvrr_stack+169100);
 tmp = dvrr_stack + 105389;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+168185, dvrr_stack+226623, dvrr_stack+152294);
 tmp = dvrr_stack + 168185;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+168773, dvrr_stack+64905, dvrr_stack+151706);
 tmp = dvrr_stack + 168773;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+64905, dvrr_stack+72537, dvrr_stack+152735);
 tmp = dvrr_stack + 64905;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+151655, dvrr_stack+139761, dvrr_stack+135729);
 tmp = dvrr_stack + 151655;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+2529, dvrr_stack+70782, dvrr_stack+242841);
 tmp = dvrr_stack + 2529;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+147309, dvrr_stack+92227, dvrr_stack+242967);
 tmp = dvrr_stack + 147309;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+5758, dvrr_stack+58468, dvrr_stack+243135);
 tmp = dvrr_stack + 5758;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+242733, dvrr_stack+47501, dvrr_stack+243351);
 tmp = dvrr_stack + 242733;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+491567, dvrr_stack+23529, dvrr_stack+106677);
 tmp = dvrr_stack + 491567;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+243183, dvrr_stack+33076, dvrr_stack+106397);
 tmp = dvrr_stack + 243183;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+106334, dvrr_stack+23970, dvrr_stack+106887);
 tmp = dvrr_stack + 106334;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+139596, dvrr_stack+50336, dvrr_stack+70332);
 tmp = dvrr_stack + 139596;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+140271, dvrr_stack+10637, dvrr_stack+70782);
 tmp = dvrr_stack + 140271;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+140712, dvrr_stack+16811, dvrr_stack+92227);
 tmp = dvrr_stack + 140712;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+135663, dvrr_stack+202397, dvrr_stack+58468);
 tmp = dvrr_stack + 135663;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+202370, dvrr_stack+203405, dvrr_stack+47501);
 tmp = dvrr_stack + 202370;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+203315, dvrr_stack+243621, dvrr_stack+23529);
 tmp = dvrr_stack + 203315;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+90869, dvrr_stack+141381, dvrr_stack+33076);
 tmp = dvrr_stack + 90869;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+141300, dvrr_stack+142389, dvrr_stack+23970);
 tmp = dvrr_stack + 141300;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+142308, dvrr_stack+82437, dvrr_stack+50336);
 tmp = dvrr_stack + 142308;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+106874, dvrr_stack+30556, dvrr_stack+143685);
 tmp = dvrr_stack + 106874;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+203903, dvrr_stack+167345, dvrr_stack+157943);
 tmp = dvrr_stack + 203903;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+204183, dvrr_stack+28387, dvrr_stack+158111);
 tmp = dvrr_stack + 204183;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+32944, dvrr_stack+36181, dvrr_stack+158327);
 tmp = dvrr_stack + 32944;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+243603, dvrr_stack+66804, dvrr_stack+4108);
 tmp = dvrr_stack + 243603;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+243918, dvrr_stack+171065, dvrr_stack+164930);
 tmp = dvrr_stack + 243918;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+47453, dvrr_stack+63609, dvrr_stack+2169);
 tmp = dvrr_stack + 47453;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+23424, dvrr_stack+36856, dvrr_stack+8477);
 tmp = dvrr_stack + 23424;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+8468, dvrr_stack+118707, dvrr_stack+30556);
 tmp = dvrr_stack + 8468;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+118692, dvrr_stack+79413, dvrr_stack+167345);
 tmp = dvrr_stack + 118692;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+226609, dvrr_stack+114279, dvrr_stack+28387);
 tmp = dvrr_stack + 226609;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+114203, dvrr_stack+129681, dvrr_stack+36181);
 tmp = dvrr_stack + 114203;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+129601, dvrr_stack+218960, dvrr_stack+66804);
 tmp = dvrr_stack + 129601;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+218930, dvrr_stack+224355, dvrr_stack+171065);
 tmp = dvrr_stack + 218930;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+224355, dvrr_stack+230979, dvrr_stack+63609);
 tmp = dvrr_stack + 224355;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+230943, dvrr_stack+238953, dvrr_stack+36856);
 tmp = dvrr_stack + 230943;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+4108, dvrr_stack+162917, dvrr_stack+246361);
 tmp = dvrr_stack + 4108;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+167325, dvrr_stack+162497, dvrr_stack+246487);
 tmp = dvrr_stack + 167325;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+130189, dvrr_stack+163232, dvrr_stack+246655);
 tmp = dvrr_stack + 130189;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+36094, dvrr_stack+163772, dvrr_stack+246871);
 tmp = dvrr_stack + 36094;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+130549, dvrr_stack+130941, dvrr_stack+160492);
 tmp = dvrr_stack + 130549;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+36544, dvrr_stack+146721, dvrr_stack+160212);
 tmp = dvrr_stack + 36544;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+36964, dvrr_stack+115287, dvrr_stack+160702);
 tmp = dvrr_stack + 36964;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+63561, dvrr_stack+30871, dvrr_stack+161062);
 tmp = dvrr_stack + 63561;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+66669, dvrr_stack+98788, dvrr_stack+162917);
 tmp = dvrr_stack + 66669;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+28338, dvrr_stack+119715, dvrr_stack+162497);
 tmp = dvrr_stack + 28338;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+119715, dvrr_stack+99376, dvrr_stack+163232);
 tmp = dvrr_stack + 119715;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+162482, dvrr_stack+100384, dvrr_stack+163772);
 tmp = dvrr_stack + 162482;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+163427, dvrr_stack+248132, dvrr_stack+130941);
 tmp = dvrr_stack + 163427;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+160049, dvrr_stack+248888, dvrr_stack+146721);
 tmp = dvrr_stack + 160049;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+248092, dvrr_stack+249896, dvrr_stack+115287);
 tmp = dvrr_stack + 248092;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+249100, dvrr_stack+240573, dvrr_stack+30871);
 tmp = dvrr_stack + 249100;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+146721, dvrr_stack+76522, dvrr_stack+170600);
 tmp = dvrr_stack + 146721;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+146931, dvrr_stack+76102, dvrr_stack+170726);
 tmp = dvrr_stack + 146931;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+164015, dvrr_stack+64365, dvrr_stack+136674);
 tmp = dvrr_stack + 164015;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+170426, dvrr_stack+67245, dvrr_stack+136890);
 tmp = dvrr_stack + 170426;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+130864, dvrr_stack+171653, dvrr_stack+120779);
 tmp = dvrr_stack + 130864;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+115148, dvrr_stack+53720, dvrr_stack+120499);
 tmp = dvrr_stack + 115148;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+171020, dvrr_stack+44276, dvrr_stack+80197);
 tmp = dvrr_stack + 171020;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+160833, dvrr_stack+21159, dvrr_stack+74877);
 tmp = dvrr_stack + 160833;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+120471, dvrr_stack+8927, dvrr_stack+76522);
 tmp = dvrr_stack + 120471;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+8909, dvrr_stack+14661, dvrr_stack+76102);
 tmp = dvrr_stack + 8909;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+76027, dvrr_stack+207360, dvrr_stack+64365);
 tmp = dvrr_stack + 76027;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+207337, dvrr_stack+208368, dvrr_stack+67245);
 tmp = dvrr_stack + 207337;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+14636, dvrr_stack+251192, dvrr_stack+171653);
 tmp = dvrr_stack + 14636;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+208282, dvrr_stack+232275, dvrr_stack+53720);
 tmp = dvrr_stack + 208282;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+232203, dvrr_stack+251948, dvrr_stack+44276);
 tmp = dvrr_stack + 232203;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+30538, dvrr_stack+253244, dvrr_stack+21159);
 tmp = dvrr_stack + 30538;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+164375, dvrr_stack+28927, dvrr_stack+170894);
 tmp = dvrr_stack + 164375;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+53672, dvrr_stack+4318, dvrr_stack+137160);
 tmp = dvrr_stack + 53672;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+209066, dvrr_stack+211168, dvrr_stack+247141);
 tmp = dvrr_stack + 209066;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+115568, dvrr_stack+20257, dvrr_stack+242193);
 tmp = dvrr_stack + 115568;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+53952, dvrr_stack+51869, dvrr_stack+68235);
 tmp = dvrr_stack + 53952;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+2105, dvrr_stack+51281, dvrr_stack+76837);
 tmp = dvrr_stack + 2105;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+67110, dvrr_stack+211708, dvrr_stack+45032);
 tmp = dvrr_stack + 67110;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+157875, dvrr_stack+212464, dvrr_stack+22104);
 tmp = dvrr_stack + 157875;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+64236, dvrr_stack+214564, dvrr_stack+28927);
 tmp = dvrr_stack + 64236;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+214522, dvrr_stack+97381, dvrr_stack+4318);
 tmp = dvrr_stack + 214522;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+136419, dvrr_stack+215152, dvrr_stack+211168);
 tmp = dvrr_stack + 136419;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+215110, dvrr_stack+216160, dvrr_stack+20257);
 tmp = dvrr_stack + 215110;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+216055, dvrr_stack+225363, dvrr_stack+51869);
 tmp = dvrr_stack + 216055;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+20255, dvrr_stack+84057, dvrr_stack+51281);
 tmp = dvrr_stack + 20255;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+21039, dvrr_stack+254864, dvrr_stack+211708);
 tmp = dvrr_stack + 21039;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+211138, dvrr_stack+256160, dvrr_stack+212464);
 tmp = dvrr_stack + 211138;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+68235, dvrr_stack+247357, dvrr_stack+13231);
 tmp = dvrr_stack + 68235;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+225363, dvrr_stack+247672, dvrr_stack+13357);
 tmp = dvrr_stack + 225363;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+225643, dvrr_stack+233283, dvrr_stack+257780);
 tmp = dvrr_stack + 225643;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+216643, dvrr_stack+158597, dvrr_stack+242463);
 tmp = dvrr_stack + 216643;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+4318, dvrr_stack+244377, dvrr_stack+226119);
 tmp = dvrr_stack + 4318;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+212398, dvrr_stack+244818, dvrr_stack+226329);
 tmp = dvrr_stack + 212398;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+226003, dvrr_stack+257996, dvrr_stack+245406);
 tmp = dvrr_stack + 226003;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+250360, dvrr_stack+258752, dvrr_stack+245766);
 tmp = dvrr_stack + 250360;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+245406, dvrr_stack+259697, dvrr_stack+247357);
 tmp = dvrr_stack + 245406;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+259697, dvrr_stack+260285, dvrr_stack+247672);
 tmp = dvrr_stack + 259697;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+260285, dvrr_stack+261069, dvrr_stack+233283);
 tmp = dvrr_stack + 260285;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+261041, dvrr_stack+262077, dvrr_stack+158597);
 tmp = dvrr_stack + 261041;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+261986, dvrr_stack+18701, dvrr_stack+244377);
 tmp = dvrr_stack + 261986;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+245847, dvrr_stack+221555, dvrr_stack+244818);
 tmp = dvrr_stack + 245847;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+246631, dvrr_stack+227379, dvrr_stack+257996);
 tmp = dvrr_stack + 246631;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+251035, dvrr_stack+263337, dvrr_stack+258752);
 tmp = dvrr_stack + 251035;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+262574, dvrr_stack+110338, dvrr_stack+264957);
 tmp = dvrr_stack + 262574;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+262784, dvrr_stack+265083, dvrr_stack+1137);
 tmp = dvrr_stack + 262784;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+263064, dvrr_stack+265503, dvrr_stack+2799);
 tmp = dvrr_stack + 263064;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+263424, dvrr_stack+266043, dvrr_stack+52310);
 tmp = dvrr_stack + 263424;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+263874, dvrr_stack+266718, dvrr_stack+4738);
 tmp = dvrr_stack + 263874;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+264189, dvrr_stack+267439, dvrr_stack+267159);
 tmp = dvrr_stack + 264189;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+212818, dvrr_stack+268387, dvrr_stack+268027);
 tmp = dvrr_stack + 212818;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+221445, dvrr_stack+219716, dvrr_stack+269143);
 tmp = dvrr_stack + 221445;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+269143, dvrr_stack+19457, dvrr_stack+110338);
 tmp = dvrr_stack + 269143;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+233211, dvrr_stack+222563, dvrr_stack+265083);
 tmp = dvrr_stack + 233211;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+264609, dvrr_stack+228675, dvrr_stack+265503);
 tmp = dvrr_stack + 264609;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+222120, dvrr_stack+233823, dvrr_stack+266043);
 tmp = dvrr_stack + 222120;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+265365, dvrr_stack+29242, dvrr_stack+266718);
 tmp = dvrr_stack + 265365;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+265953, dvrr_stack+235083, dvrr_stack+267439);
 tmp = dvrr_stack + 265953;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+266737, dvrr_stack+269593, dvrr_stack+268387);
 tmp = dvrr_stack + 266737;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+269584, dvrr_stack+270889, dvrr_stack+219716);
 tmp = dvrr_stack + 269584;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+1095, dvrr_stack+272635, dvrr_stack+272509);
 tmp = dvrr_stack + 1095;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+270844, dvrr_stack+34651, dvrr_stack+927);
 tmp = dvrr_stack + 270844;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+271124, dvrr_stack+62321, dvrr_stack+1889);
 tmp = dvrr_stack + 271124;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+271484, dvrr_stack+0, dvrr_stack+6838);
 tmp = dvrr_stack + 271484;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+4633, dvrr_stack+8027, dvrr_stack+162062);
 tmp = dvrr_stack + 4633;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+271934, dvrr_stack+26634, dvrr_stack+7108);
 tmp = dvrr_stack + 271934;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+267745, dvrr_stack+27222, dvrr_stack+3748);
 tmp = dvrr_stack + 267745;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+268285, dvrr_stack+236091, dvrr_stack+3015);
 tmp = dvrr_stack + 268285;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+247639, dvrr_stack+35506, dvrr_stack+272635);
 tmp = dvrr_stack + 247639;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+272354, dvrr_stack+220661, dvrr_stack+34651);
 tmp = dvrr_stack + 272354;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+219714, dvrr_stack+223347, dvrr_stack+62321);
 tmp = dvrr_stack + 219714;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+220470, dvrr_stack+229683, dvrr_stack+0);
 tmp = dvrr_stack + 220470;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+0, dvrr_stack+65913, dvrr_stack+8027);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+233799, dvrr_stack+110653, dvrr_stack+26634);
 tmp = dvrr_stack + 233799;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+234583, dvrr_stack+111661, dvrr_stack+27222);
 tmp = dvrr_stack + 234583;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+223065, dvrr_stack+116043, dvrr_stack+236091);
 tmp = dvrr_stack + 223065;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];


}

