/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hghh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hg|hh) integrals */

void d1hrr_order_hghh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][5][11] = int_stack + 0;
 Libderiv->deriv_classes[5][6][11] = int_stack + 441;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1029;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1785;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2730;
 Libderiv->deriv_classes[5][10][11] = int_stack + 3885;
 Libderiv->deriv_classes[6][5][11] = int_stack + 5271;
 Libderiv->deriv_classes[6][6][11] = int_stack + 5859;
 Libderiv->deriv_classes[6][7][11] = int_stack + 6643;
 Libderiv->deriv_classes[6][8][11] = int_stack + 7651;
 Libderiv->deriv_classes[6][9][11] = int_stack + 8911;
 Libderiv->deriv_classes[6][10][11] = int_stack + 10451;
 Libderiv->deriv_classes[7][5][11] = int_stack + 12299;
 Libderiv->deriv_classes[7][6][11] = int_stack + 13055;
 Libderiv->deriv_classes[7][7][11] = int_stack + 14063;
 Libderiv->deriv_classes[7][8][11] = int_stack + 15359;
 Libderiv->deriv_classes[7][9][11] = int_stack + 16979;
 Libderiv->deriv_classes[7][10][11] = int_stack + 18959;
 Libderiv->deriv_classes[8][5][11] = int_stack + 21335;
 Libderiv->deriv_classes[8][6][11] = int_stack + 22280;
 Libderiv->deriv_classes[8][7][11] = int_stack + 23540;
 Libderiv->deriv_classes[8][8][11] = int_stack + 25160;
 Libderiv->deriv_classes[8][9][11] = int_stack + 27185;
 Libderiv->deriv_classes[8][10][11] = int_stack + 29660;
 Libderiv->deriv_classes[9][5][11] = int_stack + 32630;
 Libderiv->deriv_classes[9][6][11] = int_stack + 33785;
 Libderiv->deriv_classes[9][7][11] = int_stack + 35325;
 Libderiv->deriv_classes[9][8][11] = int_stack + 37305;
 Libderiv->deriv_classes[9][9][11] = int_stack + 39780;
 Libderiv->deriv_classes[9][10][11] = int_stack + 42805;
 Libderiv->deriv_classes[5][5][10] = int_stack + 46435;
 Libderiv->deriv_classes[5][6][10] = int_stack + 46876;
 Libderiv->deriv_classes[5][7][10] = int_stack + 47464;
 Libderiv->deriv_classes[5][8][10] = int_stack + 48220;
 Libderiv->deriv_classes[5][9][10] = int_stack + 49165;
 Libderiv->deriv_classes[5][10][10] = int_stack + 50320;
 Libderiv->deriv_classes[6][5][10] = int_stack + 51706;
 Libderiv->deriv_classes[6][6][10] = int_stack + 52294;
 Libderiv->deriv_classes[6][7][10] = int_stack + 53078;
 Libderiv->deriv_classes[6][8][10] = int_stack + 54086;
 Libderiv->deriv_classes[6][9][10] = int_stack + 55346;
 Libderiv->deriv_classes[6][10][10] = int_stack + 56886;
 Libderiv->deriv_classes[7][5][10] = int_stack + 58734;
 Libderiv->deriv_classes[7][6][10] = int_stack + 59490;
 Libderiv->deriv_classes[7][7][10] = int_stack + 60498;
 Libderiv->deriv_classes[7][8][10] = int_stack + 61794;
 Libderiv->deriv_classes[7][9][10] = int_stack + 63414;
 Libderiv->deriv_classes[7][10][10] = int_stack + 65394;
 Libderiv->deriv_classes[8][5][10] = int_stack + 67770;
 Libderiv->deriv_classes[8][6][10] = int_stack + 68715;
 Libderiv->deriv_classes[8][7][10] = int_stack + 69975;
 Libderiv->deriv_classes[8][8][10] = int_stack + 71595;
 Libderiv->deriv_classes[8][9][10] = int_stack + 73620;
 Libderiv->deriv_classes[8][10][10] = int_stack + 76095;
 Libderiv->deriv_classes[9][5][10] = int_stack + 79065;
 Libderiv->deriv_classes[9][6][10] = int_stack + 80220;
 Libderiv->deriv_classes[9][7][10] = int_stack + 81760;
 Libderiv->deriv_classes[9][8][10] = int_stack + 83740;
 Libderiv->deriv_classes[9][9][10] = int_stack + 86215;
 Libderiv->deriv_classes[9][10][10] = int_stack + 89240;
 Libderiv->deriv_classes[5][5][9] = int_stack + 92870;
 Libderiv->deriv_classes[5][6][9] = int_stack + 93311;
 Libderiv->deriv_classes[5][7][9] = int_stack + 93899;
 Libderiv->deriv_classes[5][8][9] = int_stack + 94655;
 Libderiv->deriv_classes[5][9][9] = int_stack + 95600;
 Libderiv->deriv_classes[5][10][9] = int_stack + 96755;
 Libderiv->deriv_classes[6][5][9] = int_stack + 98141;
 Libderiv->deriv_classes[6][6][9] = int_stack + 98729;
 Libderiv->deriv_classes[6][7][9] = int_stack + 99513;
 Libderiv->deriv_classes[6][8][9] = int_stack + 100521;
 Libderiv->deriv_classes[6][9][9] = int_stack + 101781;
 Libderiv->deriv_classes[6][10][9] = int_stack + 103321;
 Libderiv->deriv_classes[7][5][9] = int_stack + 105169;
 Libderiv->deriv_classes[7][6][9] = int_stack + 105925;
 Libderiv->deriv_classes[7][7][9] = int_stack + 106933;
 Libderiv->deriv_classes[7][8][9] = int_stack + 108229;
 Libderiv->deriv_classes[7][9][9] = int_stack + 109849;
 Libderiv->deriv_classes[7][10][9] = int_stack + 111829;
 Libderiv->deriv_classes[8][5][9] = int_stack + 114205;
 Libderiv->deriv_classes[8][6][9] = int_stack + 115150;
 Libderiv->deriv_classes[8][7][9] = int_stack + 116410;
 Libderiv->deriv_classes[8][8][9] = int_stack + 118030;
 Libderiv->deriv_classes[8][9][9] = int_stack + 120055;
 Libderiv->deriv_classes[8][10][9] = int_stack + 122530;
 Libderiv->deriv_classes[9][5][9] = int_stack + 125500;
 Libderiv->deriv_classes[9][6][9] = int_stack + 126655;
 Libderiv->deriv_classes[9][7][9] = int_stack + 128195;
 Libderiv->deriv_classes[9][8][9] = int_stack + 130175;
 Libderiv->deriv_classes[9][9][9] = int_stack + 132650;
 Libderiv->deriv_classes[9][10][9] = int_stack + 135675;
 Libderiv->deriv_classes[5][5][8] = int_stack + 139305;
 Libderiv->deriv_classes[5][6][8] = int_stack + 139746;
 Libderiv->deriv_classes[5][7][8] = int_stack + 140334;
 Libderiv->deriv_classes[5][8][8] = int_stack + 141090;
 Libderiv->deriv_classes[5][9][8] = int_stack + 142035;
 Libderiv->deriv_classes[5][10][8] = int_stack + 143190;
 Libderiv->deriv_classes[6][5][8] = int_stack + 144576;
 Libderiv->deriv_classes[6][6][8] = int_stack + 145164;
 Libderiv->deriv_classes[6][7][8] = int_stack + 145948;
 Libderiv->deriv_classes[6][8][8] = int_stack + 146956;
 Libderiv->deriv_classes[6][9][8] = int_stack + 148216;
 Libderiv->deriv_classes[6][10][8] = int_stack + 149756;
 Libderiv->deriv_classes[7][5][8] = int_stack + 151604;
 Libderiv->deriv_classes[7][6][8] = int_stack + 152360;
 Libderiv->deriv_classes[7][7][8] = int_stack + 153368;
 Libderiv->deriv_classes[7][8][8] = int_stack + 154664;
 Libderiv->deriv_classes[7][9][8] = int_stack + 156284;
 Libderiv->deriv_classes[7][10][8] = int_stack + 158264;
 Libderiv->deriv_classes[8][5][8] = int_stack + 160640;
 Libderiv->deriv_classes[8][6][8] = int_stack + 161585;
 Libderiv->deriv_classes[8][7][8] = int_stack + 162845;
 Libderiv->deriv_classes[8][8][8] = int_stack + 164465;
 Libderiv->deriv_classes[8][9][8] = int_stack + 166490;
 Libderiv->deriv_classes[8][10][8] = int_stack + 168965;
 Libderiv->deriv_classes[9][5][8] = int_stack + 171935;
 Libderiv->deriv_classes[9][6][8] = int_stack + 173090;
 Libderiv->deriv_classes[9][7][8] = int_stack + 174630;
 Libderiv->deriv_classes[9][8][8] = int_stack + 176610;
 Libderiv->deriv_classes[9][9][8] = int_stack + 179085;
 Libderiv->deriv_classes[9][10][8] = int_stack + 182110;
 Libderiv->deriv_classes[5][5][7] = int_stack + 185740;
 Libderiv->deriv_classes[5][6][7] = int_stack + 186181;
 Libderiv->deriv_classes[5][7][7] = int_stack + 186769;
 Libderiv->deriv_classes[5][8][7] = int_stack + 187525;
 Libderiv->deriv_classes[5][9][7] = int_stack + 188470;
 Libderiv->deriv_classes[5][10][7] = int_stack + 189625;
 Libderiv->deriv_classes[6][5][7] = int_stack + 191011;
 Libderiv->deriv_classes[6][6][7] = int_stack + 191599;
 Libderiv->deriv_classes[6][7][7] = int_stack + 192383;
 Libderiv->deriv_classes[6][8][7] = int_stack + 193391;
 Libderiv->deriv_classes[6][9][7] = int_stack + 194651;
 Libderiv->deriv_classes[6][10][7] = int_stack + 196191;
 Libderiv->deriv_classes[7][5][7] = int_stack + 198039;
 Libderiv->deriv_classes[7][6][7] = int_stack + 198795;
 Libderiv->deriv_classes[7][7][7] = int_stack + 199803;
 Libderiv->deriv_classes[7][8][7] = int_stack + 201099;
 Libderiv->deriv_classes[7][9][7] = int_stack + 202719;
 Libderiv->deriv_classes[7][10][7] = int_stack + 204699;
 Libderiv->deriv_classes[8][5][7] = int_stack + 207075;
 Libderiv->deriv_classes[8][6][7] = int_stack + 208020;
 Libderiv->deriv_classes[8][7][7] = int_stack + 209280;
 Libderiv->deriv_classes[8][8][7] = int_stack + 210900;
 Libderiv->deriv_classes[8][9][7] = int_stack + 212925;
 Libderiv->deriv_classes[8][10][7] = int_stack + 215400;
 Libderiv->deriv_classes[9][5][7] = int_stack + 218370;
 Libderiv->deriv_classes[9][6][7] = int_stack + 219525;
 Libderiv->deriv_classes[9][7][7] = int_stack + 221065;
 Libderiv->deriv_classes[9][8][7] = int_stack + 223045;
 Libderiv->deriv_classes[9][9][7] = int_stack + 225520;
 Libderiv->deriv_classes[9][10][7] = int_stack + 228545;
 Libderiv->deriv_classes[5][5][6] = int_stack + 232175;
 Libderiv->deriv_classes[5][6][6] = int_stack + 232616;
 Libderiv->deriv_classes[5][7][6] = int_stack + 233204;
 Libderiv->deriv_classes[5][8][6] = int_stack + 233960;
 Libderiv->deriv_classes[5][9][6] = int_stack + 234905;
 Libderiv->deriv_classes[5][10][6] = int_stack + 236060;
 Libderiv->deriv_classes[6][5][6] = int_stack + 237446;
 Libderiv->deriv_classes[6][6][6] = int_stack + 238034;
 Libderiv->deriv_classes[6][7][6] = int_stack + 238818;
 Libderiv->deriv_classes[6][8][6] = int_stack + 239826;
 Libderiv->deriv_classes[6][9][6] = int_stack + 241086;
 Libderiv->deriv_classes[6][10][6] = int_stack + 242626;
 Libderiv->deriv_classes[7][5][6] = int_stack + 244474;
 Libderiv->deriv_classes[7][6][6] = int_stack + 245230;
 Libderiv->deriv_classes[7][7][6] = int_stack + 246238;
 Libderiv->deriv_classes[7][8][6] = int_stack + 247534;
 Libderiv->deriv_classes[7][9][6] = int_stack + 249154;
 Libderiv->deriv_classes[7][10][6] = int_stack + 251134;
 Libderiv->deriv_classes[8][5][6] = int_stack + 253510;
 Libderiv->deriv_classes[8][6][6] = int_stack + 254455;
 Libderiv->deriv_classes[8][7][6] = int_stack + 255715;
 Libderiv->deriv_classes[8][8][6] = int_stack + 257335;
 Libderiv->deriv_classes[8][9][6] = int_stack + 259360;
 Libderiv->deriv_classes[8][10][6] = int_stack + 261835;
 Libderiv->dvrr_classes[9][5] = int_stack + 264805;
 Libderiv->deriv_classes[9][5][6] = int_stack + 265960;
 Libderiv->dvrr_classes[9][6] = int_stack + 267115;
 Libderiv->deriv_classes[9][6][6] = int_stack + 268655;
 Libderiv->dvrr_classes[9][7] = int_stack + 270195;
 Libderiv->deriv_classes[9][7][6] = int_stack + 272175;
 Libderiv->dvrr_classes[9][8] = int_stack + 274155;
 Libderiv->deriv_classes[9][8][6] = int_stack + 276630;
 Libderiv->dvrr_classes[9][9] = int_stack + 279105;
 Libderiv->deriv_classes[9][9][6] = int_stack + 282130;
 Libderiv->deriv_classes[9][10][6] = int_stack + 285155;
 Libderiv->deriv_classes[5][5][2] = int_stack + 288785;
 Libderiv->deriv_classes[5][6][2] = int_stack + 289226;
 Libderiv->deriv_classes[5][7][2] = int_stack + 289814;
 Libderiv->deriv_classes[5][8][2] = int_stack + 290570;
 Libderiv->deriv_classes[5][9][2] = int_stack + 291515;
 Libderiv->deriv_classes[5][10][2] = int_stack + 292670;
 Libderiv->deriv_classes[6][5][2] = int_stack + 294056;
 Libderiv->deriv_classes[6][6][2] = int_stack + 294644;
 Libderiv->deriv_classes[6][7][2] = int_stack + 295428;
 Libderiv->deriv_classes[6][8][2] = int_stack + 296436;
 Libderiv->deriv_classes[6][9][2] = int_stack + 297696;
 Libderiv->deriv_classes[6][10][2] = int_stack + 299236;
 Libderiv->deriv_classes[7][5][2] = int_stack + 301084;
 Libderiv->deriv_classes[7][6][2] = int_stack + 301840;
 Libderiv->deriv_classes[7][7][2] = int_stack + 302848;
 Libderiv->deriv_classes[7][8][2] = int_stack + 304144;
 Libderiv->deriv_classes[7][9][2] = int_stack + 305764;
 Libderiv->deriv_classes[7][10][2] = int_stack + 307744;
 Libderiv->deriv_classes[8][5][2] = int_stack + 310120;
 Libderiv->deriv_classes[8][6][2] = int_stack + 311065;
 Libderiv->deriv_classes[8][7][2] = int_stack + 312325;
 Libderiv->deriv_classes[8][8][2] = int_stack + 313945;
 Libderiv->deriv_classes[8][9][2] = int_stack + 315970;
 Libderiv->deriv_classes[8][10][2] = int_stack + 318445;
 Libderiv->deriv_classes[9][5][2] = int_stack + 321415;
 Libderiv->deriv_classes[9][6][2] = int_stack + 322570;
 Libderiv->deriv_classes[9][7][2] = int_stack + 324110;
 Libderiv->deriv_classes[9][8][2] = int_stack + 326090;
 Libderiv->deriv_classes[9][9][2] = int_stack + 328565;
 Libderiv->deriv_classes[9][10][2] = int_stack + 331590;
 Libderiv->deriv_classes[5][5][1] = int_stack + 335220;
 Libderiv->deriv_classes[5][6][1] = int_stack + 335661;
 Libderiv->deriv_classes[5][7][1] = int_stack + 336249;
 Libderiv->deriv_classes[5][8][1] = int_stack + 337005;
 Libderiv->deriv_classes[5][9][1] = int_stack + 337950;
 Libderiv->deriv_classes[5][10][1] = int_stack + 339105;
 Libderiv->deriv_classes[6][5][1] = int_stack + 340491;
 Libderiv->deriv_classes[6][6][1] = int_stack + 341079;
 Libderiv->deriv_classes[6][7][1] = int_stack + 341863;
 Libderiv->deriv_classes[6][8][1] = int_stack + 342871;
 Libderiv->deriv_classes[6][9][1] = int_stack + 344131;
 Libderiv->deriv_classes[6][10][1] = int_stack + 345671;
 Libderiv->deriv_classes[7][5][1] = int_stack + 347519;
 Libderiv->deriv_classes[7][6][1] = int_stack + 348275;
 Libderiv->deriv_classes[7][7][1] = int_stack + 349283;
 Libderiv->deriv_classes[7][8][1] = int_stack + 350579;
 Libderiv->deriv_classes[7][9][1] = int_stack + 352199;
 Libderiv->deriv_classes[7][10][1] = int_stack + 354179;
 Libderiv->deriv_classes[8][5][1] = int_stack + 356555;
 Libderiv->deriv_classes[8][6][1] = int_stack + 357500;
 Libderiv->deriv_classes[8][7][1] = int_stack + 358760;
 Libderiv->deriv_classes[8][8][1] = int_stack + 360380;
 Libderiv->deriv_classes[8][9][1] = int_stack + 362405;
 Libderiv->deriv_classes[8][10][1] = int_stack + 364880;
 Libderiv->deriv_classes[9][5][1] = int_stack + 367850;
 Libderiv->deriv_classes[9][6][1] = int_stack + 369005;
 Libderiv->deriv_classes[9][7][1] = int_stack + 370545;
 Libderiv->deriv_classes[9][8][1] = int_stack + 372525;
 Libderiv->deriv_classes[9][9][1] = int_stack + 375000;
 Libderiv->deriv_classes[9][10][1] = int_stack + 378025;
 Libderiv->dvrr_classes[5][5] = int_stack + 381655;
 Libderiv->dvrr_classes[5][6] = int_stack + 382096;
 Libderiv->dvrr_classes[5][7] = int_stack + 382684;
 Libderiv->dvrr_classes[5][8] = int_stack + 383440;
 Libderiv->dvrr_classes[5][9] = int_stack + 384385;
 Libderiv->dvrr_classes[5][10] = int_stack + 385540;
 Libderiv->deriv_classes[5][5][0] = int_stack + 386926;
 Libderiv->deriv_classes[5][6][0] = int_stack + 387367;
 Libderiv->deriv_classes[5][7][0] = int_stack + 387955;
 Libderiv->deriv_classes[5][8][0] = int_stack + 388711;
 Libderiv->deriv_classes[5][9][0] = int_stack + 389656;
 Libderiv->deriv_classes[5][10][0] = int_stack + 390811;
 Libderiv->dvrr_classes[6][5] = int_stack + 392197;
 Libderiv->dvrr_classes[6][6] = int_stack + 392785;
 Libderiv->dvrr_classes[6][7] = int_stack + 393569;
 Libderiv->dvrr_classes[6][8] = int_stack + 394577;
 Libderiv->dvrr_classes[6][9] = int_stack + 395837;
 Libderiv->dvrr_classes[6][10] = int_stack + 397377;
 Libderiv->deriv_classes[6][5][0] = int_stack + 399225;
 Libderiv->deriv_classes[6][6][0] = int_stack + 399813;
 Libderiv->deriv_classes[6][7][0] = int_stack + 400597;
 Libderiv->deriv_classes[6][8][0] = int_stack + 401605;
 Libderiv->deriv_classes[6][9][0] = int_stack + 402865;
 Libderiv->deriv_classes[6][10][0] = int_stack + 404405;
 Libderiv->dvrr_classes[7][5] = int_stack + 406253;
 Libderiv->dvrr_classes[7][6] = int_stack + 407009;
 Libderiv->dvrr_classes[7][7] = int_stack + 408017;
 Libderiv->dvrr_classes[7][8] = int_stack + 409313;
 Libderiv->dvrr_classes[7][9] = int_stack + 410933;
 Libderiv->dvrr_classes[7][10] = int_stack + 412913;
 Libderiv->deriv_classes[7][5][0] = int_stack + 415289;
 Libderiv->deriv_classes[7][6][0] = int_stack + 416045;
 Libderiv->deriv_classes[7][7][0] = int_stack + 417053;
 Libderiv->deriv_classes[7][8][0] = int_stack + 418349;
 Libderiv->deriv_classes[7][9][0] = int_stack + 419969;
 Libderiv->deriv_classes[7][10][0] = int_stack + 421949;
 Libderiv->dvrr_classes[8][5] = int_stack + 424325;
 Libderiv->dvrr_classes[8][6] = int_stack + 425270;
 Libderiv->dvrr_classes[8][7] = int_stack + 426530;
 Libderiv->dvrr_classes[8][8] = int_stack + 428150;
 Libderiv->dvrr_classes[8][9] = int_stack + 430175;
 Libderiv->dvrr_classes[8][10] = int_stack + 432650;
 Libderiv->deriv_classes[8][5][0] = int_stack + 435620;
 Libderiv->deriv_classes[8][6][0] = int_stack + 436565;
 Libderiv->deriv_classes[8][7][0] = int_stack + 437825;
 Libderiv->deriv_classes[8][8][0] = int_stack + 439445;
 Libderiv->deriv_classes[8][9][0] = int_stack + 441470;
 Libderiv->deriv_classes[8][10][0] = int_stack + 443945;
 Libderiv->deriv_classes[9][5][0] = int_stack + 446915;
 Libderiv->deriv_classes[9][6][0] = int_stack + 448070;
 Libderiv->deriv_classes[9][7][0] = int_stack + 449610;
 Libderiv->deriv_classes[9][8][0] = int_stack + 451590;
 Libderiv->deriv_classes[9][9][0] = int_stack + 454065;
 Libderiv->deriv_classes[9][10][0] = int_stack + 457090;
 memset(int_stack,0,3685760);

 Libderiv->dvrr_stack = int_stack + 2790038;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hghh(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+460720,int_stack+382096,int_stack+381655,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+462043,int_stack+382684,int_stack+382096,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+463807,int_stack+462043,int_stack+460720,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+466453,int_stack+383440,int_stack+382684,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+468721,int_stack+466453,int_stack+462043,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+472249,int_stack+468721,int_stack+463807,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+476659,int_stack+384385,int_stack+383440,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+479494,int_stack+476659,int_stack+466453,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+484030,int_stack+479494,int_stack+468721,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+489910,int_stack+484030,int_stack+472249,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+496525,int_stack+441,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381655,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+497848,int_stack+1029,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382096,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+499612,int_stack+497848,int_stack+496525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460720,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+502258,int_stack+1785,int_stack+1029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382684,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+504526,int_stack+502258,int_stack+497848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462043,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+508054,int_stack+504526,int_stack+499612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463807,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+496525,int_stack+2730,int_stack+1785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383440,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+512464,int_stack+496525,int_stack+502258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466453,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+517000,int_stack+512464,int_stack+504526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468721,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+499360,int_stack+517000,int_stack+508054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472249,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+505975,int_stack+3885,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384385,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+522880,int_stack+505975,int_stack+496525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476659,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+528550,int_stack+522880,int_stack+512464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479494,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+505975,int_stack+528550,int_stack+517000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484030,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+514795,int_stack+505975,int_stack+499360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489910,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+496525,int_stack+392785,int_stack+392197,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+498289,int_stack+393569,int_stack+392785,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+500641,int_stack+498289,int_stack+496525,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+504169,int_stack+394577,int_stack+393569,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+507193,int_stack+504169,int_stack+498289,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+524056,int_stack+507193,int_stack+500641,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+529936,int_stack+395837,int_stack+394577,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+533716,int_stack+529936,int_stack+504169,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+539764,int_stack+533716,int_stack+507193,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+547604,int_stack+539764,int_stack+524056,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+511897,int_stack+5859,int_stack+5271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392197,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+6643,int_stack+5859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392785,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2352,int_stack+0,int_stack+511897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496525,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+556424,int_stack+7651,int_stack+6643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393569,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+559448,int_stack+556424,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498289,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+564152,int_stack+559448,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500641,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+8911,int_stack+7651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394577,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+570032,int_stack+0,int_stack+556424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504169,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+576080,int_stack+570032,int_stack+559448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507193,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+583920,int_stack+576080,int_stack+564152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524056,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+556424,int_stack+10451,int_stack+8911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395837,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+561044,int_stack+556424,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529936,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+561044,int_stack+570032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533716,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+556424,int_stack+0,int_stack+576080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539764,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+568184,int_stack+556424,int_stack+583920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547604,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+580532,int_stack+568184,int_stack+514795,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+556424,int_stack+407009,int_stack+406253,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+558692,int_stack+408017,int_stack+407009,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+561716,int_stack+558692,int_stack+556424,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+409313,int_stack+408017,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3888,int_stack+0,int_stack+558692,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+511897,int_stack+3888,int_stack+561716,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+608315,int_stack+410933,int_stack+409313,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+613175,int_stack+608315,int_stack+0,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+620951,int_stack+613175,int_stack+3888,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+631031,int_stack+620951,int_stack+511897,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9936,int_stack+13055,int_stack+12299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406253,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+519457,int_stack+14063,int_stack+13055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407009,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+642371,int_stack+519457,int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556424,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9936,int_stack+15359,int_stack+14063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408017,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+646907,int_stack+9936,int_stack+519457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558692,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+652955,int_stack+646907,int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561716,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+660515,int_stack+16979,int_stack+15359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409313,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+665375,int_stack+660515,int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+673151,int_stack+665375,int_stack+646907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+683231,int_stack+673151,int_stack+652955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511897,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9936,int_stack+18959,int_stack+16979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410933,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+642371,int_stack+9936,int_stack+660515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608315,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+652091,int_stack+642371,int_stack+665375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613175,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+694571,int_stack+652091,int_stack+673151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620951,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+642371,int_stack+694571,int_stack+683231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631031,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+658247,int_stack+642371,int_stack+568184,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+695291,int_stack+658247,int_stack+580532,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9936,int_stack+425270,int_stack+424325,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12771,int_stack+426530,int_stack+425270,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+566252,int_stack+12771,int_stack+9936,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+571922,int_stack+428150,int_stack+426530,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+576782,int_stack+571922,int_stack+12771,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+584342,int_stack+576782,int_stack+566252,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+593792,int_stack+430175,int_stack+428150,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+750857,int_stack+593792,int_stack+571922,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+760577,int_stack+750857,int_stack+576782,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+773177,int_stack+760577,int_stack+584342,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16551,int_stack+22280,int_stack+21335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424325,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+519457,int_stack+23540,int_stack+22280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+599867,int_stack+519457,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9936,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16551,int_stack+25160,int_stack+23540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426530,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+787352,int_stack+16551,int_stack+519457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12771,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+794912,int_stack+787352,int_stack+599867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566252,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+599867,int_stack+27185,int_stack+25160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428150,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+804362,int_stack+599867,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571922,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+814082,int_stack+804362,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576782,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+826682,int_stack+814082,int_stack+794912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584342,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+787352,int_stack+29660,int_stack+27185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430175,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16551,int_stack+787352,int_stack+599867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593792,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+787352,int_stack+16551,int_stack+804362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750857,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+840857,int_stack+787352,int_stack+814082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760577,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+787352,int_stack+840857,int_stack+826682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773177,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+807197,int_stack+787352,int_stack+642371,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+854825,int_stack+807197,int_stack+658247,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+928913,int_stack+854825,int_stack+695291,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+642371,int_stack+267115,int_stack+264805,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+645836,int_stack+270195,int_stack+267115,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+650456,int_stack+645836,int_stack+642371,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+657386,int_stack+274155,int_stack+270195,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+663326,int_stack+657386,int_stack+645836,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+672566,int_stack+663326,int_stack+650456,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+684116,int_stack+279105,int_stack+274155,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+691541,int_stack+684116,int_stack+657386,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+703421,int_stack+691541,int_stack+663326,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+718821,int_stack+703421,int_stack+672566,55);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+736146,int_stack+33785,int_stack+32630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264805,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+739611,int_stack+35325,int_stack+33785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267115,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16551,int_stack+739611,int_stack+736146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642371,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+744231,int_stack+37305,int_stack+35325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270195,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23481,int_stack+744231,int_stack+739611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+645836,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1021523,int_stack+23481,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650456,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+736146,int_stack+39780,int_stack+37305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274155,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1033073,int_stack+736146,int_stack+744231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657386,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1044953,int_stack+1033073,int_stack+23481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663326,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+16551,int_stack+1044953,int_stack+1021523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672566,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1021523,int_stack+42805,int_stack+39780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279105,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1060353,int_stack+1021523,int_stack+736146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684116,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1075203,int_stack+1060353,int_stack+1033073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691541,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1021523,int_stack+1075203,int_stack+1044953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703421,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1044623,int_stack+1021523,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718821,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1068878,int_stack+1044623,int_stack+787352,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1128413,int_stack+1068878,int_stack+807197,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1223669,int_stack+1128413,int_stack+854825,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+787352,int_stack+46876,int_stack+46435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381655, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+788675,int_stack+47464,int_stack+46876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382096, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+790439,int_stack+788675,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+793085,int_stack+48220,int_stack+47464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382684, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+795353,int_stack+793085,int_stack+788675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462043, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+798881,int_stack+795353,int_stack+790439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463807, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+787352,int_stack+49165,int_stack+48220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383440, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803291,int_stack+787352,int_stack+793085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466453, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+807827,int_stack+803291,int_stack+795353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468721, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+790187,int_stack+807827,int_stack+798881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472249, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+796802,int_stack+50320,int_stack+49165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384385, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+813707,int_stack+796802,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476659, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+819377,int_stack+813707,int_stack+803291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479494, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+796802,int_stack+819377,int_stack+807827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484030, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+805622,int_stack+796802,int_stack+790187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489910, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+787352,int_stack+52294,int_stack+51706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392197, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+789116,int_stack+53078,int_stack+52294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392785, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+791468,int_stack+789116,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496525, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+794996,int_stack+54086,int_stack+53078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393569, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+798020,int_stack+794996,int_stack+789116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498289, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+814883,int_stack+798020,int_stack+791468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500641, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+787352,int_stack+55346,int_stack+54086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394577, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+820763,int_stack+787352,int_stack+794996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504169, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+826811,int_stack+820763,int_stack+798020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507193, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+791132,int_stack+826811,int_stack+814883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524056, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+814883,int_stack+56886,int_stack+55346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395837, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+834651,int_stack+814883,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529936, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+842211,int_stack+834651,int_stack+820763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533716, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+814883,int_stack+842211,int_stack+826811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539764, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+826643,int_stack+814883,int_stack+791132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547604, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+838991,int_stack+826643,int_stack+805622,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+787352,int_stack+59490,int_stack+58734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406253, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+789620,int_stack+60498,int_stack+59490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407009, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+792644,int_stack+789620,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556424, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+797180,int_stack+61794,int_stack+60498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408017, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+801068,int_stack+797180,int_stack+789620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558692, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+807116,int_stack+801068,int_stack+792644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561716, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+787352,int_stack+63414,int_stack+61794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409313, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+814676,int_stack+787352,int_stack+797180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866774,int_stack+814676,int_stack+801068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+792212,int_stack+866774,int_stack+807116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511897, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+803552,int_stack+65394,int_stack+63414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410933, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876854,int_stack+803552,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608315, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+886574,int_stack+876854,int_stack+814676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613175, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+803552,int_stack+886574,int_stack+866774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620951, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+866774,int_stack+803552,int_stack+792212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631031, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+882650,int_stack+866774,int_stack+826643,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1021523,int_stack+882650,int_stack+838991,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+919694,int_stack+68715,int_stack+67770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424325, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+922529,int_stack+69975,int_stack+68715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+787352,int_stack+922529,int_stack+919694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9936, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+793022,int_stack+71595,int_stack+69975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426530, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+797882,int_stack+793022,int_stack+922529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12771, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+805442,int_stack+797882,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566252, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+919694,int_stack+73620,int_stack+71595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428150, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+814892,int_stack+919694,int_stack+793022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571922, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+824612,int_stack+814892,int_stack+797882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576782, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+787352,int_stack+824612,int_stack+805442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584342, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+801527,int_stack+76095,int_stack+73620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430175, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+837212,int_stack+801527,int_stack+919694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593792, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+849362,int_stack+837212,int_stack+814892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+801527,int_stack+849362,int_stack+824612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760577, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+820427,int_stack+801527,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773177, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+16551,int_stack+820427,int_stack+866774,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1077089,int_stack+16551,int_stack+882650,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1347149,int_stack+1077089,int_stack+1021523,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+80220,int_stack+79065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264805, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1024988,int_stack+81760,int_stack+80220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267115, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1029608,int_stack+1024988,int_stack+1021523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1036538,int_stack+83740,int_stack+81760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270195, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1042478,int_stack+1036538,int_stack+1024988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+645836, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1051718,int_stack+1042478,int_stack+1029608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650456, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+86215,int_stack+83740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274155, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1063268,int_stack+1021523,int_stack+1036538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657386, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+787352,int_stack+1063268,int_stack+1042478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663326, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1028948,int_stack+787352,int_stack+1051718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672566, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1046273,int_stack+89240,int_stack+86215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279105, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+802752,int_stack+1046273,int_stack+1021523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684116, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+840272,int_stack+802752,int_stack+1063268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691541, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1046273,int_stack+840272,int_stack+787352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703421, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+787352,int_stack+1046273,int_stack+1028948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718821, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+840272,int_stack+787352,int_stack+820427,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1439759,int_stack+840272,int_stack+16551,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+787352,int_stack+1439759,int_stack+1077089,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1439759,int_stack+93311,int_stack+92870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381655, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1441082,int_stack+93899,int_stack+93311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382096, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1442846,int_stack+1441082,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1445492,int_stack+94655,int_stack+93899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382684, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1447760,int_stack+1445492,int_stack+1441082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462043, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1451288,int_stack+1447760,int_stack+1442846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463807, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1439759,int_stack+95600,int_stack+94655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383440, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1455698,int_stack+1439759,int_stack+1445492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466453, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1460234,int_stack+1455698,int_stack+1447760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468721, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1442594,int_stack+1460234,int_stack+1451288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472249, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1449209,int_stack+96755,int_stack+95600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384385, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1466114,int_stack+1449209,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476659, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1471784,int_stack+1466114,int_stack+1455698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479494, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1449209,int_stack+1471784,int_stack+1460234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484030, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1458029,int_stack+1449209,int_stack+1442594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489910, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1439759,int_stack+98729,int_stack+98141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392197, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1441523,int_stack+99513,int_stack+98729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392785, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1443875,int_stack+1441523,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496525, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1447403,int_stack+100521,int_stack+99513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393569, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1450427,int_stack+1447403,int_stack+1441523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498289, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467290,int_stack+1450427,int_stack+1443875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500641, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1439759,int_stack+101781,int_stack+100521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394577, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1473170,int_stack+1439759,int_stack+1447403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504169, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1479218,int_stack+1473170,int_stack+1450427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507193, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1443539,int_stack+1479218,int_stack+1467290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524056, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1467290,int_stack+103321,int_stack+101781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395837, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1487058,int_stack+1467290,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529936, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1494618,int_stack+1487058,int_stack+1473170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533716, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1467290,int_stack+1494618,int_stack+1479218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539764, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1479050,int_stack+1467290,int_stack+1443539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547604, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1491398,int_stack+1479050,int_stack+1458029,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1439759,int_stack+105925,int_stack+105169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406253, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1442027,int_stack+106933,int_stack+105925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407009, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1445051,int_stack+1442027,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556424, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1449587,int_stack+108229,int_stack+106933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408017, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1453475,int_stack+1449587,int_stack+1442027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558692, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1459523,int_stack+1453475,int_stack+1445051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561716, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1439759,int_stack+109849,int_stack+108229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409313, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1467083,int_stack+1439759,int_stack+1449587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1519181,int_stack+1467083,int_stack+1453475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1444619,int_stack+1519181,int_stack+1459523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511897, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1455959,int_stack+111829,int_stack+109849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410933, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16551,int_stack+1455959,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608315, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+26271,int_stack+16551,int_stack+1467083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613175, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1455959,int_stack+26271,int_stack+1519181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620951, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1519181,int_stack+1455959,int_stack+1444619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631031, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+16551,int_stack+1519181,int_stack+1479050,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+53595,int_stack+16551,int_stack+1491398,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109161,int_stack+115150,int_stack+114205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1439759,int_stack+116410,int_stack+115150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1443539,int_stack+1439759,int_stack+109161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9936, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109161,int_stack+118030,int_stack+116410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426530, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1449209,int_stack+109161,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12771, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1456769,int_stack+1449209,int_stack+1443539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566252, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1439759,int_stack+120055,int_stack+118030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428150, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1466219,int_stack+1439759,int_stack+109161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571922, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1475939,int_stack+1466219,int_stack+1449209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576782, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1488539,int_stack+1475939,int_stack+1456769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584342, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+109161,int_stack+122530,int_stack+120055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430175, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1445834,int_stack+109161,int_stack+1439759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593792, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+109161,int_stack+1445834,int_stack+1466219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1439759,int_stack+109161,int_stack+1475939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760577, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1458659,int_stack+1439759,int_stack+1488539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773177, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1021523,int_stack+1458659,int_stack+1519181,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1069151,int_stack+1021523,int_stack+16551,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1478504,int_stack+1069151,int_stack+53595,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16551,int_stack+126655,int_stack+125500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264805, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20016,int_stack+128195,int_stack+126655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267115, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24636,int_stack+20016,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31566,int_stack+130175,int_stack+128195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270195, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37506,int_stack+31566,int_stack+20016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+645836, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46746,int_stack+37506,int_stack+24636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650456, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16551,int_stack+132650,int_stack+130175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274155, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+58296,int_stack+16551,int_stack+31566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657386, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+70176,int_stack+58296,int_stack+37506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663326, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+23976,int_stack+70176,int_stack+46746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672566, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+41301,int_stack+135675,int_stack+132650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279105, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+85576,int_stack+41301,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684116, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+100426,int_stack+85576,int_stack+58296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691541, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+41301,int_stack+100426,int_stack+70176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703421, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+64401,int_stack+41301,int_stack+23976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718821, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1143239,int_stack+64401,int_stack+1458659,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+16551,int_stack+1143239,int_stack+1021523,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1571114,int_stack+16551,int_stack+1069151,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16551,int_stack+139746,int_stack+139305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17874,int_stack+140334,int_stack+139746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19638,int_stack+17874,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22284,int_stack+141090,int_stack+140334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+24552,int_stack+22284,int_stack+17874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28080,int_stack+24552,int_stack+19638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16551,int_stack+142035,int_stack+141090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32490,int_stack+16551,int_stack+22284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+37026,int_stack+32490,int_stack+24552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+19386,int_stack+37026,int_stack+28080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+26001,int_stack+143190,int_stack+142035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+42906,int_stack+26001,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+48576,int_stack+42906,int_stack+32490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26001,int_stack+48576,int_stack+37026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+34821,int_stack+26001,int_stack+19386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16551,int_stack+145164,int_stack+144576, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18315,int_stack+145948,int_stack+145164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20667,int_stack+18315,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24195,int_stack+146956,int_stack+145948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27219,int_stack+24195,int_stack+18315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44082,int_stack+27219,int_stack+20667, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16551,int_stack+148216,int_stack+146956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49962,int_stack+16551,int_stack+24195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+56010,int_stack+49962,int_stack+27219, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+20331,int_stack+56010,int_stack+44082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+44082,int_stack+149756,int_stack+148216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+63850,int_stack+44082,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+71410,int_stack+63850,int_stack+49962, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44082,int_stack+71410,int_stack+56010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+55842,int_stack+44082,int_stack+20331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+68190,int_stack+55842,int_stack+34821,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16551,int_stack+152360,int_stack+151604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18819,int_stack+153368,int_stack+152360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21843,int_stack+18819,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26379,int_stack+154664,int_stack+153368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30267,int_stack+26379,int_stack+18819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36315,int_stack+30267,int_stack+21843, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16551,int_stack+156284,int_stack+154664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+43875,int_stack+16551,int_stack+26379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95973,int_stack+43875,int_stack+30267, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+21411,int_stack+95973,int_stack+36315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+32751,int_stack+158264,int_stack+156284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+106053,int_stack+32751,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+115773,int_stack+106053,int_stack+43875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+32751,int_stack+115773,int_stack+95973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+95973,int_stack+32751,int_stack+21411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+111849,int_stack+95973,int_stack+55842,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1021523,int_stack+111849,int_stack+68190,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148893,int_stack+161585,int_stack+160640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+151728,int_stack+162845,int_stack+161585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+155508,int_stack+151728,int_stack+148893, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16551,int_stack+164465,int_stack+162845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21411,int_stack+16551,int_stack+151728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28971,int_stack+21411,int_stack+155508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+148893,int_stack+166490,int_stack+164465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+154968,int_stack+148893,int_stack+16551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38421,int_stack+154968,int_stack+21411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+51021,int_stack+38421,int_stack+28971, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16551,int_stack+168965,int_stack+166490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+23976,int_stack+16551,int_stack+148893, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65196,int_stack+23976,int_stack+154968, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+148893,int_stack+65196,int_stack+38421, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+65196,int_stack+148893,int_stack+51021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+16551,int_stack+65196,int_stack+95973,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1077089,int_stack+16551,int_stack+111849,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1694594,int_stack+1077089,int_stack+1021523,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+173090,int_stack+171935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1024988,int_stack+174630,int_stack+173090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1029608,int_stack+1024988,int_stack+1021523, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1036538,int_stack+176610,int_stack+174630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1042478,int_stack+1036538,int_stack+1024988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+645836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1051718,int_stack+1042478,int_stack+1029608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+179085,int_stack+176610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1063268,int_stack+1021523,int_stack+1036538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+85041,int_stack+1063268,int_stack+1042478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1028948,int_stack+85041,int_stack+1051718, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1046273,int_stack+182110,int_stack+179085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+100441,int_stack+1046273,int_stack+1021523, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+115291,int_stack+100441,int_stack+1063268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1046273,int_stack+115291,int_stack+85041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+85041,int_stack+1046273,int_stack+1028948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+109296,int_stack+85041,int_stack+65196,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1787204,int_stack+109296,int_stack+16551,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+16551,int_stack+1787204,int_stack+1077089,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1787204,int_stack+186181,int_stack+185740, 0.0, zero_stack, 1.0, int_stack+381655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1788527,int_stack+186769,int_stack+186181, 0.0, zero_stack, 1.0, int_stack+382096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1790291,int_stack+1788527,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1792937,int_stack+187525,int_stack+186769, 0.0, zero_stack, 1.0, int_stack+382684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1795205,int_stack+1792937,int_stack+1788527, 0.0, zero_stack, 1.0, int_stack+462043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1798733,int_stack+1795205,int_stack+1790291, 0.0, zero_stack, 1.0, int_stack+463807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1787204,int_stack+188470,int_stack+187525, 0.0, zero_stack, 1.0, int_stack+383440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1803143,int_stack+1787204,int_stack+1792937, 0.0, zero_stack, 1.0, int_stack+466453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1807679,int_stack+1803143,int_stack+1795205, 0.0, zero_stack, 1.0, int_stack+468721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1790039,int_stack+1807679,int_stack+1798733, 0.0, zero_stack, 1.0, int_stack+472249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1796654,int_stack+189625,int_stack+188470, 0.0, zero_stack, 1.0, int_stack+384385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1813559,int_stack+1796654,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+476659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1819229,int_stack+1813559,int_stack+1803143, 0.0, zero_stack, 1.0, int_stack+479494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1796654,int_stack+1819229,int_stack+1807679, 0.0, zero_stack, 1.0, int_stack+484030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1805474,int_stack+1796654,int_stack+1790039, 0.0, zero_stack, 1.0, int_stack+489910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1787204,int_stack+191599,int_stack+191011, 0.0, zero_stack, 1.0, int_stack+392197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1788968,int_stack+192383,int_stack+191599, 0.0, zero_stack, 1.0, int_stack+392785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1791320,int_stack+1788968,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+496525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1794848,int_stack+193391,int_stack+192383, 0.0, zero_stack, 1.0, int_stack+393569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1797872,int_stack+1794848,int_stack+1788968, 0.0, zero_stack, 1.0, int_stack+498289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1814735,int_stack+1797872,int_stack+1791320, 0.0, zero_stack, 1.0, int_stack+500641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1787204,int_stack+194651,int_stack+193391, 0.0, zero_stack, 1.0, int_stack+394577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1820615,int_stack+1787204,int_stack+1794848, 0.0, zero_stack, 1.0, int_stack+504169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1826663,int_stack+1820615,int_stack+1797872, 0.0, zero_stack, 1.0, int_stack+507193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1790984,int_stack+1826663,int_stack+1814735, 0.0, zero_stack, 1.0, int_stack+524056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1814735,int_stack+196191,int_stack+194651, 0.0, zero_stack, 1.0, int_stack+395837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1834503,int_stack+1814735,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+529936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1842063,int_stack+1834503,int_stack+1820615, 0.0, zero_stack, 1.0, int_stack+533716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1814735,int_stack+1842063,int_stack+1826663, 0.0, zero_stack, 1.0, int_stack+539764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1826495,int_stack+1814735,int_stack+1790984, 0.0, zero_stack, 1.0, int_stack+547604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1838843,int_stack+1826495,int_stack+1805474,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1787204,int_stack+198795,int_stack+198039, 0.0, zero_stack, 1.0, int_stack+406253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1789472,int_stack+199803,int_stack+198795, 0.0, zero_stack, 1.0, int_stack+407009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1792496,int_stack+1789472,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+556424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1797032,int_stack+201099,int_stack+199803, 0.0, zero_stack, 1.0, int_stack+408017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1800920,int_stack+1797032,int_stack+1789472, 0.0, zero_stack, 1.0, int_stack+558692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1806968,int_stack+1800920,int_stack+1792496, 0.0, zero_stack, 1.0, int_stack+561716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1787204,int_stack+202719,int_stack+201099, 0.0, zero_stack, 1.0, int_stack+409313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1814528,int_stack+1787204,int_stack+1797032, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1866626,int_stack+1814528,int_stack+1800920, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1792064,int_stack+1866626,int_stack+1806968, 0.0, zero_stack, 1.0, int_stack+511897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1803404,int_stack+204699,int_stack+202719, 0.0, zero_stack, 1.0, int_stack+410933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+140031,int_stack+1803404,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+608315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+149751,int_stack+140031,int_stack+1814528, 0.0, zero_stack, 1.0, int_stack+613175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1803404,int_stack+149751,int_stack+1866626, 0.0, zero_stack, 1.0, int_stack+620951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1866626,int_stack+1803404,int_stack+1792064, 0.0, zero_stack, 1.0, int_stack+631031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+140031,int_stack+1866626,int_stack+1826495,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1021523,int_stack+140031,int_stack+1838843,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+177075,int_stack+208020,int_stack+207075, 0.0, zero_stack, 1.0, int_stack+424325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+179910,int_stack+209280,int_stack+208020, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+183690,int_stack+179910,int_stack+177075, 0.0, zero_stack, 1.0, int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+189360,int_stack+210900,int_stack+209280, 0.0, zero_stack, 1.0, int_stack+426530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+194220,int_stack+189360,int_stack+179910, 0.0, zero_stack, 1.0, int_stack+12771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1787204,int_stack+194220,int_stack+183690, 0.0, zero_stack, 1.0, int_stack+566252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+177075,int_stack+212925,int_stack+210900, 0.0, zero_stack, 1.0, int_stack+428150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+201780,int_stack+177075,int_stack+189360, 0.0, zero_stack, 1.0, int_stack+571922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1796654,int_stack+201780,int_stack+194220, 0.0, zero_stack, 1.0, int_stack+576782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+183150,int_stack+1796654,int_stack+1787204, 0.0, zero_stack, 1.0, int_stack+584342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1787204,int_stack+215400,int_stack+212925, 0.0, zero_stack, 1.0, int_stack+430175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1809254,int_stack+1787204,int_stack+177075, 0.0, zero_stack, 1.0, int_stack+593792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1821404,int_stack+1809254,int_stack+201780, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+197325,int_stack+1821404,int_stack+1796654, 0.0, zero_stack, 1.0, int_stack+760577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1787204,int_stack+197325,int_stack+183150, 0.0, zero_stack, 1.0, int_stack+773177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1807049,int_stack+1787204,int_stack+1866626,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1077089,int_stack+1807049,int_stack+140031,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1854677,int_stack+1077089,int_stack+1021523,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+219525,int_stack+218370, 0.0, zero_stack, 1.0, int_stack+264805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1024988,int_stack+221065,int_stack+219525, 0.0, zero_stack, 1.0, int_stack+267115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1029608,int_stack+1024988,int_stack+1021523, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1036538,int_stack+223045,int_stack+221065, 0.0, zero_stack, 1.0, int_stack+270195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1042478,int_stack+1036538,int_stack+1024988, 0.0, zero_stack, 1.0, int_stack+645836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1051718,int_stack+1042478,int_stack+1029608, 0.0, zero_stack, 1.0, int_stack+650456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+225520,int_stack+223045, 0.0, zero_stack, 1.0, int_stack+274155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1063268,int_stack+1021523,int_stack+1036538, 0.0, zero_stack, 1.0, int_stack+657386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+140031,int_stack+1063268,int_stack+1042478, 0.0, zero_stack, 1.0, int_stack+663326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1028948,int_stack+140031,int_stack+1051718, 0.0, zero_stack, 1.0, int_stack+672566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1046273,int_stack+228545,int_stack+225520, 0.0, zero_stack, 1.0, int_stack+279105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+155431,int_stack+1046273,int_stack+1021523, 0.0, zero_stack, 1.0, int_stack+684116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+170281,int_stack+155431,int_stack+1063268, 0.0, zero_stack, 1.0, int_stack+691541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1046273,int_stack+170281,int_stack+140031, 0.0, zero_stack, 1.0, int_stack+703421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+140031,int_stack+1046273,int_stack+1028948, 0.0, zero_stack, 1.0, int_stack+718821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+164286,int_stack+140031,int_stack+1787204,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1947287,int_stack+164286,int_stack+1807049,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2042543,int_stack+1947287,int_stack+1077089,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1947287,int_stack+232616,int_stack+232175, 1.0, int_stack+381655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1948610,int_stack+233204,int_stack+232616, 1.0, int_stack+382096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1950374,int_stack+1948610,int_stack+1947287, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1953020,int_stack+233960,int_stack+233204, 1.0, int_stack+382684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1955288,int_stack+1953020,int_stack+1948610, 1.0, int_stack+462043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1958816,int_stack+1955288,int_stack+1950374, 1.0, int_stack+463807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+460720,int_stack+234905,int_stack+233960, 1.0, int_stack+383440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1947287,int_stack+460720,int_stack+1953020, 1.0, int_stack+466453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1963226,int_stack+1947287,int_stack+1955288, 1.0, int_stack+468721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+463555,int_stack+1963226,int_stack+1958816, 1.0, int_stack+472249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+470170,int_stack+236060,int_stack+234905, 1.0, int_stack+384385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1951823,int_stack+470170,int_stack+460720, 1.0, int_stack+476659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1969106,int_stack+1951823,int_stack+1947287, 1.0, int_stack+479494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1947287,int_stack+1969106,int_stack+1963226, 1.0, int_stack+484030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1956107,int_stack+1947287,int_stack+463555, 1.0, int_stack+489910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1947287,int_stack+238034,int_stack+237446, 1.0, int_stack+392197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1949051,int_stack+238818,int_stack+238034, 1.0, int_stack+392785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1951403,int_stack+1949051,int_stack+1947287, 1.0, int_stack+496525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1965368,int_stack+239826,int_stack+238818, 1.0, int_stack+393569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1968392,int_stack+1965368,int_stack+1949051, 1.0, int_stack+498289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1973096,int_stack+1968392,int_stack+1951403, 1.0, int_stack+500641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+496525,int_stack+241086,int_stack+239826, 1.0, int_stack+394577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1947287,int_stack+496525,int_stack+1965368, 1.0, int_stack+504169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1978976,int_stack+1947287,int_stack+1968392, 1.0, int_stack+507193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+500305,int_stack+1978976,int_stack+1973096, 1.0, int_stack+524056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1965368,int_stack+242626,int_stack+241086, 1.0, int_stack+395837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1969988,int_stack+1965368,int_stack+496525, 1.0, int_stack+529936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1986816,int_stack+1969988,int_stack+1947287, 1.0, int_stack+533716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1965368,int_stack+1986816,int_stack+1978976, 1.0, int_stack+539764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1977128,int_stack+1965368,int_stack+500305, 1.0, int_stack+547604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1989476,int_stack+1977128,int_stack+1956107,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1947287,int_stack+245230,int_stack+244474, 1.0, int_stack+406253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1949555,int_stack+246238,int_stack+245230, 1.0, int_stack+407009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1952579,int_stack+1949555,int_stack+1947287, 1.0, int_stack+556424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1957115,int_stack+247534,int_stack+246238, 1.0, int_stack+408017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1961003,int_stack+1957115,int_stack+1949555, 1.0, int_stack+558692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1967051,int_stack+1961003,int_stack+1952579, 1.0, int_stack+561716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+556424,int_stack+249154,int_stack+247534, 1.0, int_stack+409313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1947287,int_stack+556424,int_stack+1957115, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+496525,int_stack+1947287,int_stack+1961003, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1955063,int_stack+496525,int_stack+1967051, 1.0, int_stack+511897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+251134,int_stack+249154, 1.0, int_stack+410933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1966403,int_stack+0,int_stack+556424, 1.0, int_stack+608315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+506605,int_stack+1966403,int_stack+1947287, 1.0, int_stack+613175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2017259,int_stack+506605,int_stack+496525, 1.0, int_stack+620951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+496525,int_stack+2017259,int_stack+1955063, 1.0, int_stack+631031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1787204,int_stack+496525,int_stack+1977128,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+140031,int_stack+1787204,int_stack+1989476,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+512401,int_stack+254455,int_stack+253510, 1.0, int_stack+424325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+515236,int_stack+255715,int_stack+254455, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+519016,int_stack+515236,int_stack+512401, 1.0, int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+524686,int_stack+257335,int_stack+255715, 1.0, int_stack+426530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1947287,int_stack+524686,int_stack+515236, 1.0, int_stack+12771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1954847,int_stack+1947287,int_stack+519016, 1.0, int_stack+566252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+512401,int_stack+259360,int_stack+257335, 1.0, int_stack+428150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1964297,int_stack+512401,int_stack+524686, 1.0, int_stack+571922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1974017,int_stack+1964297,int_stack+1947287, 1.0, int_stack+576782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1986617,int_stack+1974017,int_stack+1954847, 1.0, int_stack+584342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1947287,int_stack+261835,int_stack+259360, 1.0, int_stack+430175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2000792,int_stack+1947287,int_stack+512401, 1.0, int_stack+593792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+512401,int_stack+2000792,int_stack+1964297, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2000792,int_stack+512401,int_stack+1974017, 1.0, int_stack+760577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2019692,int_stack+2000792,int_stack+1986617, 1.0, int_stack+773177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1947287,int_stack+2019692,int_stack+496525,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1021523,int_stack+1947287,int_stack+1787204,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1095611,int_stack+1021523,int_stack+140031,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+140031,int_stack+268655,int_stack+265960, 1.0, int_stack+264805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+143496,int_stack+272175,int_stack+268655, 1.0, int_stack+267115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+148116,int_stack+143496,int_stack+140031, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+155046,int_stack+276630,int_stack+272175, 1.0, int_stack+270195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+160986,int_stack+155046,int_stack+143496, 1.0, int_stack+645836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+170226,int_stack+160986,int_stack+148116, 1.0, int_stack+650456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+642371,int_stack+282130,int_stack+276630, 1.0, int_stack+274155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+140031,int_stack+642371,int_stack+155046, 1.0, int_stack+657386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+181776,int_stack+140031,int_stack+160986, 1.0, int_stack+663326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+649796,int_stack+181776,int_stack+170226, 1.0, int_stack+672566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+667121,int_stack+285155,int_stack+282130, 1.0, int_stack+279105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+151911,int_stack+667121,int_stack+642371, 1.0, int_stack+684116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+667121,int_stack+151911,int_stack+140031, 1.0, int_stack+691541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+140031,int_stack+667121,int_stack+181776, 1.0, int_stack+703421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+667121,int_stack+140031,int_stack+649796, 1.0, int_stack+718821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+140031,int_stack+667121,int_stack+2019692,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+642371,int_stack+140031,int_stack+1947287,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+140031,int_stack+642371,int_stack+1021523,441);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1021523,int_stack+385540,int_stack+384385,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1024988,int_stack+1021523,int_stack+476659,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1030658,int_stack+1024988,int_stack+479494,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1021523,int_stack+1030658,int_stack+484030,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1030343,int_stack+1021523,int_stack+489910,21);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1021523,int_stack+397377,int_stack+395837,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1039604,int_stack+1021523,int_stack+529936,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1047164,int_stack+1039604,int_stack+533716,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1057244,int_stack+1047164,int_stack+539764,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1039604,int_stack+1057244,int_stack+547604,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1051952,int_stack+1039604,int_stack+1030343,441);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1079735,int_stack+412913,int_stack+410933,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1085675,int_stack+1079735,int_stack+608315,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+642371,int_stack+1085675,int_stack+613175,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1079735,int_stack+642371,int_stack+620951,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+642371,int_stack+1079735,int_stack+631031,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+658247,int_stack+642371,int_stack+1039604,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+695291,int_stack+658247,int_stack+1051952,441);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1079735,int_stack+432650,int_stack+430175,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1947287,int_stack+1079735,int_stack+593792,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1959437,int_stack+1947287,int_stack+750857,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1975637,int_stack+1959437,int_stack+760577,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+750857,int_stack+1975637,int_stack+773177,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1947287,int_stack+750857,int_stack+642371,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+460720,int_stack+1947287,int_stack+658247,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+534808,int_stack+460720,int_stack+695291,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+770702,int_stack+289226,int_stack+288785,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+772025,int_stack+289814,int_stack+289226,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+773789,int_stack+772025,int_stack+770702,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+776435,int_stack+290570,int_stack+289814,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+778703,int_stack+776435,int_stack+772025,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+782231,int_stack+778703,int_stack+773789,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+770702,int_stack+291515,int_stack+290570,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1994915,int_stack+770702,int_stack+776435,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1999451,int_stack+1994915,int_stack+778703,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+773537,int_stack+1999451,int_stack+782231,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+780152,int_stack+292670,int_stack+291515,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2005331,int_stack+780152,int_stack+770702,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2011001,int_stack+2005331,int_stack+1994915,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1021523,int_stack+2011001,int_stack+1999451,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1994915,int_stack+1021523,int_stack+773537,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+294644,int_stack+294056,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1023287,int_stack+295428,int_stack+294644,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1025639,int_stack+1023287,int_stack+1021523,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2004176,int_stack+296436,int_stack+295428,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2007200,int_stack+2004176,int_stack+1023287,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2011904,int_stack+2007200,int_stack+1025639,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+297696,int_stack+296436,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2017784,int_stack+1021523,int_stack+2004176,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2023832,int_stack+2017784,int_stack+2007200,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2031672,int_stack+2023832,int_stack+2011904,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2004176,int_stack+299236,int_stack+297696,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2008796,int_stack+2004176,int_stack+1021523,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+770702,int_stack+2008796,int_stack+2017784,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2004176,int_stack+770702,int_stack+2023832,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+770702,int_stack+2004176,int_stack+2031672,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2004176,int_stack+770702,int_stack+1994915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1030343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1994915,int_stack+301840,int_stack+301084,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1997183,int_stack+302848,int_stack+301840,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2031959,int_stack+1997183,int_stack+1994915,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2000207,int_stack+304144,int_stack+302848,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2036495,int_stack+2000207,int_stack+1997183,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1021523,int_stack+2036495,int_stack+2031959,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1994915,int_stack+305764,int_stack+304144,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1079735,int_stack+1994915,int_stack+2000207,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+263511,int_stack+1079735,int_stack+2036495,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+273591,int_stack+263511,int_stack+1021523,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1021523,int_stack+307744,int_stack+305764,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2031959,int_stack+1021523,int_stack+1994915,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+284931,int_stack+2031959,int_stack+1079735,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1079735,int_stack+284931,int_stack+263511,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+284931,int_stack+1079735,int_stack+273591,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1787204,int_stack+284931,int_stack+770702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2166023,int_stack+1787204,int_stack+2004176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1051952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+770702,int_stack+311065,int_stack+310120,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+773537,int_stack+312325,int_stack+311065,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+777317,int_stack+773537,int_stack+770702,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1079735,int_stack+313945,int_stack+312325,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1084595,int_stack+1079735,int_stack+773537,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+263511,int_stack+1084595,int_stack+777317,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+770702,int_stack+315970,int_stack+313945,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+776777,int_stack+770702,int_stack+1079735,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+300807,int_stack+776777,int_stack+1084595,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1079735,int_stack+300807,int_stack+263511,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+263511,int_stack+318445,int_stack+315970,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+270936,int_stack+263511,int_stack+770702,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1994915,int_stack+270936,int_stack+776777,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+263511,int_stack+1994915,int_stack+300807,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+300807,int_stack+263511,int_stack+1079735,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1994915,int_stack+300807,int_stack+284931, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2221589,int_stack+1994915,int_stack+1787204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2295677,int_stack+2221589,int_stack+2166023, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2166023,int_stack+322570,int_stack+321415,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2169488,int_stack+324110,int_stack+322570,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2174108,int_stack+2169488,int_stack+2166023,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2181038,int_stack+326090,int_stack+324110,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2186978,int_stack+2181038,int_stack+2169488,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2196218,int_stack+2186978,int_stack+2174108,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2166023,int_stack+328565,int_stack+326090,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2207768,int_stack+2166023,int_stack+2181038,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1787204,int_stack+2207768,int_stack+2186978,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2173448,int_stack+1787204,int_stack+2196218,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2190773,int_stack+331590,int_stack+328565,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1802604,int_stack+2190773,int_stack+2166023,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1817454,int_stack+1802604,int_stack+2207768,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2190773,int_stack+1817454,int_stack+1787204,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1787204,int_stack+2190773,int_stack+2173448,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2388287,int_stack+1787204,int_stack+300807, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+2447822,int_stack+2388287,int_stack+1994915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1947287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2543078,int_stack+2447822,int_stack+2221589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1994915,int_stack+335661,int_stack+335220,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1996238,int_stack+336249,int_stack+335661,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1998002,int_stack+1996238,int_stack+1994915,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2000648,int_stack+337005,int_stack+336249,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2002916,int_stack+2000648,int_stack+1996238,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2006444,int_stack+2002916,int_stack+1998002,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1994915,int_stack+337950,int_stack+337005,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2010854,int_stack+1994915,int_stack+2000648,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2015390,int_stack+2010854,int_stack+2002916,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1997750,int_stack+2015390,int_stack+2006444,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2004365,int_stack+339105,int_stack+337950,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2021270,int_stack+2004365,int_stack+1994915,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2026940,int_stack+2021270,int_stack+2010854,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1021523,int_stack+2026940,int_stack+2015390,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2004365,int_stack+1021523,int_stack+1997750,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+341079,int_stack+340491,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1023287,int_stack+341863,int_stack+341079,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1025639,int_stack+1023287,int_stack+1021523,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1994915,int_stack+342871,int_stack+341863,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1997939,int_stack+1994915,int_stack+1023287,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2013626,int_stack+1997939,int_stack+1025639,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+344131,int_stack+342871,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2019506,int_stack+1021523,int_stack+1994915,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2025554,int_stack+2019506,int_stack+1997939,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1994915,int_stack+2025554,int_stack+2013626,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2013626,int_stack+345671,int_stack+344131,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2033394,int_stack+2013626,int_stack+1021523,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2388287,int_stack+2033394,int_stack+2019506,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2013626,int_stack+2388287,int_stack+2025554,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2388287,int_stack+2013626,int_stack+1994915,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2013626,int_stack+2388287,int_stack+2004365, 0.0, zero_stack, 1.0, int_stack+1030343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1994915,int_stack+348275,int_stack+347519,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1997183,int_stack+349283,int_stack+348275,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2000207,int_stack+1997183,int_stack+1994915,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2004743,int_stack+350579,int_stack+349283,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2400635,int_stack+2004743,int_stack+1997183,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2406683,int_stack+2400635,int_stack+2000207,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1994915,int_stack+352199,int_stack+350579,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2414243,int_stack+1994915,int_stack+2004743,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1999775,int_stack+2414243,int_stack+2400635,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2422019,int_stack+1999775,int_stack+2406683,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2400635,int_stack+354179,int_stack+352199,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2433359,int_stack+2400635,int_stack+1994915,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2400635,int_stack+2433359,int_stack+2414243,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2433359,int_stack+2400635,int_stack+1999775,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1079735,int_stack+2433359,int_stack+2422019,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2400635,int_stack+1079735,int_stack+2388287, 0.0, zero_stack, 1.0, int_stack+1039604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2437679,int_stack+2400635,int_stack+2013626, 0.0, zero_stack, 1.0, int_stack+1051952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2388287,int_stack+357500,int_stack+356555,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2391122,int_stack+358760,int_stack+357500,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2394902,int_stack+2391122,int_stack+2388287,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2493245,int_stack+360380,int_stack+358760,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2498105,int_stack+2493245,int_stack+2391122,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2505665,int_stack+2498105,int_stack+2394902,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2388287,int_stack+362405,int_stack+360380,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2515115,int_stack+2388287,int_stack+2493245,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2524835,int_stack+2515115,int_stack+2498105,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1994915,int_stack+2524835,int_stack+2505665,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2493245,int_stack+364880,int_stack+362405,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2500670,int_stack+2493245,int_stack+2388287,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2009090,int_stack+2500670,int_stack+2515115,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2493245,int_stack+2009090,int_stack+2524835,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2009090,int_stack+2493245,int_stack+1994915,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2493245,int_stack+2009090,int_stack+1079735, 0.0, zero_stack, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2166023,int_stack+2493245,int_stack+2400635, 0.0, zero_stack, 1.0, int_stack+658247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+263511,int_stack+2166023,int_stack+2437679, 0.0, zero_stack, 1.0, int_stack+695291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1079735,int_stack+369005,int_stack+367850,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1083200,int_stack+370545,int_stack+369005,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1087820,int_stack+1083200,int_stack+1079735,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1994915,int_stack+372525,int_stack+370545,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2028935,int_stack+1994915,int_stack+1083200,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2388287,int_stack+2028935,int_stack+1087820,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1079735,int_stack+375000,int_stack+372525,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2399837,int_stack+1079735,int_stack+1994915,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2411717,int_stack+2399837,int_stack+2028935,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2427117,int_stack+2411717,int_stack+2388287,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2388287,int_stack+378025,int_stack+375000,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2444442,int_stack+2388287,int_stack+1079735,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2459292,int_stack+2444442,int_stack+2399837,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2388287,int_stack+2459292,int_stack+2411717,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2444442,int_stack+2388287,int_stack+2427117,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1787204,int_stack+2444442,int_stack+2009090, 0.0, zero_stack, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+2388287,int_stack+1787204,int_stack+2493245, 0.0, zero_stack, 1.0, int_stack+1947287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2666558,int_stack+2388287,int_stack+2166023, 0.0, zero_stack, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2166023,int_stack+387367,int_stack+386926,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2167346,int_stack+387955,int_stack+387367,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2169110,int_stack+2167346,int_stack+2166023,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2171756,int_stack+388711,int_stack+387955,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2174024,int_stack+2171756,int_stack+2167346,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2177552,int_stack+2174024,int_stack+2169110,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2166023,int_stack+389656,int_stack+388711,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2181962,int_stack+2166023,int_stack+2171756,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2186498,int_stack+2181962,int_stack+2174024,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2168858,int_stack+2186498,int_stack+2177552,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2175473,int_stack+390811,int_stack+389656,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2192378,int_stack+2175473,int_stack+2166023,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2198048,int_stack+2192378,int_stack+2181962,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1021523,int_stack+2198048,int_stack+2186498,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2175473,int_stack+1021523,int_stack+2168858,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1021523,int_stack+399813,int_stack+399225,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1023287,int_stack+400597,int_stack+399813,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1025639,int_stack+1023287,int_stack+1021523,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2166023,int_stack+401605,int_stack+400597,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2169047,int_stack+2166023,int_stack+1023287,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2184734,int_stack+2169047,int_stack+1025639,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1021523,int_stack+402865,int_stack+401605,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2190614,int_stack+1021523,int_stack+2166023,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2196662,int_stack+2190614,int_stack+2169047,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2166023,int_stack+2196662,int_stack+2184734,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2184734,int_stack+404405,int_stack+402865,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2204502,int_stack+2184734,int_stack+1021523,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2212062,int_stack+2204502,int_stack+2190614,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2184734,int_stack+2212062,int_stack+2196662,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2196494,int_stack+2184734,int_stack+2166023,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2208842,int_stack+2196494,int_stack+2175473, 1.0, int_stack+1030343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2166023,int_stack+416045,int_stack+415289,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2168291,int_stack+417053,int_stack+416045,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2171315,int_stack+2168291,int_stack+2166023,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2175851,int_stack+418349,int_stack+417053,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2179739,int_stack+2175851,int_stack+2168291,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2185787,int_stack+2179739,int_stack+2171315,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2166023,int_stack+419969,int_stack+418349,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1021523,int_stack+2166023,int_stack+2175851,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1029299,int_stack+1021523,int_stack+2179739,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2170883,int_stack+1029299,int_stack+2185787,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2182223,int_stack+421949,int_stack+419969,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2236625,int_stack+2182223,int_stack+2166023,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2182223,int_stack+2236625,int_stack+1021523,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2236625,int_stack+2182223,int_stack+1029299,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1079735,int_stack+2236625,int_stack+2170883,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2236625,int_stack+1079735,int_stack+2196494, 1.0, int_stack+1039604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2388287,int_stack+2236625,int_stack+2208842, 1.0, int_stack+1051952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2273669,int_stack+436565,int_stack+435620,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2276504,int_stack+437825,int_stack+436565,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2280284,int_stack+2276504,int_stack+2273669,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2285954,int_stack+439445,int_stack+437825,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1021523,int_stack+2285954,int_stack+2276504,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1029083,int_stack+1021523,int_stack+2280284,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2273669,int_stack+441470,int_stack+439445,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1038533,int_stack+2273669,int_stack+2285954,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2279744,int_stack+1038533,int_stack+1021523,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1048253,int_stack+2279744,int_stack+1029083,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1021523,int_stack+443945,int_stack+441470,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1062428,int_stack+1021523,int_stack+2273669,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1021523,int_stack+1062428,int_stack+1038533,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2166023,int_stack+1021523,int_stack+2279744,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1021523,int_stack+2166023,int_stack+1048253,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1994915,int_stack+1021523,int_stack+1079735, 1.0, int_stack+642371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2443853,int_stack+1994915,int_stack+2236625, 1.0, int_stack+658247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2166023,int_stack+2443853,int_stack+2388287, 1.0, int_stack+695291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2388287,int_stack+448070,int_stack+446915,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2391752,int_stack+449610,int_stack+448070,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2396372,int_stack+2391752,int_stack+2388287,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2403302,int_stack+451590,int_stack+449610,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2409242,int_stack+2403302,int_stack+2391752,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2418482,int_stack+2409242,int_stack+2396372,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2388287,int_stack+454065,int_stack+451590,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2430032,int_stack+2388287,int_stack+2403302,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2258633,int_stack+2430032,int_stack+2409242,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2395712,int_stack+2258633,int_stack+2418482,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2413037,int_stack+457090,int_stack+454065,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2274033,int_stack+2413037,int_stack+2388287,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1041368,int_stack+2274033,int_stack+2430032,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2413037,int_stack+1041368,int_stack+2258633,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2258633,int_stack+2413037,int_stack+2395712,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1787204,int_stack+2258633,int_stack+1021523, 1.0, int_stack+750857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+356121,int_stack+1787204,int_stack+1994915, 1.0, int_stack+1947287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+627418,int_stack+356121,int_stack+2443853, 1.0, int_stack+460720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+356121,int_stack+1223669,int_stack+928913,441);
     Libderiv->ABCD[11] = int_stack + 356121;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+2388287,int_stack+787352,int_stack+1347149,441);
     Libderiv->ABCD[10] = int_stack + 2388287;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+750898,int_stack+1571114,int_stack+1478504,441);
     Libderiv->ABCD[9] = int_stack + 750898;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+889813,int_stack+16551,int_stack+1694594,441);
     Libderiv->ABCD[8] = int_stack + 889813;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+0,int_stack+2042543,int_stack+1854677,441);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1188221,int_stack+140031,int_stack+1095611,441);
     Libderiv->ABCD[6] = int_stack + 1188221;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+1028728,int_stack+2543078,int_stack+2295677, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 1028728;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+2527202,int_stack+2666558,int_stack+263511, 0.0, zero_stack, 1.0, int_stack+534808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 2527202;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+138915,int_stack+627418,int_stack+2166023, 1.0, int_stack+534808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 138915;

}
